@@ -36,8 +36,6 @@
 #include "MvQTreeView.h"
 #include "MvQMethods.h"
 
-using namespace std;
-
 
 QSize ProcViewDelegate::sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
 {
@@ -66,12 +64,12 @@ ProcMonitor::ProcMonitor(svc* service, QWidget* parent) :
     // The main layout (the upper part of mainSplitter)
     //---------------------------------------------------
 
-    QVBoxLayout* mainLayout = new QVBoxLayout;
+    auto* mainLayout = new QVBoxLayout;
     mainLayout->setObjectName(QString::fromUtf8("vboxLayout"));
     mainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->setSpacing(0);
 
-    QWidget* w = new QWidget(this);
+    auto* w = new QWidget(this);
     w->setLayout(mainLayout);
     setCentralWidget(w);
 
@@ -119,7 +117,7 @@ ProcMonitor::ProcMonitor(svc* service, QWidget* parent) :
     procTree_->setRootIsDecorated(false);
     //procTree_->setIconSize(QSize(40,40));
 
-    ProcViewDelegate* delegate = new ProcViewDelegate;
+    auto* delegate = new ProcViewDelegate;
     procTree_->setItemDelegate(delegate);
 
     if (!MvProcNode::hasProcFs()) {
@@ -174,7 +172,7 @@ ProcMonitor::ProcMonitor(svc* service, QWidget* parent) :
     procReq_->document()->setDefaultStyleSheet(cssDoc);
     infoTab_->addTab(procReq_, tr("Request"));
 
-    QToolButton* tbCloseInfo = new QToolButton(this);
+    auto* tbCloseInfo = new QToolButton(this);
     tbCloseInfo->setIcon(QPixmap(":/debug/close_grey.svg"));
     tbCloseInfo->setAutoRaise(true);
     tbCloseInfo->setToolTip(tr("Hide information panel"));
@@ -243,25 +241,25 @@ void ProcMonitor::input(svcid* id, request* r)
     QString name(get_value(id->r, "NAME", 0));
     QString mode(get_value(id->r, "MODE", 0));
 
-    //cout << ref << " " << name << " " << mode << endl;
+    //std::cout << ref << " " << name << " " << mode << std::endl;
 
-    cout << "id->r ------------------------>" << endl;
+    std::cout << "id->r ------------------------>" << std::endl;
 
     print_all_requests(id->r);
 
-    cout << "r ----------------------->" << endl;
+    std::cout << "r ----------------------->" << std::endl;
 
     print_all_requests(r);
-    //cout << r << " " << id->r << endl;
+    //std::cout << r << " " << id->r << std::endl;
 
     if (mode == "REPLY") {
         //long reqid = atol(get_value(r, "REQ_ID", 0));
         //qDebug() << "reply" << name << reqid;
     }
     else if (mode == "WAIT") {
-//        long reqid     = atol(get_value(r, "REQ_ID", 0));
-//        long from      = atol(get_value(r, "SOURCE_REF", 0));
-//        const char* to = get_value(r, "TARGET", 0);
+        //        long reqid     = atol(get_value(r, "REQ_ID", 0));
+        //        long from      = atol(get_value(r, "SOURCE_REF", 0));
+        //        const char* to = get_value(r, "TARGET", 0);
         //qDebug() << "wait" << name << reqid << from << to;
     }
     else if (mode == "REGISTER") {
@@ -280,10 +278,10 @@ void ProcMonitor::input(svcid* id, request* r)
     else if (mode == "SERVICE") {
         long reqid = atol(get_value(r, "REQ_ID", 0));
         MvProcNode::addProcRequest(reqid, ref, name.toStdString(), r);
-//        long reqId = atol(get_value(r, "REQ_ID", 0));
-//        long from  = atol(get_value(r, "SOURCE_REF", 0));
-//        const char* x = get_value(r, "WAITMODE", 0);
-          //int sync      = x ? atoi(x) : 0;
+        //        long reqId = atol(get_value(r, "REQ_ID", 0));
+        //        long from  = atol(get_value(r, "SOURCE_REF", 0));
+        //        const char* x = get_value(r, "WAITMODE", 0);
+        //int sync      = x ? atoi(x) : 0;
         //qDebug() << "service" << name << ref << reqid << from << sync;
 
         if (r->next)
@@ -309,8 +307,8 @@ void ProcMonitor::input(svcid* id, request* r)
         // qDebug() << "followup" << name << reqid;
     }
 
-    cout << "<-----------------------" << endl;
-    cout << endl;
+    std::cout << "<-----------------------" << std::endl;
+    std::cout << std::endl;
 }
 
 void ProcMonitor::adjustView()
@@ -330,7 +328,7 @@ void ProcMonitor::adjustView()
 
 void ProcMonitor::startService()
 {
-    QTimer* timer = new QTimer(this);
+    auto* timer = new QTimer(this);
     timer->setInterval(3000);
     timer->start();
 
@@ -349,17 +347,17 @@ void ProcMonitor::slotContextMenu(const QPoint& position)
     if (proc) {
         QList<QAction*> lst;
 
-        QAction* infoAction = new QAction(tr("Information"), this);
+        auto* infoAction = new QAction(tr("Information"), this);
         lst << infoAction;
 
-        QAction* reqAction = new QAction(tr("Request"), this);
+        auto* reqAction = new QAction(tr("Request"), this);
         lst << reqAction;
         MvProcRequest* r = proc->procRequest();
         if (!r) {
             reqAction->setEnabled(false);
         }
 
-        QAction* abortAction = new QAction(tr("Abort"), this);
+        auto* abortAction = new QAction(tr("Abort"), this);
         abortAction->setShortcut(tr("Del"));
         abortAction->setIcon(QPixmap(":/debug/remove.svg"));
 
@@ -441,7 +439,7 @@ void ProcMonitor::showRequest(MvProcNode* proc)
 }
 
 
-void ProcMonitor::addInfoRow(QString label, const string& val, QString& info)
+void ProcMonitor::addInfoRow(QString label, const std::string& val, QString& info)
 {
     info += "<tr><td class=\"first\">" + label + "</td><td>" + QString::fromStdString(val) + "</td></tr>";
 }
