@@ -126,13 +126,13 @@ MvQColourGradWidget::MvQColourGradWidget(QWidget* parent) :
     deleteCellAc_->setIcon(QPixmap(":/desktop/deleteCell.svg"));
     deleteCellAc_->setToolTip(tr("Remove cell"));
 
-    QAction* sep1 = new QAction(this);
+    auto* sep1 = new QAction(this);
     sep1->setSeparator(true);
     addAction(sep1);
 
     addAction(deleteCellAc_);
 
-    QAction* sep2 = new QAction(this);
+    auto* sep2 = new QAction(this);
     sep2->setSeparator(true);
     addAction(sep2);
 
@@ -172,7 +172,7 @@ MvQColourGradWidget::MvQColourGradWidget(QWidget* parent) :
     connect(reverseAllAc_, SIGNAL(triggered()),
             this, SLOT(slotReverseAll()));
 
-    QAction* sep3 = new QAction(this);
+    auto* sep3 = new QAction(this);
     sep3->setSeparator(true);
     addAction(sep3);
 
@@ -194,7 +194,7 @@ MvQColourGradWidget::MvQColourGradWidget(QWidget* parent) :
     connect(pasteColAc_, SIGNAL(triggered()),
             this, SLOT(slotPasteColour()));
 
-    QAction* sep4 = new QAction(this);
+    auto* sep4 = new QAction(this);
     sep4->setSeparator(true);
     addAction(sep4);
 
@@ -262,8 +262,8 @@ QList<QColor> MvQColourGradWidget::colours() const
 }
 
 void MvQColourGradWidget::reset(QList<QColor> cols,
-                                const string& wayMethod, const vector<string>& techs,
-                                const string& direction, const vector<string>& steps)
+                                const std::string& wayMethod, const std::vector<std::string>& techs,
+                                const std::string& direction, const std::vector<std::string>& steps)
 {
     cells_.clear();
     foreach (QColor c, cols) {
@@ -1164,7 +1164,7 @@ void MvQColourGradWidget::setEdited(bool edited)
     }
 }
 
-bool MvQColourGradWidget::setWayMethod(const string& val, bool redraw)
+bool MvQColourGradWidget::setWayMethod(const std::string& val, bool redraw)
 {
     bool changed  = false;
     QString qsVal = QString::fromStdString(val).toLower();
@@ -1181,7 +1181,7 @@ bool MvQColourGradWidget::setWayMethod(const string& val, bool redraw)
     return changed;
 }
 
-bool MvQColourGradWidget::setDirection(const string& val, bool redraw)
+bool MvQColourGradWidget::setDirection(const std::string& val, bool redraw)
 {
     bool changed  = false;
     QString qsVal = QString::fromStdString(val).toLower();
@@ -1198,7 +1198,7 @@ bool MvQColourGradWidget::setDirection(const string& val, bool redraw)
     return changed;
 }
 
-bool MvQColourGradWidget::setTechs(const vector<string>& vals, bool redraw)
+bool MvQColourGradWidget::setTechs(const std::vector<std::string>& vals, bool redraw)
 {
     bool changed = false;
     int valsNum  = static_cast<int>(vals.size());
@@ -1247,7 +1247,7 @@ bool MvQColourGradWidget::setTechs(const vector<string>& vals, bool redraw)
     return changed;
 }
 
-bool MvQColourGradWidget::setSteps(const vector<string>& vals, bool redraw)
+bool MvQColourGradWidget::setSteps(const std::vector<std::string>& vals, bool redraw)
 {
     bool changed = false;
     int valsNum  = static_cast<int>(vals.size());
@@ -1359,30 +1359,30 @@ void MvQColourGradLine::slotHelperOpened(bool b)
     updateHelper();
 }
 
-void MvQColourGradLine::refresh(const vector<string>& values)
+void MvQColourGradLine::refresh(const std::vector<std::string>& values)
 {
     if (values.size() > 0) {
         QList<QColor> colours;
 
-        for (int i = 0; i < static_cast<int>(values.size()); i++) {
-            QString name = QString::fromStdString(values[i]);
-            colours << MvQPalette::magics(values[i]);
+        for (const auto& value : values) {
+            QString name = QString::fromStdString(value);
+            colours << MvQPalette::magics(value);
         }
 
-        Request r           = owner_.request();
-        vector<string> ways = r.get(waypointParam_.c_str());
-        string wayMethod;
+        Request r                     = owner_.request();
+        std::vector<std::string> ways = r.get(waypointParam_.c_str());
+        std::string wayMethod;
         if (ways.size() > 0)
             wayMethod = ways[0];
 
-        vector<string> steps = r.get(stepParam_.c_str());
+        std::vector<std::string> steps = r.get(stepParam_.c_str());
 
-        vector<string> dirs = r.get(directionParam_.c_str());
-        string direction;
+        std::vector<std::string> dirs = r.get(directionParam_.c_str());
+        std::string direction;
         if (dirs.size() > 0)
             direction = dirs[0];
 
-        vector<string> tech = r.get(techParam_.c_str());
+        std::vector<std::string> tech = r.get(techParam_.c_str());
 
         widget_->reset(colours, wayMethod, tech, direction, steps);
     }
@@ -1390,14 +1390,14 @@ void MvQColourGradLine::refresh(const vector<string>& values)
     //changed_ = false;
 }
 
-void MvQColourGradLine::changed(const char* param, const vector<string>& vals)
+void MvQColourGradLine::changed(const char* param, const std::vector<std::string>& vals)
 {
     if (param && strcmp(param, stepParam_.c_str()) == 0) {
         widget_->setSteps(vals, true);
     }
 }
 
-void MvQColourGradLine::changed(const char* param, const string& val)
+void MvQColourGradLine::changed(const char* param, const std::string& val)
 {
     if (param && strcmp(param, waypointParam_.c_str()) == 0) {
         widget_->setWayMethod(val, true);
@@ -1408,14 +1408,14 @@ void MvQColourGradLine::changed(const char* param, const string& val)
     else if (param && strcmp(param, techParam_.c_str()) == 0) {
         //Set directions. In "rgb" mode there is no direction so
         //we need to define it when we switch from "rgb" into "hsl" or "hcl".
-        Request r           = owner_.request();
-        vector<string> dirs = r.get(directionParam_.c_str());
-        string direction;
+        Request r                     = owner_.request();
+        std::vector<std::string> dirs = r.get(directionParam_.c_str());
+        std::string direction;
         if (dirs.size() > 0)
             direction = dirs[0];
         widget_->setDirection(direction, false);
 
-        vector<string> vals;
+        std::vector<std::string> vals;
         vals.push_back(val);
         widget_->setTechs(vals, true);
     }
@@ -1423,7 +1423,7 @@ void MvQColourGradLine::changed(const char* param, const string& val)
 
 void MvQColourGradLine::slotListChanged()
 {
-    vector<string> vals;
+    std::vector<std::string> vals;
     foreach (QColor col, widget_->colours()) {
         vals.push_back(MvQPalette::toString(col));
     }
@@ -1444,7 +1444,7 @@ void MvQColourGradLine::updateHelper()
     if (!helper_)
         return;
 
-    vector<string> vals;
+    std::vector<std::string> vals;
     vals.push_back(MvQPalette::toString(widget_->currentColour()));
     helper_->refresh(vals);
 }
@@ -1454,7 +1454,7 @@ void MvQColourGradLine::slotCurrentChanged(QColor)
     updateHelper();
 }
 
-void MvQColourGradLine::slotHelperEdited(const vector<string>& vals)
+void MvQColourGradLine::slotHelperEdited(const std::vector<std::string>& vals)
 {
     if (vals.size() == 0)
         return;
