@@ -32,18 +32,17 @@
 #include "Protocol.h"
 #include "MvRequest.h"
 #include "MvTemplates.h"
+#include "WsType.h"
 
 static void drop_request(svcid* id, request* r, void* data);
 static void reply_request(svcid* id, request* r, void* data);
 
-MvQDesktop::MvQDesktop(int& argc, char** argv, string appName) :
+MvQDesktop::MvQDesktop(int& argc, char** argv, std::string appName) :
     MvQApplication(argc, argv, appName.c_str(), {"desktop", "examiner", "window", "find"})
 {
 }
 
-MvQDesktop::~MvQDesktop()
-{
-}
+MvQDesktop::~MvQDesktop() = default;
 
 void MvQDesktop::init()
 {
@@ -51,28 +50,7 @@ void MvQDesktop::init()
     // Load resources
     //---------------------------
 
-    QIcon icon;
-
-    int order = 0;
-    bool more = true;
-
-    //marsinit(&argc,argv,0,0,0);
-
-    while (more || order <= 2) {
-        more       = false;
-        request* r = mars.setup;
-        while (r) {
-            //MvRequest mvr(r);
-            //mvr.print();
-            //if(strcmp(r->name,"state") == 0)
-            //	qDebug() << "state";
-            if (ConfigLoader::process(r, order))
-                more = true;
-            r = r->next;
-        }
-        order++;
-    }
-
+    ConfigLoader::init();
 
     //-----------------------------
     // Protocol
@@ -113,13 +91,19 @@ void MvQDesktop::init()
 
     MvQEditorListMenu::initDockMenu();
 
+    //-------------------------------------
+    // Weather Symbol types
+    //-------------------------------------
+
+    WsType::init(WsType::DesktopMode);
+
     //------------------------------------------------
     //Add drop callback to handle drops to uPlot
     //------------------------------------------------
 
-    add_drop_callback(MvApplication::getService(), NULL, drop_request, NULL);
+    add_drop_callback(MvApplication::getService(), nullptr, drop_request, nullptr);
 
-    add_reply_callback(MvApplication::getService(), NULL, reply_request, NULL);
+    add_reply_callback(MvApplication::getService(), nullptr, reply_request, nullptr);
 }
 
 
@@ -135,7 +119,7 @@ static void drop_request(svcid* id, request* r, void* /*data*/)
     if (!serviceCh)
         return;
 
-    string serviceName(serviceCh);
+    std::string serviceName(serviceCh);
     req("_SERVICE") = serviceCh;
 
     //Context
@@ -155,7 +139,7 @@ static void drop_request(svcid* id, request* r, void* /*data*/)
 
         //Find the iconobject
         if (iconChName) {
-            string iconName(iconChName);
+            std::string iconName(iconChName);
             IconObject* obj = IconObject::search(iconName);
             if (obj)
                 icons.insert(obj);
@@ -171,9 +155,9 @@ static void drop_request(svcid* id, request* r, void* /*data*/)
     }
 }
 
-static void reply_request(svcid* id, request* r, void* data)
+static void reply_request(svcid*, request* r, void* /*data*/)
 {
-    //cout << "reply" << endl;
+    //cout << "reply" << std::endl;
     //print_all_requests(r);
 
     if (r) {
@@ -195,7 +179,7 @@ static void reply_request(svcid* id, request* r, void* data)
 
                 //Find the iconobject and notify an error
                 if (iconChName) {
-                    string iconName(iconChName);
+                    std::string iconName(iconChName);
                     IconObject* obj = IconObject::search(iconName);
                     if (obj)
                         obj->notifyError();
