@@ -229,7 +229,7 @@ void MvQDetailedFolderView::setupShortCut()
 
 void MvQDetailedFolderView::slotIconShortCut()
 {
-    QShortcut* sc = static_cast<QShortcut*>(QObject::sender());
+    auto* sc = static_cast<QShortcut*>(QObject::sender());
     if (sc) {
         QModelIndexList lst = selectedList();
         if (lst.count() > 0)
@@ -248,7 +248,7 @@ void MvQDetailedFolderView::slotDefaultShortCut()
 
 void MvQDetailedFolderView::slotDesktopShortCut()
 {
-    QShortcut* sc = static_cast<QShortcut*>(QObject::sender());
+    auto* sc = static_cast<QShortcut*>(QObject::sender());
     if (sc) {
         //QPoint scrollOffset(horizontalScrollBar()->value(),verticalScrollBar()->value());
         //handleContextMenu(index,lst,mapToGlobal(position),position+scrollOffset,this);
@@ -433,7 +433,7 @@ void MvQDetailedFolderView::checkDropTarget(QDropEvent* event)
 {
     IconObject* dragObj = 0;
     if (event->mimeData()->hasFormat("metview/icon")) {
-        const MvQIconMimeData* mimeData = qobject_cast<const MvQIconMimeData*>(event->mimeData());
+        const auto* mimeData = qobject_cast<const MvQIconMimeData*>(event->mimeData());
 
         if (mimeData)
             dragObj = mimeData->dragObject();
@@ -527,7 +527,7 @@ void MvQDetailedFolderView::dropEvent(QDropEvent* event)
     //--------------------------------------
 
     if (event->mimeData()->hasFormat("metview/icon")) {
-        const MvQIconMimeData* mimeData = qobject_cast<const MvQIconMimeData*>(event->mimeData());
+        const auto* mimeData = qobject_cast<const MvQIconMimeData*>(event->mimeData());
 
         if (!mimeData) {
             event->ignore();
@@ -538,11 +538,12 @@ void MvQDetailedFolderView::dropEvent(QDropEvent* event)
         MvQFolderModel* model = mimeData->model();
 
         if (dragObj && (model || mimeData->fromEditor())) {
-            bool fromSameView = false;
+            bool fromSameView     = false;
             MvQFolderModel* model = mimeData->model();
             if (model) {
                 fromSameView = (model == folderModel_ || model->folder() == folderModel_->folder());
-            } else if(mimeData->fromEditor()) {
+            }
+            else if (mimeData->fromEditor()) {
                 fromSameView = (folderModel_->folder() == dragObj->parent());
             }
 
@@ -564,7 +565,7 @@ void MvQDetailedFolderView::dropEvent(QDropEvent* event)
     //--------------------------------------
 
     else if (event->mimeData()->hasFormat("metview/new_icon")) {
-        const MvQNewIconMimeData* mimeData = qobject_cast<const MvQNewIconMimeData*>(event->mimeData());
+        const auto* mimeData = qobject_cast<const MvQNewIconMimeData*>(event->mimeData());
 
         if (!mimeData) {
             event->ignore();
@@ -666,7 +667,7 @@ void MvQDetailedFolderView::slotHeaderContextMenu(const QPoint& position)
         return;
 
     QList<QAction*> lst;
-    QMenu* menu = new QMenu(this);
+    auto* menu = new QMenu(this);
     QAction* ac;
 
     for (int i = 0; i < header()->count(); i++) {
