@@ -142,7 +142,7 @@ void MvQFolderViewBase::handleContextMenu(const QModelIndex& indexClicked, QMode
     //Icon actions
     if (indexClicked.isValid() && indexClicked.column() == 0)  //indexLst[0].isValid() && indexLst[0].column() == 0)
     {
-        vector<IconObject*> objLst;
+        std::vector<IconObject*> objLst;
         for (int i = 0; i < indexLst.count(); i++) {
             IconObject* obj = folderModel_->objectFromIndex(filterModel_->mapToSource(indexLst[i]));
             if (obj)
@@ -188,7 +188,7 @@ void MvQFolderViewBase::handleIconShortCut(QShortcut* sc, QModelIndexList indexL
     if (!sc)
         return;
 
-    vector<IconObject*> objLst;
+    std::vector<IconObject*> objLst;
     for (int i = 0; i < indexLst.count(); i++) {
         IconObject* obj = folderModel_->objectFromIndex(filterModel_->mapToSource(indexLst[i]));
         if (obj)
@@ -215,7 +215,7 @@ void MvQFolderViewBase::handleDesktopShortCut(QShortcut* sc, QPoint pos, QWidget
 
 void MvQFolderViewBase::handleIconCommand(QModelIndexList indexLst, QString name)
 {
-    vector<IconObject*> objLst;
+    std::vector<IconObject*> objLst;
     for (int i = 0; i < indexLst.count(); i++) {
         IconObject* obj = folderModel_->objectFromIndex(filterModel_->mapToSource(indexLst[i]));
         if (obj)
@@ -227,22 +227,22 @@ void MvQFolderViewBase::handleIconCommand(QModelIndexList indexLst, QString name
     }
 }
 
-void MvQFolderViewBase::handleIconCommand(const vector<IconObject*>& objLstIn, QString name)
+void MvQFolderViewBase::handleIconCommand(const std::vector<IconObject*>& objLstIn, QString name)
 {
     if (objLstIn.empty())
         return;
 
     //Selects the iconobjects for that the command is valid
-    vector<IconObject*> objLst;
-    for (vector<IconObject*>::const_iterator it = objLstIn.begin(); it != objLstIn.end(); it++) {
-        if (*it) {
-            std::set<string> cmdSet = (*it)->can();
-            QString canCmd          = name;
+    std::vector<IconObject*> objLst;
+    for (auto it : objLstIn) {
+        if (it) {
+            std::set<std::string> cmdSet = it->can();
+            QString canCmd               = name;
             if (name.startsWith("compress_"))
                 canCmd = "compress";
 
             if (cmdSet.find(canCmd.toStdString()) != cmdSet.end()) {
-                objLst.push_back(*it);
+                objLst.push_back(it);
             }
         }
     }
@@ -261,15 +261,15 @@ void MvQFolderViewBase::handleIconCommand(const vector<IconObject*>& objLstIn, Q
     }
     else if (name == "destroy") {
         if (confirmDelete(objLst.size())) {
-            for (vector<IconObject*>::const_iterator it = objLst.begin(); it != objLst.end(); it++)
-                (*it)->command(name.toStdString());
+            for (auto it : objLst)
+                it->command(name.toStdString());
         }
     }
     else if (name == "copy") {
         if (objLst.size() > 0) {
             QList<IconObject*> lst;
-            for (vector<IconObject*>::const_iterator it = objLst.begin(); it != objLst.end(); it++)
-                lst << *it;
+            for (auto it : objLst)
+                lst << it;
 
             copyToClipboard(lst.at(0), lst);
         }
@@ -277,9 +277,9 @@ void MvQFolderViewBase::handleIconCommand(const vector<IconObject*>& objLstIn, Q
     else if (name == "cut") {
         if (objLst.size() > 0) {
             QList<IconObject*> lst;
-            for (vector<IconObject*>::const_iterator it = objLst.begin(); it != objLst.end(); it++) {
+            for (auto it : objLst) {
                 //(*it)->notifyCutBegin();
-                lst << *it;
+                lst << it;
             }
 
             cutToClipboard(lst.at(0), lst);
@@ -288,8 +288,8 @@ void MvQFolderViewBase::handleIconCommand(const vector<IconObject*>& objLstIn, Q
     else if (name == "copy_path") {
         if (objLst.size() > 0) {
             QList<IconObject*> lst;
-            for (vector<IconObject*>::const_iterator it = objLst.begin(); it != objLst.end(); it++) {
-                lst << *it;
+            for (auto it : objLst) {
+                lst << it;
             }
 
             copyPathToClipboard(lst.at(0), lst);
@@ -299,8 +299,8 @@ void MvQFolderViewBase::handleIconCommand(const vector<IconObject*>& objLstIn, Q
         MvQ::emptyWasteBasket();
     }
     else {
-        for (vector<IconObject*>::const_iterator it = objLst.begin(); it != objLst.end(); it++)
-            handleIconCommand(*it, name);
+        for (auto it : objLst)
+            handleIconCommand(it, name);
     }
 }
 
@@ -310,7 +310,7 @@ void MvQFolderViewBase::handleIconCommand(IconObject* obj, QString name)
         return;
 
     //Check if the command is valid for the object
-    std::set<string> cmdSet = obj->can();
+    std::set<std::string> cmdSet = obj->can();
     if (cmdSet.find(name.toStdString()) == cmdSet.end())
         return;
 
@@ -412,8 +412,8 @@ void MvQFolderViewBase::handleDesktopCommand(QString name, QPoint pos, QWidget*
             QStringList lst = dialog.selectedFiles();
             if (lst.count() > 0) {
                 Path result(lst[0].toStdString());
-                string name = folder->uniqueName(result.name());
-                Path path   = folder->path().add(name);
+                std::string name = folder->uniqueName(result.name());
+                Path path        = folder->path().add(name);
 
                 path.symlink(result);
 
@@ -469,7 +469,7 @@ void MvQFolderViewBase::cutToClipboard(IconObject* obj, QList<IconObject*> lst)
 #endif
 }
 
-void MvQFolderViewBase::copyPathToClipboard(IconObject* obj, QList<IconObject*> lst)
+void MvQFolderViewBase::copyPathToClipboard(IconObject* obj, QList<IconObject*>)
 {
     if (!obj)
         return;
@@ -489,7 +489,7 @@ void MvQFolderViewBase::copyPathToClipboard(IconObject* obj, QList<IconObject*>
 void MvQFolderViewBase::fromClipboard(QPoint pos)
 {
 #if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-    const MvQIconMimeData* mimeData =
+    const auto* mimeData =
         qobject_cast<const MvQIconMimeData*>(QGuiApplication::clipboard()->mimeData());
 #else
     const MvQIconMimeData* mimeData =
@@ -594,7 +594,7 @@ void MvQFolderViewBase::showLastCreated()
 
 QPixmap MvQFolderViewBase::dragPixmapWithCount(IconObject* dragObj, int cnt, QRect& iconPix)
 {
-    QFont f =  MvQ::findMonospaceFont();
+    QFont f = MvQ::findMonospaceFont();
     f.setPointSize(9);
     f.setBold(true);
 
@@ -617,8 +617,8 @@ QPixmap MvQFolderViewBase::dragPixmapWithCount(IconObject* dragObj, int cnt, QRe
     iconPix = QRect(0, pix.height() - getIconSize(), getIconSize(), getIconSize());
 
     //Item count indicator
-    QPen pen=MvQTheme::pen("folderview", "drag_count_pen");
-    QBrush brush=MvQTheme::brush("folderview", "drag_count_brush");
+    QPen pen     = MvQTheme::pen("folderview", "drag_count_pen");
+    QBrush brush = MvQTheme::brush("folderview", "drag_count_brush");
     painter.setPen(pen);
     painter.setBrush(brush);
     painter.setFont(f);
@@ -675,9 +675,9 @@ MvQIconMimeData* MvQFolderViewBase::buildClipboardData(IconObject* dragObj, QLis
             ca = MvQIconMimeData::CutAction;
 
         //Create and set drag mime data
-        MvQIconMimeData* mimeData = new MvQIconMimeData(folderModel_,
-                                                        dragObj, hotSpotInPix,
-                                                        objLst, pixDistanceLst, ca);
+        auto* mimeData = new MvQIconMimeData(folderModel_,
+                                             dragObj, hotSpotInPix,
+                                             objLst, pixDistanceLst, ca);
         mimeData->setFromHelper(fromHelper);
 
         return mimeData;
@@ -689,7 +689,7 @@ MvQIconMimeData* MvQFolderViewBase::buildClipboardData(IconObject* dragObj, QLis
 QDrag* MvQFolderViewBase::buildDrag(IconObject* dragObj, QList<IconObject*> objLst, bool fromHelper, QWidget* dragParent, QPoint dragPos)
 {
     if (dragObj && objLst.contains(dragObj)) {
-        QDrag* drag = new QDrag(dragParent);
+        auto* drag = new QDrag(dragParent);
 
         //Hotspot is the bottom right corner of the dragged object's pixmap
         //we overwrite it if dragPos is null!! We use normalised coordinates
@@ -792,9 +792,9 @@ QDrag* MvQFolderViewBase::buildDrag(IconObject* dragObj, QList<IconObject*> objL
 
 
         //Create and set drag mime data
-        MvQIconMimeData* mimeData = new MvQIconMimeData(folderModel_,
-                                                        dragObj, hotSpotInPix,
-                                                        objLst, pixDistanceLst);
+        auto* mimeData = new MvQIconMimeData(folderModel_,
+                                             dragObj, hotSpotInPix,
+                                             objLst, pixDistanceLst);
 
         mimeData->setFromHelper(fromHelper);
 
@@ -829,14 +829,14 @@ void MvQFolderViewBase::dropToFolder(Folder* folder, QDropEvent* event)
     //--------------------------------------
 
     if (event->mimeData()->hasFormat("metview/icon")) {
-        const MvQIconMimeData* mimeData = qobject_cast<const MvQIconMimeData*>(event->mimeData());
+        const auto* mimeData = qobject_cast<const MvQIconMimeData*>(event->mimeData());
 
         if (!mimeData) {
             event->ignore();
             return;
         }
 
-        IconObject* dragObj   = mimeData->dragObject();
+        IconObject* dragObj = mimeData->dragObject();
         if (!dragObj) {
             event->ignore();
             return;
@@ -851,7 +851,7 @@ void MvQFolderViewBase::dropToFolder(Folder* folder, QDropEvent* event)
         //Drop from another view/model or from the clipboard  or from an editor --> copy or move
 
         for (int i = 0; i < mimeData->objects().count(); i++) {
-             IconObject* obj = mimeData->objects().at(i);
+            IconObject* obj = mimeData->objects().at(i);
 
             //We set the object position to zero. This will instuct the icon folder view
             //(when the folder is next open in it) to find meaningful positions to the
@@ -873,7 +873,7 @@ void MvQFolderViewBase::dropToFolder(Folder* folder, QDropEvent* event)
         return;
     }
     else if (event->mimeData()->hasFormat("metview/new_icon")) {
-        const MvQNewIconMimeData* mimeData = qobject_cast<const MvQNewIconMimeData*>(event->mimeData());
+        const auto* mimeData = qobject_cast<const MvQNewIconMimeData*>(event->mimeData());
 
         if (!mimeData) {
             event->ignore();
