@@ -185,7 +185,7 @@ QRectF MvQIconItem::boundingRect() const
 
 void MvQIconItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWidget*)
 {
-    QPixmap pixmap = index_.data(Qt::DecorationRole).value<QPixmap>();
+    auto pixmap = index_.data(Qt::DecorationRole).value<QPixmap>();
 
     //Save painter state
     painter->save();
@@ -226,7 +226,7 @@ void MvQIconItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWid
     painter->drawPixmap(iconRect_.toRect(), pixmap);
 
     //Tender text
-    QFont font = index_.data(Qt::FontRole).value<QFont>();
+    auto font = index_.data(Qt::FontRole).value<QFont>();
     painter->setFont(font);
 
     if (blinkState_ == BlinkOn)
@@ -334,7 +334,7 @@ MvQIconFolderView::MvQIconFolderView(MvQFolderModel* folderModel,
     setAlignment(Qt::AlignLeft | Qt::AlignTop);
     setDragMode(QGraphicsView::RubberBandDrag);
 
-    QGraphicsScene* scene_ = new QGraphicsScene(this);
+    auto* scene_ = new QGraphicsScene(this);
     setScene(scene_);
 
     //qDebug() << maximumViewportSize() << items().count();
@@ -357,9 +357,7 @@ MvQIconFolderView::MvQIconFolderView(MvQFolderModel* folderModel,
     attachModel();
 }
 
-MvQIconFolderView::~MvQIconFolderView()
-{
-}
+MvQIconFolderView::~MvQIconFolderView() = default;
 
 //Connect the models signal to the view
 void MvQIconFolderView::attachModel()
@@ -435,7 +433,7 @@ QModelIndex MvQIconFolderView::indexAt(QPointF scenePos)
 {
     QGraphicsItem* item = scene()->itemAt(scenePos, QTransform());
     if (item) {
-        MvQIconItem* icItem = static_cast<MvQIconItem*>(item);
+        auto* icItem = static_cast<MvQIconItem*>(item);
         return icItem->index();
     }
     return QModelIndex();
@@ -445,7 +443,7 @@ IconObject* MvQIconFolderView::iconObjectAt(QPointF scenePos)
 {
     QGraphicsItem* item = scene()->itemAt(scenePos, QTransform());
     if (item) {
-        MvQIconItem* icItem = static_cast<MvQIconItem*>(item);
+        auto* icItem = static_cast<MvQIconItem*>(item);
         return folderModel_->objectFromIndex(icItem->index());
     }
     return 0;
@@ -472,7 +470,7 @@ const QPersistentModelIndex& MvQIconFolderView::itemToIndex(QGraphicsItem* item)
     static QPersistentModelIndex emptyPersIndex(emptyIndex);
 
     if (item) {
-        MvQIconItem* icItem = static_cast<MvQIconItem*>(item);
+        auto* icItem = static_cast<MvQIconItem*>(item);
         return icItem->index();
     }
     return emptyPersIndex;
@@ -481,7 +479,7 @@ const QPersistentModelIndex& MvQIconFolderView::itemToIndex(QGraphicsItem* item)
 IconObject* MvQIconFolderView::itemToObject(QGraphicsItem* item)
 {
     if (item) {
-        MvQIconItem* icItem = static_cast<MvQIconItem*>(item);
+        auto* icItem = static_cast<MvQIconItem*>(item);
         return folderModel_->objectFromIndex(icItem->index());
     }
     return 0;
@@ -621,8 +619,8 @@ void MvQIconFolderView::slotContextMenu(const QPoint& position)
 
 void MvQIconFolderView::mouseDoubleClickEvent(QMouseEvent* event)
 {
-    QModelIndexList lst = selectedIndexes();
-    const QModelIndex& index  = indexAt(mapToScene(event->pos()));
+    QModelIndexList lst      = selectedIndexes();
+    const QModelIndex& index = indexAt(mapToScene(event->pos()));
     if (lst.count() == 1 && lst.at(0) == index)
         handleDoubleClick(index);
 }
@@ -713,7 +711,7 @@ void MvQIconFolderView::reset()
     for (int i = 0; i < filterModel_->rowCount(); i++) {
         QModelIndex idx = filterModel_->index(i, 0);
 
-        MvQIconItem* item = new MvQIconItem(idx, itemProp_, this);
+        auto* item = new MvQIconItem(idx, itemProp_, this);
         scene()->addItem(item);
 
         QPersistentModelIndex idxP(idx);
@@ -828,13 +826,13 @@ void MvQIconFolderView::computeGrid(Desktop::GridSortMode sortMode)
             sizeItems.insert(std::pair<qint64, QModelIndex>(filterModel_->data(idx, Qt::UserRole).toLongLong(), filterModel_->index(i, 0)));
         }
         int cntS = 0;
-        for (std::multimap<qint64, QModelIndex>::const_iterator it = sizeItems.begin(); it != sizeItems.end(); it++, cntS++) {
+        for (auto it = sizeItems.begin(); it != sizeItems.end(); it++, cntS++) {
             items.insert(std::pair<QString, QModelIndex>(QString::number(cntS), it->second));
         }
     }
 
     int cnt = 0;
-    for (std::multimap<QString, QModelIndex>::const_iterator it = items.begin(); it != items.end(); it++, cnt++) {
+    for (auto it = items.begin(); it != items.end(); it++, cnt++) {
         MvQIconItem* item = indexToItem(it->second);
 
         QPoint pos;
@@ -981,7 +979,7 @@ void MvQIconFolderView::checkPositions()
         }
     }
 
-    for (auto item: needPos) {
+    for (auto item : needPos) {
         QPoint pos;
         int w = item->boundingRect().width();
         if (itemProp_->viewMode() == Desktop::IconViewMode) {
@@ -1034,7 +1032,7 @@ void MvQIconFolderView::mousePressEvent(QMouseEvent* event)
             bool outside = true;
             foreach (QObject* chObj, editor_->editor()->children()) {
                 if (chObj->isWidgetType()) {
-                    if (QWidget* w = static_cast<QWidget*>(chObj)) {
+                    if (auto* w = static_cast<QWidget*>(chObj)) {
                         QPoint posInW = w->mapFromGlobal(event->globalPos());
                         if (w->rect().contains(posInW)) {
                             outside = false;
@@ -1151,7 +1149,7 @@ void MvQIconFolderView::checkDropTarget(QDropEvent* event)
 {
     IconObject* dragObj = 0;
     if (event->mimeData()->hasFormat("metview/icon")) {
-        const MvQIconMimeData* mimeData = qobject_cast<const MvQIconMimeData*>(event->mimeData());
+        const auto* mimeData = qobject_cast<const MvQIconMimeData*>(event->mimeData());
 
         if (mimeData)
             dragObj = mimeData->dragObject();
@@ -1163,7 +1161,7 @@ void MvQIconFolderView::checkDropTarget(QDropEvent* event)
         return;
     }
 
-    QPointF scenePos          = mapToScene(event->pos());
+    QPointF scenePos          = mapToScene(MvQ::eventPos(event));
     Qt::DropAction dropAction = event->proposedAction();
 
     IconObject* obj = iconObjectAt(scenePos);
@@ -1171,7 +1169,7 @@ void MvQIconFolderView::checkDropTarget(QDropEvent* event)
     if (obj != dragObj && obj && obj->isFolder() && !obj->locked()) {
         MvQDropTarget::Instance()->reset(QString::fromStdString(obj->name()), (dropAction == Qt::MoveAction));
         if (window()) {
-            MvQDropTarget::Instance()->move(mapToGlobal(event->pos()) + QPoint(20, 20));
+            MvQDropTarget::Instance()->move(mapToGlobal(MvQ::eventPos(event)) + QPoint(20, 20));
         }
         return;
     }
@@ -1235,14 +1233,14 @@ void MvQIconFolderView::dropEvent(QDropEvent* event)
         return;
     }
 
-    QPoint pos = mapToScene(event->pos()).toPoint();
+    QPoint pos = mapToScene(MvQ::eventPos(event)).toPoint();
 
     //--------------------------------------
     // Drag and drop from another Metview folder
     //--------------------------------------
 
     if (event->mimeData()->hasFormat("metview/icon")) {
-        const MvQIconMimeData* mimeData = qobject_cast<const MvQIconMimeData*>(event->mimeData());
+        const auto* mimeData = qobject_cast<const MvQIconMimeData*>(event->mimeData());
 
         if (!mimeData) {
             event->ignore();
@@ -1257,7 +1255,8 @@ void MvQIconFolderView::dropEvent(QDropEvent* event)
 
             if (model) {
                 fromSameView = (model == folderModel_ || model->folder() == folderModel_->folder());
-            } else if(mimeData->fromEditor()) {
+            }
+            else if (mimeData->fromEditor()) {
                 fromSameView = (folderModel_->folder() == dragObj->parent());
             }
 
@@ -1279,7 +1278,7 @@ void MvQIconFolderView::dropEvent(QDropEvent* event)
             return;
         }
 
-        const MvQNewIconMimeData* mimeData = qobject_cast<const MvQNewIconMimeData*>(event->mimeData());
+        const auto* mimeData = qobject_cast<const MvQNewIconMimeData*>(event->mimeData());
 
         if (!mimeData) {
             event->ignore();
@@ -1479,8 +1478,8 @@ void MvQIconFolderView::edit(QGraphicsItem* item)
     if (item && !editor_) {
         //qDebug() << "create editor";
 
-        MvQIconItem* ic = static_cast<MvQIconItem*>(item);
-        editor_         = new MvQEditorProxy(ic);
+        auto* ic = static_cast<MvQIconItem*>(item);
+        editor_  = new MvQEditorProxy(ic);
 
         //Warning: editingFinished is emitted twice !!! It is a known qt bug!!
         //So we needed to use returnPressed here.
@@ -1551,7 +1550,7 @@ void MvQIconFolderView::setupShortCut()
 
 void MvQIconFolderView::slotIconShortCut()
 {
-    QShortcut* sc = static_cast<QShortcut*>(QObject::sender());
+    auto* sc = static_cast<QShortcut*>(QObject::sender());
     if (sc) {
         QModelIndexList lst = selectedIndexes();
 
@@ -1574,7 +1573,7 @@ void MvQIconFolderView::slotDefaultShortCut()
 
 void MvQIconFolderView::slotDesktopShortCut()
 {
-    QShortcut* sc = static_cast<QShortcut*>(QObject::sender());
+    auto* sc = static_cast<QShortcut*>(QObject::sender());
     if (sc) {
         QPoint scrollOffset(horizontalScrollBar()->value(), verticalScrollBar()->value());
         handleDesktopShortCut(sc, mousePos_ + scrollOffset, this);
@@ -1593,7 +1592,7 @@ void MvQIconFolderView::keyPressEvent(QKeyEvent* event)
         return;
     }
 
-    bool hasCtrl = event->modifiers() & Qt::ControlModifier;
+    bool hasCtrl  = event->modifiers() & Qt::ControlModifier;
     bool hasShift = event->modifiers() & Qt::ShiftModifier;
 
     //Ctrl+Shift
