@@ -8,24 +8,29 @@
  ***************************** LICENSE END *************************************/
 
 #include "HovHeight.h"
+
+#include <algorithm>
+#include <iomanip>
+#include <sstream>
+
 #include "MvException.h"
 
 #define HOV_SP 1013.25  // stardard pressure
 
-void HovHeightToolkit::GenerateKey(string& str, MvRequest& rq)
+void HovHeightToolkit::GenerateKey(std::string& str, MvRequest& rq)
 {
     // The level value is ignored to build the key
     int par            = rq("PARAM");
     int level          = 0;
     const char* expver = rq("EXPVER");
 
-    ostringstream oss;
-    oss << setfill('0')
-        << setw(1) << 'p'
-        << setw(3) << par
-        << setw(4) << level
-        << setw(4) << (expver ? expver : "_")
-        << ends;
+    std::ostringstream oss;
+    oss << std::setfill('0')
+        << std::setw(1) << 'p'
+        << std::setw(3) << par
+        << std::setw(4) << level
+        << std::setw(4) << (expver ? expver : "_")
+        << std::ends;
 
     str = oss.str();
 
@@ -37,7 +42,7 @@ void HovHeightToolkit::UpdateLevelList(MvField& field, double ilevel)
     // Check if conversion from model level to pressure level is needed
     double level = (vertAxisType_ == HOV_PRESSURE && field.isModelLevel()) ? field.meanML_to_Pressure_bySP(double(HOV_SP * 100.), (int)ilevel) / 100. : ilevel;
 
-    vector<double>::iterator iter = find(coord1_.begin(), coord1_.end(), level);
+    auto iter = std::find(coord1_.begin(), coord1_.end(), level);
     if (iter == coord1_.end())
         coord1_.push_back(level);
 }
@@ -85,11 +90,11 @@ bool HovHeightToolkit::GenerateData(MvRequest& data)
 
     // Generate data
     int currentGenerated = 0, lastNrGenerated = -1;
-    int ind       = 0;
-    string sfirst = "FIRSTFIELD";
-    string timeKey, keystr;
-    string lastTimeKey = sfirst;
-    string lastKey     = sfirst;
+    int ind            = 0;
+    std::string sfirst = "FIRSTFIELD";
+    std::string timeKey, keystr;
+    std::string lastTimeKey = sfirst;
+    std::string lastKey     = sfirst;
     MvField field, lastField;
     ParamIterator paramIter;
     while ((field = iter())) {
@@ -148,7 +153,7 @@ bool HovHeightToolkit::GenerateData(MvRequest& data)
     return true;
 }
 
-string HovHeightToolkit::GetTitle(ParamInfo* par)
+std::string HovHeightToolkit::GetTitle(ParamInfo* par)
 {
     char title[256];
     sprintf(title, "Hovmoeller of %s %s (%.1f%s/%.1f%s/%.1f%s/%.1f%s)",
@@ -158,7 +163,7 @@ string HovHeightToolkit::GetTitle(ParamInfo* par)
             (y2_ < 0) ? -y2_ : y2_, (y2_ < 0) ? "S" : "N",
             (x2_ < 0) ? -x2_ : x2_, (x2_ < 0) ? "W" : "E");
 
-    return string(title);
+    return std::string(title);
 }
 
 bool HovHeightToolkit::GetInputInfo(MvRequest& in)
@@ -211,10 +216,10 @@ bool HovHeightToolkit::GetInputInfo(MvNetCDF* netcdf)
 
     // Retrieve vertical type axes flag
     const char* cp = (const char*)req("vertical_type");
-    if (cp == NULL)
+    if (cp == nullptr)
         throw MvException("Hovmoeller-> Netcdf input file error: vertical_type attribute not found");
 
-    vertAxisType_ = (string(cp) == "PRESSURE") ? HOV_PRESSURE : HOV_ASINDATA;
+    vertAxisType_ = (std::string(cp) == "PRESSURE") ? HOV_PRESSURE : HOV_ASINDATA;
 
     // Set axis orientation
     verticalAxis_ = HOV_GEO;
@@ -232,8 +237,8 @@ void HovHeightToolkit::NcWriteGlobalAttributesApp()
 bool HovHeightToolkit::NcWriteSecondCoord()
 {
     // Add second coordinate to the netCDF file
-    vector<string> v_sdim(1, GetSecondCoordName());
-    vector<long> v_ndim(1, nrPoints_);
+    std::vector<std::string> v_sdim(1, GetSecondCoordName());
+    std::vector<long> v_ndim(1, nrPoints_);
     MvNcVar* ncx = netcdf_->addVariable(v_sdim[0], ncDouble, v_ndim, v_sdim);
     ncx->addAttribute("long_name", "Atmospheric Levels");
     ncx->addAttribute("units", "hPa");
@@ -246,7 +251,7 @@ bool HovHeightToolkit::consistencyCheck(MvRequest& req1, MvRequest& req2)
 {
     // Check input TYPE
     if ((const char*)req1("TYPE") != (const char*)req2.getVerb()) {
-        ostringstream oss;
+        std::ostringstream oss;
         oss << "Hovmoeller-> TYPE parameter is not consistent: "
             << (const char*)req1("TYPE")
             << " and "
@@ -263,7 +268,7 @@ bool HovHeightToolkit::consistencyCheck(MvRequest& req1, MvRequest& req2)
 
     // Check VERTICAL_LEVEL_TYPE
     if ((const char*)req1("VERTICAL_LEVEL_TYPE") != (const char*)req2("VERTICAL_LEVEL_TYPE")) {
-        ostringstream oss;
+        std::ostringstream oss;
         oss << "Hovmoeller-> VERTICAL_LEVEL_TYPE parameter is not consistent: "
             << (const char*)req1("VERTICAL_LEVEL_TYPE")
             << " and "
@@ -297,7 +302,7 @@ MvRequest HovHeightToolkit::CreateViewRequest()
 
 void HeightHovmoeller::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "Request IN:" << endl;
+    std::cout << "Request IN:" << std::endl;
     in.print();
 
     // Compute Hovmoeller diagram
@@ -305,7 +310,7 @@ void HeightHovmoeller::serve(MvRequest& in, MvRequest& out)
     if (!Compute(in, out))
         setError(1, "HeightHovmoeller-> Failed to generate Hovmoeller Vertical");
 
-    cout << "Request OUT:" << endl;
+    std::cout << "Request OUT:" << std::endl;
     out.print();
 }
 
