@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef HOVHEIGHT_H
-#define HOVHEIGHT_H
+#pragma once
 
 #include "Hovmoeller.h"
 #include "HovToolkit.h"
@@ -18,7 +17,7 @@ class HovHeightToolkit : public HovToolkit
 public:
     // Common functions
     bool GenerateData(MvRequest&);
-    string GetTitle(ParamInfo*);
+    std::string GetTitle(ParamInfo*);
     const char* GetSecondCoordName() { return "vertical"; }
     bool SecondAuxiliaryCoord() { return false; }
     const char* ApplicationType() { return "VERTICAL_HOVM"; }
@@ -36,7 +35,7 @@ public:
     bool ComputeSecondCoord();
 
     // Create access keys
-    void GenerateKey(string&, MvRequest&);
+    void GenerateKey(std::string&, MvRequest&);
 
     // Initialize variables
     bool GetInputInfo(MvRequest&);  //from user interface
@@ -58,11 +57,11 @@ class HeightHovmoeller : public HovHeightToolkit, public Hovmoeller
 {
 public:
     HeightHovmoeller() :
-        Hovmoeller("VERTICAL_HOVM"){};
+        Hovmoeller("VERTICAL_HOVM") {}
     HeightHovmoeller(const char* kw) :
-        Hovmoeller(kw){};
+        Hovmoeller(kw) {}
 
-    ~HeightHovmoeller(){};
+    ~HeightHovmoeller() = default;
 
     // Entry point
     void serve(MvRequest&, MvRequest&);
@@ -76,11 +75,9 @@ class HeightHovmoellerM3 : public HeightHovmoeller
 {
 public:
     HeightHovmoellerM3() :
-        HeightHovmoeller("HEIGHT_HOV"){};
-    ~HeightHovmoellerM3(){};
+        HeightHovmoeller("HEIGHT_HOV") {}
+    ~HeightHovmoellerM3() = default;
 
     // Entry point
     void serve(MvRequest&, MvRequest&);
 };
-
-#endif
