@@ -8,6 +8,10 @@
  ***************************** LICENSE END *************************************/
 
 #include "HovToolkit.h"
+
+#include <iomanip>
+#include <sstream>
+
 #include "MvException.h"
 #include "MvRequestUtil.hpp"
 
@@ -56,8 +60,8 @@ void HovToolkit::ReleaseMemory()
 void HovToolkit::ReleaseMemoryParam()
 {
     if (params_.size()) {
-        for (ParamIterator iter = params_.begin(); iter != params_.end(); iter++)
-            delete (*iter).second;
+        for (auto& param : params_)
+            delete param.second;
 
         params_.clear();
     }
@@ -66,7 +70,7 @@ void HovToolkit::ReleaseMemoryParam()
 }
 
 // Main function. It is called from the Expand option
-bool HovToolkit::Compute(string& netfnameIn, MvRequest& data, string action, MvRequest& out)
+bool HovToolkit::Compute(std::string& netfnameIn, MvRequest& data, std::string action, MvRequest& out)
 {
     // Initialise variables
     expand_      = true;
@@ -146,8 +150,8 @@ MvRequest HovToolkit::CreateOutputRequest()
 
     // Currently, the netcdf file contains only one parameter.
     // Update this code for more than one parameter
-    ParamIterator ii = params_.begin();
-    ParamInfo* par   = (*ii).second;
+    auto ii        = params_.begin();
+    ParamInfo* par = (*ii).second;
 
     // Create netCDF output request
     MvRequest out1("NETCDF_XY_MATRIX");
@@ -157,7 +161,7 @@ MvRequest HovToolkit::CreateOutputRequest()
     if (verticalAxis_ == HOV_TIME)  // TIME is vertical axis
     {
         out1("NETCDF_Y_VARIABLE") = HOV_VARTIME.c_str();
-        ;
+
         out1("NETCDF_X_VARIABLE") = secondCoordName;
         if (SecondAuxiliaryCoord()) {
             out1("NETCDF_X_AUXILIARY_VARIABLE") = GetSecondAuxiliaryCoordName();
@@ -254,7 +258,7 @@ bool HovToolkit::GetInputParameters(MvRequest& in)
         throw MvException("Hovmoeller-> No Data file specified");
 
     // Get and save action mode. Default value is "prepare"
-    string actionMode = (const char*)in("_ACTION") ? (const char*)in("_ACTION") : "prepare";
+    std::string actionMode = (const char*)in("_ACTION") ? (const char*)in("_ACTION") : "prepare";
     this->ActionMode(actionMode);
 
     // Retrieve the Cartesian View request if exists, e.g. if a
@@ -338,27 +342,27 @@ bool HovToolkit::GetInputCommonInfo(MvNetCDF* netcdf)
     // Retrieve Grid values
     MvRequest req  = netcdf->getRequest();
     const char* cp = (const char*)req("grid");
-    if (cp == NULL)
+    if (cp == nullptr)
         throw MvException("Hovmoeller-> Netcdf file: GRID attribute not found");
 
-    string str = cp;
-    gridEW_    = atof(strtok((char*)str.c_str(), "/"));
-    gridNS_    = atof(strtok(NULL, "/"));
+    std::string str = cp;
+    gridEW_         = atof(strtok((char*)str.c_str(), "/"));
+    gridNS_         = atof(strtok(nullptr, "/"));
 
     // Retrieve Coordinates values
     cp = (const char*)req("coordinates");
-    if (cp == NULL)
+    if (cp == nullptr)
         throw MvException("Hovmoeller-> Netcdf file: COORDINATES attribute not found");
 
     str = cp;
     y1_ = atof(strtok((char*)str.c_str(), "/"));
-    x1_ = atof(strtok(NULL, "/"));
-    y2_ = atof(strtok(NULL, "/"));
-    x2_ = atof(strtok(NULL, "/"));
+    x1_ = atof(strtok(nullptr, "/"));
+    y2_ = atof(strtok(nullptr, "/"));
+    x2_ = atof(strtok(nullptr, "/"));
 
     // Retrieve vertical axis flag
     cp            = (const char*)req("vertical_axis");
-    verticalAxis_ = (cp == NULL) ? HOV_TIME : atoi(cp);
+    verticalAxis_ = (cp == nullptr) ? HOV_TIME : atoi(cp);
 
     return true;
 }
@@ -376,7 +380,7 @@ bool HovToolkit::CreateParamInfo(MvRequest& data)
     // Retrieve basic information from the fieldset
     dateMinD_ = 99999999.;
     dateMaxD_ = 0.;
-    string keystr, timekey;
+    std::string keystr, timekey;
     int iparam;
     double level;
     const char* expver = 0;
@@ -391,10 +395,10 @@ bool HovToolkit::CreateParamInfo(MvRequest& data)
         // MvFieldExpander	x(field);
         MvRequest rq = field.getRequest();
 
-        iparam    = rq("PARAM");
-        level     = rq("LEVELIST", 0);
-        expver    = rq("EXPVER");
-        string ev = expver ? expver : "_";
+        iparam         = rq("PARAM");
+        level          = rq("LEVELIST", 0);
+        expver         = rq("EXPVER");
+        std::string ev = expver ? expver : "_";
 
         // Save basic information
         GenerateKey(keystr, rq);
@@ -410,10 +414,10 @@ bool HovToolkit::CreateParamInfo(MvRequest& data)
         if (dateMaxD_ < d1)
             dateMaxD_ = d1;
 
-        ParamInfo* par = new ParamInfo(iparam, d1, level, ev,
-                                       field.getGribKeyValueString("shortName"),
-                                       field.getGribKeyValueString("name"),
-                                       field.getGribKeyValueString("units"));
+        auto* par = new ParamInfo(iparam, d1, level, ev,
+                                  field.getGribKeyValueString("shortName"),
+                                  field.getGribKeyValueString("name"),
+                                  field.getGribKeyValueString("units"));
 
         ParamInsertPair inserted = params_.insert(ParamPair(keystr, par));
         ParamInfo* pp            = (*(inserted.first)).second;
@@ -426,7 +430,7 @@ bool HovToolkit::CreateParamInfo(MvRequest& data)
 
     // Maybe this restriction should be removed in the future
     if (params_.size() > 1) {
-        ostringstream oss;
+        std::ostringstream oss;
         oss << "Hovmoeller-> Creation of Hovmoeller diagrams from multiple parameters or vertical levels is not yet supported. This data has "
             << params_.size()
             << " parameters or levels";
@@ -436,49 +440,49 @@ bool HovToolkit::CreateParamInfo(MvRequest& data)
     return true;
 }
 
-void HovToolkit::GenerateKey(string& str, MvRequest& rq)
+void HovToolkit::GenerateKey(std::string& str, MvRequest& rq)
 {
     int par   = rq("PARAM");
     int level = rq("LEVELIST", 0);
 
-    ostringstream oss;
-    oss << setfill('0')
-        << setw(1) << 'p'
-        << setw(3) << par
-        << setw(4) << level
-        << ends;
+    std::ostringstream oss;
+    oss << std::setfill('0')
+        << std::setw(1) << 'p'
+        << std::setw(3) << par
+        << std::setw(4) << level
+        << std::ends;
 
     str = oss.str();
 
     return;
 }
 
-void HovToolkit::GenerateTimeKey(string& str, MvRequest& rq)
+void HovToolkit::GenerateTimeKey(std::string& str, MvRequest& rq)
 {
     int istep = rq("STEP");
     int itime = rq("TIME");
     int idate = rq.getBaseDate();
 
-    ostringstream oss;
-    oss << setfill('0')
-        << setw(8) << idate
-        << setw(4) << itime
-        << setw(HOV_STEPSIZE) << istep
-        << ends;
+    std::ostringstream oss;
+    oss << std::setfill('0')
+        << std::setw(8) << idate
+        << std::setw(4) << itime
+        << std::setw(HOV_STEPSIZE) << istep
+        << std::ends;
 
     str = oss.str();
 
     return;
 }
 
-double HovToolkit::GetDateDif(string& timekey)
+double HovToolkit::GetDateDif(std::string& timekey)
 {
     // Extract date information
     double ddate = atof(timekey.substr(0, 8).c_str());
     double dhour = atof(timekey.substr(8, 2).c_str());
     double dmin  = atof(timekey.substr(10, 2).c_str());
     double dstep;
-    string strStep = timekey.substr(12, HOV_STEPSIZE);
+    std::string strStep = timekey.substr(12, HOV_STEPSIZE);
 
 
     // Note that the step can be a negative number. Since it has been padded
@@ -545,11 +549,11 @@ void HovToolkit::GetTimeInfoFromParam()
 {
     // Get time series from the first variable
     double dd;
-    string timekey;
+    std::string timekey;
     ParamInfo* par  = (*params_.begin()).second;
     IndexesMap lmap = par->Indexes();
-    for (IndexIterator ii = lmap.begin(); ii != lmap.end(); ii++) {
-        timekey = (*ii).first;
+    for (auto& ii : lmap) {
+        timekey = ii.first;
         dd      = this->GetDateDif(timekey);
         vtime_.push_back(dd);
     }
@@ -578,8 +582,8 @@ bool HovToolkit::GenerateData(MvRequest& data)
 
     // Generate data
     int currentGenerated = 0, lastNrGenerated = -1;
-    string timekey, keystr;
-    string lastKey = "FIRSTFIELD";
+    std::string timekey, keystr;
+    std::string lastKey = "FIRSTFIELD";
     MvField field, lastField;
     ParamIterator paramIter;
     while ((field = iter())) {
@@ -602,7 +606,7 @@ bool HovToolkit::GenerateData(MvRequest& data)
         par->FillIndex(xint_, timekey, nrPoints_);
 
         // Write out data, if it can be grouped together
-        if (lastKey != keystr && lastKey != string("FIRSTFIELD")) {
+        if (lastKey != keystr && lastKey != std::string("FIRSTFIELD")) {
             if (!NcWriteData(lastField, lastKey))
                 return false;
             lastNrGenerated = currentGenerated;
@@ -673,8 +677,8 @@ void HovToolkit::NcWriteGlobalAttributes()
     // produce a title and Hovmoeller plots only the first variable then
     // we are adding this code below. REMOVE it when Magics is capable to
     // produce a title from the Variable Attributes.
-    ParamIterator ii = params_.begin();
-    ParamInfo* par   = (*ii).second;
+    auto ii        = params_.begin();
+    ParamInfo* par = (*ii).second;
     netcdf_->addAttribute("title", this->GetTitle(par).c_str());
 }
 
@@ -682,8 +686,8 @@ void HovToolkit::NcWriteGlobalAttributes()
 bool HovToolkit::NcWriteTimeInfo()
 {
     // Add 'time' variable to netCDF
-    vector<long> v_ndim(1, nrIndexes_);
-    vector<string> v_sdim(1, HOV_VARTIME);
+    std::vector<long> v_ndim(1, nrIndexes_);
+    std::vector<std::string> v_sdim(1, HOV_VARTIME);
     MvNcVar* nctime = netcdf_->addVariable(v_sdim[0], ncDouble, v_ndim, v_sdim);
 
     char buf[128];
@@ -699,7 +703,7 @@ bool HovToolkit::NcWriteTimeInfo()
 
 // We have all the values for one set of data
 // Call functions to write the values to netcdf file
-bool HovToolkit::NcWriteData(MvField&, const string& key)
+bool HovToolkit::NcWriteData(MvField&, const std::string& key)
 {
     // Get parameter info
     ParamInfo* par = this->GetParamInfo(key);
@@ -707,8 +711,8 @@ bool HovToolkit::NcWriteData(MvField&, const string& key)
         return false;
 
     // Generate the CDF variable
-    vector<long> vdim(2);
-    vector<string> vname(2);
+    std::vector<long> vdim(2);
+    std::vector<std::string> vname(2);
     int nrIndexes = this->NrIndexes();
     if (verticalAxis_ == HOV_TIME) {
         vdim[0]  = nrIndexes;
@@ -743,7 +747,7 @@ void HovToolkit::NcAddMetadata(MvNcVar* ncvar, ParamInfo* par)
     ncvar->addAttribute("_FillValue", HMISSING_VALUE);
 
     // Write title
-    string title = this->GetTitle(par);
+    std::string title = this->GetTitle(par);
     ncvar->addAttribute("title", title.c_str());
 
     return;
@@ -793,7 +797,7 @@ void HovToolkit::NcFillValues(MvNcVar* ncvar, ParamInfo* par)
         // Retrieve all values from the internal structure
         int i, j = 0;
         int nrInd = lmap.size();  // or nrIndexes_ - nrIndexesIn_
-        vector<double> mat(nrInd * nrPoints_);
+        std::vector<double> mat(nrInd * nrPoints_);
         IndexIterator ii;
         for (ii = lmap.begin(); ii != lmap.end(); ii++) {
             IndexesInfo* lInfo = (*ii).second;
@@ -803,7 +807,7 @@ void HovToolkit::NcFillValues(MvNcVar* ncvar, ParamInfo* par)
 
         // Write matrix data to the netcdf file
         const char* key = ncvar->name();  //get variable name
-        vector<double> cp(nrIndexes_);
+        std::vector<double> cp(nrIndexes_);
         for (i = 0; i < nrPoints_; i++) {
             // 'Expand' option: write previous values
             if (!this->ExpandFillValues(key, i, cp))
@@ -824,7 +828,7 @@ void HovToolkit::NcFillValues(MvNcVar* ncvar, ParamInfo* par)
 void HovToolkit::NcWriteValues(MvNcVar* ncvar, IndexesInfo* lInfo, int pos)
 {
     // Get values from the structure
-    vector<double> cp(nrPoints_);
+    std::vector<double> cp(nrPoints_);
     for (int i = 0; i < nrPoints_; i++)
         cp[i] = lInfo->Values()[i];
 
@@ -833,12 +837,12 @@ void HovToolkit::NcWriteValues(MvNcVar* ncvar, IndexesInfo* lInfo, int pos)
     ncvar->put(cp, 1, (long)nrPoints_);
 }
 
-ParamInfo* HovToolkit::GetParamInfo(const string& key)
+ParamInfo* HovToolkit::GetParamInfo(const std::string& key)
 {
     // Check if field is valid
-    ParamIterator ii = params_.find(key);
+    auto ii = params_.find(key);
     if (ii == params_.end()) {
-        ostringstream oss;
+        std::ostringstream oss;
         oss << "Hovmoeller-> GetParamInfo: Could not find the requested field " << key;
         throw MvException(oss.str());
     }
@@ -882,11 +886,11 @@ bool HovToolkit::IsDataModule(const char* verb)
 
 // Variable name in netCDF has some restrictions, e.g. can not
 // start with a non-alphabetic letter.
-string HovToolkit::getNetcdfVarname(string name)
+std::string HovToolkit::getNetcdfVarname(std::string name)
 {
     // Netcdf only accepts variable name starting with a alphabetic letter
     if (!isalpha(name[0])) {
-        string newname = "a_" + name;
+        std::string newname = "a_" + name;
         return newname;
     }
 
@@ -926,8 +930,8 @@ void HovToolkit::ExpandFillValues(MvNcVar* ncvar, int& pos)
         return;
 
     // Copy values from the input netcdf file
-    vector<double> vals;
-    string key       = ncvar->name();  //get variable name
+    std::vector<double> vals;
+    std::string key  = ncvar->name();  //get variable name
     MvNcVar* ncvarIn = netcdfIn_->getVariable(key.c_str());
     long* edges      = ncvarIn->edges();
     ncvarIn->get(vals, edges);
@@ -938,14 +942,14 @@ void HovToolkit::ExpandFillValues(MvNcVar* ncvar, int& pos)
     return;
 }
 
-bool HovToolkit::ExpandFillValues(const char* key, int pos, vector<double>& cp)
+bool HovToolkit::ExpandFillValues(const char* key, int pos, std::vector<double>& cp)
 {
     // Return if option is not Expand
     if (!expand_)
         return true;
 
     // Get values from the input netcdf file
-    vector<double> vals;
+    std::vector<double> vals;
     MvNcVar* ncvarIn = netcdfIn_->getVariable(key);
     long* edges      = ncvarIn->edges();
     ncvarIn->setCurrent(pos);
@@ -969,13 +973,13 @@ bool HovToolkit::ExpandGetTimeInfo()
         throw MvException("Hovmoeller-> Input NetCDF file not accessible");
 
     // Copy 'time' values from the input file
-    vector<double> vals;
+    std::vector<double> vals;
     MvNcVar* tvar = netcdfIn_->getVariable(HOV_VARTIME);
     long* edges   = tvar->edges();
     nrIndexesIn_  = edges[0];
     tvar->get(vals, edges);
-    for (unsigned int i = 0; i < vals.size(); i++)
-        vtime_.push_back(vals[i]);
+    for (double& val : vals)
+        vtime_.push_back(val);
 
     return true;
 }
