@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef HOVTOOLKIT_H
-#define HOVTOOLKIT_H
+#pragma once
 
 #include "Factory.h"
 #include "MvHovmFrame.h"
@@ -30,10 +29,10 @@ enum
     HOV_PRESSURE
 };  //height axis type options
 
-const string HOV_VARLEVEL = "nlev";
-const string HOV_VARTIME  = "time";
-const string HOV_VARLAT   = "lat";
-const string HOV_VARLON   = "lon";
+const std::string HOV_VARLEVEL = "nlev";
+const std::string HOV_VARTIME  = "time";
+const std::string HOV_VARLAT   = "lat";
+const std::string HOV_VARLON   = "lon";
 
 class HovToolkit
 {
@@ -59,7 +58,7 @@ public:
 
     // Compute Hovmoeller diagram (main routine)
     // Expand a existing netcdf file
-    virtual bool Compute(string&, MvRequest&, string, MvRequest&);
+    virtual bool Compute(std::string&, MvRequest&, std::string, MvRequest&);
 
     // Handle creating variables, data and file
     virtual bool ComputeValues(MvField&, int = 0) = 0;
@@ -79,14 +78,14 @@ public:
     bool CreateParamInfo(MvRequest&);
 
     // Create access keys
-    virtual void GenerateKey(string&, MvRequest&);
-    void GenerateTimeKey(string&, MvRequest&);
+    virtual void GenerateKey(std::string&, MvRequest&);
+    void GenerateTimeKey(std::string&, MvRequest&);
 
     // Access time/date information
     double GetRefTime() { return refTime_; }
     void SetRefTime(double ref) { refTime_ = ref; }
     MvDate GetDate(MvField&);
-    double GetDateDif(string&);
+    double GetDateDif(std::string&);
     bool GetTimeInfo();
     void GetTimeInfoFromParam();
 
@@ -103,11 +102,11 @@ public:
 
     // Functions to handle the netcdf file
     bool NcAddCommonVariables();
-    bool NcWriteData(MvField&, const string& key);
+    bool NcWriteData(MvField&, const std::string& key);
     void NcAddMetadata(MvNcVar*, ParamInfo*);
-    string getNetcdfVarname(string);  // Get netCDF variable name
-    virtual string GetTitle(ParamInfo*)   = 0;
-    virtual const char* ApplicationType() = 0;
+    std::string getNetcdfVarname(std::string);  // Get netCDF variable name
+    virtual std::string GetTitle(ParamInfo*) = 0;
+    virtual const char* ApplicationType()    = 0;
     virtual void NcWriteGlobalAttributes();
     virtual void NcWriteGlobalAttributesApp() = 0;
     virtual bool NcWriteTimeInfo();
@@ -121,7 +120,7 @@ public:
     void ExpandOpenNcFile();
     void ExpandCloseNcFile();
     void ExpandFillValues(MvNcVar*, int&);
-    bool ExpandFillValues(const char*, int, vector<double>&);
+    bool ExpandFillValues(const char*, int, std::vector<double>&);
     bool ExpandGetTimeInfo();
 
     MvRequest GetVariableData(MvRequest&);
@@ -132,16 +131,16 @@ public:
     virtual const char* GetSecondAuxiliaryCoordName() { return " "; }
     virtual bool SecondAuxiliaryCoord() = 0;
     virtual bool ComputeSecondCoord()   = 0;
-    virtual string GeolineConvention() { return glConvention_; }
+    virtual std::string GeolineConvention() { return glConvention_; }
 
     // Functions to handle action mode
-    void ActionMode(string action) { actionMode_ = action; }
-    string ActionMode() { return actionMode_; }
+    void ActionMode(std::string action) { actionMode_ = action; }
+    std::string ActionMode() { return actionMode_; }
     bool IsVisualise();
     bool IsDataModule(const char*);
 
     // Get Parameter info given the key
-    ParamInfo* GetParamInfo(const string&);
+    ParamInfo* GetParamInfo(const std::string&);
 
     // Get application view
     MvRequest GetAppView(MvRequest&);
@@ -154,34 +153,32 @@ public:
     MvRequest buildMacroConverterRequest();
 
 protected:
-    bool swapAxes_{false};               // swap default axes
-    int procType_;                // process type
-    int verticalAxis_;            // Time axis or Geo axis
-    int nrPoints_;                // number of points of the second axis
-    int nrIndexes_;               // number of points of the time axis
-    double x1_, x2_, y1_, y2_;    // geographical coordinates
-    double gridNS_, gridEW_;      // grid interval
-    double refTime_;              // reference Time value
-    double dateMinD_, dateMaxD_;  // min/max date values
-    string ncdfPath_;             // netCDF file path
-    string actionMode_;           // "examine"/"save"/"execute"/...
-    string glConvention_{"lonlat"};         // geoline convention: lonlat or latlon
-    MvNetCDF* netcdf_{nullptr};            // netcdf structure
-    MvRequest dataRequest_;       // grib data
-    MvRequest origReq_;           // original input request
+    bool swapAxes_{false};                // swap default axes
+    int procType_;                        // process type
+    int verticalAxis_;                    // Time axis or Geo axis
+    int nrPoints_;                        // number of points of the second axis
+    int nrIndexes_;                       // number of points of the time axis
+    double x1_, x2_, y1_, y2_;            // geographical coordinates
+    double gridNS_, gridEW_;              // grid interval
+    double refTime_;                      // reference Time value
+    double dateMinD_, dateMaxD_;          // min/max date values
+    std::string ncdfPath_;                // netCDF file path
+    std::string actionMode_;              // "examine"/"save"/"execute"/...
+    std::string glConvention_{"lonlat"};  // geoline convention: lonlat or latlon
+    MvNetCDF* netcdf_{nullptr};           // netcdf structure
+    MvRequest dataRequest_;               // grib data
+    MvRequest origReq_;                   // original input request
 
     // Variables related to Param info and values
-    double* xint_{nullptr};           // point values
-    vector<double> coord1_;  // second coordinate values (lat/lng/level)
-    vector<double> coord2_;  // second coordinate values (lat/lng)
-    vector<double> vtime_;   // time values
-    ParamMap params_;        // structure holding computed values
+    double* xint_{nullptr};       // point values
+    std::vector<double> coord1_;  // second coordinate values (lat/lng/level)
+    std::vector<double> coord2_;  // second coordinate values (lat/lng)
+    std::vector<double> vtime_;   // time values
+    ParamMap params_;             // structure holding computed values
 
     // Variables related to the Expand option
-    bool expand_{false};         // true: expand option
-    int nrIndexesIn_;     // number of initial time points
-    string netfnameIn_;   // input netcdf filename
+    bool expand_{false};           // true: expand option
+    int nrIndexesIn_;              // number of initial time points
+    std::string netfnameIn_;       // input netcdf filename
     MvNetCDF* netcdfIn_{nullptr};  // Input netcdf structure
 };
-
-#endif
