@@ -7,6 +7,9 @@
 
  ***************************** LICENSE END *************************************/
 
+#include <string>
+#include <vector>
+
 #include <math.h>
 #include <ctype.h>
 #include <float.h>
@@ -15,7 +18,6 @@
 #include "arith.h"
 #include "cbufr.h"
 #include "MvFieldSet.h"
-#include "inc_stl.h"
 #include "MvPath.hpp"
 
 // should include MvFieldSet.h, but it requires other header files...
@@ -170,7 +172,7 @@ class MergeBufrFunction : public Function
 {
 public:
     MergeBufrFunction(const char* n) :
-        Function(n, 2, tbufr, tbufr){};
+        Function(n, 2, tbufr, tbufr) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -239,10 +241,10 @@ void CGeopts::load(void)
 
 void CGeopts::unload(bool doFree)
 {
-    //	if( gpts.count() > 0 || (r == NULL))
+    //	if( gpts.count() > 0 || (r == nullptr))
     //	  {
     if (doFree) {
-        if (r == NULL) {
+        if (r == nullptr) {
             char* path = marstmp();
             gpts_.write(path);
 
@@ -281,21 +283,21 @@ CGeopts::CGeopts(long count, int nvals, eGeoFormat efmt, bool init) :
     InPool(tgeopts),
     gpts_(count, nvals, efmt, init)
 {
-    r = NULL;
+    r = nullptr;
 }
 
-CGeopts::CGeopts(long count, const MvGeoPointColumnInfo &colInfo, eGeoFormat efmt, bool init) :
+CGeopts::CGeopts(long count, const MvGeoPointColumnInfo& colInfo, eGeoFormat efmt, bool init) :
     InPool(tgeopts),
     gpts_(count, colInfo, efmt, init)
 {
-    r = NULL;
+    r = nullptr;
 }
 
 
 CGeopts::CGeopts(CGeopts* p) :
     InPool(tgeopts)
 {
-    r = NULL;
+    r = nullptr;
     p->load();
     gpts_ = p->gpts_;
 }
@@ -303,7 +305,7 @@ CGeopts::CGeopts(CGeopts* p) :
 CGeopts::CGeopts(MvGeoPoints& gptsIn) :
     InPool(tgeopts)
 {
-    r    = NULL;
+    r     = nullptr;
     gpts_ = gptsIn;  // makes a copy, we should make this more efficient
 }
 
@@ -311,17 +313,17 @@ CGeopts::CGeopts(MvGeoPoints& gptsIn) :
 CGeopts::CGeopts(CGeopts* p, fieldset* v, int n, bool nearest, bool nearestValid, bool storeLocs) :
     InPool(tgeopts)
 {
-    r = NULL;
+    r = nullptr;
     p->load();
-    eGeoFormat fmt = (storeLocs)
-                     ? eGeoNCols
-                     : p->gpts_.format();
+    eGeoFormat fmt        = (storeLocs)
+                                ? eGeoNCols
+                                : p->gpts_.format();
     eGeoCopyMode copyMode = (fmt == eGeoNCols)
-                            ? eGeoCopyCoordinatesOnly
-                            : eGeoCopyAll;
+                                ? eGeoCopyCoordinatesOnly
+                                : eGeoCopyAll;
 
 
-    gpts_.copy(p->gpts_, copyMode); // make a copy of the input geopoints
+    gpts_.copy(p->gpts_, copyMode);  // make a copy of the input geopoints
 
     if (storeLocs) {
         gpts_.set_format(eGeoNCols, 3);
@@ -337,7 +339,7 @@ CGeopts::CGeopts(CGeopts* p, fieldset* v, int n, bool nearest, bool nearestValid
     // be destroyed before releasing the field (field* g). This is
     // because the destructor of MvField will try to restore the
     // previous memory status of the field, which is expand memory.
-    MvField* fld = new MvField(g);
+    auto* fld = new MvField(g);
 
     //-- get date/time/level metadata from the GRIB field
     MvDate base(fld->yyyymmddFoh());  //-- base (analysis) date
@@ -349,18 +351,18 @@ CGeopts::CGeopts(CGeopts* p, fieldset* v, int n, bool nearest, bool nearestValid
 
     n = 0;
     for (size_t i = 0; i < p->gpts_.count(); i++) {
-        double x = DBL_MAX;
+        double x        = DBL_MAX;
         double near_lat = DBL_MAX;
         double near_lon = DBL_MAX;
-        gpts_.set_rowIndex(i); // all row-based ops will operate on this row
+        gpts_.set_rowIndex(i);  // all row-based ops will operate on this row
         // if lat/lon are missing, then it will be DBL_MAX
         if (!gpts_.latlon_missing() && gpts_.isLocationValid()) {  // if lat/lon are missing, then it will be DBL_MAX
             if (nearest) {
                 if (storeLocs) {
                     MvGridPoint gridp = fld->nearestGridpointInfo(gpts_.lon_x(), gpts_.lat_y(), nearestValid);
-                    near_lat = gridp.loc_.latitude();
-                    near_lon = gridp.loc_.longitude();
-                    x = gridp.value_;
+                    near_lat          = gridp.loc_.latitude();
+                    near_lon          = gridp.loc_.longitude();
+                    x                 = gridp.value_;
                 }
                 else
                     x = fld->nearestGridpoint(gpts_.lon_x(), gpts_.lat_y(), nearestValid);
@@ -444,7 +446,7 @@ void CGeopts::ToRequest(request*& s)
 
 
 // NOTE: this function could be put into the MvGeoPoints class if needed
-bool const CGeopts::doesMetadataMatch(const request* r)
+bool CGeopts::doesMetadataMatch(const request* r)
 {
     // for each parameter in the request, check that it exists in the metadata
     // and its value matches
@@ -457,8 +459,8 @@ bool const CGeopts::doesMetadataMatch(const request* r)
 
         if (key) {
             // loop through all the given values for this key - succeed if any match
-            bool doesThisKeyMatch                = false;
-            MvGeoPoints::metadata_t::iterator it = md.find(key);
+            bool doesThisKeyMatch = false;
+            auto it               = md.find(key);
 
             if (it == md.end())  // key not found
                 return false;
@@ -543,10 +545,13 @@ std::string CGeopts::SetColumnValues(eGeoColType col, Value& newVals, bool isLis
         gpts_.set_rowIndex(i);
         if (isList) {
             vtype listElementType = (*lst)[i].GetType();
-            if (listElementType == tnumber)
+            if (listElementType == tnumber) {
                 (*lst)[i].GetValue(cur);  //-- if list and current list element is number
-            else if (listElementType == tnil)
-                {} // id remains ""
+                if (is_number_nan_d(cur))  // nans can come from Python
+                    cur = val;  // missing
+            }
+            else if (listElementType == tnil) {
+            }  // id remains ""
             else if (listElementType == tdate) {
                 (*lst)[i].GetValue(d);
                 isDate = true;
@@ -576,7 +581,7 @@ std::string CGeopts::SetColumnValues(eGeoColType col, Value& newVals, bool isLis
 
             case eGeoColElevation:
                 gpts_.set_elevation(cur);
-                gpts_.hasElevations(true); // record that we have a 'real' elevation
+                gpts_.hasElevations(true);  // record that we have a 'real' elevation
                 break;
 
             case eGeoColDate:
@@ -600,7 +605,7 @@ std::string CGeopts::SetColumnValues(eGeoColType col, Value& newVals, bool isLis
 
             case eGeoColStnId:
                 gpts_.set_stnid(id);
-                gpts_.hasStnIds(true); // record that we have a 'real' stnid
+                gpts_.hasStnIds(true);  // record that we have a 'real' stnid
                 break;
 
             case eGeoColError:
@@ -623,7 +628,7 @@ void CGeopts::SetSubValue(Value& v, int arity, Value* arg)
     bool isList             = v.GetType() == tlist;
     bool isVector           = v.GetType() == tvector;
     bool valueIndexProvided = false;
-    Value* valueIndex       = NULL;
+    Value* valueIndex       = nullptr;
 
 
     // standard column names
@@ -665,7 +670,7 @@ class CountGeoFunction : public Function
 {
 public:
     CountGeoFunction(const char* n) :
-        Function(n, 1, tgeopts){};
+        Function(n, 1, tgeopts) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -685,7 +690,7 @@ class MaxGeoFunction : public Function
 public:
     MaxGeoFunction(const char* n, int m) :
         Function(n, 1, tgeopts),
-        usemax(m){};
+        usemax(m) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -753,7 +758,7 @@ class FilterBoxFunction : public Function
 {
 public:
     FilterBoxFunction(const char* n) :
-        Function(n){};
+        Function(n) {}
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
@@ -776,7 +781,7 @@ Value FilterBoxFunction::Execute(int arity, Value* arg)
     MvGeoBox myArea(d[0], d[1], d[2], d[3]);
 
     g->load();
-    CGeopts* x = new CGeopts(g);
+    auto* x = new CGeopts(g);
 
     int n = 0;
     for (size_t i = 0; i < g->Count(); i++) {
@@ -840,7 +845,7 @@ class FilterLevelFunction : public Function
 {
 public:
     FilterLevelFunction(const char* n) :
-        Function(n){};
+        Function(n) {}
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
@@ -880,7 +885,7 @@ Value FilterLevelFunction::Execute(int arity, Value* arg)
 
     g->load();
 
-    CGeopts* x = new CGeopts(g);
+    auto* x = new CGeopts(g);
 
     int n = 0;
 
@@ -890,7 +895,7 @@ Value FilterLevelFunction::Execute(int arity, Value* arg)
         }
     }
 
-     x->SetSize(n);
+    x->SetSize(n);
 
     g->unload();
     x->unload();
@@ -946,7 +951,7 @@ class FilterDateFunction : public Function
 {
 public:
     FilterDateFunction(const char* n) :
-        Function(n){};
+        Function(n) {}
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
@@ -981,7 +986,7 @@ Value FilterDateFunction::Execute(int arity, Value* arg)
 
     g->load();
 
-    CGeopts* x = new CGeopts(g);
+    auto* x = new CGeopts(g);
 
     int n = 0;
 
@@ -989,7 +994,6 @@ Value FilterDateFunction::Execute(int arity, Value* arg)
         Date date(g->gpts().date(r), g->gpts().time(r));
         if (d1 <= date && date <= d2)
             x->gpts().copyRow(g->gpts(), r, n++);
-
     }
     x->SetSize(n);
 
@@ -1060,7 +1064,7 @@ public:
     virtual Value Execute(int arity, Value* arg);
 };
 
-Value GeoMaskFunction::Execute(int arity, Value* arg)
+Value GeoMaskFunction::Execute(int /*arity*/, Value* arg)
 {
     CGeopts* g;
     int i;
@@ -1084,7 +1088,7 @@ Value GeoMaskFunction::Execute(int arity, Value* arg)
     MvGeoBox geoArea(n, w, s, e);
 
     g->load();
-    CGeopts* x = new CGeopts(g);
+    auto* x = new CGeopts(g);
 
     size_t m = 0;
     for (size_t i = 0; i < g->Count(); i++) {
@@ -1097,7 +1101,6 @@ Value GeoMaskFunction::Execute(int arity, Value* arg)
 }
 
 
-
 //-------------------------------------------------------------------
 
 
@@ -1119,7 +1122,7 @@ public:
         Function(n, 1, tgeopts)
     {
         info = "Copies a set of geopoints, removing missing values";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -1135,7 +1138,7 @@ Value RemoveMissingValuesFunction::Execute(int, Value* arg)
 
     g->load();
 
-    CGeopts* x = new CGeopts(g);
+    auto* x = new CGeopts(g);
 
 
     // for each input geopoint, only copy it over if it is not missing
@@ -1174,7 +1177,7 @@ public:
         Function(n, 1, tgeopts)
     {
         info = "Copies a set of geopoints, removing missing lat/lons";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -1189,7 +1192,7 @@ Value RemoveMissingLatLonsFunction::Execute(int, Value* arg)
 
     g->load();
 
-    CGeopts* x = new CGeopts(g);
+    auto* x = new CGeopts(g);
 
 
     // for each input geopoint, only copy it over if it is not missing
@@ -1320,7 +1323,7 @@ Value GeoIntBits::Execute(int arity, Value* arg)
         geo->gpts().set_rowIndex(r);
         geonew->gpts().set_rowIndex(r);
         value = (int)geo->gpts().value();  // take input value as an integer
-        bits  = value & bitmask;         // mask off the bits we want
+        bits  = value & bitmask;           // mask off the bits we want
 
         // shift the result down. For instance, if the 5th bit is set, we
         // just want the result to be 1 when checking for that bit. If
@@ -1353,7 +1356,7 @@ class GeoGetFieldFunction : public Function
     char expandedInfo[100];
 
 public:
-    GeoGetFieldFunction(const char* n, eGeoColType field, bool d, const char* fieldn, const char* nn = NULL) :
+    GeoGetFieldFunction(const char* n, eGeoColType field, bool d, const char* fieldn, const char* nn = nullptr) :
         Function(n),
         fieldtype(field),
         deprecated(d),
@@ -1419,7 +1422,7 @@ Value GeoGetFieldFunction::Execute(int arity, Value* arg)
     switch (fieldtype)  // which column do we wish to extract?
     {
         case eGeoColLevel: {
-            CVector* v = new CVector(g->Count());
+            auto* v = new CVector(g->Count());
 
             for (i = 0; i < g->Count(); i++)
                 v->setIndexedValue(i, g->gpts().height(i));
@@ -1429,10 +1432,9 @@ Value GeoGetFieldFunction::Execute(int arity, Value* arg)
         }
 
         case eGeoColLat: {
-            CVector* v = new CVector(g->Count());
+            auto* v = new CVector(g->Count());
 
-            for (i = 0; i < g->Count(); i++)
-            {
+            for (i = 0; i < g->Count(); i++) {
                 double value = g->gpts().lat_y(i);
                 if (value != GEOPOINTS_MISSING_VALUE)
                     v->setIndexedValue(i, value);
@@ -1445,10 +1447,9 @@ Value GeoGetFieldFunction::Execute(int arity, Value* arg)
         }
 
         case eGeoColLon: {
-            CVector* v = new CVector(g->Count());
+            auto* v = new CVector(g->Count());
 
-            for (i = 0; i < g->Count(); i++)
-            {
+            for (i = 0; i < g->Count(); i++) {
                 double value = g->gpts().lon_x(i);
                 if (value != GEOPOINTS_MISSING_VALUE)
                     v->setIndexedValue(i, value);
@@ -1461,7 +1462,7 @@ Value GeoGetFieldFunction::Execute(int arity, Value* arg)
         }
 
         case eGeoColDate: {
-            CList* v = new CList(g->Count());
+            auto* v = new CList(g->Count());
 
             for (i = 0; i < g->Count(); i++) {
                 Date d(g->gpts().date(i), g->gpts().time(i));
@@ -1473,7 +1474,7 @@ Value GeoGetFieldFunction::Execute(int arity, Value* arg)
         }
 
         case eGeoColTime: {
-            CVector* v = new CVector(g->Count());
+            auto* v = new CVector(g->Count());
 
             for (i = 0; i < g->Count(); i++)
                 v->setIndexedValue(i, g->gpts().time(i));
@@ -1485,15 +1486,15 @@ Value GeoGetFieldFunction::Execute(int arity, Value* arg)
         case eGeoColValue: {
             // strings are put into a list
             if (g->gpts().format() == eGeoString) {
-                CList* v = new CList(g->Count());
+                auto* v = new CList(g->Count());
                 for (i = 0; i < g->Count(); i++) {
-                    (*v)[i]= g->gpts().strValue(i).c_str();
+                    (*v)[i] = g->gpts().strValue(i).c_str();
                 }
                 return Value(v);
             }
             // numbers are put into a vector
             else {
-                CVector* v = new CVector(g->Count());
+                auto* v = new CVector(g->Count());
                 for (i = 0; i < g->Count(); i++) {
                     double value = g->gpts().ivalue(i, vit);
 
@@ -1508,7 +1509,7 @@ Value GeoGetFieldFunction::Execute(int arity, Value* arg)
         }
 
         case eGeoColValue2: {
-            CVector* v = new CVector(g->Count());
+            auto* v = new CVector(g->Count());
 
             for (i = 0; i < g->Count(); i++) {
                 double value = g->gpts().direc(i);
@@ -1523,7 +1524,7 @@ Value GeoGetFieldFunction::Execute(int arity, Value* arg)
         }
 
         case eGeoColStnId: {
-            CList* v = new CList(g->Count());
+            auto* v = new CList(g->Count());
             for (i = 0; i < g->Count(); i++) {
                 if (g->gpts().isStnIdEmpty(i))
                     (*v)[i] = Value();  // nil
@@ -1535,10 +1536,16 @@ Value GeoGetFieldFunction::Execute(int arity, Value* arg)
         }
 
         case eGeoColElevation: {
-            CVector* v = new CVector(g->Count());
+            auto* v = new CVector(g->Count());
 
-            for (i = 0; i < g->Count(); i++)
-                v->setIndexedValue(i, g->gpts().elevation(i));
+            for (i = 0; i < g->Count(); i++) {
+                double value = g->gpts().elevation(i);
+
+                if (value != GEOPOINTS_MISSING_VALUE)
+                    v->setIndexedValue(i, value);
+                else
+                    v->setIndexedValueToMissing(i);
+            }
 
             return Value(v);
             break;
@@ -1557,7 +1564,7 @@ class GeoFilterFunction : public Function
 {
 public:
     GeoFilterFunction(const char* n) :
-        Function(n){};
+        Function(n) {}
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
@@ -1577,7 +1584,7 @@ int GeoFilterFunction::ValidArguments(int arity, Value* arg)
 
 Value GeoFilterFunction::Execute(int, Value* arg)
 {
-    CGeopts* x = NULL;
+    CGeopts* x = nullptr;
     CGeopts* g;
     arg[0].GetValue(g);
     g->load();
@@ -1606,7 +1613,7 @@ Value GeoFilterFunction::Execute(int, Value* arg)
         CVector* v;
         arg[1].GetValue(v);
 
-        if (g->Count() != (size_t) v->Count())
+        if (g->Count() != (size_t)v->Count())
             return Error("filter: the geopoints and vector have different sizes");
 
         x = new CGeopts(g);
@@ -1630,7 +1637,7 @@ class GeoVectorFunction : public Function
 {
 public:
     GeoVectorFunction(const char* n) :
-        Function(n, 2, tgeopts, tgeopts){};
+        Function(n, 2, tgeopts, tgeopts) {}
     virtual Value Execute(int arity, Value* arg);
     virtual eGeoFormat vectorType() = 0;
 };
@@ -1642,7 +1649,7 @@ public:
         GeoVectorFunction(n)
     {
         info = "Combines two 1-parameter geopoints variables into polar vector style";
-    };
+    }
     virtual eGeoFormat vectorType() { return eGeoVectorPolar; }
 };
 
@@ -1653,7 +1660,7 @@ public:
         GeoVectorFunction(n)
     {
         info = "Combines two 1-parameter geopoints variables into u/v vector style";
-    };
+    }
     virtual eGeoFormat vectorType() { return eGeoVectorXY; }
 };
 
@@ -1669,7 +1676,7 @@ Value GeoVectorFunction::Execute(int, Value* arg)
     if (g->Count() != h->Count())
         return Error("The two geopoints have different sizes");
 
-    CGeopts* cgpts = new CGeopts(g);
+    auto* cgpts = new CGeopts(g);
     cgpts->gpts().set_format(vectorType());
     cgpts->gpts().setColumnsForFormat();
     cgpts->gpts().valuesColumn(0) = g->gpts().valuesColumn(0);
@@ -1688,7 +1695,7 @@ class GeoFromGribFunction1 : public Function
 {
 public:
     GeoFromGribFunction1(const char* n) :
-        Function(n, 2, tgrib, tgeopts){};
+        Function(n, 2, tgrib, tgeopts) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -1714,7 +1721,7 @@ public:
     virtual Value Execute(int arity, Value* arg);
 };
 
-Value GeoFromGribFunction2::Execute(int arity, Value* arg)
+Value GeoFromGribFunction2::Execute(int /*arity*/, Value* arg)
 {
     fieldset* v;
     CGeopts* g;
@@ -1730,9 +1737,11 @@ class GeoFromGribFunction3 : public Function
 {
 public:
     GeoFromGribFunction3(const char* n) :
-        Function(n), 
-                 validOptionString_("valid"), storeLocsOptionString_("store_locs"),
-                 valid_(false), storeLocs_(false) {}
+        Function(n),
+        validOptionString_("valid"),
+        storeLocsOptionString_("store_locs"),
+        valid_(false),
+        storeLocs_(false) {}
     int ValidArguments(int arity, Value* arg);
     virtual Value Execute(int arity, Value* arg);
 
@@ -1751,26 +1760,27 @@ int GeoFromGribFunction3::ValidArguments(int arity, Value* arg)
         return false;
 
     // the 3rd and optional 4th args are string parameters
-    for (int a = 2; a <= arity-1; a++) {
+    for (int a = 2; a <= arity - 1; a++) {
         if (arg[a].GetType() == tstring) {
             const char* tmpCh;
             arg[a].GetValue(tmpCh);
             if (tmpCh) {
-                if (strcmp(tmpCh,validOptionString_.c_str()) == 0)
+                if (strcmp(tmpCh, validOptionString_.c_str()) == 0)
                     valid_ = true;
-                if (strcmp(tmpCh,storeLocsOptionString_.c_str()) == 0)
+                if (strcmp(tmpCh, storeLocsOptionString_.c_str()) == 0)
                     storeLocs_ = true;
             }
             if (!valid_ && !storeLocs_)
                 return false;
-        } else {
+        }
+        else {
             return false;
         }
     }
     return true;
 }
 
-Value GeoFromGribFunction3::Execute(int arity, Value* arg)
+Value GeoFromGribFunction3::Execute(int /*arity*/, Value* arg)
 {
     fieldset* v;
     CGeopts* g;
@@ -1810,7 +1820,7 @@ class SubGeoFunction : public Function
 public:
     SubGeoFunction(const char* n) :
         Function(n),
-        indexByNumber_(true){};
+        indexByNumber_(true) {}
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
@@ -1842,7 +1852,7 @@ Value SubGeoFunction::Execute(int, Value* arg)
     arg[0].GetValue(p);
     p->load();
 
-    request* r = empty_request(NULL);
+    request* r = empty_request(nullptr);
 
     // index by number? then return a definition with that single indexed geopoint
     if (indexByNumber_) {
@@ -1864,7 +1874,7 @@ Value SubGeoFunction::Execute(int, Value* arg)
         set_value(r, "value_missing", "%d", g.value_missing() ? 1 : 0);
 
         //-- valid only for geovectors
-        double direc = (g.nValCols() > 1) ? g.direc() : 0;
+        double direc       = (g.nValCols() > 1) ? g.direc() : 0;
         bool direc_missing = (g.nValCols() > 1) ? g.direc_missing() : false;
         set_value(r, "value2", "%g", direc);
         set_value(r, "value2_missing", "%d", direc_missing ? 1 : 0);
@@ -1957,7 +1967,7 @@ Value GeoUnOp::Execute(int, Value* arg)
             p->gpts().set_rowIndex(r);
             if (g->gpts().value_missing(c))      // if the input value is missing
                 p->gpts().set_value_missing(c);  // set the output value to missing
-            else                               // otherwise, compute with (first) value
+            else                                 // otherwise, compute with (first) value
                 p->gpts().set_ivalue(F_(g->gpts().ivalue(c)), r, c);
         }
     }
@@ -1989,7 +1999,7 @@ Value GribGeoBinOp::Execute(int, Value* arg)
         arg[0].GetValue(v);
         arg[1].GetValue(g);
 
-        CGeopts* p = new CGeopts(g, v, 0, false, false, false);
+        auto* p = new CGeopts(g, v, 0, false, false, false);
 
 
         // for each point,
@@ -2012,7 +2022,7 @@ Value GribGeoBinOp::Execute(int, Value* arg)
         arg[0].GetValue(g);
         arg[1].GetValue(v);
 
-        CGeopts* p = new CGeopts(g, v, 0, false, false, false);
+        auto* p = new CGeopts(g, v, 0, false, false, false);
 
 
         // for each point,
@@ -2067,7 +2077,7 @@ Value NumGeoBinOp::Execute(int, Value* arg)
         arg[0].GetValue(d);
         arg[1].GetValue(g);
 
-        CGeopts* p = new CGeopts(g);
+        auto* p = new CGeopts(g);
 
         // for each point,
         //   if the geopoint value is missing
@@ -2096,7 +2106,7 @@ Value NumGeoBinOp::Execute(int, Value* arg)
         arg[0].GetValue(g);
         arg[1].GetValue(d);
 
-        CGeopts* p = new CGeopts(g);
+        auto* p = new CGeopts(g);
 
 
         // for each point,
@@ -2162,7 +2172,7 @@ Value GeoGeoBinOp::Execute(int, Value* arg)
         return Error("geopoints do not have the same number of value columns");
 
 
-    CGeopts* p = new CGeopts(g);
+    auto* p = new CGeopts(g);
 
     size_t ncols = g->gpts().nValColsForCompute();
     for (size_t c = 0; c < ncols; c++) {
@@ -2240,7 +2250,7 @@ public:
         compute_mean(m)
     {
         info = "Returns the sum or mean of the values in a geopoints variable";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -2295,7 +2305,7 @@ class GeoDistanceFunction : public Function
 {
 public:
     GeoDistanceFunction(const char* n) :
-        Function(n){};
+        Function(n) {}
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
@@ -2325,14 +2335,13 @@ Value GeoDistanceFunction::Execute(int arity, Value* arg)
 
     g->load();
 
-    CGeopts* x = new CGeopts(g);
+    auto* x = new CGeopts(g);
 
     for (size_t i = 0; i < g->Count(); i++) {
-        lat = g->gpts().lat_y(i);
-        lon = g->gpts().lon_x(i);
+        lat         = g->gpts().lat_y(i);
+        lon         = g->gpts().lon_x(i);
         double dist = GEOPOINTS_MISSING_VALUE;
-        if (lat != GEOPOINTS_MISSING_VALUE && lon != GEOPOINTS_MISSING_VALUE)
-        {
+        if (lat != GEOPOINTS_MISSING_VALUE && lon != GEOPOINTS_MISSING_VALUE) {
             point.set(lat, lon);
             dist = point.distanceInMeters(centre);
         }
@@ -2406,7 +2415,7 @@ public:
         Function(n, 2, tgeopts, tgeopts)
     {
         info = "Merges 2 sets of geopoints";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -2475,7 +2484,7 @@ public:
         Function(n)
     {
         info = "Creates a new set of geopoints";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
     std::string removeTrailingS(const std::string& str);
 };
@@ -2495,7 +2504,7 @@ std::string GeoCreateFunction::removeTrailingS(const std::string& str)
 
 Value GeoCreateFunction::Execute(int arity, Value* arg)
 {
-    CGeopts* gnew = NULL;
+    CGeopts* gnew = nullptr;
     int n;
     int nv           = 1;
     int numUserCols  = 0;
@@ -2587,12 +2596,11 @@ Value GeoCreateFunction::Execute(int arity, Value* arg)
                             return Error("create_geo: unrecognised type: %s", typeName);
                         continue;
                     }
-                    
+
                     // also on the first pass: count the number of user-defined value columns
                     else {
-                        if (efmt == eGeoNCols && 
-                               (MvGeoPoints::colTypeFromName(removeTrailingS(param), true) == eGeoColError
-                             || MvGeoPoints::colTypeFromName(removeTrailingS(param), true) == eGeoColValue)) {
+                        if (efmt == eGeoNCols &&
+                            (MvGeoPoints::colTypeFromName(removeTrailingS(param), true) == eGeoColError || MvGeoPoints::colTypeFromName(removeTrailingS(param), true) == eGeoColValue)) {
                             numUserCols++;
                         }
                     }
@@ -2606,7 +2614,7 @@ Value GeoCreateFunction::Execute(int arity, Value* arg)
                         continue;
 
                     // first column to set? if so, create the CGeopts with that many values
-                    if (gnew == NULL) {
+                    if (gnew == nullptr) {
                         CVector* vec;
                         value.GetValue(vec);
                         if (numUserCols == 0)  // always have at least one value column
@@ -2620,7 +2628,7 @@ Value GeoCreateFunction::Execute(int arity, Value* arg)
                     bool isList              = (value.GetType() == tlist);
                     bool isVector            = (value.GetType() == tvector);
                     bool valueIndexProvided  = false;
-                    Value* indexValue        = NULL;
+                    Value* indexValue        = nullptr;
                     eGeoColType colTypeToSet = colType;
 
                     // column name not one of our standard ones, e.g. latitude?
@@ -2628,7 +2636,7 @@ Value GeoCreateFunction::Execute(int arity, Value* arg)
                         // user-defined column?
                         if (efmt == eGeoNCols) {
                             valueIndexProvided = true;
-                            indexValue = &arg[i];
+                            indexValue         = &arg[i];
                             gnew->gpts().addColName(colName);
                             colTypeToSet = eGeoColValue;
                         }
@@ -2659,7 +2667,7 @@ public:
         Function(n, 1, tgeopts)
     {
         info = "Returns the subtype of a geopoints variable";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -2699,7 +2707,7 @@ public:
         type(t)
     {
         info = "Returns a list of column names for a geopoints variable";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -2710,13 +2718,13 @@ Value GeoColumnsFunction::Execute(int, Value* arg)
 
     g->load();
 
-    const vector<string> colNames = (type == GCRT_ALL)
-                                        ? g->gpts().usedColNames()
-                                        : g->gpts().valueColNames();
+    const std::vector<std::string> colNames = (type == GCRT_ALL)
+                                                  ? g->gpts().usedColNames()
+                                                  : g->gpts().valueColNames();
 
     size_t ncols = colNames.size();
     if (ncols > 0) {
-        CList* l   = new CList(ncols);
+        auto* l = new CList(ncols);
         for (size_t i = 0; i < ncols; i++) {
             (*l)[i] = colNames[i].c_str();
         }
@@ -2735,7 +2743,7 @@ public:
         Function(n, 1, tgeopts)
     {
         info = "Sorts the geopoints North to South and West to East";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -2747,7 +2755,7 @@ Value GeoSortFunction::Execute(int, Value* arg)
     g->load();
     g->sort();
 
-    CGeopts* x = new CGeopts(g);
+    auto* x = new CGeopts(g);
 
 
     // XXX it looks as though this function modifies the input geopoints
@@ -2767,7 +2775,7 @@ public:
         Function(n, 2, tgeopts, tgeopts)
     {
         info = "Filters from the first geopoints variable points that exist in the second";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -2785,15 +2793,15 @@ Value GeoSubsampleFunction::Execute(int, Value* arg)
     g1->sort();
     g2->sort();
 
-    CGeopts* gx = new CGeopts(g2);
+    auto* gx = new CGeopts(g2);
 
-    MvGeoPoints &gp1 = g1->gpts();
-    MvGeoPoints &gp2 = g2->gpts();
-    MvGeoPoints &gpx = gx->gpts();
-    size_t count_g1 = g1->Count();
-    size_t count_g2 = g2->Count();
-    size_t rx       = 0;
-    size_t rg1      = 0;
+    MvGeoPoints& gp1 = g1->gpts();
+    MvGeoPoints& gp2 = g2->gpts();
+    MvGeoPoints& gpx = gx->gpts();
+    size_t count_g1  = g1->Count();
+    size_t count_g2  = g2->Count();
+    size_t rx        = 0;
+    size_t rg1       = 0;
     for (size_t rg2 = 0; rg2 < count_g2; ++rg2) {
         // both sets of gpts are sorted geographically, so we can immediately
         // discard any points that are outside the bounds of our source points
@@ -2801,11 +2809,11 @@ Value GeoSubsampleFunction::Execute(int, Value* arg)
             ++rg1;
 
         if (rg1 < count_g1 && gp1.sameLocation(gp2, rg1, rg2)) {
-            gpx.copyRow(gp1, rg1++, rx); //-- g2 location exists in g1
+            gpx.copyRow(gp1, rg1++, rx);  //-- g2 location exists in g1
         }
         else {
             gpx.copyRow(gp2, rg2, rx);
-            gpx.set_value_missing(rx, 0);   //-- g2 location missing in g1
+            gpx.set_value_missing(rx, 0);  //-- g2 location missing in g1
             if (gpx.have_direc())
                 gpx.set_direc_missing(rx);
         }
@@ -2832,7 +2840,7 @@ public:
         Function(n)
     {
         info = "Offsets the locations of geopoints";
-    };
+    }
     virtual int ValidArguments(int arity, Value* arg);
     virtual Value Execute(int arity, Value* arg);
 };
@@ -2892,7 +2900,7 @@ Value GeoOffsetFunction::Execute(int, Value* arg)
     arg[0].GetValue(g);
     g->load();
 
-    CGeopts* x = new CGeopts(g);
+    auto* x = new CGeopts(g);
 
     g->unload();
 
@@ -2911,7 +2919,7 @@ public:
         Function(n, 1, tgeopts)
     {
         info = "Removes geopoint duplicates";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -2923,7 +2931,7 @@ Value GeoRemoveDuplicatesFunction::Execute(int, Value* arg)
     g->load();
     g->removeDuplicates();
 
-    CGeopts* x = new CGeopts(g);
+    auto* x = new CGeopts(g);
 
     // XXX it looks as though this function modifies the input geopoints
     // - is this intentional?
@@ -2950,7 +2958,7 @@ class GeoSetFunction : public Function
     char expandedInfo[100];
 
 public:
-    GeoSetFunction(const char* n, eGeoColType c, bool d, const char* fieldn, const char* nn = NULL) :
+    GeoSetFunction(const char* n, eGeoColType c, bool d, const char* fieldn, const char* nn = nullptr) :
         Function(n),
         col(c),
         deprecated(d),
@@ -3024,16 +3032,15 @@ Value GeoSetFunction::Execute(int, Value* arg)
     }
 
 
-
     // value index provided? check for correctness
-    Value* indexValPtr = NULL;
+    Value* indexValPtr = nullptr;
     Value indexVal;
     if (valueIndexProvided) {
         indexValPtr = &(arg[1]);
     }
 
     g->load();
-    CGeopts* x = new CGeopts(g);  //-- create a copy of input geopoints
+    auto* x = new CGeopts(g);  //-- create a copy of input geopoints
 
 
     std::string errmsg = x->SetColumnValues(col, arg[indexOfValueArg], isList, isVector, valueIndexProvided, indexValPtr);
@@ -3056,13 +3063,13 @@ public:
         Function(n, 1, tgeopts)
     {
         info = "Returns a metadata definition from the given geopoints.";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
 Value GeoMetadataFunction::Execute(int, Value* arg)
 {
-    request* r = empty_request(NULL);
+    request* r = empty_request(nullptr);
 
     CGeopts* g;
     arg[0].GetValue(g);
@@ -3070,15 +3077,15 @@ Value GeoMetadataFunction::Execute(int, Value* arg)
 
     MvGeoPoints::metadata_t& md = g->gpts().metadata();
     if (md.size() > 0) {
-        for (MvGeoPoints::metadata_t::iterator it = md.begin(); it != md.end(); ++it)
-            set_value(r, (it->first).c_str(), "%s", (it->second).toString().c_str());
+        for (auto& it : md)
+            set_value(r, (it.first).c_str(), "%s", (it.second).toString().c_str());
 
         g->unload();
         return Value(r);
     }
     else {
         g->unload();
-        request* r = empty_request(NULL); // return an empty request if no metadata
+        request* r = empty_request(nullptr);  // return an empty request if no metadata
         return Value(r);
     }
 }
@@ -3091,20 +3098,20 @@ public:
         Function(n, 2, tgeopts, trequest)
     {
         info = "Sets a geopoints metadata from a definition";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
 Value GeoSetMetadataFunction::Execute(int, Value* arg)
 {
-    request* r = empty_request(NULL);
+    request* r = empty_request(nullptr);
     CGeopts* g;
     arg[0].GetValue(g);
     arg[1].GetValue(r);
     g->load();
-    CGeopts* newg = new CGeopts(g);  // create a clone of the input geopoints
+    auto* newg = new CGeopts(g);  // create a clone of the input geopoints
 
-    MvGeoPoints::metadata_t& md = newg->gpts().metadata();
+    auto& md = newg->gpts().metadata();
     md.clear();
 
     // loop through the request/definition and add each element to the metadata map
@@ -3129,7 +3136,7 @@ public:
         Function(n)
     {
         info = "Returns a string of the database from the given geopoints.";
-    };
+    }
     virtual int ValidArguments(int arity, Value* arg);
     virtual Value Execute(int arity, Value* arg);
 };
@@ -3147,7 +3154,7 @@ int GeoDbFunction::ValidArguments(int arity, Value* arg)
         if (arity == 3) {
             const char* cval;
             arg[1].GetValue(cval);
-            string db_item = cval;
+            std::string db_item = cval;
 
             if (arg[2].GetType() == tstring &&
                 (db_item == "column" || db_item == "alias")) {
@@ -3170,7 +3177,7 @@ Value GeoDbFunction::Execute(int, Value* arg)
     g->load();
 
     const char* cval;
-    string db_item;
+    std::string db_item;
     arg[1].GetValue(cval);
 
     db_item = cval;
@@ -3183,7 +3190,6 @@ Value GeoDbFunction::Execute(int, Value* arg)
         arg[2].GetValue(col);
 
         return Value(g->gpts().dbColumn(col).c_str());
-        ;
     }
     else if (db_item == "alias") {
         const char* col;
@@ -3197,7 +3203,7 @@ Value GeoDbFunction::Execute(int, Value* arg)
     else if (db_item == "query") {
         int n = g->gpts().dbQuery().size();
 
-        CList* v = new CList(n);
+        auto* v = new CList(n);
 
         for (unsigned int i = 0; i < g->gpts().dbQuery().size(); i++) {
             (*v)[i] = g->gpts().dbQuery().at(i).c_str();
