@@ -15,6 +15,7 @@ an Intergovernmental Organization or submit itself to any jurisdiction.
 #include <memory>
 #include <ostream>
 #include <string>
+#include <utility>
 #include <vector>
 
 #include "eckit/config/LibEcKit.h"
@@ -32,17 +33,17 @@ an Intergovernmental Organization or submit itself to any jurisdiction.
 #include "mir/util/Trace.h"
 
 #include "MvApplication.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 
 //--------------------------------------------------------
 
 
-namespace {
-
-
+namespace
+{
 // hardcoded defaults
-struct defaults_t {
+struct defaults_t
+{
     static constexpr auto grid_definition_mode = "grid";
     static constexpr auto debug                = false;
     static constexpr double first_point[]      = {0., 0.};
@@ -50,7 +51,8 @@ struct defaults_t {
 };
 
 
-std::string sane_key(const std::string& insane) {
+std::string sane_key(const std::string& insane)
+{
     std::string sane(insane);
     std::transform(insane.begin(), insane.end(), sane.begin(),
                    [=](unsigned char c) { return std::isalnum(c) != 0 ? std::toupper(c) : '_'; });
@@ -58,7 +60,8 @@ std::string sane_key(const std::string& insane) {
 }
 
 
-std::string sane_value(const std::string& insane) {
+std::string sane_value(const std::string& insane)
+{
     std::string sane(insane);
     std::transform(insane.begin(), insane.end(), sane.begin(),
                    [=](unsigned char c) { return std::isalnum(c) != 0 ? std::tolower(c) : '-'; });
@@ -67,15 +70,18 @@ std::string sane_value(const std::string& insane) {
 
 
 // Use MvRequest satisfying MIRParametrisation interface
-class RequestWrapper final : public mir::param::MIRParametrisation {
+class RequestWrapper final : public mir::param::MIRParametrisation
+{
 public:
-    RequestWrapper(const MvRequest& request) : request_(request) {}
+    explicit RequestWrapper(const MvRequest& request) :
+        request_(request) {}
 
     // From MIRParametrisation
     const MIRParametrisation& userParametrisation() const override { return *this; }
     const MIRParametrisation& fieldParametrisation() const override { return *this; }
 
-    bool has(const std::string& name) const override {
+    bool has(const std::string& name) const override
+    {
         auto sane     = sane_key(name);
         const char* v = request_(sane.c_str());
         return (v != nullptr) && (strlen(v) > 0);
@@ -100,7 +106,8 @@ private:
     void print(std::ostream& s) const override { s << "MvRequest[" << request_ << "]"; }
 
     template <typename T>
-    bool _getValue(const std::string& name, T& value) const {
+    bool _getValue(const std::string& name, T& value) const
+    {
         auto sane     = sane_key(name);
         const char* v = request_(sane.c_str());
         if ((v != nullptr) && (strlen(v) > 0)) {
@@ -111,9 +118,10 @@ private:
     }
 
     template <typename T>
-    bool _getVector(const std::string& name, std::vector<T>& value) const {
+    bool _getVector(const std::string& name, std::vector<T>& value) const
+    {
         auto sane     = sane_key(name);
-        auto k        = sane.c_str();
+        const auto* k = sane.c_str();
         const char* v = request_(k);
         if (v != nullptr && strlen(v) > 0) {
             auto c = size_t(request_.countValues(k));
@@ -135,19 +143,24 @@ private:
 };
 
 
-class JobWrapper final : public mir::api::MIRJob {
+class JobWrapper final : public mir::api::MIRJob
+{
     std::string source_;
     std::string target_;
+    int target_is_temporary_;  // 'int' because that is what we pass to the output request
 
 public:
     const std::string& source() const { return source_; }
     const std::string& target() const { return target_; }
+    const int target_is_temporary() const { return target_is_temporary_; }
     void source(const std::string& path) { source_ = path; }
     void target(const std::string& path) { target_ = path; }
+    void target_is_temporary(int temp) { target_is_temporary_ = temp; }
 };
 
 
-std::string get_path(const RequestWrapper& param, const std::string& pathKey, const std::string& dataKey) {
+std::string get_path(const RequestWrapper& param, const std::string& pathKey, const std::string& dataKey)
+{
     std::string path;
     if (!param.get(pathKey, path) || path.empty()) {
         MvRequest data;
@@ -162,55 +175,71 @@ std::string get_path(const RequestWrapper& param, const std::string& pathKey, co
 }
 
 
-struct Param {
-    Param(MvProtocol& protocol, const std::string& name) : name_(name), protocol_(protocol) {}
+struct Param
+{
+    Param(MvProtocol& protocol, std::string name) :
+        name_(std::move(name)), protocol_(protocol) {}
+
+    Param(const Param&) = delete;
+    Param(Param&&)      = delete;
+    void operator=(const Param&) = delete;
+    void operator=(Param&&) = delete;
+
     virtual ~Param() = default;
 
     virtual void eval(const RequestWrapper&, JobWrapper&) const = 0;
-    const std::string name_;
     void error(const std::string& msg) const { const_cast<MvProtocol&>(protocol_).setError(1, msg.c_str()); }
+    const std::string& name() const { return name_; }
 
 private:
+    const std::string name_;
     MvProtocol& protocol_;
 };
 
 
 template <typename T>
-struct ParamT : Param {
+struct ParamT : Param
+{
     using Param::Param;
 
-    void eval(const RequestWrapper& param, JobWrapper& job) const override {
+    void eval(const RequestWrapper& param, JobWrapper& job) const override
+    {
         T value;
-        if (param.get(name_, value)) {
-            job.set(name_, value);
+        if (param.get(name(), value)) {
+            job.set(name(), value);
         }
     }
 };
 
 
 template <>
-void ParamT<std::string>::eval(const RequestWrapper& param, JobWrapper& job) const {
+void ParamT<std::string>::eval(const RequestWrapper& param, JobWrapper& job) const
+{
     std::string value;
-    if (param.get(name_, value) && !value.empty()) {
-        job.set(name_, sane_value(value));  // sanitize strings
+    if (param.get(name(), value) && !value.empty()) {
+        job.set(name(), sane_value(value));  // sanitize strings
     }
 };
 
 
 template <typename T>
-struct ParamVectorT : Param {
-    ParamVectorT(MvProtocol& protocol, const std::string& name, size_t n = 0) : Param(protocol, name), n_(n) {}
+struct ParamVectorT : Param
+{
+    ParamVectorT(MvProtocol& protocol, const std::string& name, size_t n = 0) :
+        Param(protocol, name), n_(n) {}
 
-    void eval(const RequestWrapper& param, JobWrapper& job) const override {
+    void eval(const RequestWrapper& param, JobWrapper& job) const override
+    {
         std::vector<T> value;
         if (get(param, value)) {
-            job.set(name_, value);
+            job.set(name(), value);
         }
     }
 
-    bool get(const mir::param::MIRParametrisation& param, std::vector<T>& value) const {
+    bool get(const mir::param::MIRParametrisation& param, std::vector<T>& value) const
+    {
         std::vector<T> v;
-        if (param.get(name_, v)) {
+        if (param.get(name(), v)) {
             ASSERT(!v.empty());
             if (n_ == 0 || n_ == v.size()) {
                 value.swap(v);
@@ -220,40 +249,49 @@ struct ParamVectorT : Param {
         return false;
     }
 
+private:
     const size_t n_;
 };
 
 
-struct ParamArea final : ParamVectorT<double> {
-    ParamArea(MvProtocol& protocol, const std::string& name) : ParamVectorT(protocol, name, 4) {}
+struct ParamArea final : ParamVectorT<double>
+{
+    ParamArea(MvProtocol& protocol, const std::string& name) :
+        ParamVectorT(protocol, name, 4) {}
 
-    void eval(const RequestWrapper& param, JobWrapper& job) const override {
+    void eval(const RequestWrapper& param, JobWrapper& job) const override
+    {
         std::vector<double> value;
         if (get(param, value)) {
             ASSERT(value.size() == 4);
             std::vector<double> area{value[2] /*N*/, value[1] /*W*/, value[0] /*S*/, value[3] /*E*/};
-            job.set(name_, area);
+            job.set(name(), area);
         }
     }
 };
 
 
-struct ParamMultiDimensional final : Param {
+struct ParamMultiDimensional final : Param
+{
     using Param::Param;
 
-    void eval(const RequestWrapper& param, JobWrapper& job) const override {
+    void eval(const RequestWrapper& param, JobWrapper& job) const override
+    {
         long value = defaults_t::multi_dimensional;
-        if (param.get(name_, value) && value > 1) {
+        if (param.get(name(), value) && value > 1) {
             job.set("input", "{multiDimensional: " + std::to_string(value) + "}");
         }
     }
 };
 
 
-struct SetupInput final : Param {
-    SetupInput(MvProtocol& protocol) : Param(protocol, "source") {}
+struct SetupInput final : Param
+{
+    explicit SetupInput(MvProtocol& protocol) :
+        Param(protocol, "source") {}
 
-    void eval(const RequestWrapper& param, JobWrapper& job) const override {
+    void eval(const RequestWrapper& param, JobWrapper& job) const override
+    {
         auto src = get_path(param, "SOURCE", "DATA");
         if (src.empty()) {
             error("Regrid: 'SOURCE' or 'DATA' must be defined");
@@ -265,11 +303,14 @@ struct SetupInput final : Param {
 };
 
 
-struct SetupOutput final : Param {
-    SetupOutput(MvProtocol& protocol) : Param(protocol, "grid-definition-mode") {}
+struct SetupOutput final : Param
+{
+    explicit SetupOutput(MvProtocol& protocol) :
+        Param(protocol, "grid-definition-mode") {}
 
 private:
-    std::string mandatory_key(const RequestWrapper& param, const std::string& fromKey, const std::string& toKey) const {
+    std::string mandatory_key(const RequestWrapper& param, const std::string& fromKey, const std::string& toKey) const
+    {
         std::string value;
         if (!param.get(fromKey, value) || value.empty()) {
             error("Regrid: key '" + sane_key(fromKey) + "' must be defined");
@@ -278,7 +319,8 @@ private:
     }
 
     std::string mandatory_keys(const RequestWrapper& param, const std::string& fromKey1, const std::string& fromKey2,
-                               const std::string& toKey) const {
+                               const std::string& toKey) const
+    {
         bool ok = true;
 
         std::string value1;
@@ -296,8 +338,9 @@ private:
         return ok ? ";" + toKey + "=" + value1 + "/" + value2 : "";
     }
 
-    std::string first_point_keys(const RequestWrapper& param, const std::string& fromKey, const std::string& toKey1,
-                                 const std::string& toKey2) const {
+    static std::string first_point_keys(const RequestWrapper& param, const std::string& fromKey,
+                                        const std::string& toKey1, const std::string& toKey2)
+    {
         std::vector<double> value{defaults_t::first_point[0], defaults_t::first_point[1]};
         if (param.get(fromKey, value)) {
             ASSERT(value.size() == 2);
@@ -305,21 +348,38 @@ private:
         return ";" + toKey1 + "=" + std::to_string(value[0]) + ";" + toKey2 + "=" + std::to_string(value[1]);
     }
 
-    std::string optional_key(const RequestWrapper& param, const std::string& fromKey, const std::string& toKey) const {
+    static std::string optional_key(const RequestWrapper& param, const std::string& fromKey, const std::string& toKey)
+    {
         std::string value;
         return param.get(fromKey, value) && !value.empty() ? ";" + toKey + "=" + value : "";
     }
 
-    void eval(const RequestWrapper& param, JobWrapper& job) const override {
+    void eval(const RequestWrapper& param, JobWrapper& job) const override
+    {
         // requires prior setup of input, sets temporary output
         ASSERT(!job.source().empty());
         ASSERT(job.target().empty());
 
+
+        std::string userTarget;
+        std::string outputPath;
+        int targetTemporary;
+        if (param.get("TARGET", userTarget)) {
+            outputPath = userTarget;
+            targetTemporary = 0;
+        }
+        else {
+            outputPath = marstmp();
+            targetTemporary = 1;
+        }
+
+
         // setup a temporary target
-        job.target(marstmp());
+        job.target(outputPath);
+        job.target_is_temporary(targetTemporary);
 
         std::string mode = defaults_t::grid_definition_mode;
-        param.get(name_, mode);
+        param.get(name(), mode);
         mode = sane_value(mode);
 
 
@@ -421,17 +481,19 @@ private:
             return;
         }
 
-        error("Regrid: key '" + sane_key(name_) + "' unrecognized value '" + mode + "'");
+        error("Regrid: key '" + sane_key(name()) + "' unrecognized value '" + mode + "'");
     }
 };
 
 
-struct SetupWindProcessing final : Param {
+struct SetupWindProcessing final : Param
+{
     using Param::Param;
 
-    void eval(const RequestWrapper& param, JobWrapper& job) const override {
+    void eval(const RequestWrapper& param, JobWrapper& job) const override
+    {
         std::string wind;
-        if (param.get(name_, wind) && !wind.empty()) {
+        if (param.get(name(), wind) && !wind.empty()) {
             wind = sane_value(wind);
 
             if (wind == "uv-to-uv") {
@@ -444,7 +506,7 @@ struct SetupWindProcessing final : Param {
                 return;
             }
 
-            error("Regrid: key '" + sane_key(name_) + "' unrecognized value '" + wind + "'");
+            error("Regrid: key '" + sane_key(name()) + "' unrecognized value '" + wind + "'");
         }
     }
 };
@@ -456,8 +518,9 @@ struct SetupWindProcessing final : Param {
 //--------------------------------------------------------
 
 
-void Regrid::serve(MvRequest& in, MvRequest& out) {
-    cout << "Regrid::serve in" << endl;
+void Regrid::serve(MvRequest& in, MvRequest& out)
+{
+    std::cout << "Regrid::serve in" << std::endl;
     out.clean();
     in.print();
 
@@ -472,15 +535,15 @@ void Regrid::serve(MvRequest& in, MvRequest& out) {
     mir::Log::debug().reset();
     eckit::Log::debug<eckit::LibEcKit>().reset();
 
-    mir::Log::info().setStream(cout);
-    mir::Log::warning().setStream(cerr);
-    mir::Log::error().setStream(cerr);
+    mir::Log::info().setStream(std::cout);
+    mir::Log::warning().setStream(std::cerr);
+    mir::Log::error().setStream(std::cerr);
 
     std::string debug;
     if (args.get("debug", debug) && !debug.empty() ? eckit::Translator<std::string, bool>()(debug)
                                                    : defaults_t::debug) {
-        mir::Log::debug().setStream(cout);
-        eckit::Log::debug<eckit::LibEcKit>().setStream(cout);
+        mir::Log::debug().setStream(std::cout);
+        eckit::Log::debug<eckit::LibEcKit>().setStream(std::cout);
     }
 
     static const std::vector<Param*> parameters{
@@ -525,6 +588,8 @@ void Regrid::serve(MvRequest& in, MvRequest& out) {
         new ParamT<std::string>(*this, "lsm-named-output"),
         new ParamT<std::string>(*this, "lsm-file-output"),
         new ParamT<double>(*this, "lsm-value-threshold-output"),
+        new ParamT<bool>(*this, "pre-globalise"),
+        new ParamT<bool>(*this, "globalise"),
         new ParamT<long>(*this, "accuracy"),
         new ParamT<std::string>(*this, "packing"),
         new ParamT<int>(*this, "edition"),
@@ -546,10 +611,10 @@ void Regrid::serve(MvRequest& in, MvRequest& out) {
     JobWrapper job;
     ASSERT(getError() == 0);
 
-    for (auto p : parameters) {
+    for (const auto* p : parameters) {
         p->eval(args, job);
         if (getError() != 0) {
-            mir::Log::error() << "Regrid: error in setup, cannot continue" << endl;
+            mir::Log::error() << "Regrid: error in setup, cannot continue" << std::endl;
             return;
         }
     }
@@ -569,11 +634,18 @@ void Regrid::serve(MvRequest& in, MvRequest& out) {
         job.set("style", "custom");
     }
 
-    // linear algebra backend
+    // linear algebra dense/sparse backends
+    // If we want to control the backend, we can move that to MIRJob
     std::string backend;
-    if (args.get("backend", backend)) {
-        // If we want to control the backend, we can move that to MIRJob
-        eckit::linalg::LinearAlgebra::backend(backend);
+    if (args.get("dense-backend", backend) || args.get("backend", backend)) {
+        if (eckit::linalg::LinearAlgebra::hasDenseBackend(backend)) {
+            eckit::linalg::LinearAlgebra::denseBackend(backend);
+        }
+    }
+    if (args.get("sparse-backend", backend) || args.get("backend", backend)) {
+        if (eckit::linalg::LinearAlgebra::hasSparseBackend(backend)) {
+            eckit::linalg::LinearAlgebra::sparseBackend(backend);
+        }
     }
 
 
@@ -592,21 +664,22 @@ void Regrid::serve(MvRequest& in, MvRequest& out) {
     // Set output
     out.setVerb("GRIB");
     out("PATH")      = job.target().c_str();
-    out("TEMPORARY") = 1;
+    out("TEMPORARY") = job.target_is_temporary();
 
 
-    cout << "Regrid::serve out" << endl;
+    std::cout << "Regrid::serve out" << std::endl;
     out.print();
 }
 
 
 void Regrid::process(const mir::api::MIRJob& job, mir::input::MIRInput& input, mir::output::MIROutput& output,
-                     const std::string& what) const {
+                     const std::string& what)
+{
     mir::trace::ResourceUsage usage("regrid");
     mir::trace::Timer timer("Total time");
 
     mir::util::MIRStatistics statistics;
-    mir::Log::debug() << "Using '" << eckit::linalg::LinearAlgebra::backend().name() << "' backend." << std::endl;
+    mir::Log::debug() << "Using '" << eckit::linalg::LinearAlgebra::backend() << std::endl;
 
     job.mirToolCall(mir::Log::debug());
 
@@ -626,7 +699,8 @@ void Regrid::process(const mir::api::MIRJob& job, mir::input::MIRInput& input, m
 //--------------------------------------------------------
 
 
-int main(int argc, char** argv) {
+int main(int argc, char** argv)
+{
     MvApplication theApp(argc, argv, "regrid");
     Regrid perc("REGRID");
 
