@@ -7,9 +7,13 @@
 
  ***************************** LICENSE END *************************************/
 
-#include <inc_iostream.h>
 #include <stdio.h>
 
+#include <cstring>
+#include <fstream>
+#include <iostream>
+#include "fstream_mars_fix.h"
+
 #include <gdbm.h>
 
 #include <fcntl.h>
@@ -62,7 +66,7 @@ void StationService::AddToResult(MvRequest& out, datum& key)
     station st;
 
     content = gdbm_fetch(db, key);
-    memcpy(&st, content.dptr, MIN(content.dsize, sizeof(st)));
+    std::memcpy(&st, content.dptr, MIN(content.dsize, sizeof(st)));
 
     AddToResult(out, st);
 }
@@ -88,7 +92,7 @@ void StationService::AddToResult(MvRequest& out, station& st)
 
 void StationService::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "StationService::serve() in" << endl;
+    std::cout << "StationService::serve() in" << std::endl;
     in.print();
 
     const char cIDENT = 'I';
@@ -160,14 +164,14 @@ void StationService::serve(MvRequest& in, MvRequest& out)
         }
     }
 
-    cout << "StationService::serve() out" << endl;
+    std::cout << "StationService::serve() out" << std::endl;
     out.print();
 }
 
 bool StationService::serve_WMO(MvRequest& in, MvRequest& out)
 {
     datum key, k;
-    const char* name = NULL;
+    const char* name = nullptr;
 
     if (open_database(mode)) {
         setError(1, "Station-> Cannot open database %s", getenv("METVIEW_STATIONS"));
@@ -189,7 +193,7 @@ bool StationService::serve_WMO(MvRequest& in, MvRequest& out)
 
                 key = gdbm_fetch(db, k);
 
-                if (key.dptr != NULL) {
+                if (key.dptr != nullptr) {
                     AddToResult(out, k);
                     gdbm_close(db);
                     return true;
@@ -206,7 +210,7 @@ bool StationService::serve_WMO(MvRequest& in, MvRequest& out)
 
                     key = gdbm_fetch(db, k);
 
-                    if (key.dptr != NULL) {
+                    if (key.dptr != nullptr) {
                         AddToResult(out, k);
                         gdbm_close(db);
                         return true;
@@ -216,24 +220,24 @@ bool StationService::serve_WMO(MvRequest& in, MvRequest& out)
 
         default:
             break;
-    };
+    }
 
     // If no match, loop
 
-    for (key = gdbm_firstkey(db); key.dptr != NULL; key = gdbm_nextkey(db, key)) {
+    for (key = gdbm_firstkey(db); key.dptr != nullptr; key = gdbm_nextkey(db, key)) {
         int m, ok = 0;
         int n = 0;
 
         switch (mode) { /* open database related to request */
 
             case 'n':
-                while ((name = in("NAME", n++)) != NULL)
+                while ((name = in("NAME", n++)) != nullptr)
                     if (same(name, (const char*)key.dptr))
                         ok = 1;
                 break;
 
             case 'i':
-                memcpy(&m, key.dptr, sizeof(m));
+                std::memcpy(&m, key.dptr, sizeof(m));
                 if (ident < 100)
                     ok = (m / 1000 == ident);
                 else
@@ -241,7 +245,7 @@ bool StationService::serve_WMO(MvRequest& in, MvRequest& out)
                 break;
 
             case 'l':
-                memcpy(&pos, key.dptr, sizeof(pos));
+                std::memcpy(&pos, key.dptr, sizeof(pos));
                 point_lat = ((double)pos.lat) / 100.0;
                 point_lon = ((double)pos.lon) / 100.0;
                 ok        = inbox(point_lat, point_lon, north, west, south, east);
@@ -272,7 +276,7 @@ bool StationService::serve_EPS(MvRequest& in, MvRequest& out)
 {
     //serve_WMO( in, out ); //-- not yet implementd, use WMO!!!!
     const char* name;
-    ifstream* EPS_file = 0;
+    std::ifstream* EPS_file = nullptr;
     station st;
 
     if (open_EPS_stationfile(EPS_file)) {
@@ -282,7 +286,7 @@ bool StationService::serve_EPS(MvRequest& in, MvRequest& out)
 
             switch (mode) {
                 case 'n':
-                    while ((name = in("NAME", n++)) != NULL)
+                    while ((name = in("NAME", n++)) != nullptr)
                         if (same(name, st.name))
                             ok = 1;
                     break;
