@@ -61,14 +61,14 @@ CrossS::CrossS(const char* kw) :
 void CrossS::init()
 {
     Xsect::init();
-    windProjection_ = NoWindProjection;
-    windMode_ = NoWindMode;
+    windProjection_   = NoWindProjection;
+    windMode_         = NoWindMode;
     useWindIntensity_ = false;
-    outputMode_ = ScalarOutput;
-    oroColour_ = "CYAN";
-    wScaling_ = -100;
-    wMode_ = Mv3VerticalVelocity;
-    plotVar_ = nullptr;
+    outputMode_       = ScalarOutput;
+    oroColour_        = "CYAN";
+    wScaling_         = -100;
+    wMode_            = Mv3VerticalVelocity;
+    plotVar_          = nullptr;
 }
 
 bool CrossS::getCoordinates(MvRequest& in, ApplicationInfo& appInfo)
@@ -95,17 +95,18 @@ bool CrossS::getAppParameters(MvRequest& in, ApplicationInfo& appInfo)
 
     // Retrieve Wind input info
     if (in.getValue("WIND_PARALLEL", val) && val == "ON") {
-            windProjection_ = ParallelWindProjection;
+        windProjection_ = ParallelWindProjection;
     }
 
     if (in.getValue("WIND_PERPENDICULAR", val) && val == "ON") {
         if (windProjection_ == ParallelWindProjection) {
             setError(1, "CrossS-> cannot set both WIND_PARALLEL and WIND_PERPENDICULAR to ON");
-                return false;
-            } else {
-                windProjection_ = NormalWindProjection;
-            }
-     }
+            return false;
+        }
+        else {
+            windProjection_ = NormalWindProjection;
+        }
+    }
 
     if (in.getValue("WIND_INTENSITY", val) && val == "ON") {
         useWindIntensity_ = true;
@@ -114,7 +115,7 @@ bool CrossS::getAppParameters(MvRequest& in, ApplicationInfo& appInfo)
     if (in.getValue("WIND_UNPROJECTED", val) && val == "ON") {
         if (useWindIntensity_) {
             setError(1, "CrossS-> cannot set both WIND_INTENSITY and WIND_UNPROJECTED to ON");
-                return false;
+            return false;
         }
         if (windProjection_ != NoWindProjection) {
             setError(1, "CrossS-> cannot set WIND_UNPROJECTED to ON when WIND_PARALLEL or WIND_PERPENDICULAR is ON");
@@ -144,28 +145,31 @@ bool CrossS::getAppParameters(MvRequest& in, ApplicationInfo& appInfo)
 
     // Retrieve vertical coordinates information
     if ((const char*)in("VERTICAL_COORDINATES") &&
-        (const char*)in("VERTICAL_COORDINATES") == string("USER"))
+        (const char*)in("VERTICAL_COORDINATES") == std::string("USER"))
         appInfo.haveGHBC(true);
 
     if ((const char*)in("VERTICAL_COORDINATE_PARAM"))
         appInfo.setGHBC((int)in("VERTICAL_COORDINATE_PARAM"));
 
-    if (const char *ch = in("VERTICAL_COORDINATE_EXTRAPOLATE"))
+    if (const char* ch = in("VERTICAL_COORDINATE_EXTRAPOLATE"))
         appInfo.setGHBCExtrapolate(strcmp(ch, "ON") == 0);
 
     // W wind component computation mode/scaling factor
     std::string wModeStr;
     CROSS_S_CHK(in.getValue("W_WIND_SCALING_FACTOR_MODE", wModeStr));
-    in.getValue(wScaling_,"W_WIND_SCALING_FACTOR");
+    in.getValue(wScaling_, "W_WIND_SCALING_FACTOR");
 
     if (wModeStr == "AUTOMATIC") {
         wMode_ = Mv3VerticalVelocity;
-    } else if (wModeStr == "USER") {
+    }
+    else if (wModeStr == "USER") {
         wMode_ = ScaledVerticalVelocity;
-    } else if (wModeStr == "COMPUTE"){
+    }
+    else if (wModeStr == "COMPUTE") {
         wMode_ = ComputedVerticalVelocity;
-    } else {
-        setError(1,"CrossS -> Invalid value (=%s) specified for parameter W_WIND_SCALING_FACTOR_MODE!",
+    }
+    else {
+        setError(1, "CrossS -> Invalid value (=%s) specified for parameter W_WIND_SCALING_FACTOR_MODE!",
                  wModeStr.c_str());
     }
 
@@ -182,7 +186,7 @@ bool CrossS::getAppParameters(MvRequest& in, ApplicationInfo& appInfo)
         double val;
         double factor = 100.;  // input values are in hPa
         int cnt       = in.iterInit("LEVEL_LIST");
-        vector<double> lslist;
+        std::vector<double> lslist;
         lslist.reserve(cnt);
         for (int i = 0; i < cnt; ++i) {
             in.iterGetNextValue(val);
@@ -199,8 +203,8 @@ bool CrossS::getAppParameters(MvRequest& in, ApplicationInfo& appInfo)
         appInfo.levelCount((int)in("LEVEL_COUNT"));
 
     if ((const char*)in("VERTICAL_SCALING")) {
-        string vs = (const char*)in("VERTICAL_SCALING");
-        bool bvs  = (vs == "LINEAR") ? true : false;
+        std::string vs = (const char*)in("VERTICAL_SCALING");
+        bool bvs       = (vs == "LINEAR") ? true : false;
         appInfo.vLinearScaling(bvs);
     }
 
@@ -250,7 +254,7 @@ bool CrossS::consistencyCheck(MvRequest& req1, MvRequest& req2)
 
 bool CrossS::generateData(ApplicationInfo& appInfo, ParamMap& params,
                           MvNetCDF& cdf, MvField& field,
-                          const string& key)
+                          const std::string& key)
 {
     // Get parameter info
     ParamInfo* par = appInfo.getParamInfo(params, key);
@@ -271,7 +275,7 @@ bool CrossS::generateData(ApplicationInfo& appInfo, ParamMap& params,
 // generate the data according to the values set.
 bool CrossS::generateXsectData(ApplicationInfo& appInfo, ParamMap& params,
                                MvNetCDF& cdf, MvField& field,
-                               const string& key)
+                               const std::string& key)
 {
     // Get parameter info
     ParamInfo* par = appInfo.getParamInfo(params, key);
@@ -281,32 +285,37 @@ bool CrossS::generateXsectData(ApplicationInfo& appInfo, ParamMap& params,
     if (windMode_ == Wind2DMode) {
         if (par->Parameter() != std::max({U_FIELD, V_FIELD}))
             return true;
-    } else if (windMode_ == Wind3DMode) {
+    }
+    else if (windMode_ == Wind3DMode) {
         if (par->Parameter() != std::max({U_FIELD, V_FIELD, W_FIELD}))
             return true;
-    } else if (windMode_ == Wind3DWithTMode) {
+    }
+    else if (windMode_ == Wind3DWithTMode) {
         if (par->Parameter() != std::max({U_FIELD, V_FIELD, W_FIELD, T_FIELD}))
             return true;
     }
 
     // Generate the netCDF parameter variable(s)
     if (windMode_ == Wind2DMode &&
-            (!useWindIntensity_ && windProjection_ == NoWindProjection &&
-             needVectorOutput_)) {
+        (!useWindIntensity_ && windProjection_ == NoWindProjection &&
+         needVectorOutput_)) {
         assert(par->Parameter() == std::max({U_FIELD, V_FIELD}));
         outputMode_ = determineWindOutputMode();
         assert(outputMode_ == VectorOutput);
         return wind2DValues(appInfo, params, cdf, key, field);
-    } else if (windMode_ == Wind2DMode) {
+    }
+    else if (windMode_ == Wind2DMode) {
         assert(par->Parameter() == std::max({U_FIELD, V_FIELD}));
         outputMode_ = determineWindOutputMode();
         assert(outputMode_ == ScalarOutput);
         return wind2DValues(appInfo, params, cdf, key, field);
-    } else if (windMode_ == Wind3DMode) {
+    }
+    else if (windMode_ == Wind3DMode) {
         assert(par->Parameter() == std::max({U_FIELD, V_FIELD, W_FIELD}));
         outputMode_ = determineWindOutputMode();
         return wind3DValues(appInfo, params, cdf, key, field);
-    } else if (windMode_ == Wind3DWithTMode) {
+    }
+    else if (windMode_ == Wind3DWithTMode) {
         assert(par->Parameter() == std::max({U_FIELD, V_FIELD, W_FIELD, T_FIELD}));
         outputMode_ = determineWindOutputMode();
         return wind3DValues(appInfo, params, cdf, key, field);
@@ -374,20 +383,20 @@ bool CrossS::generateLNSP(ApplicationInfo& appInfo, MvNetCDF& cdf, ParamInfo* pa
 
     // Add/update LNSP and auxiliary variables to the netCDF
     // These auxiliary variables will be used to plot the orography
-    string varname = Xsect::getNetcdfVarname(par->ParamName());  // varname is LNSP
-    MvNcVar* ncx1  = cdf.getVariable("orography_x_values");
-    MvNcVar* ncy1  = cdf.getVariable("orography_y1_values");
-    MvNcVar* ncy2  = cdf.getVariable("orography_y2_values");
-    MvNcVar* ncln  = cdf.getVariable(varname);
+    std::string varname = Xsect::getNetcdfVarname(par->ParamName());  // varname is LNSP
+    MvNcVar* ncx1       = cdf.getVariable("orography_x_values");
+    MvNcVar* ncy1       = cdf.getVariable("orography_y1_values");
+    MvNcVar* ncy2       = cdf.getVariable("orography_y2_values");
+    MvNcVar* ncln       = cdf.getVariable(varname);
     if (!ncx1 || !ncy1 || !ncy2 || !ncln)  // Create new variables
     {
         ntime_ = -1;
 
         // Initialise dimensions
-        vector<long> values_ndim;
+        std::vector<long> values_ndim;
         values_ndim.push_back(appInfo.NTimes());
         values_ndim.push_back(nrPoints);
-        vector<string> values_sdim;
+        std::vector<std::string> values_sdim;
         values_sdim.push_back(XS_VARTIME);
         values_sdim.push_back("npoints");
 
@@ -432,13 +441,13 @@ bool CrossS::generateLNSP(ApplicationInfo& appInfo, MvNetCDF& cdf, ParamInfo* pa
     }
 
     // Memory allocation
-    double* y1_values = new double[nrPoints];
-    double* y2_values = new double[nrPoints];
+    auto* y1_values = new double[nrPoints];
+    auto* y2_values = new double[nrPoints];
 
     // Get X values
-    const vector<double>& lon      = (appInfo.haveLonsForPlotting()) ? appInfo.getLongitudeForPlotting() : appInfo.getLongitude();
-    const vector<double>& lat      = (appInfo.haveLatsForPlotting()) ? appInfo.getLatitudeForPlotting() : appInfo.getLatitude();
-    const vector<double>& x_values = (lon[0] == lon[1]) ? lat : lon;
+    const std::vector<double>& lon      = (appInfo.haveLonsForPlotting()) ? appInfo.getLongitudeForPlotting() : appInfo.getLongitude();
+    const std::vector<double>& lat      = (appInfo.haveLatsForPlotting()) ? appInfo.getLatitudeForPlotting() : appInfo.getLatitude();
+    const std::vector<double>& x_values = (lon[0] == lon[1]) ? lat : lon;
 
     // Compute Y values
     for (int i = 0; i < nrPoints; i++) {
@@ -474,7 +483,7 @@ bool CrossS::generateLNSP(ApplicationInfo& appInfo, MvNetCDF& cdf, ParamInfo* pa
 
 // Generate values for horizontal wind
 bool CrossS::wind2DValues(ApplicationInfo& appInfo, ParamMap& params, MvNetCDF& cdf,
-                        const string& key, MvField& field)
+                          const std::string& key, MvField& field)
 {
     // Find the v field
     ParamInfo* par_v = appInfo.getParamInfo(params, V_FIELD, key);
@@ -496,8 +505,8 @@ bool CrossS::wind2DValues(ApplicationInfo& appInfo, ParamMap& params, MvNetCDF&
         // Temporary used for holding mapped u/v values.
         ParamInfo par_uv(par_v->Parameter(), par_v->Date(), par_v->Time(), par_v->Step(), par_v->ParamName(), par_v->ParamLongName(), par_v->Units(), par_v->LevelType());
 
-        vector<double> y_values;
-        vector<double> cp;
+        std::vector<double> y_values;
+        std::vector<double> cp;
 
         // compute values
         computeWind2D(appInfo, par_uv, par_u, par_v);
@@ -513,7 +522,7 @@ bool CrossS::wind2DValues(ApplicationInfo& appInfo, ParamMap& params, MvNetCDF&
 
         if (nrLevels <= 0) {
             setError(1, "CrossS::wind2DValues --> Incorrect number of vertical levels =%d", nrLevels);
-                    return false;
+            return false;
         }
 
         if (nrPoints <= 0) {
@@ -529,17 +538,16 @@ bool CrossS::wind2DValues(ApplicationInfo& appInfo, ParamMap& params, MvNetCDF&
 
         // Create variable 'levels'
         std::string levname = this->getNetcdfLevelVarname(varname);
-        MvNcVar* nclevels = cdf.getVariable(levname);
+        MvNcVar* nclevels   = cdf.getVariable(levname);
 
         // Create variable 'levels'
-        if (!nclevels)
-        {
+        if (!nclevels) {
             // Initialise dimensions
             std::vector<long> values_ndim;
             values_ndim.push_back(appInfo.NTimes());
             values_ndim.push_back(nrLevels);
 
-            std::vector<string> values_sdim;
+            std::vector<std::string> values_sdim;
             values_sdim.push_back(XS_VARTIME);
             values_sdim.push_back(XS_VARLEVEL);
 
@@ -558,14 +566,13 @@ bool CrossS::wind2DValues(ApplicationInfo& appInfo, ParamMap& params, MvNetCDF&
         // Create netCDF variable
         MvNcVar* ncv = cdf.getVariable(varname);
         if (!ncv) {
-
             // Initialise dimensions
             std::vector<long> values_ndim;
             values_ndim.push_back(appInfo.NTimes());
             values_ndim.push_back(nrLevels);
             values_ndim.push_back(nrPoints);
 
-            std::vector<string> values_sdim;
+            std::vector<std::string> values_sdim;
             values_sdim.push_back(XS_VARTIME);
             values_sdim.push_back(XS_VARLEVEL);
             values_sdim.push_back(XS_VARLON);
@@ -598,14 +605,15 @@ bool CrossS::wind2DValues(ApplicationInfo& appInfo, ParamMap& params, MvNetCDF&
 
         ntime_++;
 
-    // Unprojected wind components
-    } else {
+        // Unprojected wind components
+    }
+    else {
         assert(outputMode_ == VectorOutput);
         assert(windProjection_ == NoWindProjection);
         assert(useWindIntensity_ == false);
 
-        vector<double> y_values;
-        vector<double> cp;
+        std::vector<double> y_values;
+        std::vector<double> cp;
 
         // ----------------------------------
         // First: handle u component
@@ -622,7 +630,7 @@ bool CrossS::wind2DValues(ApplicationInfo& appInfo, ParamMap& params, MvNetCDF&
 
         if (nrLevels <= 0) {
             setError(1, "CrossS::wind2DValues --> Incorrect number of vertical levels=%d", nrLevels);
-                    return false;
+            return false;
         }
 
         if (nrPoints <= 0) {
@@ -632,23 +640,22 @@ bool CrossS::wind2DValues(ApplicationInfo& appInfo, ParamMap& params, MvNetCDF&
 
         // define the netCDF variable + level name
         std::string varname = this->getNetcdfXComponentVarname();
-//        if (!plotVar_) {
-//            plotVar_ = par_u;
-//        }
+        //        if (!plotVar_) {
+        //            plotVar_ = par_u;
+        //        }
 
         // Create variable 'levels'
         std::string levname = this->getNetcdfLevelVarname(varname);
-        MvNcVar* nclevels = cdf.getVariable(levname);
+        MvNcVar* nclevels   = cdf.getVariable(levname);
 
         // Create variable 'levels'
-        if (!nclevels)
-        {
+        if (!nclevels) {
             // Initialise dimensions
             std::vector<long> values_ndim;
             values_ndim.push_back(appInfo.NTimes());
             values_ndim.push_back(nrLevels);
 
-            std::vector<string> values_sdim;
+            std::vector<std::string> values_sdim;
             values_sdim.push_back(XS_VARTIME);
             values_sdim.push_back(XS_VARLEVEL);
 
@@ -667,14 +674,13 @@ bool CrossS::wind2DValues(ApplicationInfo& appInfo, ParamMap& params, MvNetCDF&
         // Create netCDF variable
         MvNcVar* ncv = cdf.getVariable(varname);
         if (!ncv) {
-
             // Initialise dimensions
             std::vector<long> values_ndim;
             values_ndim.push_back(appInfo.NTimes());
             values_ndim.push_back(nrLevels);
             values_ndim.push_back(nrPoints);
 
-            std::vector<string> values_sdim;
+            std::vector<std::string> values_sdim;
             values_sdim.push_back(XS_VARTIME);
             values_sdim.push_back(XS_VARLEVEL);
             values_sdim.push_back(XS_VARLON);
@@ -710,7 +716,7 @@ bool CrossS::wind2DValues(ApplicationInfo& appInfo, ParamMap& params, MvNetCDF&
         //---------------------------------------
 
         size_t y_values_size_ori = y_values.size();
-        size_t cp_size_ori = cp.size();
+        size_t cp_size_ori       = cp.size();
 
         if (!appInfo.computeLevelMatrixValues(params, key, par_v, y_values, cp, field)) {
             setError(1, "CrossS::wind2DValues --> Could not find the requested field for v wind component! key=%s", key.c_str());
@@ -719,13 +725,13 @@ bool CrossS::wind2DValues(ApplicationInfo& appInfo, ParamMap& params, MvNetCDF&
 
         if (y_values_size_ori != y_values.size()) {
             setError(1, "CrossS::wind2DValues --> Inconsitent number of vertical levels for v wind component! u=%d v=%d",
-                     y_values_size_ori, y_values.size() );
+                     y_values_size_ori, y_values.size());
             return false;
         }
 
         if (cp_size_ori != cp.size()) {
             setError(1, "CrossS::wind2DValues --> Inconsitent number of values for v wind component! u=%d v=%d",
-                     cp_size_ori, cp.size() );
+                     cp_size_ori, cp.size());
             return false;
         }
 
@@ -735,14 +741,13 @@ bool CrossS::wind2DValues(ApplicationInfo& appInfo, ParamMap& params, MvNetCDF&
         // Create netCDF variable
         ncv = cdf.getVariable(varname);
         if (!ncv) {
-
             // Initialise dimensions
             std::vector<long> values_ndim;
             values_ndim.push_back(appInfo.NTimes());
             values_ndim.push_back(nrLevels);
             values_ndim.push_back(nrPoints);
 
-            std::vector<string> values_sdim;
+            std::vector<std::string> values_sdim;
             values_sdim.push_back(XS_VARTIME);
             values_sdim.push_back(XS_VARLEVEL);
             values_sdim.push_back(XS_VARLON);
@@ -774,7 +779,7 @@ bool CrossS::wind2DValues(ApplicationInfo& appInfo, ParamMap& params, MvNetCDF&
 
 // Generate wind data for U/V/W
 bool CrossS::wind3DValues(ApplicationInfo& appInfo, ParamMap& params,
-                            MvNetCDF& cdf, const string& key, MvField& field)
+                          MvNetCDF& cdf, const std::string& key, MvField& field)
 {
     // Find the w field
     ParamInfo* par_w = appInfo.getParamInfo(params, W_FIELD, key);
@@ -795,35 +800,38 @@ bool CrossS::wind3DValues(ApplicationInfo& appInfo, ParamMap& params,
                      par_v->ParamName(), par_v->ParamLongName(), par_v->Units(),
                      par_v->LevelType());
 
-    vector<double> y_values;
-    vector<double> cp;
+    std::vector<double> y_values;
+    std::vector<double> cp;
 
     if (windProjection_ == NormalWindProjection) {
         this->computeWind2D(appInfo, par_uv, par_u, par_v);
-    } else {
+    }
+    else {
         // Compute/scale the vertical wind component
 
         // MV3 method
         if (wMode_ == Mv3VerticalVelocity) {
             appInfo.scaleVerticalVelocity_mv3(par_w);
 
-        // hydrostatic computation: omega to w
-        } else if (wMode_ == ComputedVerticalVelocity) {
-            ParamInfo* par_t = nullptr;
+            // hydrostatic computation: omega to w
+        }
+        else if (wMode_ == ComputedVerticalVelocity) {
+            ParamInfo* par_t    = nullptr;
             ParamInfo* par_lnsp = nullptr;
-            if(windMode_ == Wind3DWithTMode) {
+            if (windMode_ == Wind3DWithTMode) {
                 par_t = appInfo.getParamInfo(params, T_FIELD, key);
                 if (!par_t)
-                     return false;
-             }
-             if(appInfo.levelType() == XS_ML_LNSP) {
+                    return false;
+            }
+            if (appInfo.levelType() == XS_ML_LNSP) {
                 par_lnsp = appInfo.getParamInfo(params, LNSP_FIELD, key);
                 if (!par_lnsp)
                     return false;
-             }
+            }
 
             appInfo.computeVerticalVelocity(par_w, par_t, par_lnsp, field, wScaling_);
-        } else {
+        }
+        else {
             appInfo.scaleVerticalVelocity(par_w, wScaling_);
         }
 
@@ -859,7 +867,8 @@ bool CrossS::wind3DValues(ApplicationInfo& appInfo, ParamMap& params,
         if (!plotVar_) {
             plotVar_ = par_u;
         }
-    } else if (outputMode_ == VectorOutput) {
+    }
+    else if (outputMode_ == VectorOutput) {
         assert(!useWindIntensity_);
         assert(windProjection_ != NormalWindProjection);
         varname = this->getNetcdfXComponentVarname();
@@ -868,17 +877,16 @@ bool CrossS::wind3DValues(ApplicationInfo& appInfo, ParamMap& params,
     // Create variable 'levels'
     // this depends on the output mode!
     std::string levname = this->getNetcdfLevelVarname(varname);
-    MvNcVar* nclevels = cdf.getVariable(levname);
+    MvNcVar* nclevels   = cdf.getVariable(levname);
 
     // Create variable 'levels'
-    if (!nclevels)
-    {
+    if (!nclevels) {
         // Initialise dimensions
         std::vector<long> values_ndim;
         values_ndim.push_back(appInfo.NTimes());
         values_ndim.push_back(nrLevels);
 
-        std::vector<string> values_sdim;
+        std::vector<std::string> values_sdim;
         values_sdim.push_back(XS_VARTIME);
         values_sdim.push_back(XS_VARLEVEL);
 
@@ -896,14 +904,13 @@ bool CrossS::wind3DValues(ApplicationInfo& appInfo, ParamMap& params,
     // Create netCDF variable
     MvNcVar* ncv = cdf.getVariable(varname);
     if (!ncv) {
-
         // Initialise dimensions
         std::vector<long> values_ndim;
         values_ndim.push_back(appInfo.NTimes());
         values_ndim.push_back(nrLevels);
         values_ndim.push_back(nrPoints);
 
-        std::vector<string> values_sdim;
+        std::vector<std::string> values_sdim;
         values_sdim.push_back(XS_VARTIME);
         values_sdim.push_back(XS_VARLEVEL);
         values_sdim.push_back(XS_VARLON);
@@ -942,7 +949,7 @@ bool CrossS::wind3DValues(ApplicationInfo& appInfo, ParamMap& params,
         assert(windProjection_ == ParallelWindProjection && !useWindIntensity_);
 
         size_t y_values_size_ori = y_values.size();
-        size_t cp_size_ori = cp.size();
+        size_t cp_size_ori       = cp.size();
 
         // interpolate w result onto the output levels
         if (!appInfo.computeLevelMatrixValues(params, key, par_w, y_values, cp, field)) {
@@ -952,13 +959,13 @@ bool CrossS::wind3DValues(ApplicationInfo& appInfo, ParamMap& params,
 
         if (y_values_size_ori != y_values.size()) {
             setError(1, "CrossS::wind3DValues --> Inconsitent number of vertical levels for projected wind components: uv=%d w=%d",
-                     y_values_size_ori, y_values.size() );
+                     y_values_size_ori, y_values.size());
             return false;
         }
 
         if (cp_size_ori != cp.size()) {
             setError(1, "CrossS::wind3DValues --> Inconsitent number of values for projected wind components: uv=%d w=%d",
-                     cp_size_ori, cp.size() );
+                     cp_size_ori, cp.size());
             return false;
         }
 
@@ -969,14 +976,13 @@ bool CrossS::wind3DValues(ApplicationInfo& appInfo, ParamMap& params,
         // Create netCDF variable
         ncv = cdf.getVariable(varname);
         if (!ncv) {
-
             // Initialise dimensions
             std::vector<long> values_ndim;
             values_ndim.push_back(appInfo.NTimes());
             values_ndim.push_back(nrLevels);
             values_ndim.push_back(nrPoints);
 
-            std::vector<string> values_sdim;
+            std::vector<std::string> values_sdim;
             values_sdim.push_back(XS_VARTIME);
             values_sdim.push_back(XS_VARLEVEL);
             values_sdim.push_back(XS_VARLON);
@@ -1008,8 +1014,8 @@ bool CrossS::wind3DValues(ApplicationInfo& appInfo, ParamMap& params,
 #if 0
 
     // Compute UV values (x_component).
-    vector<double> cp;
-    vector<double> y_values;
+    std::vector<double> cp;
+    std::vector<double> y_values;
     double* splin = 0;
     if (!appInfo.isInterpolate()) {
         // Compute level values and interpolate matrix
@@ -1043,7 +1049,7 @@ bool CrossS::wind3DValues(ApplicationInfo& appInfo, ParamMap& params,
     }
 
     // Get/create the netCDF variable (x_component)
-    string varname = this->getNetcdfXComponentVarname();
+    std::string varname = this->getNetcdfXComponentVarname();
     MvNcVar* ncvx  = this->getNetcdfVariable(cdf, varname, appInfo, varname, par_u);
 
     // Write UV values to the netCDF (x_component)
@@ -1095,7 +1101,6 @@ bool CrossS::wind3DValues(ApplicationInfo& appInfo, ParamMap& params,
 
     return true;
 #endif
-
 }
 
 #if 0
@@ -1112,15 +1117,17 @@ void CrossS::setHorCompFlags(bool foundU, bool foundV, bool foundW, bool foundT)
 {
     windMode_ = NoWindMode;
 
-    if( foundU && foundV && foundW) {
+    if (foundU && foundV && foundW) {
         if (windProjection_ != NoWindProjection || useWindIntensity_) {
             if (wMode_ == ComputedVerticalVelocity && foundT) {
                 windMode_ = Wind3DWithTMode;
-            } else {
+            }
+            else {
                 windMode_ = Wind3DMode;
             }
         }
-    } else if (foundU && foundV) {
+    }
+    else if (foundU && foundV) {
         if (windProjection_ != NoWindProjection || useWindIntensity_ || needVectorOutput_) {
             windMode_ = Wind2DMode;
         }
@@ -1135,26 +1142,27 @@ void CrossS::setHorCompFlags(bool foundU, bool foundV, bool foundW, bool foundT)
 CrossS::OutputMode CrossS::determineWindOutputMode() const
 {
     if (windMode_ == Wind2DMode) {
-        return (useWindIntensity_ || windProjection_ != NoWindProjection || !needVectorOutput_)?ScalarOutput:VectorOutput;
-    } else if (windMode_ != NoWindMode) {
-        return (useWindIntensity_ || windProjection_ == NormalWindProjection)?ScalarOutput:VectorOutput;
+        return (useWindIntensity_ || windProjection_ != NoWindProjection || !needVectorOutput_) ? ScalarOutput : VectorOutput;
     }
-    return  ScalarOutput;
+    else if (windMode_ != NoWindMode) {
+        return (useWindIntensity_ || windProjection_ == NormalWindProjection) ? ScalarOutput : VectorOutput;
+    }
+    return ScalarOutput;
 }
 
 // Project the uv wind components in the specified way
 void CrossS::computeWind2D(ApplicationInfo& appInfo, ParamInfo& par_uv, ParamInfo* par_u, ParamInfo* par_v)
 {
     // Map U/V into planes
-    LevelMap lmap_u  = par_u->Levels();
-    LevelMap lmap_v  = par_v->Levels();
-    LevelIterator uu = lmap_u.begin(), vv = lmap_v.begin();
+    LevelMap lmap_u = par_u->Levels();
+    LevelMap lmap_v = par_v->Levels();
+    auto uu = lmap_u.begin(), vv = lmap_v.begin();
     double *uValues, *vValues;
 
-    int nrPoints     = appInfo.NrPoints();
-    double* valuesuv = new double[nrPoints];
-    double ansin     = appInfo.Ansin();
-    double ancos     = appInfo.Ancos();
+    int nrPoints   = appInfo.NrPoints();
+    auto* valuesuv = new double[nrPoints];
+    double ansin   = appInfo.Ansin();
+    double ancos   = appInfo.Ancos();
 
     for (; uu != lmap_u.end() && vv != lmap_v.end(); uu++, vv++) {
         uValues = (*uu).second->XValues();
@@ -1167,12 +1175,14 @@ void CrossS::computeWind2D(ApplicationInfo& appInfo, ParamInfo& par_uv, ParamInf
                     if (useWindIntensity_) {
                         valuesuv[i] = fabs(valuesuv[i]);
                     }
-                } else if (windProjection_ == ParallelWindProjection) {
+                }
+                else if (windProjection_ == ParallelWindProjection) {
                     valuesuv[i] = uValues[i] * ancos + vValues[i] * ansin;
                     if (useWindIntensity_) {
                         valuesuv[i] = fabs(valuesuv[i]);
                     }
-                } else {
+                }
+                else {
                     assert(windProjection_ == NoWindProjection);
                     assert(useWindIntensity_);
                     valuesuv[i] = sqrt(uValues[i] * uValues[i] + vValues[i] * vValues[i]);
@@ -1187,26 +1197,26 @@ void CrossS::computeWind2D(ApplicationInfo& appInfo, ParamInfo& par_uv, ParamInf
         par_uv.Level(valuesuv, (*uu).first, nrPoints, modlev);
     }
 
-    delete [] valuesuv;
+    delete[] valuesuv;
 }
 
 void CrossS::computeWind3D(ApplicationInfo& appInfo, ParamInfo& par_uv, ParamInfo* par_u, ParamInfo* par_v,
                            ParamInfo* par_w)
 {
     // Map U/V into planes
-    LevelMap lmap_u  = par_u->Levels();
-    LevelMap lmap_v  = par_v->Levels();
-    LevelMap lmap_w  = par_w->Levels();
-    LevelIterator uu = lmap_u.begin();
-    LevelIterator vv = lmap_v.begin();
-    LevelIterator ww = lmap_w.begin();
+    LevelMap lmap_u = par_u->Levels();
+    LevelMap lmap_v = par_v->Levels();
+    LevelMap lmap_w = par_w->Levels();
+    auto uu         = lmap_u.begin();
+    auto vv         = lmap_v.begin();
+    auto ww         = lmap_w.begin();
 
-    double *uValues=nullptr, *vValues=nullptr, *wValues=nullptr ;
+    double *uValues = nullptr, *vValues = nullptr, *wValues = nullptr;
 
-    int nrPoints     = appInfo.NrPoints();
-    double* valuesuv = new double[nrPoints];
-    double ansin     = appInfo.Ansin();
-    double ancos     = appInfo.Ancos();
+    int nrPoints   = appInfo.NrPoints();
+    auto* valuesuv = new double[nrPoints];
+    double ansin   = appInfo.Ansin();
+    double ancos   = appInfo.Ancos();
 
     for (; uu != lmap_u.end() && vv != lmap_v.end() && ww != lmap_w.end(); uu++, vv++, ww++) {
         uValues = (*uu).second->XValues();
@@ -1214,29 +1224,32 @@ void CrossS::computeWind3D(ApplicationInfo& appInfo, ParamInfo& par_uv, ParamInf
         wValues = (*ww).second->XValues();
 
         for (int i = 0; i < nrPoints; i++) {
-
             if (windProjection_ == NormalWindProjection) {
                 if (uValues[i] < XMISSING_VALUE && vValues[i] < XMISSING_VALUE) {
                     valuesuv[i] = -uValues[i] * ansin + vValues[i] * ancos;
                     if (useWindIntensity_) {
                         valuesuv[i] = abs(valuesuv[i]);
                     }
-                } else {
+                }
+                else {
                     valuesuv[i] = XMISSING_VALUE;
                 }
-            } else {
+            }
+            else {
                 if (uValues[i] < XMISSING_VALUE && vValues[i] < XMISSING_VALUE && wValues[i] < XMISSING_VALUE) {
                     if (windProjection_ == ParallelWindProjection) {
                         valuesuv[i] = uValues[i] * ancos + vValues[i] * ansin;
                         if (useWindIntensity_) {
-                           valuesuv[i] = sqrt(valuesuv[i]*valuesuv[i] + wValues[i] * wValues[i]);
+                            valuesuv[i] = sqrt(valuesuv[i] * valuesuv[i] + wValues[i] * wValues[i]);
                         }
-                    } else {
+                    }
+                    else {
                         assert(windProjection_ == NoWindProjection);
                         assert(useWindIntensity_);
                         valuesuv[i] = sqrt(uValues[i] * uValues[i] + vValues[i] * vValues[i] + wValues[i] * wValues[i]);
                     }
-                } else {
+                }
+                else {
                     valuesuv[i] = XMISSING_VALUE;
                 }
             }
@@ -1246,7 +1259,7 @@ void CrossS::computeWind3D(ApplicationInfo& appInfo, ParamInfo& par_uv, ParamInf
         par_uv.Level(valuesuv, (*uu).first, nrPoints, modlev);
     }
 
-    delete [] valuesuv;
+    delete[] valuesuv;
 }
 
 int CrossS::computeGeographicalPoints(ApplicationInfo& appInfo, MvField* field)
@@ -1256,7 +1269,7 @@ int CrossS::computeGeographicalPoints(ApplicationInfo& appInfo, MvField* field)
     appInfo.getAreaLine(x1, x2, y1, y2);
     double dellat = ABS(y2 - y1), dellon = ABS(x2 - x1);
 
-    int np=64;
+    int np = 64;
     // Compute initial number of points
     if (appInfo.GridNS() != cValueNotGiven && appInfo.GridEW() != cValueNotGiven) {
         np = int(sqrt(dellon * dellon + dellat * dellat) / MIN(fabs(appInfo.GridNS()), fabs(appInfo.GridEW())));
@@ -1279,9 +1292,9 @@ bool CrossS::fillValues(ApplicationInfo& appInfo, MvField& field, double* vals)
     MvFieldExpander x(field);
 
     // Get number of points and lat/long interpolation points
-    int npoint                = appInfo.NrPoints();
-    const vector<double>& lat = appInfo.getLatitude();
-    const vector<double>& lon = appInfo.getLongitude();
+    int npoint                     = appInfo.NrPoints();
+    const std::vector<double>& lat = appInfo.getLatitude();
+    const std::vector<double>& lon = appInfo.getLongitude();
 
     if (appInfo.isHorInterpolate()) {
         // Interpolatate along XS line
@@ -1310,14 +1323,14 @@ MvRequest CrossS::createOutputRequest(ApplicationInfo& appInfo, ParamInfo* parIn
     std::string dims = XS_VARTIME + ":0";
 
     // Create NetCDF output request
-    string varname = getNetcdfVarname(parInfo->ParamName()).c_str();
+    std::string varname = getNetcdfVarname(parInfo->ParamName()).c_str();
     MvRequest out1("NETCDF_XY_MATRIX");
-    out1("NETCDF_DATA")              = xs;
-    out1("NETCDF_MISSING_ATTRIBUTE") = "_FillValue";
-    out1("NETCDF_VALUE_VARIABLE")    = varname.c_str();
-    out1("NETCDF_Y_VARIABLE")        = getNetcdfLevelVarname(varname).c_str();
+    out1("NETCDF_DATA")                     = xs;
+    out1("NETCDF_MISSING_ATTRIBUTE")        = "_FillValue";
+    out1("NETCDF_VALUE_VARIABLE")           = varname.c_str();
+    out1("NETCDF_Y_VARIABLE")               = getNetcdfLevelVarname(varname).c_str();
     out1("NETCDF_DIMENSION_SETTING_METHOD") = "index";
-    out1("NETCDF_DIMENSION_SETTING") = dims.c_str();
+    out1("NETCDF_DIMENSION_SETTING")        = dims.c_str();
 
     double X1, X2, Y1, Y2;
     appInfo.getAreaLine(X1, X2, Y1, Y2);
@@ -1325,8 +1338,8 @@ MvRequest CrossS::createOutputRequest(ApplicationInfo& appInfo, ParamInfo* parIn
 
     // across the pole?
     if (X1 == X2) {
-        const string latsVar                = (appInfo.haveLatsForPlotting()) ? XS_VARLATPLOT : XS_VARLAT;
-        const string lonsVar                = (appInfo.haveLonsForPlotting()) ? XS_VARLONPLOT : XS_VARLON;
+        const std::string latsVar           = (appInfo.haveLatsForPlotting()) ? XS_VARLATPLOT : XS_VARLAT;
+        const std::string lonsVar           = (appInfo.haveLonsForPlotting()) ? XS_VARLONPLOT : XS_VARLON;
         out1("NETCDF_X_VARIABLE")           = latsVar.c_str();
         out1("NETCDF_X_AUXILIARY_VARIABLE") = lonsVar.c_str();
         out1("NETCDF_X_GEOLINE_CONVENTION") = "latlon";
@@ -1353,15 +1366,15 @@ MvRequest CrossS::createOutputRequest(ApplicationInfo& appInfo, ParamInfo* parIn
     // Add the orography curve visualiser
     if (appInfo.haveLNSP() && (appInfo.levelType() == XS_ML_LNSP || appInfo.levelType() == XS_PL)) {
         MvRequest out_orog("NETCDF_XY_POINTS");
-        out_orog("NETCDF_DATA")              = xs;
-        out_orog("NETCDF_Y_VARIABLE")        = "orography_y2_values";
-        out_orog("NETCDF_Y2_VARIABLE")       = "orography_y1_values";
-        out_orog("NETCDF_X_VARIABLE")        = "orography_x_values";
-        out_orog("NETCDF_X2_VARIABLE")       = "orography_x_values";  //"orography_x2_values";
-        out_orog("NETCDF_MISSING_ATTRIBUTE") = "_FillValue";
+        out_orog("NETCDF_DATA")                     = xs;
+        out_orog("NETCDF_Y_VARIABLE")               = "orography_y2_values";
+        out_orog("NETCDF_Y2_VARIABLE")              = "orography_y1_values";
+        out_orog("NETCDF_X_VARIABLE")               = "orography_x_values";
+        out_orog("NETCDF_X2_VARIABLE")              = "orography_x_values";  //"orography_x2_values";
+        out_orog("NETCDF_MISSING_ATTRIBUTE")        = "_FillValue";
         out_orog("NETCDF_DIMENSION_SETTING_METHOD") = "index";
-        out_orog("NETCDF_DIMENSION_SETTING") = dims.c_str();
-        out_orog("_SKIP_MACRO")              = 1;  // tell MacroConverter to ignore this request
+        out_orog("NETCDF_DIMENSION_SETTING")        = dims.c_str();
+        out_orog("_SKIP_MACRO")                     = 1;  // tell MacroConverter to ignore this request
 
         // create Graph Plotting subrequest
         // OBS: itt should use a definition from the Default folder
@@ -1425,7 +1438,7 @@ MvRequest CrossS::createOutputRequest(ApplicationInfo& appInfo, ParamInfo* parIn
     return out;
 }
 
-string CrossS::titleVariable(ApplicationInfo&, ParamInfo* par)
+std::string CrossS::titleVariable(ApplicationInfo&, ParamInfo* par)
 {
     char titlestr[150];
 
@@ -1433,48 +1446,51 @@ string CrossS::titleVariable(ApplicationInfo&, ParamInfo* par)
     if (windMode_ != NoWindMode) {
         if (outputMode_ == ScalarOutput && windProjection_ != NoWindProjection) {
             sprintf(titlestr, "Cross section of wind %s %d %02d step %d %s",
-                (windProjection_ == NormalWindProjection) ? "normal component" : "parallel speed",
-                par->Date(), par->Time(), par->Step(),
-                par->ExpVerTitle().c_str());            
+                    (windProjection_ == NormalWindProjection) ? "normal component" : "parallel speed",
+                    par->Date(), par->Time(), par->Step(),
+                    par->ExpVerTitle().c_str());
         }
         else if (outputMode_ == ScalarOutput && windMode_ == Wind2DMode) {
             sprintf(titlestr, "Cross section of UV speed  %d %02d step %d %s",
-                par->Date(), par->Time(), par->Step(),
-                par->ExpVerTitle().c_str());
-
-        } else if (outputMode_ == VectorOutput) {
+                    par->Date(), par->Time(), par->Step(),
+                    par->ExpVerTitle().c_str());
+        }
+        else if (outputMode_ == VectorOutput) {
             if (windMode_ == Wind2DMode) {
                 sprintf(titlestr, "Cross section of UV %d %02d step %d %s",
-                    par->Date(), par->Time(), par->Step(),
-                    par->ExpVerTitle().c_str());
-            } else {
-                sprintf(titlestr, "Cross section of UVW parallel %d %02d step %d %s",
-                    par->Date(), par->Time(), par->Step(),
-                    par->ExpVerTitle().c_str());
+                        par->Date(), par->Time(), par->Step(),
+                        par->ExpVerTitle().c_str());
             }
-        } else {
+            else {
+                sprintf(titlestr, "Cross section of UVW parallel %d %02d step %d %s",
+                        par->Date(), par->Time(), par->Step(),
+                        par->ExpVerTitle().c_str());
+            }
+        }
+        else {
             sprintf(titlestr, "Cross section of %s %d %02d step %d %s",
+                    par->ParamLongName().c_str(), par->Date(), par->Time(), par->Step(),
+                    par->ExpVerTitle().c_str());
+        }
+    }
+    else {
+        sprintf(titlestr, "Cross section of %s %d %02d step %d %s",
                 par->ParamLongName().c_str(), par->Date(), par->Time(), par->Step(),
                 par->ExpVerTitle().c_str());
-        }
-    } else {
-        sprintf(titlestr, "Cross section of %s %d %02d step %d %s",
-            par->ParamLongName().c_str(), par->Date(), par->Time(), par->Step(),
-            par->ExpVerTitle().c_str());
     }
 
-    return string(titlestr);
+    return std::string(titlestr);
 }
 
-string CrossS::getNetcdfLevelVarname(string& varname)
+std::string CrossS::getNetcdfLevelVarname(std::string& varname)
 {
     if (outputMode_ == VectorOutput)
-        return string("lev");
+        return std::string("lev");
 
     return Xsect::getNetcdfLevelVarname(varname);
 }
 
-string CrossS::getNetcdfVarname(const string& varname)
+std::string CrossS::getNetcdfVarname(const std::string& varname)
 {
     if (outputMode_ == VectorOutput)
         return getNetcdfXComponentVarname();
