@@ -8,6 +8,10 @@
  ***************************** LICENSE END *************************************/
 
 #include "MvXsectFrame.h"
+
+#include <iomanip>
+#include <sstream>
+
 #include "MvException.h"
 
 #include <assert.h>
@@ -42,22 +46,22 @@ bool ParamInfo::IsSurface()
     return (LevelType() == "sfc" || NrLevels() < 1) ? true : false;
 }
 
-string ParamInfo::ExpVerTitle()
+std::string ParamInfo::ExpVerTitle()
 {
     if (expver_ == "_")  //-- missing ExpVer is stored as "_"
-        return string("");
+        return std::string("");
     else
-        return string("Expver ") + expver_;
+        return std::string("Expver ") + expver_;
 }
 
 // Fill in data into a level in the LevelMap. Generate the level if needed,
 // and delete any old values from the level.
-void ParamInfo::Level(double* x, string lev, int n, bool modlev)
+void ParamInfo::Level(double* x, std::string lev, int n, bool modlev)
 {
     double flev = atof(lev.c_str());
 
     // Save data for one level
-    LevelIterator ii = levels_.find(lev);
+    auto ii = levels_.find(lev);
     if (ii == levels_.end()) {
         levels_[lev] = new LevelInfo(flev, modlev);
         ii           = levels_.find(lev);
@@ -88,7 +92,7 @@ void ParamInfo::UpdateLevels(bool modlev)
     }
 }
 
-void ParamInfo::AddLevel(string lev)
+void ParamInfo::AddLevel(std::string lev)
 {
     if (levels_.find(lev) == levels_.end())
         levels_[lev] = new LevelInfo;
@@ -106,10 +110,10 @@ MvDate ParamInfo::VerificationDate()
     return MvDate(tt);
 }
 
-double* ParamInfo::getOneLevelValues(const string& clev)
+double* ParamInfo::getOneLevelValues(const std::string& clev)
 {
     // Find the input level
-    LevelIterator ll = levels_.find(clev);
+    auto ll = levels_.find(clev);
     if (ll == levels_.end())
         return 0;
 
@@ -305,8 +309,8 @@ void ApplicationInfo::computeLine(int& npoints, MvField* field)
     MvLocation loc(lat_[0], lon_[0]);
     MvLocation loc2 = field->nearestGridPointLocation(loc);
     double distmin  = loc.distanceInMeters(loc2);
-    vector<double> lat2;
-    vector<double> lon2;
+    std::vector<double> lat2;
+    std::vector<double> lon2;
     double distc;   // current distance in meters
     int index = 0;  // index of the closest location
     for (int k = 1; k < nrPoints_; k++) {
@@ -344,7 +348,7 @@ void ApplicationInfo::computeLine(int& npoints, MvField* field)
 
 // Generate data values.
 // Only ever called if we use pressure levels or UKMO model levels
-void ApplicationInfo::InterpolateVerticala(vector<double>& cp, ParamInfo* param, vector<double>& yvals)
+void ApplicationInfo::InterpolateVerticala(std::vector<double>& cp, ParamInfo* param, std::vector<double>& yvals)
 {
     if (!interpolate_) {
         this->getLevelValues(param, cp);
@@ -391,7 +395,7 @@ void ApplicationInfo::InterpolateVerticala(vector<double>& cp, ParamInfo* param,
 
 // Generate data values.
 // Only ever called if levType_ == XS_ML_LNSP ie if we use non-UKMO model levels
-void ApplicationInfo::InterpolateVerticalb(MvField& field, vector<double>& cp, ParamInfo* param, double* splin, vector<double>& yvals)
+void ApplicationInfo::InterpolateVerticalb(MvField& field, std::vector<double>& cp, ParamInfo* param, double* splin, std::vector<double>& yvals)
 {
     if (!interpolate_) {
         this->getLevelValues(param, cp);
@@ -399,7 +403,7 @@ void ApplicationInfo::InterpolateVerticalb(MvField& field, vector<double>& cp, P
     }
 
     // Convert surface pressure
-    vector<double> sp;
+    std::vector<double> sp;
     sp.reserve(nrPoints_);
     for (int i = 0; i < nrPoints_; i++)
         sp.push_back(exp(splin[i]));
@@ -453,7 +457,7 @@ void ApplicationInfo::InterpolateVerticalb(MvField& field, vector<double>& cp, P
 
 // Generate data values.
 // Only ever called if levType_ == XS_ML_GHBC
-void ApplicationInfo::InterpolateVerticalGHBC(vector<double>& cp, ParamInfo* param, ParamInfo* paramGHBC, vector<double>& yvals)
+void ApplicationInfo::InterpolateVerticalGHBC(std::vector<double>& cp, ParamInfo* param, ParamInfo* paramGHBC, std::vector<double>& yvals)
 {
     if (!interpolate_) {
         // we completely ignore yvals!
@@ -464,7 +468,7 @@ void ApplicationInfo::InterpolateVerticalGHBC(vector<double>& cp, ParamInfo* par
 
     double lpa, vcVal1, vcVal2;
     LevelInfo *parLev1, *parLev2;
-    int nrLevels     = outputLevels();
+    int nrLevels = outputLevels();
     cp.clear();
     cp.reserve(nrLevels * nrPoints_);
     assert(nrLevels >= 2);
@@ -480,15 +484,17 @@ void ApplicationInfo::InterpolateVerticalGHBC(vector<double>& cp, ParamInfo* par
                                       parLev1, parLev2, vcVal1, vcVal2)) {
                 if (parLev1->XValues()[i] < XMISSING_VALUE &&
                     parLev2->XValues()[i] < XMISSING_VALUE) {
-                        lpa = (level - vcVal1) / (vcVal2 - vcVal1);
-                        cp.push_back(parLev1->XValues()[i] + (parLev2->XValues()[i] - parLev1->XValues()[i]) * lpa);
-                } else {
+                    lpa = (level - vcVal1) / (vcVal2 - vcVal1);
+                    cp.push_back(parLev1->XValues()[i] + (parLev2->XValues()[i] - parLev1->XValues()[i]) * lpa);
+                }
+                else {
                     cp.push_back(XMISSING_VALUE);
                 }
-            } else {
+            }
+            else {
                 cp.push_back(XMISSING_VALUE);
             }
-       }
+        }
     }
 
     return;
@@ -496,8 +502,8 @@ void ApplicationInfo::InterpolateVerticalGHBC(vector<double>& cp, ParamInfo* par
 
 bool ApplicationInfo::findPressure(LevelMap& lmap, double value, LevelInfo*& l1, LevelInfo*& l2)
 {
-    LevelIterator ii = lmap.begin();
-    LevelInfo *tmp1  = (*ii).second, *tmp2;
+    auto ii         = lmap.begin();
+    LevelInfo *tmp1 = (*ii).second, *tmp2;
     ii++;
 
     for (; ii != lmap.end(); ii++) {
@@ -518,7 +524,7 @@ bool ApplicationInfo::findModelPressure(LevelMap& lmap, double value, double spl
                                         MvField& field, LevelInfo*& l1, LevelInfo*& l2,
                                         double& val1, double& val2)
 {
-    LevelIterator ii = lmap.begin();
+    auto ii = lmap.begin();
     double tmpval1, tmpval2;
     LevelInfo *tmpl1, *tmpl2;
 
@@ -559,17 +565,17 @@ bool ApplicationInfo::findModelPressureGHBC(LevelMap& parLevels, LevelMap& vcLev
                                             LevelInfo*& parLev1, LevelInfo*& parLev2,
                                             double& vcVal1, double& vcVal2)
 {
-    LevelIterator itParLev = parLevels.begin();
-    LevelIterator itVcLev = vcLevels.begin();
+    auto itParLev = parLevels.begin();
+    auto itVcLev  = vcLevels.begin();
 
     auto actParLev1 = (*itParLev).second;
-    auto actVcLev1 = (*itVcLev).second;
-    vcVal1 = actVcLev1->XValues()[xsPointIdx];
+    auto actVcLev1  = (*itVcLev).second;
+    vcVal1          = actVcLev1->XValues()[xsPointIdx];
     itParLev++;
     itVcLev++;
-    auto actParLev2 = (*itParLev).second;
-    auto actVcLev2 = (*itVcLev).second;
-    vcVal2 = actVcLev2->XValues()[xsPointIdx];
+    auto actParLev2  = (*itParLev).second;
+    auto actVcLev2   = (*itVcLev).second;
+    vcVal2           = actVcLev2->XValues()[xsPointIdx];
     bool vcAscending = vcVal1 < vcVal2;
 
     //this will allow extrapolation at top/bottom
@@ -577,24 +583,25 @@ bool ApplicationInfo::findModelPressureGHBC(LevelMap& parLevels, LevelMap& vcLev
         if (!vcAscending) {
             assert(vcVal2 < vcVal1);
             if (level > vcVal1) {
-                parLev1   = actParLev1;
-                parLev2   = actParLev2;
+                parLev1 = actParLev1;
+                parLev2 = actParLev2;
                 return true;
             }
-        } else {
+        }
+        else {
             assert(vcVal1 < vcVal2);
             if (level < vcVal1) {
-                parLev1   = actParLev1;
-                parLev2   = actParLev2;
+                parLev1 = actParLev1;
+                parLev2 = actParLev2;
                 return true;
             }
         }
     }
 
-    while(itVcLev != vcLevels.end()) {
+    while (itVcLev != vcLevels.end()) {
         if (isWithinRange(vcVal1, vcVal2, level)) {
-            parLev1   = actParLev1;
-            parLev2   = actParLev2;
+            parLev1 = actParLev1;
+            parLev2 = actParLev2;
             return true;
         }
 
@@ -603,10 +610,10 @@ bool ApplicationInfo::findModelPressureGHBC(LevelMap& parLevels, LevelMap& vcLev
 
         if (itVcLev != vcLevels.end()) {
             actParLev1 = actParLev2;
-            vcVal1 = vcVal2;
+            vcVal1     = vcVal2;
             actParLev2 = (*itParLev).second;
-            actVcLev2 = (*itVcLev).second;
-            vcVal2 = actVcLev2->XValues()[xsPointIdx];
+            actVcLev2  = (*itVcLev).second;
+            vcVal2     = actVcLev2->XValues()[xsPointIdx];
         }
     }
 
@@ -615,19 +622,20 @@ bool ApplicationInfo::findModelPressureGHBC(LevelMap& parLevels, LevelMap& vcLev
         if (!vcAscending) {
             assert(vcVal2 < vcVal1);
             if (level < vcVal2) {
-                parLev1   = actParLev1;
-                parLev2   = actParLev2;
+                parLev1 = actParLev1;
+                parLev2 = actParLev2;
                 return true;
             }
-        } else {
+        }
+        else {
             assert(vcVal1 < vcVal2);
             if (level > vcVal2) {
-                parLev1   = actParLev1;
-                parLev2   = actParLev2;
+                parLev1 = actParLev1;
+                parLev2 = actParLev2;
                 return true;
             }
-         }
-     }
+        }
+    }
 
     return false;
 }
@@ -635,8 +643,8 @@ bool ApplicationInfo::findModelPressureGHBC(LevelMap& parLevels, LevelMap& vcLev
 // the method from MV3 to scale vertical velocity
 void ApplicationInfo::scaleVerticalVelocity_mv3(ParamInfo* par)
 {
-    LevelMap lmap    = par->Levels();
-    LevelIterator ii = lmap.begin();
+    LevelMap lmap = par->Levels();
+    auto ii       = lmap.begin();
 
     // Compute distance
     double dellat = ABS(y2_ - y1_), dellon = ABS(x2_ - x1_);
@@ -667,19 +675,19 @@ void ApplicationInfo::scaleVerticalVelocity_mv3(ParamInfo* par)
 // compute vertical velocity from omega using the hydrostatic equation
 void ApplicationInfo::computeVerticalVelocity(ParamInfo* parW, ParamInfo* parT, ParamInfo* parLnsp, MvField& field, double factor)
 {
-    LevelMap lmap_w    = parW->Levels();
-    LevelIterator ww = lmap_w.begin();
-    double *wValues=nullptr;
-    double *splin=nullptr;
+    LevelMap lmap_w = parW->Levels();
+    auto ww         = lmap_w.begin();
+    double* wValues = nullptr;
+    double* splin   = nullptr;
 
-    const double Rd = 287.058; //Gas constant
-    const double g = 9.81; // gravitational acceleration
-    const double t0 = 273.16; // reference temperature
+    const double Rd = 287.058;  //Gas constant
+    const double g  = 9.81;     // gravitational acceleration
+    const double t0 = 273.16;   // reference temperature
 
     // we have the values on the cross section line but have not
     // performed the vertical interpolation yet
 
-    assert(levType_ == XS_ML_LNSP  || levType_ == XS_PL || levType_ == XS_ML_GHBC);
+    assert(levType_ == XS_ML_LNSP || levType_ == XS_PL || levType_ == XS_ML_GHBC);
     if (levType_ != XS_ML_LNSP && levType_ != XS_PL && levType_ != XS_ML_GHBC) {
         throw MvException("XSection-> Cannot compute vertical velocity! Level type is not supported!");
     }
@@ -687,7 +695,6 @@ void ApplicationInfo::computeVerticalVelocity(ParamInfo* parW, ParamInfo* parT,
     // for model levels with lnsp we need to compute the pressure on the current level along the
     // cross section line
     if (levType_ == XS_ML_LNSP || levType_ == XS_ML_GHBC) {
-
         // Get LNSP values
         if (!parLnsp)
             throw MvException("XSection-> Cannot compute vertical velocity! LNSP field is not found!");
@@ -695,15 +702,14 @@ void ApplicationInfo::computeVerticalVelocity(ParamInfo* parW, ParamInfo* parT,
         splin = parLnsp->getOneLevelValues("1");
         if (!splin)
             throw MvException("XSection-> Cannot compute vertical velocity! LNSP field is empty!");
-
     }
 
     if (parT) {
-        LevelMap lmap_t  = parT->Levels();
-        LevelIterator tt = lmap_t.begin();
-        double *tValues;
+        LevelMap lmap_t = parT->Levels();
+        auto tt         = lmap_t.begin();
+        double* tValues;
 
-        for (; ww != lmap_w.end() && tt != lmap_t.end(); ww++,tt++) {
+        for (; ww != lmap_w.end() && tt != lmap_t.end(); ww++, tt++) {
             wValues = (*ww).second->XValues();
             tValues = (*tt).second->XValues();
 
@@ -713,16 +719,16 @@ void ApplicationInfo::computeVerticalVelocity(ParamInfo* parW, ParamInfo* parT,
             getPressureOnLevel(splin, field, p, level);
 
             for (int i = 0; i < nrPoints_; i++) {
-                if (wValues[i] < XMISSING_VALUE && tValues[i] < XMISSING_VALUE )
+                if (wValues[i] < XMISSING_VALUE && tValues[i] < XMISSING_VALUE)
                     wValues[i] = -factor * wValues[i] / (g * p[i] / (Rd * tValues[i]));
                 else
                     wValues[i] = XMISSING_VALUE;
             }
         }
-    } else {
-
+    }
+    else {
         for (; ww != lmap_w.end(); ww++) {
-            wValues   = (*ww).second->XValues();
+            wValues = (*ww).second->XValues();
 
             // the pressure values along the line
             std::vector<double> p(nrPoints_, XMISSING_VALUE);
@@ -742,8 +748,8 @@ void ApplicationInfo::computeVerticalVelocity(ParamInfo* parW, ParamInfo* parT,
 // scale vertical velocity with the given factor
 void ApplicationInfo::scaleVerticalVelocity(ParamInfo* par, double factor)
 {
-    LevelMap lmap    = par->Levels();
-    LevelIterator ii = lmap.begin();
+    LevelMap lmap = par->Levels();
+    auto ii       = lmap.begin();
 
     double* values;
     for (; ii != lmap.end(); ii++) {
@@ -755,7 +761,6 @@ void ApplicationInfo::scaleVerticalVelocity(ParamInfo* par, double factor)
                 values[i] = XMISSING_VALUE;
         }
     }
-
 }
 
 void ApplicationInfo::getPressureOnLevel(double* splin, MvField& field, std::vector<double>& p, double level)
@@ -765,17 +770,20 @@ void ApplicationInfo::getPressureOnLevel(double* splin, MvField& field, std::vec
         for (int i = 0; i < nrPoints_; i++) {
             if (splin[i] < XMISSING_VALUE) {
                 p[i] = field.meanML_to_Pressure_byLNSP(splin[i], level);
-            } else {
+            }
+            else {
                 p[i] = XMISSING_VALUE;
             }
         }
-    } else if (levType_ == XS_PL) {
+    }
+    else if (levType_ == XS_PL) {
         //we need Pa units
         double p_val = level;
         for (int i = 0; i < nrPoints_; i++) {
             p[i] = p_val;
         }
-    } else {
+    }
+    else {
         for (int i = 0; i < nrPoints_; i++) {
             p[i] = XMISSING_VALUE;
         }
@@ -855,14 +863,14 @@ void ApplicationInfo::setYValues(MvNcVar *yvar, ParamInfo *par)
 }
 #endif
 
-bool ApplicationInfo::computeLevelMatrixValues(ParamMap& params, const string& key,
+bool ApplicationInfo::computeLevelMatrixValues(ParamMap& params, const std::string& key,
                                                ParamInfo* resPar,
-                                               vector<double>& y_values,
-                                               vector<double>& cp, MvField& field)
+                                               std::vector<double>& y_values,
+                                               std::vector<double>& cp, MvField& field)
 {
     // Get parameter info
-    ParamIterator ii = params.find(key);
-    ParamInfo* par   = (*ii).second;
+    auto ii        = params.find(key);
+    ParamInfo* par = (*ii).second;
 
     // Compute values
     double* splin = 0;
@@ -906,16 +914,16 @@ bool ApplicationInfo::computeLevelMatrixValues(ParamMap& params, const string& k
     return true;
 }
 
-bool ApplicationInfo::computeLevelMatrixValues(ParamMap& params, const string& key,
-                                               vector<double>& y_values,
-                                               vector<double>& cp,
+bool ApplicationInfo::computeLevelMatrixValues(ParamMap& params, const std::string& key,
+                                               std::vector<double>& y_values,
+                                               std::vector<double>& cp,
                                                MvField& field)
-{  
+{
     // Get parameter info
-    ParamIterator ii = params.find(key);
-    ParamInfo* par   = (*ii).second;
+    auto ii        = params.find(key);
+    ParamInfo* par = (*ii).second;
 
-    return computeLevelMatrixValues(params,key,par,y_values,cp,field);
+    return computeLevelMatrixValues(params, key, par, y_values, cp, field);
 
 #if 0
     // Compute values
@@ -961,7 +969,7 @@ bool ApplicationInfo::computeLevelMatrixValues(ParamMap& params, const string& k
 #endif
 }
 
-int ApplicationInfo::computeLevelInfoUI(ParamInfo* par, vector<double>& vals, double* splin, MvField& field)
+int ApplicationInfo::computeLevelInfoUI(ParamInfo* par, std::vector<double>& vals, double* splin, MvField& field)
 {
     // Compute the levels according to the parameters given in the user interface
     if (uiLSType_ == "FROM_DATA") {
@@ -984,22 +992,22 @@ int ApplicationInfo::computeLevelInfoUI(ParamInfo* par, vector<double>& vals, do
     }
 }
 
-int ApplicationInfo::computeLevelInfo(ParamInfo* par, vector<double>& vals)
+int ApplicationInfo::computeLevelInfo(ParamInfo* par, std::vector<double>& vals)
 {
     // Get levels
     LevelMap lmap = par->Levels();
     int nrLevels  = lmap.size();
     vals.clear();
     vals.reserve(nrLevels);
-    for (LevelIterator jj = lmap.begin(); jj != lmap.end(); jj++)
-        vals.push_back((*jj).second->YValue());
+    for (auto& jj : lmap)
+        vals.push_back(jj.second->YValue());
 
     nInputLevels_ = nOutputLevels_ = nrLevels;
 
     return nrLevels;
 }
 
-int ApplicationInfo::computeLevelInfo(ParamInfo* par, vector<double>& vals, double* splin, MvField& field)
+int ApplicationInfo::computeLevelInfo(ParamInfo* par, std::vector<double>& vals, double* splin, MvField& field)
 {
     // Convert ML&LNSP to PL using the following algorithm:
     // a) for each ML value (1,2,...N) get all the correspondent values
@@ -1015,8 +1023,8 @@ int ApplicationInfo::computeLevelInfo(ParamInfo* par, vector<double>& vals, doub
     int nrLevels  = lmap.size();
     vals.clear();
     vals.reserve(nrLevels);  // initial allocation, it will increase in part B
-    for (LevelIterator jj = lmap.begin(); jj != lmap.end(); jj++) {
-        LevelInfo* lInfo = (*jj).second;
+    for (auto& jj : lmap) {
+        LevelInfo* lInfo = jj.second;
         double dlev      = 0.;
         int count        = 0;
         for (int i = 0; i < nrPoints_; i++) {
@@ -1046,7 +1054,7 @@ int ApplicationInfo::computeLevelInfo(ParamInfo* par, vector<double>& vals, doub
     return nOutputLevels_;
 }
 
-int ApplicationInfo::computeLevelInfo(vector<double>& vals)
+int ApplicationInfo::computeLevelInfo(std::vector<double>& vals)
 {
     // Initialize array
     vals.clear();
@@ -1072,7 +1080,7 @@ int ApplicationInfo::computeLevelInfo(vector<double>& vals)
     return nOutputLevels_;
 }
 
-void ApplicationInfo::computeLevelInfoGHBC(ParamInfo* par, vector<double>& vals)
+void ApplicationInfo::computeLevelInfoGHBC(ParamInfo* par, std::vector<double>& vals)
 {
     //Compute the average vertical coordinate value for each input GHBC level
     //along the cross section line. The result is one coordinate value per level.
@@ -1082,8 +1090,8 @@ void ApplicationInfo::computeLevelInfoGHBC(ParamInfo* par, vector<double>& vals)
     double minVal = 1E20;
     double maxVal = -1E20;
     double xval;
-    for (LevelIterator jj = lmap.begin(); jj != lmap.end(); jj++) {
-        LevelInfo* lInfo = (*jj).second;
+    for (auto& jj : lmap) {
+        LevelInfo* lInfo = jj.second;
         double dlev      = 0.;
         int count        = 0;
         for (int i = 0; i < nrPoints_; i++) {
@@ -1098,7 +1106,7 @@ void ApplicationInfo::computeLevelInfoGHBC(ParamInfo* par, vector<double>& vals)
             }
         }
 
-        double mean = (count)?(dlev/count):0.;
+        double mean = (count) ? (dlev / count) : 0.;
         vals.push_back(mean);
     }
 
@@ -1109,20 +1117,21 @@ void ApplicationInfo::computeLevelInfoGHBC(ParamInfo* par, vector<double>& vals)
     //that we do not know anything about the nature of the vertical
     //coordinate (since it is "generic").
     if (extrapolateGHBC_ && nrLevels > 1) {
-        double deltaFirst = fabs(vals[0]-vals[1]);
-        double deltaLast = fabs(vals[nrLevels-1]-vals[nrLevels-2]);
+        double deltaFirst = fabs(vals[0] - vals[1]);
+        double deltaLast  = fabs(vals[nrLevels - 1] - vals[nrLevels - 2]);
         if (vals[0] < vals[1]) {
-            vals.insert(vals.begin(), minVal-deltaFirst);
-            vals.push_back(maxVal+deltaLast);
-        } else {
-            vals.insert(vals.begin(), maxVal+deltaFirst);
-            vals.push_back(minVal-deltaLast);
+            vals.insert(vals.begin(), minVal - deltaFirst);
+            vals.push_back(maxVal + deltaLast);
         }
-        nOutputLevels_+=2;
+        else {
+            vals.insert(vals.begin(), maxVal + deltaFirst);
+            vals.push_back(minVal - deltaLast);
+        }
+        nOutputLevels_ += 2;
     }
 }
 
-void ApplicationInfo::getLevelValues(ParamInfo* par, vector<double>& cp)
+void ApplicationInfo::getLevelValues(ParamInfo* par, std::vector<double>& cp)
 {
     LevelMap lmap = par->Levels();
     LevelIterator ii;
@@ -1241,10 +1250,10 @@ void ApplicationInfo::setVerticalInterpolationFlag(bool flag)
     interpolate_ = flag;
 }
 
-ParamInfo* ApplicationInfo::getParamInfo(ParamMap& params, const string& key)
+ParamInfo* ApplicationInfo::getParamInfo(ParamMap& params, const std::string& key)
 {
     // Check if field is valid
-    ParamIterator ii = params.find(key);
+    auto ii = params.find(key);
     if (ii == params.end()) {
         std::ostringstream error;
         error << "XSection getParamInfo-> Could not find the requested field: " << key;
@@ -1255,16 +1264,16 @@ ParamInfo* ApplicationInfo::getParamInfo(ParamMap& params, const string& key)
     return (*ii).second;
 }
 
-ParamInfo* ApplicationInfo::getParamInfo(ParamMap& params, int key, const string& keyBase)
+ParamInfo* ApplicationInfo::getParamInfo(ParamMap& params, int key, const std::string& keyBase)
 {
     // Build the new key based on keyBase
-    ostringstream os;
-    os << setfill('0')
+    std::ostringstream os;
+    os << std::setfill('0')
        << "p"
-       << setw(6) << key
+       << std::setw(6) << key
        << keyBase.substr(7);
 
-    string newKey = os.str();
+    std::string newKey = os.str();
 
     // Get paraminfo
     ParamInfo* par;
@@ -1277,8 +1286,8 @@ ParamInfo* ApplicationInfo::getParamInfo(ParamMap& params, int key, const string
         // Special case: if paramInfo not found and key is "extra" (LNSP or GHBC)
         // then try to find any other "extra" paramInfo (do not use the keyBase info)
         if (this->isLNSP(key) || this->isGHBC(key)) {
-            for (ParamIterator ii = params.begin(); ii != params.end(); ii++) {
-                par = (*ii).second;
+            for (auto& param : params) {
+                par = param.second;
                 if (par->Parameter() == key)
                     return par;
             }
@@ -1292,7 +1301,7 @@ ParamInfo* ApplicationInfo::getParamInfo(ParamMap& params, int key, const string
     return par;
 }
 
-void ApplicationInfo::levelList(vector<double>& list)
+void ApplicationInfo::levelList(std::vector<double>& list)
 {
     uiLSList_    = list;
     topLevel_    = list[0];
