@@ -11,8 +11,7 @@
 // Average and Vertical Profile, depending on which request it receives.
 
 
-#ifndef MVXSECTFRAME_H
-#define MVXSECTFRAME_H
+#pragma once
 
 #include "Metview.h"
 #include "MvNetCDF.h"
@@ -30,22 +29,22 @@ const float OFFSET_LEVELINFO = 1000.;  // 10hPa
 // cML_UKMO_ND =  n;       // UKMO New Dynamics - defined elsewhere
 enum
 {
-    XS_ML, //ECMWF model levels, no lnsp specified
-    XS_PL, //Pressure levels or level as is (not falling into any other category)
-    XS_ML_LNSP, //ECMWF model levels with lnsp
-    XS_ML_GHBC //User specified vertical coordinate fields (NOTE: the name is
-               // misleading since it does not have to be ML at all!
+    XS_ML,       //ECMWF model levels, no lnsp specified
+    XS_PL,       //Pressure levels or level as is (not falling into any other category)
+    XS_ML_LNSP,  //ECMWF model levels with lnsp
+    XS_ML_GHBC   //User specified vertical coordinate fields (NOTE: the name is
+                 // misleading since it does not have to be ML at all!
 };
 
 const double cCDR = atan(1.0) / 45.0;  //-- conversion factor Degrees->Radians
                                        //-- atan(1)/45 = (PI/4)/45 = PI/180
 
-const string XS_VARLEVEL   = "nlev";
-const string XS_VARTIME    = "time";
-const string XS_VARLAT     = "lat";
-const string XS_VARLON     = "lon";
-const string XS_VARLATPLOT = "lat_for_plot";
-const string XS_VARLONPLOT = "lon_for_plot";
+const std::string XS_VARLEVEL   = "nlev";
+const std::string XS_VARTIME    = "time";
+const std::string XS_VARLAT     = "lat";
+const std::string XS_VARLON     = "lon";
+const std::string XS_VARLATPLOT = "lat_for_plot";
+const std::string XS_VARLONPLOT = "lon_for_plot";
 
 //-- Q&D trick: still use global vars
 //-- but let them be non-const!
@@ -54,7 +53,7 @@ int U_FIELD    = 131;
 int V_FIELD    = 132;
 int W_FIELD    = 135;
 int LNSP_FIELD = 152;
-int T_FIELD = 130;
+int T_FIELD    = 130;
 #else
 extern int U_FIELD;
 extern int V_FIELD;
@@ -104,13 +103,13 @@ private:
 class LevelCompare
 {
 public:
-    bool operator()(const string& s1, const string& s2) const
+    bool operator()(const std::string& s1, const std::string& s2) const
     {
         return (atof(s1.c_str()) < atof(s2.c_str()));
     }
 };
 
-typedef map<string, LevelInfo*, LevelCompare> LevelMap;
+typedef std::map<std::string, LevelInfo*, LevelCompare> LevelMap;
 typedef LevelMap::iterator LevelIterator;
 
 
@@ -130,7 +129,7 @@ public:
         units_(" "),
         levType_(" ") {}
 
-    ParamInfo(int i1, int i2, int i3, int i4, string sn, string ln, string u, string lt) :
+    ParamInfo(int i1, int i2, int i3, int i4, std::string sn, std::string ln, std::string u, std::string lt) :
         param_(i1),
         date_(i2),
         step_(i4),
@@ -147,49 +146,49 @@ public:
     int Time() { return time_; }
     int Step() { return step_; }
     int Parameter() { return param_; }
-    string ParamName() { return paramName_; }
-    string ParamLongName() { return paramLongName_; }
-    string Units() { return units_; }
-    string LevelType() { return levType_; }
+    std::string ParamName() { return paramName_; }
+    std::string ParamLongName() { return paramLongName_; }
+    std::string Units() { return units_; }
+    std::string LevelType() { return levType_; }
     bool IsSurface();
     const char* ExpVer() { return expver_.c_str(); }
-    string ExpVerTitle();
+    std::string ExpVerTitle();
     void ExpVer(const char* xx) { expver_ = xx; }
-    void Level(double*, string, int, bool);
+    void Level(double*, std::string, int, bool);
     LevelMap& Levels() { return levels_; }
     MvDate ReferenceDate();
     MvDate VerificationDate();
 
-    void AddLevel(string);
+    void AddLevel(std::string);
     void UpdateLevels(bool);
 
     int NrLevels() { return levels_.size(); }
     void Print()
     {
         printf("P: %d %d %d %d %s %s %s\n", param_, date_, step_, time_, paramName_.c_str(), units_.c_str(), levType_.c_str());
-    };
+    }
 
     friend int operator<(const ParamInfo& p1, const ParamInfo& p2)
     {
         return (p1.param_ < p2.param_ || p1.date_ < p2.date_ || p1.time_ < p2.time_ || p1.step_ < p2.step_);
     }
 
-    double* getOneLevelValues(const string&);
+    double* getOneLevelValues(const std::string&);
 
 private:
     int param_, date_, step_, time_;
-    string paramName_;
-    string paramLongName_;
-    string expver_;
-    string units_;
-    string levType_;
+    std::string paramName_;
+    std::string paramLongName_;
+    std::string expver_;
+    std::string units_;
+    std::string levType_;
     LevelMap levels_;
 };
 
-typedef map<string, ParamInfo*> ParamMap;
+typedef std::map<std::string, ParamInfo*> ParamMap;
 typedef ParamMap::iterator ParamIterator;
-typedef pair<ParamIterator, bool> ParamInsertPair;
-typedef pair<const string, ParamInfo*> ParamPair;
+typedef std::pair<ParamIterator, bool> ParamInsertPair;
+typedef std::pair<const std::string, ParamInfo*> ParamPair;
 
 
 //------------------------------ General info for application.
@@ -208,10 +207,10 @@ public:
     // Handle geographical coordinates
     void computeLine(int);
     void computeLine(int&, MvField*);
-    const vector<double>& getLongitude() const { return lon_; }
-    const vector<double>& getLatitude() const { return lat_; }
-    const vector<double>& getLatitudeForPlotting() const { return latForPlotting_; }
-    const vector<double>& getLongitudeForPlotting() const { return lonForPlotting_; }
+    const std::vector<double>& getLongitude() const { return lon_; }
+    const std::vector<double>& getLatitude() const { return lat_; }
+    const std::vector<double>& getLatitudeForPlotting() const { return latForPlotting_; }
+    const std::vector<double>& getLongitudeForPlotting() const { return lonForPlotting_; }
 
     void setAreaLine(double, double, double, double);
     void getAreaLine(double&, double&, double&, double&);
@@ -228,8 +227,8 @@ public:
     double Ancos();
     double Ansin();
 
-    void actionMode(string action) { actionMode_ = action; }
-    string actionMode() { return actionMode_; }
+    void actionMode(std::string action) { actionMode_ = action; }
+    std::string actionMode() { return actionMode_; }
 
     void processType(int type) { procType_ = type; }
     int processType() { return procType_; }
@@ -252,25 +251,25 @@ public:
     int outputLevels() { return nOutputLevels_; }
 
     // Get level values
-    void getLevelValues(ParamInfo*, vector<double>&);
+    void getLevelValues(ParamInfo*, std::vector<double>&);
 
     // Compute indexes levels (vertical values)
-    int computeLevelInfoUI(ParamInfo*, vector<double>&, double*, MvField&);  // from UI
-    int computeLevelInfo(ParamInfo*, vector<double>&);                       // model/pressure level
-    int computeLevelInfo(ParamInfo*, vector<double>&, double*, MvField&);    // model level & LNSP
-    int computeLevelInfo(vector<double>&);                                   // compute equal separated levels
-    void computeLevelInfoGHBC(ParamInfo*, vector<double>&);                   // model level & GHBC
+    int computeLevelInfoUI(ParamInfo*, std::vector<double>&, double*, MvField&);  // from UI
+    int computeLevelInfo(ParamInfo*, std::vector<double>&);                       // model/pressure level
+    int computeLevelInfo(ParamInfo*, std::vector<double>&, double*, MvField&);    // model level & LNSP
+    int computeLevelInfo(std::vector<double>&);                                   // compute equal separated levels
+    void computeLevelInfoGHBC(ParamInfo*, std::vector<double>&);                  // model level & GHBC
 
-    bool computeLevelMatrixValues(ParamMap&, const string&, ParamInfo*, vector<double>&, vector<double>&, MvField&);
-    bool computeLevelMatrixValues(ParamMap&, const string&, vector<double>&, vector<double>&, MvField&);
+    bool computeLevelMatrixValues(ParamMap&, const std::string&, ParamInfo*, std::vector<double>&, std::vector<double>&, MvField&);
+    bool computeLevelMatrixValues(ParamMap&, const std::string&, std::vector<double>&, std::vector<double>&, MvField&);
 
     void scaleVerticalVelocity_mv3(ParamInfo*);
-    void computeVerticalVelocity(ParamInfo* ,ParamInfo*, ParamInfo*, MvField& field, double);
+    void computeVerticalVelocity(ParamInfo*, ParamInfo*, ParamInfo*, MvField& field, double);
     void scaleVerticalVelocity(ParamInfo*, double);
 
-    void InterpolateVerticala(vector<double>&, ParamInfo*, vector<double>&);
-    void InterpolateVerticalb(MvField&, vector<double>&, ParamInfo*, double*, vector<double>&);
-    void InterpolateVerticalGHBC(vector<double>&, ParamInfo*, ParamInfo*, vector<double>&);
+    void InterpolateVerticala(std::vector<double>&, ParamInfo*, std::vector<double>&);
+    void InterpolateVerticalb(MvField&, std::vector<double>&, ParamInfo*, double*, std::vector<double>&);
+    void InterpolateVerticalGHBC(std::vector<double>&, ParamInfo*, ParamInfo*, std::vector<double>&);
 
     void getPressureOnLevel(double* splin, MvField& field, std::vector<double>& p, double level);
     bool findModelPressure(LevelMap&, double, double, MvField&, LevelInfo*&, LevelInfo*&, double&, double&);
@@ -279,7 +278,7 @@ public:
 
     bool findPressure(LevelMap&, double, LevelInfo*&, LevelInfo*&);
 
-    bool generateAverageData(ParamMap&, MvNetCDF&, const string&, MvField&, double*, double*, double*);
+    bool generateAverageData(ParamMap&, MvNetCDF&, const std::string&, MvField&, double*, double*, double*);
 
     // Handle vertical interpolation settings
     // Two ways to set a vertical interpolation flag:
@@ -311,23 +310,23 @@ public:
     int GHBC() { return paramGHBC_; }
 
     // Handle horizontal point mode
-    void horPointMode(string mode) { hor_point_ = mode; }
-    string horPointMode() { return hor_point_; }
+    void horPointMode(std::string mode) { hor_point_ = mode; }
+    std::string horPointMode() { return hor_point_; }
     bool isHorInterpolate() { return hor_point_ == "INTERPOLATE"; }
 
     // Retrieve information about one parameter
-    ParamInfo* getParamInfo(ParamMap&, const string&);
-    ParamInfo* getParamInfo(ParamMap&, int, const string&);
+    ParamInfo* getParamInfo(ParamMap&, const std::string&);
+    ParamInfo* getParamInfo(ParamMap&, int, const std::string&);
 
     // Handle parameters retrieved from the User Interface
-    string levelSelectionType() { return uiLSType_; }
-    void levelSelectionType(const string& type) { uiLSType_ = type; }
+    std::string levelSelectionType() { return uiLSType_; }
+    void levelSelectionType(const std::string& type) { uiLSType_ = type; }
 
     int levelCount() { return uiLSCount_; }
     void levelCount(int count) { uiLSCount_ = count; }
 
-    vector<double> levelList() { return uiLSList_; }
-    void levelList(vector<double>&);
+    std::vector<double> levelList() { return uiLSList_; }
+    void levelList(std::vector<double>&);
 
     bool vLinearScaling() { return uiVLinearScaling_; }
     void vLinearScaling(bool bvs) { uiVLinearScaling_ = bvs; }
@@ -348,25 +347,23 @@ private:
     bool haveLatsForPlotting_;
     bool haveLonsForPlotting_;
     bool haveLNSP_;
-    bool haveGHBC_;      // vertical coordinates flag
-    int paramGHBC_;      // vertical coordinate parameter
+    bool haveGHBC_;  // vertical coordinates flag
+    int paramGHBC_;  // vertical coordinate parameter
     bool extrapolateGHBC_{false};
-    string actionMode_;  // e.g. "examine"/"save"/"execute"/...
-    int procType_;       // processing type
+    std::string actionMode_;  // e.g. "examine"/"save"/"execute"/...
+    int procType_;            // processing type
 
-    string hor_point_;    // horizontal point mode
-    vector<double> lat_;  // geographical coordinates
-    vector<double> lon_;
-    vector<double> latForPlotting_;  // used when line is over a pole and Magics cannot plot the lat co-ordinates
-    vector<double> lonForPlotting_;  // used when line is over a pole and Magics cannot plot the lon co-ordinates
+    std::string hor_point_;    // horizontal point mode
+    std::vector<double> lat_;  // geographical coordinates
+    std::vector<double> lon_;
+    std::vector<double> latForPlotting_;  // used when line is over a pole and Magics cannot plot the lat co-ordinates
+    std::vector<double> lonForPlotting_;  // used when line is over a pole and Magics cannot plot the lon co-ordinates
 
     bool interpolate_;  // vertical interpolation flag
 
     // Parameters from the User Interface
-    string uiLSType_;          // level selection type: FROM_DATA, COUNT, LEVEL_LIST
-    int uiLSCount_;            // level selection count
-    vector<double> uiLSList_;  // level list
-    bool uiVLinearScaling_;    // vertical scaling: [true=LINEAR, false=LOG]
+    std::string uiLSType_;          // level selection type: FROM_DATA, COUNT, LEVEL_LIST
+    int uiLSCount_;                 // level selection count
+    std::vector<double> uiLSList_;  // level list
+    bool uiVLinearScaling_;         // vertical scaling: [true=LINEAR, false=LOG]
 };
-
-#endif
