@@ -28,10 +28,13 @@
 #define INITIALISE_HERE
 
 #include "Xsect.h"
+
+#include <iomanip>
+
 #include "Average.h"
 #include "CrossS.h"
 #include "MvException.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "Vprofile.h"
 
 Xsect::Xsect(const char* kw) :
@@ -44,8 +47,8 @@ Xsect::Xsect(const char* kw) :
 // will have to reset things between each request
 void Xsect::init()
 {
-    ncName_ = "toto.nc";
-    ntime_ = 0;
+    ncName_      = "toto.nc";
+    ntime_       = 0;
     geoIndexVar_ = XS_VARLON;
 }
 
@@ -56,7 +59,7 @@ void Xsect::serve(MvRequest& in, MvRequest& out)
 
     init();
 
-    cout << "request IN" << endl;
+    std::cout << "request IN" << std::endl;
     in.print();
 
     // Get Input parameters
@@ -85,7 +88,7 @@ void Xsect::serve(MvRequest& in, MvRequest& out)
     if ((const char*)in("_NAME"))
         out("_NAME") = in("_NAME");
 
-    cout << "request OUT" << endl;
+    std::cout << "request OUT" << std::endl;
     out.print();
 
     return;
@@ -114,7 +117,7 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
         setError(0, "Xsect line via Pole");
 
     // Allocate memory/initialise auxiliary variables
-    double* xint = new double[npoint];
+    auto* xint = new double[npoint];
     ParamMap params;
 
     // First loop: build field keystring and get the Level info.
@@ -122,7 +125,7 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
     // matrices are computed in the second loop.
     boolean isPL = false;
     boolean isML = false;
-    string keystr;
+    std::string keystr;
     bool foundU = false, foundV = false, foundW = false, foundT = false;
     int iparam, idate, itime, istep;
     const char* expver = 0;
@@ -132,7 +135,7 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
         MvRequest rq     = field.getRequest();
         iparam           = rq("PARAM");
         const char* levc = rq("LEVELIST");
-        string lev       = (levc) ? levc : "";
+        std::string lev  = (levc) ? levc : "";
         istep            = rq("STEP");
         idate            = rq.getBaseDate();
         itime            = rq("TIME");
@@ -154,8 +157,8 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
             if (field.levelTypeString() == cML_UKMO_ND_STR)
                 dlev = field.level_L2();
 
-            ostringstream s;
-            s << dlev << ends;
+            std::ostringstream s;
+            s << dlev << std::ends;
 
             lev = s.str();
         }
@@ -181,11 +184,11 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
             }
 
             // Create a new ParamInfo instance
-            ParamInfo* par = new ParamInfo(iparam, idate, itime, istep,
-                                           field.getGribKeyValueString("shortName"),
-                                           field.getGribKeyValueString("name"),
-                                           field.getGribKeyValueString("units"),
-                                           field.getGribKeyValueString("levelType"));
+            auto* par = new ParamInfo(iparam, idate, itime, istep,
+                                      field.getGribKeyValueString("shortName"),
+                                      field.getGribKeyValueString("name"),
+                                      field.getGribKeyValueString("units"),
+                                      field.getGribKeyValueString("levelType"));
 
             // Insert ParamInfo and the 'level' values
             ParamInsertPair inserted = params.insert(ParamPair(keystr, par));
@@ -204,11 +207,11 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
                 foundT = true;
 
             // Create a new ParamInfo instance
-            ParamInfo* par = new ParamInfo(iparam, idate, itime, istep,
-                                           field.getGribKeyValueString("shortName"),
-                                           field.getGribKeyValueString("name"),
-                                           field.getGribKeyValueString("units"),
-                                           field.getGribKeyValueString("levelType"));
+            auto* par = new ParamInfo(iparam, idate, itime, istep,
+                                      field.getGribKeyValueString("shortName"),
+                                      field.getGribKeyValueString("name"),
+                                      field.getGribKeyValueString("units"),
+                                      field.getGribKeyValueString("levelType"));
 
             // Insert ParamInfo and only the 'level'info (not the values)
             ParamInsertPair inserted = params.insert(ParamPair(keystr, par));
@@ -264,7 +267,7 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
     appInfo.NTimes(ntimes);
 
     // Initialize variables
-    string lastKey       = "FIRSTFIELD";
+    std::string lastKey  = "FIRSTFIELD";
     int currentGenerated = 0, lastNrGenerated = -1;
     MvField lastField;
 
@@ -294,14 +297,14 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
 
         // Update level info accordingly
         const char* clevc = r("LEVELIST");
-        string clev       = (clevc) ? clevc : "";
+        std::string clev  = (clevc) ? clevc : "";
         if (clev.empty() || clev != "0" || field.levelTypeString() == cML_UKMO_ND_STR) {
             double myLevel = field.level();
             if (field.levelTypeString() == cML_UKMO_ND_STR)
                 myLevel = field.level_L2();
 
-            ostringstream s;
-            s << myLevel << ends;
+            std::ostringstream s;
+            s << myLevel << std::ends;
 
             clev = s.str();
         }
@@ -330,7 +333,7 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
         }
 
         // Write out the data if we have the end of what can be grouped together.
-        if (lastKey != keystr && lastKey != string("FIRSTFIELD")) {
+        if (lastKey != keystr && lastKey != std::string("FIRSTFIELD")) {
             if (!generateData(appInfo, params, netcdf, lastField, lastKey)) {
                 setError(1, "Xsect-> Could not generate NETCDF data: error on fieldset or fieldset not suitable");
                 deleteAuxiliaryMemory(xint, params);
@@ -377,19 +380,19 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
     return true;
 }
 
-void Xsect::generateKey(string& str, int par, int date, int time,
+void Xsect::generateKey(std::string& str, int par, int date, int time,
                         int step, const char* expver)
 {
     // Format: pPPPPPPYYYYMMDDHHmmSSSS
-    ostringstream oss;
-    oss << setfill('0')
+    std::ostringstream oss;
+    oss << std::setfill('0')
         << "p"
-        << setw(6) << par
-        << setw(8) << date
-        << setw(4) << time
-        << setw(4) << step
-        << setw(4) << (expver ? expver : "_");
-    //<< ends;  // be careful, it adds one more character
+        << std::setw(6) << par
+        << std::setw(8) << date
+        << std::setw(4) << time
+        << std::setw(4) << step
+        << std::setw(4) << (expver ? expver : "_");
+    //<< std::ends;  // be careful, it adds one more character
 
     str = oss.str();
 }
@@ -456,8 +459,8 @@ bool Xsect::isVisualise(ApplicationInfo& appInfo)
     // If the output is not 'visualisation' related: actions
     // "not visualise" or "prepare" (in certain cases), then
     // send back the "netCDF" request
-    string actionMode = appInfo.actionMode();
-    int procType      = appInfo.processType();
+    std::string actionMode = appInfo.actionMode();
+    int procType           = appInfo.processType();
     if (actionMode != "visualise" &&
         !(actionMode == "prepare" && procType == XS_DATA_MODULE_DROPPED) &&
         !(actionMode == "prepare" && procType == XS_DATA_DROPPED))
@@ -548,7 +551,7 @@ bool Xsect::getInputParameters(MvRequest& in, MvRequest& data, ApplicationInfo&
     }
 
     // Retrieve action mode. Default value is "prepare"
-    string actionMode = (const char*)in("_ACTION") ? (const char*)in("_ACTION") : "prepare";
+    std::string actionMode = (const char*)in("_ACTION") ? (const char*)in("_ACTION") : "prepare";
 
     // Save info
     appInfo.actionMode(actionMode);
@@ -616,7 +619,7 @@ MvRequest Xsect::getAppView(MvRequest& viewRequest)
 
     // The original view request has not been processed yet.
     // Retrieve it from the input request
-    string sview = viewRequest.getVerb();
+    std::string sview = viewRequest.getVerb();
     if (view_ == sview)
         return viewRequest;
 
@@ -633,7 +636,7 @@ bool Xsect::consistencyCheck(ParamMap& params, ApplicationInfo& appInfo)
 
     // 2) If there is only one parameter, it must contain several levels
     if (params.size() == 1) {
-        ParamIterator ii = params.begin();
+        auto ii = params.begin();
         if ((*ii).second->NrLevels() <= 1) {
             setError(1, "Xsect-> Number of levels must be greater than 1");
             return false;
@@ -643,10 +646,11 @@ bool Xsect::consistencyCheck(ParamMap& params, ApplicationInfo& appInfo)
     // 3) Options related to the level_selection_type parameters in the
     // user interface must be compatible to the input fieldset
     if (appInfo.levelType() == XS_ML && appInfo.levelSelectionType() != "FROM_DATA") {
-        setError(1, "Xsect-> Invalid value for parameter LEVEL_SELECTION_TYPE (=%s).\
+        setError(1,
+                 "Xsect-> Invalid value for parameter LEVEL_SELECTION_TYPE (=%s).\
                     It must be set to FROM_DATA because the input model level data does\
                     not contain LNSP!",
-                    appInfo.levelSelectionType().c_str());
+                 appInfo.levelSelectionType().c_str());
         return false;
     }
 
@@ -659,13 +663,13 @@ bool Xsect::consistencyCheck(ParamMap& params, ApplicationInfo& appInfo)
 bool Xsect::writeTimeInfoNetcdf(MvNetCDF& cdf, ParamMap& params, int& ntimes)
 {
     // Loop through all parameters
-    vector<int> stepS;
+    std::vector<int> stepS;
     int idNew;
-    bool first       = true;
-    int ntimesNew    = 0;
-    ParamIterator ii = params.begin();
-    int id           = (*ii).second->Parameter();  // parameter id
-    MvDate refDate   = (*ii).second->ReferenceDate();
+    bool first     = true;
+    int ntimesNew  = 0;
+    auto ii        = params.begin();
+    int id         = (*ii).second->Parameter();  // parameter id
+    MvDate refDate = (*ii).second->ReferenceDate();
     while (ii != params.end()) {
         // Accumulate and check time consistency
         idNew = (*ii).second->Parameter();
@@ -708,8 +712,8 @@ bool Xsect::writeTimeInfoNetcdf(MvNetCDF& cdf, ParamMap& params, int& ntimes)
     }
 
     // Add the 'time' variable to netCDF
-    vector<long> levels_dimsize(1, ntimes);
-    vector<string> levels_name(1, XS_VARTIME);
+    std::vector<long> levels_dimsize(1, ntimes);
+    std::vector<std::string> levels_name(1, XS_VARTIME);
     MvNcVar* nctime = cdf.addVariable(levels_name[0], ncInt, levels_dimsize, levels_name);
     char referenceDateString[128];
     refDate.Format(refDate.StringFormat(), referenceDateString);
@@ -730,7 +734,7 @@ bool Xsect::writeGlobalAttributesNetcdf(MvNetCDF& netcdf, ParamMap& params, Appl
     netcdf.addAttribute("_FillValue", XMISSING_VALUE);
     netcdf.addAttribute("_View", view_.c_str());
     netcdf.addAttribute("type", type_.c_str());
-    std::string xsHorizontalMethod = (appInfo.isHorInterpolate())?"interpolate":"nearest";
+    std::string xsHorizontalMethod = (appInfo.isHorInterpolate()) ? "interpolate" : "nearest";
     netcdf.addAttribute("xsHorizontalMethod", xsHorizontalMethod.c_str());
 
     // Add title to the Global Attributes.
@@ -742,7 +746,7 @@ bool Xsect::writeGlobalAttributesNetcdf(MvNetCDF& netcdf, ParamMap& params, Appl
     if (!parInfo)
         return false;
 
-    string title = this->titleVariable(appInfo, parInfo);
+    std::string title = this->titleVariable(appInfo, parInfo);
     return netcdf.addAttribute("title", title.c_str());
 }
 
@@ -750,9 +754,9 @@ ParamInfo* Xsect::plotVariable(ApplicationInfo& appInfo, ParamMap& params)
 {
     // Return the first variable that has more than 1 level and
     // it is not a GHBC
-    for (ParamIterator ii = params.begin(); ii != params.end(); ii++) {
-        if ((*ii).second->NrLevels() > 1 && !appInfo.isGHBC((*ii).second->Parameter()))
-            return (*ii).second;
+    for (auto& param : params) {
+        if (param.second->NrLevels() > 1 && !appInfo.isGHBC(param.second->Parameter()))
+            return param.second;
     }
 
     setError(1, "Xsect-> Fieldset to be processed must have more than 2 levels");
@@ -763,13 +767,13 @@ ParamInfo* Xsect::plotVariable(ApplicationInfo& appInfo, ParamMap& params)
 bool Xsect::writeGeoCoordsNetcdf(MvNetCDF& cdf, ApplicationInfo& appInfo)
 {
     // Compute lat/long interpolation points
-    int npoint                = appInfo.NrPoints();
-    const vector<double>& lon = appInfo.getLongitude();
-    const vector<double>& lat = appInfo.getLatitude();
+    int npoint                     = appInfo.NrPoints();
+    const std::vector<double>& lon = appInfo.getLongitude();
+    const std::vector<double>& lat = appInfo.getLatitude();
 
     // Add Latitude value
-    vector<string> coord_sdim(1, XS_VARLAT);
-    vector<long> coord_ndim(1, npoint);
+    std::vector<std::string> coord_sdim(1, XS_VARLAT);
+    std::vector<long> coord_ndim(1, npoint);
     MvNcVar* nccoord = cdf.addVariable(coord_sdim[0], ncDouble, coord_ndim, coord_sdim);
     nccoord->addAttribute("long_name", "latitude");
     nccoord->addAttribute("units", "degrees_north");
@@ -785,18 +789,18 @@ bool Xsect::writeGeoCoordsNetcdf(MvNetCDF& cdf, ApplicationInfo& appInfo)
     // Add a 'latitude for plotting' variable?
     if (appInfo.viaPole()) {
         if (appInfo.haveLatsForPlotting()) {
-            const vector<double>& latForPlotting = appInfo.getLatitudeForPlotting();
-            coord_sdim[0]                        = XS_VARLATPLOT;
-            nccoord                              = cdf.addVariable(coord_sdim[0], ncDouble, coord_ndim, coord_sdim);
+            const std::vector<double>& latForPlotting = appInfo.getLatitudeForPlotting();
+            coord_sdim[0]                             = XS_VARLATPLOT;
+            nccoord                                   = cdf.addVariable(coord_sdim[0], ncDouble, coord_ndim, coord_sdim);
             nccoord->addAttribute("long_name", "latitude_plot");
             nccoord->addAttribute("units", "degrees_north");
             nccoord->put(latForPlotting, (long)npoint);
         }
 
         if (appInfo.haveLonsForPlotting()) {
-            const vector<double>& lonForPlotting = appInfo.getLongitudeForPlotting();
-            coord_sdim[0]                        = XS_VARLONPLOT;
-            nccoord                              = cdf.addVariable(coord_sdim[0], ncDouble, coord_ndim, coord_sdim);
+            const std::vector<double>& lonForPlotting = appInfo.getLongitudeForPlotting();
+            coord_sdim[0]                             = XS_VARLONPLOT;
+            nccoord                                   = cdf.addVariable(coord_sdim[0], ncDouble, coord_ndim, coord_sdim);
             nccoord->addAttribute("long_name", "longitude_plot");
             nccoord->addAttribute("units", "degrees_east");
             nccoord->put(lonForPlotting, (long)npoint);
@@ -808,42 +812,42 @@ bool Xsect::writeGeoCoordsNetcdf(MvNetCDF& cdf, ApplicationInfo& appInfo)
 
 // Generate contour data ( for xsection or average).
 bool Xsect::contourValues(ApplicationInfo& appInfo, ParamMap& params,
-                          MvNetCDF& cdf, MvField& field, string key)
+                          MvNetCDF& cdf, MvField& field, std::string key)
 {
-    vector<double> y_values;
-    vector<double> cp;
+    std::vector<double> y_values;
+    std::vector<double> cp;
     if (!appInfo.computeLevelMatrixValues(params, key, y_values, cp, field)) {
         setError(1, "Xsect-> Could not find the requested key field: %s", key.c_str());
         return false;
     }
 
     // Get parameter info
-    ParamIterator ii = params.find(key);
-    ParamInfo* par   = (*ii).second;
+    auto ii        = params.find(key);
+    ParamInfo* par = (*ii).second;
 
     // Add/update variable to the netCDF
-    int nrLevels      = appInfo.outputLevels();
-    int nrPoints      = appInfo.NrPoints();
-    string varname    = this->getNetcdfVarname(par->ParamName());
-    string levname    = this->getNetcdfLevelVarname(varname);
-    MvNcVar* nclevels = cdf.getVariable(levname);
-    MvNcVar* ncv      = cdf.getVariable(varname);
+    int nrLevels        = appInfo.outputLevels();
+    int nrPoints        = appInfo.NrPoints();
+    std::string varname = this->getNetcdfVarname(par->ParamName());
+    std::string levname = this->getNetcdfLevelVarname(varname);
+    MvNcVar* nclevels   = cdf.getVariable(levname);
+    MvNcVar* ncv        = cdf.getVariable(varname);
     if (!ncv || !nclevels)  // Create new variables
     {
         ntime_ = -1;
 
         // Initialise dimensions
-        vector<long> values_ndim;
+        std::vector<long> values_ndim;
         values_ndim.push_back(appInfo.NTimes());
         values_ndim.push_back(nrLevels);
-        vector<string> values_sdim;
+        std::vector<std::string> values_sdim;
         values_sdim.push_back(XS_VARTIME);
         values_sdim.push_back(XS_VARLEVEL);
 
         // Create variable 'levels'
         if (!nclevels) {
-            string levname = getNetcdfLevelVarname(varname);
-            nclevels       = cdf.addVariable(levname, ncDouble, values_ndim, values_sdim);
+            std::string levname = getNetcdfLevelVarname(varname);
+            nclevels            = cdf.addVariable(levname, ncDouble, values_ndim, values_sdim);
             nclevels->addAttribute("long_name", "Atmospheric Levels");
             nclevels->addAttribute("units", "hPa");
             nclevels->addAttribute("positive", "down");
@@ -868,7 +872,7 @@ bool Xsect::contourValues(ApplicationInfo& appInfo, ParamMap& params,
 
     double factor = 1;
     if (appInfo.levelType() == XS_PL || appInfo.levelType() == XS_ML_LNSP) {
-        factor = 100; //Pa -> hPa
+        factor = 100;  //Pa -> hPa
     }
 
     for (i = 0; i < nrLevels; i++)
@@ -892,16 +896,16 @@ bool Xsect::contourValues(ApplicationInfo& appInfo, ParamMap& params,
 // b) variable name starting with non-alphabetic letter is
 //    replaced by the following scheme: all non-alphabetic
 //    letters are moved to the end, e.g. 10u becomes u_10
-string Xsect::getNetcdfVarname(const string& name)
+std::string Xsect::getNetcdfVarname(const std::string& name)
 {
     // RTTOV specific
     if (name == "skt")
-        return string("t_skin");
+        return std::string("t_skin");
 
     // Netcdf only accepts variable name starting with a alphabetic letter
     // Copy initial numbers
     unsigned int j = 0, i;
-    string snum;
+    std::string snum;
     for (i = 0; i < name.size(); i++) {
         if (isalpha(name[i]))
             break;
@@ -916,12 +920,12 @@ string Xsect::getNetcdfVarname(const string& name)
 
     // The name has only numbers. Add a prefix.
     else if (j == name.size()) {
-        string newname = "a_" + snum;
+        std::string newname = "a_" + snum;
         return newname;
     }
 
     // The name has numbers in the begining. Move them to the end.
-    string newname = name.substr(i, name.size() - i) + "_";
+    std::string newname = name.substr(i, name.size() - i) + "_";
     newname += snum;
 
     return newname;
@@ -961,8 +965,8 @@ void Xsect::deleteAuxiliaryMemory(double* xint, ParamMap& params)
     }
 
     // Free memory for parameters
-    for (ParamIterator paramIter = params.begin(); paramIter != params.end(); paramIter++)
-        delete (*paramIter).second;
+    for (auto& param : params)
+        delete param.second;
 }
 
 bool Xsect::initialiseNetcdf(MvNetCDF& netcdf, ParamMap& params, ApplicationInfo& appInfo, int& ntimes, MvField& field, double* xint)
@@ -993,17 +997,17 @@ bool Xsect::initialiseNetcdf(MvNetCDF& netcdf, ParamMap& params, ApplicationInfo
     return true;
 }
 
-MvNcVar* Xsect::getNetcdfVariable(MvNetCDF& cdf, const string& varname, ApplicationInfo& appInfo, const string& longname, ParamInfo* param)
+MvNcVar* Xsect::getNetcdfVariable(MvNetCDF& cdf, const std::string& varname, ApplicationInfo& appInfo, const std::string& longname, ParamInfo* param)
 {
     MvNcVar* ncv = cdf.getVariable(varname);
     if (!ncv)  // Create new variable
     {
         // Initialise dimensions
-        vector<long> values_ndim;
+        std::vector<long> values_ndim;
         values_ndim.push_back(appInfo.NTimes());
         values_ndim.push_back(appInfo.outputLevels());
         values_ndim.push_back(appInfo.NrPoints());
-        vector<string> values_sdim;
+        std::vector<std::string> values_sdim;
         values_sdim.push_back(XS_VARTIME);
         values_sdim.push_back(XS_VARLEVEL);
         values_sdim.push_back(XS_VARLON);
@@ -1019,16 +1023,16 @@ MvNcVar* Xsect::getNetcdfVariable(MvNetCDF& cdf, const string& varname, Applicat
     return ncv;
 }
 
-MvNcVar* Xsect::getNetcdfVariableLevel(MvNetCDF& cdf, const string& varname, ApplicationInfo& appInfo)
+MvNcVar* Xsect::getNetcdfVariableLevel(MvNetCDF& cdf, const std::string& varname, ApplicationInfo& appInfo)
 {
     MvNcVar* ncv = cdf.getVariable(varname);
     if (!ncv)  // Create new variable
     {
         // Initialise dimensions
-        vector<long> values_ndim;
+        std::vector<long> values_ndim;
         values_ndim.push_back(appInfo.NTimes());
         values_ndim.push_back(appInfo.outputLevels());
-        vector<string> values_sdim;
+        std::vector<std::string> values_sdim;
         values_sdim.push_back(XS_VARTIME);
         values_sdim.push_back(XS_VARLEVEL);
 
