@@ -9,7 +9,6 @@
 
 #include <iostream>
 #include <sstream>
-#include <fstream>
 #include <cstdio>
 #include <stdio.h>
 #include <algorithm>
@@ -18,7 +17,7 @@
 #include "LogHandler.h"
 #include "MvKeyProfile.h"
 #include "MvMessageMetaData.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "MvTmpFile.h"
 #include "MvWindef.h"
 #include "Tokenizer.h"
@@ -39,7 +38,7 @@ std::vector<std::string> GribTableDump::definitionsDir_;
 #endif
 #endif
 
-static bool codesCheck(const char* call, const char* file, int line, int e, const char* msg)
+static bool codesCheck(const char* call, const char* /*file*/, int /*line*/, int e, const char* /*msg*/)
 {
     if (e) {
         GuiLog().error() << call << grib_get_error_message(e);
@@ -68,7 +67,7 @@ static bool shellCommand(const std::string& command, std::stringstream& out, std
         return false;
     }
 
-    while (fgets(cbuf, sizeof(cbuf), in) != NULL) {
+    while (fgets(cbuf, sizeof(cbuf), in) != nullptr) {
         out << cbuf;
     }
 
@@ -80,7 +79,7 @@ static bool shellCommand(const std::string& command, std::stringstream& out, std
         return false;
     }
 
-    while (fgets(cbuf, sizeof(cbuf), in) != NULL) {
+    while (fgets(cbuf, sizeof(cbuf), in) != nullptr) {
         err << cbuf;
     }
 
@@ -90,12 +89,12 @@ static bool shellCommand(const std::string& command, std::stringstream& out, std
 }
 
 #if 0
-static void shellCommand(string &command, stringstream& out,stringstream& err, string &ftmp)
+static void shellCommand(std::string &command, std::stringstream& out,std::stringstream& err, std::string &ftmp)
 {
 	FILE *in;
 	char cbuf[512];
 
-	string cmd;
+	std::string cmd;
 	if(!GRIB_DEFINITION_PATH_ENV.empty())
 	{
 		cmd+="export GRIB_DEFINITION_PATH=" + GRIB_DEFINITION_PATH_ENV + ";";
@@ -103,12 +102,17 @@ static void shellCommand(string &command, stringstream& out,stringstream& err, s
 	
 	cmd+=command + " 2>" + ftmp;
 		
-	if (!(in = popen(cmd.c_str() ,"r")) )
+    if (!(in = popen(void setValue(long val, const std::string& strVal ={}) {
+                     value_ = val; strValue_ = strVal.empty()?val:strVal;}
+                 void setValue(double val, const std::string& strVal ={}) {
+                     value_ = val; strValue_ = strVal.empty()?val:strVal;}
+                 void setValue(const std::string& val) {
+                     value_ = val; strValue_ = val;}cmd.c_str() ,"r")) )
 	{
 		return;
 	}
 
-	while(fgets(cbuf, sizeof(cbuf), in) != NULL)
+	while(fgets(cbuf, sizeof(cbuf), in) != nullptr)
 	{
 		out << cbuf;		
 	}	
@@ -121,7 +125,7 @@ static void shellCommand(string &command, stringstream& out,stringstream& err, s
 		return;
 	}
 
-	while(fgets(cbuf, sizeof(cbuf), in) != NULL)
+	while(fgets(cbuf, sizeof(cbuf), in) != nullptr)
 	{
 		err << cbuf;		
 	}	
@@ -134,14 +138,12 @@ static void shellCommand(string &command, stringstream& out,stringstream& err, s
 
 GribSection::~GribSection()
 {
-    for (std::vector<GribItem*>::iterator it = item_.begin(); it != item_.end(); it++) {
-        delete *it;
+    for (auto& it : item_) {
+        delete it;
     }
 }
 
 
-
-
 //===================================================
 //
 //  GribWmoDump
@@ -155,8 +157,8 @@ GribWmoDump::~GribWmoDump()
 
 void GribWmoDump::clear()
 {
-    for (std::vector<GribSection*>::iterator it = section_.begin(); it != section_.end(); it++) {
-        delete *it;
+    for (auto& it : section_) {
+        delete it;
     }
     section_.clear();
     text_.clear();
@@ -169,7 +171,7 @@ bool GribWmoDump::read(const std::string& fgrib, int msgCnt)
     //int count=1;
     std::string errOut;
 
-    std::string cmd = GRIB_DUMP_EXE + " -O -w count=" + metview::toString(msgCnt) + " " + "\"" + fgrib + "\"";
+    std::string cmd = GRIB_DUMP_EXE + " -O -w count=" + std::to_string(msgCnt) + " " + "\"" + fgrib + "\"";
 
     GuiLog().task() << "Generating WMO-style dump for message: " << msgCnt << GuiLog::commandKey() << cmd;
 
@@ -183,7 +185,7 @@ bool GribWmoDump::read(const std::string& fgrib, int msgCnt)
         hasError = true;
         GuiLog().error() << "Command exited with code: " << exitCode;
         if (err.str().empty())
-            errOut += "<b>Command</b>" + cmd + " exited with <b>code:</b> " + metview::toString<int>(exitCode) + " ";
+            errOut += "<b>Command</b>" + cmd + " exited with <b>code:</b> " + std::to_string(exitCode) + " ";
     }
 
     if (!ret) {
@@ -238,7 +240,7 @@ void GribWmoDump::parse(std::stringstream& in)
         }
         else if ((pos = stmp.find("SECTION_")) != std::string::npos ||
                  (pos = stmp.find("SECTION")) != std::string::npos) {
-            GribSection* sec                 = new GribSection;
+            auto* sec                        = new GribSection;
             std::string::size_type posNumEnd = stmp.find(" ", pos + 8);
             if (posNumEnd != std::string::npos) {
                 sec->name("Section " + stmp.substr(pos + 8, posNumEnd - pos - 8));
@@ -252,20 +254,20 @@ void GribWmoDump::parse(std::stringstream& in)
         }
 
         else if (asec != 0) {
-            int i          = 0;
-            GribItem* item = new GribItem;
+            int i      = 0;
+            auto* item = new GribItem;
             while (ss >> buf) {
                 if (i == 0) {
-                    item->pos(buf);
+                    item->setPos(buf);
                 }
                 else if (i == 1) {
-                    item->name(buf);
+                    item->setName(buf);
                 }
                 else if (i == 2 && buf == "=") {
                     pos  = stmp.find("=");
                     pos1 = stmp.rfind("{");
                     if (pos1 != std::string::npos) {
-                        item->value(stmp.substr(pos, pos1 - pos + 1));
+                        item->setValue(stmp.substr(pos, pos1 - pos + 1));
 
                         in.getline(c, 256);
                         stmp = c;
@@ -294,9 +296,9 @@ void GribWmoDump::parse(std::stringstream& in)
                         //stmp now contains the "}" character
                     }
 
-                    else  //if(buf.find("[") == string::npos || buf.find("]") == string::npos )
+                    else  //if(buf.find("[") ==std::string::npos || buf.find("]") == string::npos )
                     {
-                        item->value(stmp.substr(pos + 1));
+                        item->setValue(stmp.substr(pos + 1));
                         //item->value(buf);
                     }
 
@@ -324,8 +326,8 @@ GribStdDump::~GribStdDump()
 
 void GribStdDump::clear()
 {
-    for (std::vector<GribItem*>::iterator it = item_.begin(); it != item_.end(); it++) {
-        delete *it;
+    for (auto& it : item_) {
+        delete it;
     }
     item_.clear();
     text_.clear();
@@ -335,7 +337,7 @@ void GribStdDump::clear()
 bool GribStdDump::read(const std::string& fname, int msgCnt)
 {
     std::string errOut;
-    std::string cmd = GRIB_DUMP_EXE + " -w count=" + metview::toString(msgCnt) + " " + "\"" + fname + "\"";  //+ "  > " + tmpFile_;
+    std::string cmd = GRIB_DUMP_EXE + " -w count=" + std::to_string(msgCnt) + " " + "\"" + fname + "\"";  //+ "  > " + tmpFile_;
 
     GuiLog().task() << "Generating default dump for message: " << msgCnt << GuiLog::commandKey() << cmd;
 
@@ -350,7 +352,7 @@ bool GribStdDump::read(const std::string& fname, int msgCnt)
         hasError = true;
         GuiLog().error() << "Command exited with code: " << exitCode;
         if (err.str().empty())
-            errOut += "<b>Command</b>" + cmd + " exited with <b>code:</b> " + metview::toString<int>(exitCode) + " ";
+            errOut += "<b>Command</b>" + cmd + " exited with <b>code:</b> " + std::to_string(exitCode) + " ";
     }
 
     if (!ret) {
@@ -390,7 +392,7 @@ void GribStdDump::parse(std::stringstream& in)
     }
 
     while (in.getline(c, 512)) {
-        //cout << c << endl ;
+        //std::cout << c << std::endl ;
 
         std::string buf;  // Have a buffer string
         stmp = c;
@@ -400,10 +402,10 @@ void GribStdDump::parse(std::stringstream& in)
             descText = stmp;
         }
         else {
-            //vector<string> sv;
+            //std::vector<std::string> sv;
             int i = 0;
 
-            GribItem* item = new GribItem;
+            auto* item = new GribItem;
             item_.push_back(item);
 
             while (ss >> buf) {
@@ -417,13 +419,13 @@ void GribStdDump::parse(std::stringstream& in)
                 }
 
                 if (i == 0) {
-                    item->name(buf);
+                    item->setName(buf);
                 }
                 else if (i == 2 && buf != "{") {
-                    item->value(buf.substr(0, buf.size() - 1));
+                    item->setValue(buf.substr(0, buf.size() - 1));
 
                     if (descText.size() > 0) {
-                        item->description(descText);
+                        item->setDescription(descText);
                         descText.clear();
                     }
                 }
@@ -434,7 +436,7 @@ void GribStdDump::parse(std::stringstream& in)
                     while (stmp.find("}") == std::string::npos) {
                         if (stmp.find("}") == std::string::npos) {
                             if (stmp.find("...") == std::string::npos) {
-                                stringstream ssdata(stmp);
+                                std::stringstream ssdata(stmp);
                                 while (ssdata >> buf) {
                                     item->addArrayData(buf);
                                 }
@@ -473,9 +475,9 @@ GribMvDump::GribMvDump()
     //tmpfilename_ = tmpfilename;
 
     if (keyMap_.empty()) {
-        keyMap_[GRIB_TYPE_STRING] = "string";
-        keyMap_[GRIB_TYPE_LONG]   = "long";
-        keyMap_[GRIB_TYPE_DOUBLE] = "double";
+        keyMap_[CODES_TYPE_STRING] = "string";
+        keyMap_[CODES_TYPE_LONG]   = "long";
+        keyMap_[CODES_TYPE_DOUBLE] = "double";
     }
 }
 
@@ -486,8 +488,8 @@ GribMvDump::~GribMvDump()
 
 void GribMvDump::clear()
 {
-    for (std::vector<GribItem*>::iterator it = item_.begin(); it != item_.end(); it++) {
-        delete *it;
+    for (auto& it : item_) {
+        delete it;
     }
     item_.clear();
 }
@@ -495,34 +497,24 @@ void GribMvDump::clear()
 //msgCnt starts from 1!!!
 bool GribMvDump::read(const std::string& fname, int count)
 {
-    std::vector<std::string> name_space;
-    name_space.push_back("Default");
-    name_space.push_back("geography");
-    name_space.push_back("ls");
-    name_space.push_back("mars");
-    name_space.push_back("parameter");
-    name_space.push_back("statistics");
-    name_space.push_back("time");
-    name_space.push_back("vertical");
+    std::vector<std::string> name_space = {"Default", "geography", "ls", "mars",
+                                           "parameter", "statistics", "time", "vertical"};
 
-    // list of blacklisted keys - these can be very expensive to compute; we can
+    // list of skipped keys - these can be very expensive to compute; we can
     // always put them back in if someone really really needs them...
     // to be considered: minimum, maximum
-    std::vector<std::string> key_blacklist;
-    key_blacklist.push_back("distinctLatitudes");
-    key_blacklist.push_back("distinctLongitudes");
-    key_blacklist.push_back("distinctLatitudes");
+    std::vector<std::string> key_skiplist  ={"distinctLatitudes", "distinctLongitudes","distinctLatitudes"};
 
     // keys which are redundant or not properly defined
-    key_blacklist.push_back("GRIBEditionNumber");
+    key_skiplist.push_back("GRIBEditionNumber");
 
     //Other keys which define constant values and are not really useful for users
-    key_blacklist.push_back("7777");
-    key_blacklist.push_back("x");
+    key_skiplist.push_back("7777");
+    key_skiplist.push_back("x");
 
     FILE* fp;
-    grib_handle* gh           = NULL;
-    grib_keys_iterator* kiter = NULL;
+    grib_handle* gh           = nullptr;
+    grib_keys_iterator* kiter = nullptr;
     //const int MAX_KEY_LEN=255;
     const int MAX_VAL_LEN                   = 1024;
     unsigned long key_iterator_filter_flags = GRIB_KEYS_ITERATOR_ALL_KEYS;
@@ -531,8 +523,7 @@ bool GribMvDump::read(const std::string& fname, int count)
     int grib_count = 0;
 
     int keyType;
-    //long longValue;
-    string svalue;
+    std::string svalue;
     char value[MAX_VAL_LEN];
     size_t vlen = MAX_VAL_LEN;
 
@@ -546,7 +537,7 @@ bool GribMvDump::read(const std::string& fname, int count)
     }
 
     //Get messages form the file
-    while ((gh = grib_handle_new_from_file(0, fp, &err)) != NULL || err != GRIB_SUCCESS) {
+    while ((gh = grib_handle_new_from_file(0, fp, &err)) != nullptr || err !=CODES_SUCCESS) {
         grib_count++;
 
         //if(!gh)
@@ -556,19 +547,19 @@ bool GribMvDump::read(const std::string& fname, int count)
         //}
 
         if (grib_count == count) {
-            //cout << "-- GRIB N. " << grib_count << "---/n";
+            //std::cout << "-- GRIB N. " << grib_count << "---/n";
 
             if (!gh) {
                 GuiLog().error() << "Unable to create grib handle for message no: " << grib_count << "\n";
                 return false;
             }
 
-            for (unsigned int ns = 0; ns < name_space.size(); ns++) {
+            for (auto& ns : name_space) {
                 //Get key iterator
-                if (name_space[ns] != "Default")
-                    kiter = grib_keys_iterator_new(gh, key_iterator_filter_flags, const_cast<char*>(name_space[ns].c_str()));
+                if (ns != "Default")
+                    kiter = grib_keys_iterator_new(gh, key_iterator_filter_flags, const_cast<char*>(ns.c_str()));
                 else
-                    kiter = grib_keys_iterator_new(gh, key_iterator_filter_flags, NULL);
+                    kiter = grib_keys_iterator_new(gh, key_iterator_filter_flags, nullptr);
 
                 if (!kiter) {
                     GuiLog().error() << "Unable to create keys iterator for message no: " << grib_count << "\n";
@@ -583,55 +574,57 @@ bool GribMvDump::read(const std::string& fname, int count)
                         continue;
                     }
 
-                    string cbuff = name;
+                    std::string cbuff = name;
 
-                    // if this key is in our blacklist, then do not use it
-                    std::vector<string>::const_iterator i = find(key_blacklist.begin(), key_blacklist.end(), name);
-
-                    if (i != key_blacklist.end())
+                    // if this key is in our skiplist, then do not use it
+                    auto i = std::find(key_skiplist.begin(), key_skiplist.end(), name);
+                    if (i != key_skiplist.end())
                         continue;
 
 
                     //Add namespace prefix to the key name (e.g. mars.param)
-                    if (name_space[ns] != "Default") {
-                        cbuff = name_space[ns] + "." + cbuff;
+                    if (ns != "Default") {
+                        cbuff = ns + "." + cbuff;
                     }
 
                     //Get string value
                     vlen = MAX_VAL_LEN;
                     size_t len;
+                    long longValue;
+                    double doubleValue;
 
-                    if (grib_get_native_type(gh, name, &keyType) == GRIB_SUCCESS &&
-                        grib_get_size(gh, name, &len) == GRIB_SUCCESS &&
-                        (keyType == GRIB_TYPE_STRING || keyType == GRIB_TYPE_LONG ||
-                         keyType == GRIB_TYPE_DOUBLE)) {
-                        GribItem* item = new GribItem;
+                    if (grib_get_native_type(gh, name, &keyType) == CODES_SUCCESS &&
+                        grib_get_size(gh, name, &len) == CODES_SUCCESS &&
+                        (keyType == CODES_TYPE_STRING || keyType == CODES_TYPE_LONG ||
+                         keyType == CODES_TYPE_DOUBLE)) {
+                        auto* item = new GribItem;
                         item_.push_back(item);
-                        item->name(cbuff);
+                        item->setName(cbuff);
 
-                        if (keyType == GRIB_TYPE_STRING || len == 1) {
-                            if (grib_get_string(gh, name, value, &vlen) == GRIB_SUCCESS) {
-                                //cout << "   " << cbuff << " =  " << value << endl;
-                                //Create the grib item
+                        if(keyType == CODES_TYPE_STRING || len == 1) {
+                            grib_get_string(gh, name, value, &vlen);
+                        }
 
-                                item->value(value);
+                        if (keyType == CODES_TYPE_LONG && len == 1) {
+                            if (codes_get_long(gh, name, &longValue) == CODES_SUCCESS) {
+                                item->setValue(longValue, value);
                             }
-                        }
-                        else if (strcmp(name, "paramId") == 0 && keyType == GRIB_TYPE_LONG) {
-                            if (grib_get_string(gh, name, value, &vlen) == GRIB_SUCCESS) {
-                                item->value(value);
+                        } else if (keyType == CODES_TYPE_DOUBLE && len == 1) {
+                            if (codes_get_double(gh, name, &doubleValue) == CODES_SUCCESS) {
+                                item->setValue(doubleValue, value);
                             }
-                        }
-                        else {
-                            stringstream s;
-                            s << len;
-                            svalue = "Array (" + s.str() + ")";
-                            item->value(svalue);
+                        } else if (keyType == CODES_TYPE_STRING) {
+                            if (grib_get_string(gh, name, value, &vlen) == CODES_SUCCESS) {
+                                item->setValue(value);
+                            }
+                        } else {
+                            svalue = "Array (" + std::to_string(len) + ")";
+                            item->setValue(svalue);
                         }
 
-                        map<int, string>::const_iterator it = keyMap_.find(keyType);
+                        auto it = keyMap_.find(keyType);
                         if (it != keyMap_.end()) {
-                            item->type(it->second);
+                            item->setType(it->second);
                         }
                     }
                 }
@@ -661,9 +654,9 @@ bool GribTableDump::read(const std::string& fgrib, int msgCnt,
                          std::vector<std::string>& tablesMasterDir, std::vector<std::string>& tablesLocalDir)
 {
     FILE* fp;
-    grib_handle* gh = NULL;
-    int err        = 0;
-    int grib_count = 0;
+    grib_handle* gh = nullptr;
+    int err         = 0;
+    int grib_count  = 0;
 
     GuiLog().task() << "Generating table dump for message: " << msgCnt << GuiLog::methodKey() << "ecCodes C interface";
 
@@ -675,7 +668,7 @@ bool GribTableDump::read(const std::string& fgrib, int msgCnt,
     }
 
     //Get messages form the file
-    while (((gh = grib_handle_new_from_file(0, fp, &err)) != NULL || err != GRIB_SUCCESS) && grib_count < msgCnt) {
+    while (((gh = grib_handle_new_from_file(0, fp, &err)) != nullptr || err !=CODES_SUCCESS) && grib_count < msgCnt) {
         grib_count++;
         if (grib_count == msgCnt) {
             if (!gh) {
@@ -705,20 +698,20 @@ bool GribTableDump::read(const std::string& fgrib, int msgCnt,
                 centreStr = std::string(charVal);
             }
 
-            long centre=0;
+            long centre = 0;
             MV_CODES_CHECK(grib_get_long(gh, "centre", &centre), 0);
             localDirPattern = metview::replace(localDirPattern, "[centre:l]", std::to_string(centre));
             localDirPattern = metview::replace(localDirPattern, "[centre:s]", centreStr);
 
             if (definitionsDir_.empty()) {
-                if (char* defPath = codes_definition_path(NULL)) {
+                if (char* defPath = codes_definition_path(nullptr)) {
                     std::string dStr(defPath);
                     Tokenizer parse(":");
                     parse(dStr, definitionsDir_);
                 }
             }
 
-            for(auto defDir: definitionsDir_) {
+            for (auto defDir : definitionsDir_) {
                 tablesMasterDir.push_back(defDir + "/" + masterDirPattern);
                 tablesLocalDir.push_back(defDir + "/" + localDirPattern);
             }
@@ -787,7 +780,7 @@ bool GribValueDump::read(const std::string& fgrib, int msgCnt)
     //Get grib dump for the given field
 
     FILE* fp;
-    grib_handle* gh = NULL;
+    grib_handle* gh = nullptr;
 
     int err        = 0;
     int grib_count = 0;
@@ -805,7 +798,7 @@ bool GribValueDump::read(const std::string& fgrib, int msgCnt)
     }
 
     //Get messages form the file
-    while (((gh = grib_handle_new_from_file(0, fp, &err)) != NULL || err != GRIB_SUCCESS) && grib_count < msgCnt) {
+    while (((gh = grib_handle_new_from_file(0, fp, &err)) != nullptr || err !=CODES_SUCCESS) && grib_count < msgCnt) {
         grib_count++;
 
         //if(!gh)
@@ -822,17 +815,17 @@ bool GribValueDump::read(const std::string& fgrib, int msgCnt)
             }
 
             size_t latNum, lonNum, valNum;
-            string latName, lonName;
+            std::string latName, lonName;
 
-            //cout << "-- GRIB N. " << grib_count << "---/n";
+            //std::cout << "-- GRIB N. " << grib_count << "---/n";
 
             const int MAX_VAL_LEN = 1024;
             char cval[MAX_VAL_LEN];
             size_t vlen = MAX_VAL_LEN;
 
             //Grid type
-            if (grib_get_string(gh, "gridType", cval, &vlen) == GRIB_SUCCESS) {
-                gridType_ = string(cval);
+            if (grib_get_string(gh, "gridType", cval, &vlen) ==CODES_SUCCESS) {
+                gridType_ = std::string(cval);
             }
             else {
                 GuiLog().error() << "No gridType data found";
@@ -924,13 +917,13 @@ bool GribValueDump::read(const std::string& fgrib, int msgCnt)
 
             //Statistics
             /*double dval;
-			if(grib_get_double(gh,"average",&dval) == GRIB_SUCCESS)
+            if(grib_get_double(gh,"average",&dval) ==CODES_SUCCESS)
 				average_=dval;
-			if(grib_get_double(gh,"standardDeviation",&dval) == GRIB_SUCCESS)
+            if(grib_get_double(gh,"standardDeviation",&dval) ==CODES_SUCCESS)
 				stdev_=dval;				
-			if(grib_get_double(gh,"skewness",&dval) == GRIB_SUCCESS)
+            if(grib_get_double(gh,"skewness",&dval) ==CODES_SUCCESS)
 				skewness_=dval;
-			if(grib_get_double(gh,"kurtosis",&dval) == GRIB_SUCCESS)
+            if(grib_get_double(gh,"kurtosis",&dval) ==CODES_SUCCESS)
 				kurtosis_=dval;*/
             num_ = latNum;
         }
@@ -960,7 +953,7 @@ GribMetaData::GribMetaData() :
     GRIB_DEFINITION_PATH_ENV = "";
     const char* grb_def_path = getenv("GRIB_DEFINITION_PATH");
     if (grb_def_path) {
-        GRIB_DEFINITION_PATH_ENV = string(grb_def_path);
+        GRIB_DEFINITION_PATH_ENV = std::string(grb_def_path);
     }
 
     //Define the grib dump program name
@@ -1015,7 +1008,7 @@ void GribMetaData::updateFilterCnt(const std::vector<off_t>& offset, const std::
     filterCnt_    = cnt;
 }
 
-void GribMetaData::setFileName(string fname)
+void GribMetaData::setFileName(std::string fname)
 {
     clear();
 
@@ -1035,7 +1028,7 @@ int GribMetaData::computeTotalMessageNum()
     }
 
     int res = 0;
-    if (grib_count_in_file(0, fp, &res) != GRIB_SUCCESS)
+    if (grib_count_in_file(0, fp, &res) !=CODES_SUCCESS)
         res = 0;
 
     fclose(fp);
@@ -1050,33 +1043,30 @@ void GribMetaData::setTotalMessageNum(int num)
     }
 }
 
-void GribMetaData::getKeyProfileForFirstMessage(MvKeyProfile *prof)
+void GribMetaData::getKeyProfileForFirstMessage(MvKeyProfile* prof)
 {
-	prof->clearKeyData();
+    prof->clearKeyData();
 
     FILE* fp;
-    grib_handle* gh=NULL;
-    int err=0;
-    string cbuff;
+    grib_handle* gh = nullptr;
+    int err         = 0;
+    std::string cbuff;
 
     //open grib file for reading
-    fp = fopen(fileName_.c_str(),"r");
-    if(!fp)
-    {
+    fp = fopen(fileName_.c_str(), "r");
+    if (!fp) {
         //GuiLog().error() << "GribMetaData::readMessages() ---> Cannot open grib file: \n        " << fileName_ << "\n";
         return;
     }
 
-    while((gh = grib_handle_new_from_file(0,fp,&err)) != NULL || err != GRIB_SUCCESS)
-    {
-        if(!gh)
-        {
-            //GuiLog().error() <<  "GribMetaData::readMessages() --->  Unable to create grib handle for message count: " << grib_count+1 << endl;
+    while ((gh = grib_handle_new_from_file(0, fp, &err)) != nullptr || err !=CODES_SUCCESS) {
+        if (!gh) {
+            //GuiLog().error() <<  "GribMetaData::readMessages() --->  Unable to create grib handle for message count: " << grib_count+1 << std::endl;
         }
 
-        readMessage(prof,gh);
+        readMessage(prof, gh);
 
-        if(gh)
+        if (gh)
             grib_handle_delete(gh);
 
         return;
@@ -1086,21 +1076,21 @@ void GribMetaData::getKeyProfileForFirstMessage(MvKeyProfile *prof)
 #if 0
 void GribMetaData::readMessages(MvKeyProfile *prof)
 {
-	/*vector<char*> name_space;
+	/*std::vector<char*> name_space;
 	name_space.push_back(0);
 	name_space.push_back("geography");
-	name_space.push_back("ls");== GRIB_SUCCESS
+    name_space.push_back("ls");==CODES_SUCCESS
 	name_space.push_back("mars");
 	name_space.push_back("parameter");
 	name_space.push_back("time");
 	name_space.push_back("vertical");*/
 
   	FILE* fp;
-  	grib_handle* gh=NULL;
+  	grib_handle* gh=nullptr;
  	int err=0;
  	int grib_count=0;
 	long longValue;
-	string cbuff;
+	std::string cbuff;
 
     GuiLog().task() << "Generating grib key list for all the messages" <<
                        GuiLog::methodKey() << "ecCodes C interface";
@@ -1123,7 +1113,7 @@ void GribMetaData::readMessages(MvKeyProfile *prof)
 		{
 			//long currentOffset=0;
 			int msgCnt=0;
-			while((gh = grib_handle_new_from_file(0,fp,&err)) != NULL || err != GRIB_SUCCESS)
+            while((gh = grib_handle_new_from_file(0,fp,&err)) != nullptr || err !=CODES_SUCCESS)
 	 		{
                 if(!gh)
 				{      				
@@ -1134,7 +1124,7 @@ void GribMetaData::readMessages(MvKeyProfile *prof)
 
 				if(gh)
 				{  
-					if(grib_get_long(gh,"offset",&longValue) == GRIB_SUCCESS)
+                    if(grib_get_long(gh,"offset",&longValue) ==CODES_SUCCESS)
 					{
 						for(unsigned int i=0; i < filterOffset_.size(); i++)
 						{
@@ -1186,11 +1176,11 @@ void GribMetaData::readMessages(MvKeyProfile *prof)
 	else
 	{	  
 		//Get messages form the file
-  		while((gh = grib_handle_new_from_file(0,fp,&err)) != NULL || err != GRIB_SUCCESS)
+        while((gh = grib_handle_new_from_file(0,fp,&err)) != nullptr || err !=CODES_SUCCESS)
 	 	{
             if(!gh)
 			{      		
-                GuiLog().error() <<  "GribMetaData::readMessages() --->  Unable to create grib handle for message count: " << grib_count+1 << endl;
+                GuiLog().error() <<  "GribMetaData::readMessages() --->  Unable to create grib handle for message count: " << grib_count+1 << std::endl;
             }
 		
 			grib_count++;
@@ -1252,10 +1242,10 @@ void GribMetaData::readMessages(MvKeyProfile *prof)
 	{
 		for(unsigned int i=0; i< key->value().size(); i++)
 		{
-			string s=key->value()[i];
+			std::string s=key->value()[i];
 			if(s != "")
 			{ 
-				stringstream sst(s);
+				std::stringstream sst(s);
 				sst >> n;
 				sprintf(c,c_format[c_format_id],n);
 				s=c;
@@ -1271,7 +1261,7 @@ void GribMetaData::readMessages(MvKeyProfile *prof)
 		for(unsigned int i=0; i< key->value().size(); i++)
 		{
 			sprintf(c,c_format[c_format_id],i+1);
-			string s(c);
+			std::string s(c);
 			key->setValue(i,s);
 		}
 	
@@ -1280,17 +1270,17 @@ void GribMetaData::readMessages(MvKeyProfile *prof)
 #endif
 
 
-void GribMetaData::getKeyList(int count, string nameSpace, MvKeyProfile* prof)
+void GribMetaData::getKeyList(int count, std::string nameSpace, MvKeyProfile* prof)
 {
-    list<string> keys;
+    std::list<std::string> keys;
     getKeyList(count, nameSpace, keys);
-    for (list<string>::iterator it = keys.begin(); it != keys.end(); it++) {
-        prof->addKey(new MvKey((*it), (*it)));
+    for (auto& key : keys) {
+        prof->addKey(new MvKey(key, key));
     }
 }
 
 
-void GribMetaData::getKeyList(int count, string nameSpace, list<string>& keys)
+void GribMetaData::getKeyList(int count, std::string nameSpace, std::list<std::string>& keys)
 {
     std::vector<char*> nameSpaceL;
 
@@ -1304,22 +1294,19 @@ void GribMetaData::getKeyList(int count, string nameSpace, list<string>& keys)
         nameSpaceL.push_back(nsC);
     }
 
-    // list of blacklisted keys - these can be very expensive to compute; we can
+    // list of skipped keys - these can be very expensive to compute; we can
     // always put them back in if someone really really needs them...
     // to be considered: minimum, maximum
-    std::vector<string> key_blacklist;
-    key_blacklist.push_back("distinctLatitudes");
-    key_blacklist.push_back("distinctLongitudes");
-    key_blacklist.push_back("distinctLatitudes");
+    std::vector<std::string> key_skiplist = {"distinctLatitudes", "distinctLongitudes", "distinctLatitudes"};
 
     //Other keys which define constant values and are not really useful for users
-    key_blacklist.push_back("7777");
-    key_blacklist.push_back("x");
+    key_skiplist.push_back("7777");
+    key_skiplist.push_back("x");
 
 
     FILE* fp;
-    grib_handle* gh           = NULL;
-    grib_keys_iterator* kiter = NULL;
+    grib_handle* gh           = nullptr;
+    grib_keys_iterator* kiter = nullptr;
     //const int MAX_KEY_LEN=255;
     //const int MAX_VAL_LEN=1024;
     unsigned long key_iterator_filter_flags = GRIB_KEYS_ITERATOR_ALL_KEYS;
@@ -1330,7 +1317,7 @@ void GribMetaData::getKeyList(int count, string nameSpace, list<string>& keys)
 
     //char value[MAX_VAL_LEN];
     //size_t vlen=MAX_VAL_LEN;
-    string cbuff;
+    std::string cbuff;
 
     GuiLog().task() << "Generating grib key list for message: " << count << GuiLog::methodKey() << "ecCodes C interface";
 
@@ -1342,7 +1329,7 @@ void GribMetaData::getKeyList(int count, string nameSpace, list<string>& keys)
     }
 
     //Get messages form the file
-    while ((gh = grib_handle_new_from_file(0, fp, &err)) != NULL || err != GRIB_SUCCESS) {
+    while ((gh = grib_handle_new_from_file(0, fp, &err)) != nullptr || err !=CODES_SUCCESS) {
         grib_count++;
 
         /*if(!gh) 
@@ -1352,14 +1339,14 @@ void GribMetaData::getKeyList(int count, string nameSpace, list<string>& keys)
     		}*/
 
         if (grib_count == count) {
-            //cout << "-- GRIB N. " << grib_count << "---/n";
+            //std::cout << "-- GRIB N. " << grib_count << "---/n";
 
             if (!gh) {
                 GuiLog().error() << "GribMetaData::getKeyList() ---> Unable to create grib handle for message no: " << grib_count << "\n";
 
-                for (std::vector<char*>::iterator it = nameSpaceL.begin(); it != nameSpaceL.end(); it++) {
-                    if ((*it) != 0)
-                        delete[] * it;
+                for (auto& it : nameSpaceL) {
+                    if (it != 0)
+                        delete[] it;
                 }
 
                 return;
@@ -1371,9 +1358,9 @@ void GribMetaData::getKeyList(int count, string nameSpace, list<string>& keys)
                 if (!kiter) {
                     GuiLog().error() << "GribMetaData::getKeyList() ---> Unable to create keys iterator for message no: " << grib_count << "\n";
 
-                    for (std::vector<char*>::iterator it = nameSpaceL.begin(); it != nameSpaceL.end(); it++) {
-                        if ((*it) != 0)
-                            delete[] * it;
+                    for (auto& it : nameSpaceL) {
+                        if (it != 0)
+                            delete[] it;
                     }
 
                     return;
@@ -1386,12 +1373,11 @@ void GribMetaData::getKeyList(int count, string nameSpace, list<string>& keys)
                         continue;
                     }
 
-                    string cbuff = name;
+                    std::string cbuff = name;
 
-                    // if this key is in our blacklist, then do not use it
-                    std::vector<string>::const_iterator i = find(key_blacklist.begin(), key_blacklist.end(), name);
-
-                    if (i != key_blacklist.end())
+                    // if this key is in our skiplist, then do not use it
+                    auto i = std::find(key_skiplist.begin(), key_skiplist.end(), name);
+                    if (i != key_skiplist.end())
                         continue;
 
                     //Add namespace prefix to the key name (e.g. mars.param)
@@ -1399,9 +1385,9 @@ void GribMetaData::getKeyList(int count, string nameSpace, list<string>& keys)
                         cbuff = std::string(nameSpaceL[ns]) + "." + cbuff;
                     }
 
-                    if (grib_get_native_type(gh, cbuff.c_str(), &keyType) == GRIB_SUCCESS &&
-                        (keyType == GRIB_TYPE_STRING || keyType == GRIB_TYPE_LONG ||
-                         keyType == GRIB_TYPE_DOUBLE)) {
+                    if (grib_get_native_type(gh, cbuff.c_str(), &keyType) ==CODES_SUCCESS &&
+                        (keyType == CODES_TYPE_STRING || keyType == CODES_TYPE_LONG ||
+                         keyType == CODES_TYPE_DOUBLE)) {
                         keys.push_back(cbuff);
                     }
                 }
@@ -1421,9 +1407,9 @@ void GribMetaData::getKeyList(int count, string nameSpace, list<string>& keys)
     fclose(fp);
 
     //This has to be called before calling return in this method!!
-    for (std::vector<char*>::iterator it = nameSpaceL.begin(); it != nameSpaceL.end(); it++) {
-        if ((*it) != 0)
-            delete[] * it;
+    for (auto& it : nameSpaceL) {
+        if (it != 0)
+            delete[] it;
     }
 }
 
@@ -1444,24 +1430,24 @@ void GribMetaData::readMessage(MvKeyProfile* prof, grib_handle* gh)
     const int MAX_VAL_LEN = 1024;
     long longValue;
     char value[MAX_VAL_LEN];
-    string svalue;
+    std::string svalue;
     size_t vlen = MAX_VAL_LEN;
 
     for (unsigned int i = 0; i < prof->size(); i++) {
         size_t len;
         int keyType;
-        const string& name = prof->at(i)->name();
-        bool foundValue    = false;
+        const std::string& name = prof->at(i)->name();
+        bool foundValue         = false;
 
-        if (grib_get_native_type(gh, name.c_str(), &keyType) == GRIB_SUCCESS &&
-            grib_get_size(gh, name.c_str(), &len) == GRIB_SUCCESS &&
-            (keyType == GRIB_TYPE_STRING || keyType == GRIB_TYPE_LONG ||
-             keyType == GRIB_TYPE_DOUBLE)) {
-            if (keyType == GRIB_TYPE_STRING || len == 1) {
+        if (grib_get_native_type(gh, name.c_str(), &keyType) ==CODES_SUCCESS &&
+            grib_get_size(gh, name.c_str(), &len) ==CODES_SUCCESS &&
+            (keyType == CODES_TYPE_STRING || keyType == CODES_TYPE_LONG ||
+             keyType == CODES_TYPE_DOUBLE)) {
+            if (keyType == CODES_TYPE_STRING || len == 1) {
                 if (prof->at(i)->readIntAsString() == false &&
-                    keyType == GRIB_TYPE_LONG) {
-                    if (grib_get_long(gh, name.c_str(), &longValue) == GRIB_SUCCESS) {
-                        stringstream s;
+                    keyType == CODES_TYPE_LONG) {
+                    if (grib_get_long(gh, name.c_str(), &longValue) ==CODES_SUCCESS) {
+                        std::stringstream s;
                         s << longValue;
                         prof->at(i)->addValue(s.str().c_str());
                         foundValue = true;
@@ -1469,17 +1455,17 @@ void GribMetaData::readMessage(MvKeyProfile* prof, grib_handle* gh)
                 }
                 else {
                     vlen = MAX_VAL_LEN;
-                    if (grib_get_string(gh, name.c_str(), value, &vlen) == GRIB_SUCCESS) {
+                    if (grib_get_string(gh, name.c_str(), value, &vlen) ==CODES_SUCCESS) {
                         prof->at(i)->addValue(value);
                         foundValue = true;
                     }
                 }
             }
             else if ((strcmp(name.c_str(), "paramId") == 0 || strcmp(name.c_str(), "parameter.paramId") == 0) &&
-                     keyType == GRIB_TYPE_LONG) {
+                     keyType == CODES_TYPE_LONG) {
                 if (prof->at(i)->readIntAsString() == false) {
-                    if (grib_get_long(gh, name.c_str(), &longValue) == GRIB_SUCCESS) {
-                        stringstream s;
+                    if (grib_get_long(gh, name.c_str(), &longValue) ==CODES_SUCCESS) {
+                        std::stringstream s;
                         s << longValue;
                         prof->at(i)->addValue(s.str().c_str());
                         foundValue = true;
@@ -1487,14 +1473,14 @@ void GribMetaData::readMessage(MvKeyProfile* prof, grib_handle* gh)
                 }
                 else {
                     vlen = MAX_VAL_LEN;
-                    if (grib_get_string(gh, name.c_str(), value, &vlen) == GRIB_SUCCESS) {
+                    if (grib_get_string(gh, name.c_str(), value, &vlen) ==CODES_SUCCESS) {
                         prof->at(i)->addValue(value);
                         foundValue = true;
                     }
                 }
             }
             else {
-                stringstream s;
+                std::stringstream s;
                 s << len;
                 svalue = "Array (" + s.str() + ")";
                 prof->at(i)->addValue(svalue);
