@@ -11,18 +11,29 @@
 #include <Metview.h>
 #include <stdarg.h>
 
-svc* MvApplication::Service           = NULL;
-MvApplication* MvApplication::app     = 0;
-int KeepAlive::count_                 = 0;
-boolean MvApplication::ProcessReplies = 0;
-static const char* cPreferencesFile   = "General";
+svc* MvApplication::service_        = nullptr;
+MvApplication* MvApplication::app_  = nullptr;
+int KeepAlive::count_               = 0;
+static const char* cPreferencesFile = "General";
 
-MvApplication::MvApplication(int& argc, char** argv, const char* name, void* aparg, int nopt, option* opt)
+// This class is used by method MvApplication::wantPreferences().
+class MvPreferenceMessage : public MvMessage
 {
-    app = this;
+    MvApplication* appl;
+
+public:
+    MvPreferenceMessage(const char* name, MvApplication* a) :
+        MvMessage(name), appl(a) {}
+    virtual void callback(MvRequest& r) { appl->newPreferences(r); }
+};
+
+MvApplication::MvApplication(int& argc, char** argv, const char* name, void* aparg, int nopt, option* opt) :
+    MvAbstractApplication(name)
+{
+    app_ = this;
 
     marsinit(&argc, argv, aparg, nopt, opt);
-    Service = create_service(name ? name : progname());
+    service_ = create_service(name ? name : progname());
     MvServiceFactory::installServices();
 }
 
@@ -43,30 +54,30 @@ boolean MvApplication::stopAll(const char* fmt, ...)
     vsprintf(buf, fmt, list);
     va_end(list);
 
-    stop_all(Service, buf, 1);
+    stop_all(service_, buf, 1);
 
     return true;
 }
 
 void MvApplication::setKeepAlive(boolean on)
 {
-    keep_alive(Service, on ? 1 : 0);
+    keep_alive(service_, on ? 1 : 0);
 }
 
 void MvApplication::setMaximum(int n)
 {
-    set_maximum(Service, n);
+    set_maximum(service_, n);
 }
 
 void MvApplication::setExitTimeout(int minutes)
 {
-    exit_timeout(Service, minutes);
+    exit_timeout(service_, minutes);
 }
 
 void MvApplication::run()
 {
     /* if (!mars.nofork) setExitTimeout(1); // 1 minute */
-    service_run(Service);
+    service_run(service_);
 }
 
 void MvApplication::callService(const char* s, const MvRequest& r, void* d)
@@ -79,28 +90,44 @@ void MvApplication::callService(const char* s, const MvRequest& r, void* d)
 			process_service(Service);
 		}
 */
-    call_service(Service, s, r, (long)d);
+    call_service(service_, s, r, (long)d);
 }
 
 MvRequest MvApplication::waitService(const char* s, const MvRequest& r, int& err)
 {
     err = 0;
-    return MvRequest(wait_service(Service, (char*)s, r, &err), false);
+    return MvRequest(wait_service(service_, (char*)s, r, &err), false);
 }
 
 void MvApplication::callFunction(const char* s, const MvRequest& r, void* d)
 {
-    call_function(Service, s, r, (long)d);
+    call_function(service_, s, r, (long)d);
+}
+
+void MvApplication::destroyService()
+{
+    destroy_service(service_);
 }
 
 void MvApplication::sendMessage(const MvRequest& r)
 {
-    send_message(Service, r);
+    send_message(service_, r);
+}
+
+void MvApplication::sendMessage(const std::string& msg)
+{
+    char c_msg[1024];
+    strncpy(c_msg, msg.c_str(), 1023);
+
+    // copy the message into a C string and send it to the service
+    if (service_ != nullptr && service_->id != nullptr) {
+        set_svc_msg(service_->id, c_msg);
+    }
 }
 
 void MvApplication::recordOn(boolean on)
 {
-    recording(Service, on);
+    recording(service_, on);
 }
 
 void MvApplication::setFork(boolean on)
@@ -114,7 +141,7 @@ void MvApplication::notifyIconCreation(const char* icon_name, const char* icon_c
     set_value(u, "NAME", "%s", icon_name);
     set_value(u, "CLASS", "%s", icon_class);
     set_value(u, "STATUS", "CREATED");
-    send_message(Service, u);
+    send_message(service_, u);
     free_all_requests(u);
 }
 
@@ -124,13 +151,13 @@ void MvApplication::notifyIconModified(const char* icon_name, const char* icon_c
     set_value(u, "NAME", "%s", icon_name);
     set_value(u, "CLASS", "%s", icon_class);
     set_value(u, "STATUS", "MODIFIED");
-    send_message(Service, u);
+    send_message(service_, u);
     free_all_requests(u);
 }
 
 MvRequest MvApplication::getPreferences(const char* name)
 {
-    const char* prefs_name = (name == NULL) ? cPreferencesFile : name;
+    const char* prefs_name = (name == nullptr) ? cPreferencesFile : name;
     char buf[1024];
     sprintf(buf, "%s/System/Preferences/%s",
             getenv("METVIEW_USER_DIRECTORY"), prefs_name);
@@ -140,7 +167,7 @@ MvRequest MvApplication::getPreferences(const char* name)
 
 MvRequest MvApplication::getExpandedPreferences(const char* name)
 {
-    const char* prefs_name = (name == NULL) ? cPreferencesFile : name;
+    const char* prefs_name = (name == nullptr) ? cPreferencesFile : name;
     //MvRequest req=get_preferences(Service,prefs_name);
     MvRequest req = getPreferences(prefs_name);
 
@@ -148,11 +175,11 @@ MvRequest MvApplication::getExpandedPreferences(const char* name)
     if (!shareDir)
         return req;
 
-    string path(shareDir);
+    std::string path(shareDir);
     path.append("/etc/");
 
-    string defFileName   = path + "ConfigDef";
-    string rulesFileName = path + "ConfigRules";
+    std::string defFileName   = path + "ConfigDef";
+    std::string rulesFileName = path + "ConfigRules";
 
     MvLanguage langMetview(defFileName.c_str(),
                            rulesFileName.c_str(),
@@ -163,7 +190,7 @@ MvRequest MvApplication::getExpandedPreferences(const char* name)
 
 void MvApplication::setPreferences(const MvRequest& req, const char* name)
 {
-    const char* prefs_name = (name == NULL) ? cPreferencesFile : name;
+    const char* prefs_name = (name == nullptr) ? cPreferencesFile : name;
     char buf[1024];
     sprintf(buf, "%s/System/Preferences/%s",
             getenv("METVIEW_USER_DIRECTORY"), prefs_name);
@@ -171,20 +198,6 @@ void MvApplication::setPreferences(const MvRequest& req, const char* name)
     req.save(buf);
 }
 
-//! (used by MvApplication)
-/*! This class is used by method MvApplication::wantPreferences().
- */
-class MvPreferenceMessage : public MvMessage
-{
-    MvApplication* appl;
-
-public:
-    MvPreferenceMessage(const char* name, MvApplication* a) :
-        MvMessage(name),
-        appl(a) {}
-    virtual void callback(MvRequest& r) { appl->newPreferences(r); }
-};
-
 void MvApplication::wantPreferences(const char* name)
 {
     new MvPreferenceMessage(name ? name : "GENERAL_PREFERENCES", this);
@@ -192,29 +205,22 @@ void MvApplication::wantPreferences(const char* name)
 
 void MvApplication::addInputCallback(FILE* f, inputproc p, void* data)
 {
-    add_input_callback(Service, f, p, data);
+    add_input_callback(service_, f, p, data);
 }
 
-
 MvRequest MvApplication::poolFetch(const char* icon_name, const char* icon_class)
 {
-    return pool_fetch(Service, icon_name, icon_class);
+    return pool_fetch(service_, icon_name, icon_class);
 }
 void MvApplication::poolStore(const char* icon_name, const char* icon_class,
                               const MvRequest& r)
 {
-    pool_store(Service, icon_name, icon_class, r);
+    pool_store(service_, icon_name, icon_class, r);
 }
 
 void MvApplication::poolLink(const char* name1, const char* name2)
 {
-    pool_link(Service, name1, name2);
-}
-
-
-std::string MvApplication::buildAppName(const std::string& name)
-{
-    return name + "@" + std::to_string(getpid());
+    pool_link(service_, name1, name2);
 }
 
 void MvApplication::saveErrorAsRequest(const std::string& outPath, const std::string& msg)
@@ -223,3 +229,37 @@ void MvApplication::saveErrorAsRequest(const std::string& outPath, const std::st
     out("MESSAGE") = msg.c_str();
     out.save(outPath.c_str());
 }
+
+std::string MvApplication::buildAppName(const std::string& name)
+{
+    return name + "@" + std::to_string(getpid());
+}
+
+void MvApplication::writeToLog(const std::string& msg, MvLogLevel level)
+{
+    // TODO: figure out when sendMessage is to use
+    sendMessage(msg);
+
+    // TODO: break multiline text into lines for marslog
+    if (level == MvLogLevel::INFO) {
+        marslog(LOG_INFO, msg.c_str());
+    }
+    else if (level == MvLogLevel::WARN) {
+        marslog(LOG_WARN, msg.c_str());
+    }
+    else if (level == MvLogLevel::ERROR) {
+        marslog(LOG_EROR, msg.c_str());
+    }
+    else if (level == MvLogLevel::DBG) {
+        marslog(LOG_INFO, msg.c_str());
+        //        marslog(LOG_DBUG, msg.c_str());
+    }
+    //marslog(LOG_INFO | LOG_PERR, msg.c_str());
+}
+
+// The module will exit with an error code
+void MvApplication::exitWithError()
+{
+    if (service_ != nullptr)
+        set_svc_err(service_->id, 1);
+}
