@@ -7,83 +7,76 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvApplication_DEFINED
-#define MvApplication_DEFINED
+#pragma once
 
-#include <MvRequest.h>
+#include "MvFwd.h"
+#include "MvAbstractApplication.h"
+#include "MvRequest.h"
 
-//! Establishes communication with \c event module
-/*! This class, together with MvService, form the basis
- *  of Metview Application C++ Framework.
- */
-
-class MvApplication
+// The application of a non-ui module. It gets the basic parameters
+// from the configuration file and command line, registers the service name
+// and starts the communication with event.
+// Only one instance can be created in a program!
+class MvApplication : public MvAbstractApplication
 {
-    static MvApplication* app;
-    static svc* Service;
-    static boolean ProcessReplies;
-
+    friend class MvLog;
 
 public:
-    //! The standard constructor
-    /*! The standard constructor for a non X Window module. It gets the basic parameters
- *  from the configuration file and command line, registers the service \c name
- *  and starts the communication with \c event.
- */
-    MvApplication(int& argc, char** argv, const char* name = NULL,
-                  void* aparg = NULL, int nopt = 0, option* = NULL);
+    MvApplication(int& argc, char** argv, const char* name = nullptr,
+                  void* aparg = nullptr, int nopt = 0, option* = nullptr);
 
-
-    static MvApplication& instance() { return *app; }
-
-    void wantPreferences(const char* = NULL);
-
-    //! Starts the module's main loop.
+    // Starts the module's main MARS event loop.
     virtual void run();
 
+    void wantPreferences(const char* = nullptr);
     virtual void newPreferences(const MvRequest&) {}
     virtual void addInputCallback(FILE*, inputproc, void*);
 
-    static void setProcessReplies(boolean onOff) { ProcessReplies = onOff; }
+    static MvRequest getPreferences(const char* = nullptr);
+    static MvRequest getExpandedPreferences(const char* = nullptr);
+    static void setPreferences(const MvRequest&, const char* = nullptr);
 
-    static MvRequest getPreferences(const char* = NULL);
-    static MvRequest getExpandedPreferences(const char* = NULL);
-    static void setPreferences(const MvRequest&, const char* = NULL);
-
-    //! Sends request \c req to service \c name.
+    // Sends request req to service
     static void callService(const char* name, const MvRequest& req, void* ref);
-
     static MvRequest waitService(const char*, const MvRequest&, int&);
     static void callFunction(const char*, const MvRequest&, void*);
 
-    //! Broadcasts the message contained in request \c req.
+    // Broadcasts the message
     static void sendMessage(const MvRequest& req);
+    static void sendMessage(const std::string& msg);
 
     static void recordOn(boolean = true);
     static void setFork(boolean);
 
-    //! Defines the maximum time the module may stay in an idle state before being aborted.
+    // Defines the maximum time the module may stay in an idle state before being aborted.
     static void setExitTimeout(int minutes);
 
-    static void destroyService() { destroy_service(Service); }
+    static void destroyService();
     static void setKeepAlive(boolean);
     static void setMaximum(int);
     static boolean stopAll(const char*, ...);
     static void notifyIconCreation(const char* icon_name, const char* icon_class);
     static void notifyIconModified(const char* icon_name, const char* icon_class);
 
-    //! Returns the service structure created by the constructor.
-    static svc* getService() { return Service; }
-
+    // Returns the service structure created by the constructor.
+    static svc* getService() { return service_; }
 
     static MvRequest poolFetch(const char* icon_name, const char* icon_class);
     static void poolStore(const char* icon_name, const char* icon_class,
                           const MvRequest&);
-
     static void poolLink(const char* name1, const char* name2);
 
-    static std::string buildAppName(const std::string& name);
     static void saveErrorAsRequest(const std::string& outPath, const std::string& msg);
+    static std::string buildAppName(const std::string& name);
+
+protected:
+    void writeToLog(const std::string& msg, MvLogLevel level) override;
+    void writeToUiLog(const std::string&, MvLogLevel, bool) override {}
+    void exitWithError() override;
+
+private:
+    static MvApplication* app_;
+    static svc* service_;
 };
 
 
@@ -108,5 +101,3 @@ public:
     }
 };
 #endif
-
-#endif
