@@ -7,8 +7,12 @@
 
  ***************************** LICENSE END *************************************/
 
-#include "inc_iostream.h"
-#include "inc_stl.h"
+#include <fstream>
+#include <iostream>
+#include <memory>
+#include <string>
+
+#include "fstream_mars_fix.h"
 
 #include <float.h>
 #include <math.h>
@@ -19,8 +23,8 @@
 #include "MvException.h"
 
 
-const bool cReleaseMemoryTrue  = true;
-const bool cReleaseMemoryFlag  = cReleaseMemoryTrue;
+const bool cReleaseMemoryTrue = true;
+const bool cReleaseMemoryFlag = cReleaseMemoryTrue;
 
 const bool cExpandGridFalse = false;
 
@@ -57,7 +61,7 @@ double interpolateValue( field* Grib, double lat, double lon )
  //-- get GRIB field parameters
  //-
 
-  cout << "INFO: calling obsolete function interpolateValue(), relinking needed!!!!" << endl;
+  std::cout << "INFO: calling obsolete function interpolateValue(), relinking needed!!!!" << std::endl;
 
    if( ( Grib->ksec2[0] != 0 ) &&       //-- Data Representation, GRIB Table 6
        ( Grib->ksec2[0] != 10 ) )       //-- for rotated: use rotated coords!
@@ -99,7 +103,7 @@ double interpolateValue( field* Grib, double lat, double lon )
    double ires2 = (lon9-lon1)/(ipoints-1.0);
    if( fabs( ires-ires2 ) > cGridEpsilon )
      {
-       cout << "use computed i increment: " << ires2 << ", not " << ires << endl;
+       std::cout << "use computed i increment: " << ires2 << ", not " << ires << std::endl;
        ires = ires2;
      }
 
@@ -107,7 +111,7 @@ double interpolateValue( field* Grib, double lat, double lon )
    double jres2 = (lat9-lat1)/(jpoints-1.0);
    if( fabs( jres-jres2 ) > cGridEpsilon )
      {
-       cout << "use computed j increment: " << jres2 << ", not " << jres << endl;
+       std::cout << "use computed j increment: " << jres2 << ", not " << jres << std::endl;
        jres = jres2;
      }
 
@@ -230,7 +234,7 @@ void MvFieldSet::_init()
 
 MvFieldSet::MvFieldSet(const char* file)
 {
-    Fs = read_fieldset(file, NULL);
+    Fs = read_fieldset(file, nullptr);
     _init();
 }
 
@@ -311,8 +315,8 @@ void MvFieldSet::operator+=(const MvField& f)
     add_field(Fs, copy_field(f.libmars_field(), true));
 
     //-- add new field also to 'Fields'
-    int cnt       = Fs->count;
-    MvField** tmp = new MvField*[cnt];
+    int cnt    = Fs->count;
+    auto** tmp = new MvField*[cnt];
 
     for (int i = 0; i < cnt - 1; i++)  //-- copy existing pointers
         tmp[i] = Fields[i];
@@ -342,7 +346,7 @@ MvFieldSetIterator::MvFieldSetIterator(MvFieldSet& fs)
 MvField& MvFieldSetIterator::operator()()
 {
     static MvField EmptyField;  // Grib is NULL by default
-    MvField* Match = NULL;
+    MvField* Match = nullptr;
 
     if (Current >= Count)
         return EmptyField;
@@ -355,7 +359,7 @@ MvField& MvFieldSetIterator::operator()()
             if (Filter(r))
                 return *f;
 
-        } while (Current < Count && Match == NULL);
+        } while (Current < Count && Match == nullptr);
 
         return EmptyField;  // if there is no match
     }
@@ -377,7 +381,7 @@ void MvFieldSetIterator::sort(const char* parm, char order)
         MvField& f1    = (*FieldSet)[Order[i]];
         MvRequest& r1  = f1.getRequest();
         const char* p1 = get_value(r1, parm, 0);
-        if (p1 == NULL)
+        if (p1 == nullptr)
             p1 = "";
 
         // This test is necessary to prevent infinit looping.
@@ -392,9 +396,9 @@ void MvFieldSetIterator::sort(const char* parm, char order)
             isdat = isnum = 0;
         }
         else {
-            isdat = isdate(p1);
-            isnum = is_number(p1);
-            valp1 = atof(p1);
+            isdat      = isdate(p1);
+            isnum      = is_number(p1);
+            valp1      = atof(p1);
             isclimdate = 0;
         }
 
@@ -407,7 +411,7 @@ void MvFieldSetIterator::sort(const char* parm, char order)
             MvField& f2    = (*FieldSet)[Order[j]];
             MvRequest& r2  = f2.getRequest();
             const char* p2 = get_value(r2, parm, 0);
-            if (p2 == NULL)
+            if (p2 == nullptr)
                 p2 = "";
 
             if (isdat)
@@ -554,11 +558,11 @@ void MvField::set_libmars_field(field* f)
     mvgrid_ = MvGridFactory(f, cReleaseMemoryFlag, cExpandGridFalse);
 }
 
-MvRequest& MvField::getRequest(void)
+MvRequest& MvField::getRequest()
 {
-    if (Request == NULL) {
+    if (Request == nullptr) {
         const bool cThrowOnError = 1;
-        string strGridType(mvgrid_->gridType());
+        std::string strGridType(mvgrid_->gridType());
 
         //-- field_to_request() does the expansion!!!
         //-- MvFieldLoader loader(*this); // Expand field
@@ -602,7 +606,7 @@ MvField::operator void*()
 }
 int MvField::operator!()
 {
-    return libmars_field() == 0;  // NULL;
+    return libmars_field() == nullptr;  // NULL;
 }
 
 
@@ -687,7 +691,7 @@ double MvField::ML_to_Pressure_bySP(double sp, int ml_in)
 bool MvField::vertCoordCoefs(int level, double& C1, double& C2)
 {
     if (!isModelLevel()) {
-        cerr << "MvField::vertCoordCoefs: not a model level field" << endl;
+        std::cerr << "MvField::vertCoordCoefs: not a model level field" << std::endl;
         return false;
     }
 
@@ -700,7 +704,7 @@ bool MvField::vertCoordCoefs(int level, double& C1, double& C2)
    int        nb   = vertCoordCoefPairCount();
    if( level > nb )
      {
-       cerr << "MvField::vertCoordCoefs: not enough coefficients in GRIB header" << endl;
+       std::cerr << "MvField::vertCoordCoefs: not enough coefficients in GRIB header" << std::endl;
        return false;
      }
 
@@ -715,7 +719,7 @@ bool MvField::vertCoordCoefs(int level, double& C1, double& C2)
 bool MvField::vertCoordCoefs(double& C1, double& C2)
 {
     if (!isModelLevel()) {
-        cerr << "MvField::vertCoordCoefs: not a model level field" << endl;
+        std::cerr << "MvField::vertCoordCoefs: not a model level field" << std::endl;
         return false;
     }
 
@@ -985,7 +989,7 @@ double MvField::averageAt(double X1, double Y1, double X2, double Y2)
         val /= weight;
     else
         val = DBL_MAX;
-    //cout << samples << '\t' << val << endl;
+    //std::cout << samples << '\t' << val << std::endl;
     return val;
 #endif
 }
@@ -1168,8 +1172,8 @@ double MvField::cornerGridpoint(double x, double y, int c)
     else
         iy1 = int((y1 - yy) / ry);
 
-//    x1 += ix * rx;
-//    y1 -= iy * ry;
+    //    x1 += ix * rx;
+    //    y1 -= iy * ry;
 
     int ix_found, iy_found;
     if (c == 0) {
@@ -1246,7 +1250,7 @@ double MvField::integrate(double north, double west, double south, double east)
     else
         val = mars.grib_missing_value;  // all values were missing
 
-    //cout << pcnt << '\t' << val << endl;
+    //std::cout << pcnt << '\t' << val << std::endl;
     return val;
 }
 
@@ -1413,33 +1417,35 @@ double MvField::gridNS()
         suppliedDy = cValueNotGiven;
     }
 
-    bool scanNeg = (mvgrid_->getLong("jScansPositively") != 0);
+    bool scanNeg    = (mvgrid_->getLong("jScansPositively") != 0);
     double northVal = north();
     double southVal = south();
-    long numLat = numberOfLat();
+    long numLat     = numberOfLat();
     double computed = cValueNotGiven;
     if (northVal != cValueNotGiven && southVal != cValueNotGiven &&
-         numLat != GRIB_MISSING_LONG) {
-         computed   = (northVal - southVal) / (numLat - 1);
+        numLat != GRIB_MISSING_LONG) {
+        computed = (northVal - southVal) / (numLat - 1);
     }
 
     if (suppliedDy != cValueNotGiven && computed != cValueNotGiven) {
         // This is the case when GRIB header precision is too small
         if (fabs(computed - suppliedDy) > cGridEpsilon) {
             return computed;
-        } else {
+        }
+        else {
             if (scanNeg) {
                 suppliedDy = -suppliedDy;
             }
             return suppliedDy;
         }
-    } else if (suppliedDy != cValueNotGiven) {
+    }
+    else if (suppliedDy != cValueNotGiven) {
         if (scanNeg) {
             suppliedDy = -suppliedDy;
         }
         return suppliedDy;
-
-    } else if (computed != cValueNotGiven) {
+    }
+    else if (computed != cValueNotGiven) {
         return computed;
     }
 
@@ -1454,33 +1460,35 @@ double MvField::gridWE()
         suppliedDx = cValueNotGiven;
     }
 
-    bool scanPos = (mvgrid_->getLong("iScansNegatively") != 0);
-    double eastVal = east();
-    double westVal = west();
-    long numLon = numberOfLon();
+    bool scanPos    = (mvgrid_->getLong("iScansNegatively") != 0);
+    double eastVal  = east();
+    double westVal  = west();
+    long numLon     = numberOfLon();
     double computed = cValueNotGiven;
     if (eastVal != cValueNotGiven && westVal != cValueNotGiven &&
-         numLon != GRIB_MISSING_LONG) {
-         computed   = (eastVal - westVal) / (numLon - 1);
+        numLon != GRIB_MISSING_LONG) {
+        computed = (eastVal - westVal) / (numLon - 1);
     }
 
     if (suppliedDx != cValueNotGiven && computed != cValueNotGiven) {
         // This is the case when GRIB header precision is too small
         if (fabs(computed - suppliedDx) > cGridEpsilon) {
             return computed;
-        } else {
+        }
+        else {
             if (scanPos) {
                 suppliedDx = -suppliedDx;
             }
             return suppliedDx;
         }
-    } else if (suppliedDx != cValueNotGiven) {
+    }
+    else if (suppliedDx != cValueNotGiven) {
         if (scanPos) {
             suppliedDx = -suppliedDx;
         }
         return suppliedDx;
-
-    } else if (computed != cValueNotGiven) {
+    }
+    else if (computed != cValueNotGiven) {
         return computed;
     }
 
@@ -1503,8 +1511,8 @@ double MvField::parameter()
     //return s1->parameter;
 #if 1
     //return mvgrid_->getDouble("mars.param"); //- does not work in GRIB 2 ???
-    string p = mvgrid_->getString("mars.param");
-    double d = atof(p.c_str());
+    std::string p = mvgrid_->getString("mars.param");
+    double d      = atof(p.c_str());
     return d;
 #else
     if (mvgrid_->getLong("editionNumber") > 1)
@@ -1514,7 +1522,7 @@ double MvField::parameter()
 #endif
 }
 
-string MvField::parameterName()
+std::string MvField::parameterName()
 {
     return mvgrid_->getString("mars.param");
 }
@@ -1592,9 +1600,9 @@ double MvField::level_L2()
 #endif
 }
 
-string MvField::levelTypeString()
+std::string MvField::levelTypeString()
 {
-    string levTyp = mvgrid_->getString("mars.levtype");
+    std::string levTyp = mvgrid_->getString("mars.levtype");
     return levTyp;
 }
 
@@ -1619,7 +1627,7 @@ int MvField::dataRepres()
     // into a number. The problem is that GRIB 2 does not seem to
     // be able to give dataRepresentationType as a number.
 
-    string gridType = mvgrid_->gridType();
+    std::string gridType = mvgrid_->gridType();
 
     if (gridType == cLatLonGrid)
         return GRIB_LAT_LONG;
@@ -1650,7 +1658,7 @@ bool MvField::isModelLevel()
 
     //return levelType() == GRIB_MODEL_LEVEL || levelType() == cML_UKMO_ND;
 
-    string levTyp = mvgrid_->getString("mars.levtype");
+    std::string levTyp = mvgrid_->getString("mars.levtype");
     if (levTyp == "ml" || levTyp == cML_UKMO_ND_STR) {
         return true;
     }
@@ -1668,7 +1676,7 @@ bool MvField::isPressureLevel()
     //return  levelType() == GRIB_PRESSURE_LEVEL ||
     //	levelType() == GRIB_ABOVE_1HPA;
 
-    string levTyp = mvgrid_->getString("mars.levtype");
+    std::string levTyp = mvgrid_->getString("mars.levtype");
     return levTyp == "pl";
 }
 
@@ -1683,7 +1691,8 @@ long MvField::pressureLevelInPa()
     if (isPressureLevel()) {
         if (mvgrid_->getString("typeOfLevel") == "isobaricInhPa") {
             return mvgrid_->getLong("level") * 100;
-        } else if (mvgrid_->getString("typeOfLevel") == "isobaricInPa") {
+        }
+        else if (mvgrid_->getString("typeOfLevel") == "isobaricInPa") {
             return mvgrid_->getLong("level");
         }
     }
@@ -1798,7 +1807,7 @@ double MvField::stepFoh()
     if (stepUnit < 0)  // means that the key could not be found, therefore assume 'hours'
         stepUnit = 1;
 
-    if (stepUnit == 0) // minutes
+    if (stepUnit == 0)  // minutes
         d3 /= 60.0;
 
     return d3 / 24.0;
@@ -1820,7 +1829,7 @@ int MvField::stepRangeDecoder(const char* stepString)
     long start_step, step;
     char* p = buff;
 
-    if (stepString != NULL) {
+    if (stepString != nullptr) {
         strncpy(buff, stepString, sizeof(buff) - 1);
 
         start_step = strtol(stepString, &p, 10);  // convert to int, 'p' points to first non-numeric char
@@ -1828,7 +1837,7 @@ int MvField::stepRangeDecoder(const char* stepString)
         if (*p == 0)  // step was just a number, so use that
             step = start_step;
         else  // step was a range, so use the number after the non-numeric char
-            step = strtol(++p, NULL, 10);
+            step = strtol(++p, nullptr, 10);
 
         return step;
     }
@@ -1846,7 +1855,7 @@ int MvField::stepRangeDecoder(const char* stepString)
 
 Cached MvField::marsName()
 {
-    string p = mvgrid_->getString("shortName");
+    std::string p = mvgrid_->getString("shortName");
     Cached c(p.c_str());
 
     if (isDerived())        //-- generally ok?
@@ -1868,7 +1877,7 @@ Cached MvField::vectorPair()
 {
 	char buf[ 512 ];
 
-	ifstream istrm( (const char*)MagicsTable2FileName(), ios::in );
+	std::ifstream istrm( (const char*)MagicsTable2FileName(), std::ios::in );
 	if( ! istrm )
 	{
 	    marslog(LOG_INFO, "Magics Extended GRIB Table 2 Version %d open error", table() );
@@ -1879,7 +1888,7 @@ Cached MvField::vectorPair()
 	ostrstream tvstr( tableVers, sizeof( tableVers ) );
 	tvstr << "."
 	      << table()                 //-- required for new (030612) MARS param syntax
-	      << ends;
+	      << std::ends;
 
 	istrm.getline( buf, sizeof( buf ) );
 	int  current = atoi( buf );
@@ -1957,7 +1966,7 @@ MvLocation MvField::nearestGridPointLocation(const MvLocation& l)
     return nearestLoc;
 }
 
-int MvField::find(double min, double max, vector<double>& lat, vector<double>& lon)
+int MvField::find(double min, double max, std::vector<double>& lat, std::vector<double>& lon)
 {
     if (!mvgrid_->hasLocationInfo()) {
         marslog(LOG_EROR, "MvField::Find(). unimplemented or spectral data - unable to extract location data");
@@ -1983,6 +1992,7 @@ int MvField::find(double min, double max, vector<double>& lat, vector<double>& l
     return count;
 }
 
-bool MvField::isSpectral() {
+bool MvField::isSpectral()
+{
     return getGribKeyValueString("gridType") == "sh";
 }
