@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvFieldSet_DEFINED
-#define MvFieldSet_DEFINED
+#pragma once
 
 #include "MvRequest.h"
 #include "MvFilter.h"
@@ -18,9 +17,9 @@
 //for-the-moment//#define INCLUDE_OLD_CODE
 
 
-const double cValueNotGiven  = DBL_MAX;
-const int cML_UKMO_ND        = 205;    //-- level type for UKMO New Dynamics data
-const string cML_UKMO_ND_STR = "205";  //-- level type for UKMO New Dynamics data
+const double cValueNotGiven       = DBL_MAX;
+const int cML_UKMO_ND             = 205;    //-- level type for UKMO New Dynamics data
+const std::string cML_UKMO_ND_STR = "205";  //-- level type for UKMO New Dynamics data
 
 #if 0
 double interpolateValue( field* Grib, double lat, double lon );
@@ -293,7 +292,7 @@ public:
     double parameter();
 
     //! Returns the parameter name used by MARS
-    string parameterName();
+    std::string parameterName();
 
     //! Assigns a different parameter code number
     void setParameter(int v) { mvgrid_->setLong("indicatorOfParameter", v); }
@@ -317,7 +316,7 @@ public:
     double level_L2();
 
     //! Returns the type of the level as a string
-    string levelTypeString();
+    std::string levelTypeString();
 
     //! Returns the code number for the level type
     int levelType();
@@ -359,49 +358,49 @@ public:
     void setShape(field_state newState) { set_field_state(mvgrid_->field_, newState); }
 
     //! Interface to ecCodes to request a \c long valued keyword
-    long getGribKeyValueLong(const string& key, bool throwOnError = false, bool quiet = false)
+    long getGribKeyValueLong(const std::string& key, bool throwOnError = false, bool quiet = false)
     {
         return mvgrid_->getLong(key.c_str(), throwOnError, quiet);
     }
 
     //! Interface to ecCodes to request a \c double valued keyword
-    double getGribKeyValueDouble(const string& key, bool throwOnError = false, bool quiet = false)
+    double getGribKeyValueDouble(const std::string& key, bool throwOnError = false, bool quiet = false)
     {
         return mvgrid_->getDouble(key.c_str(), throwOnError, quiet);
     }
 
     //! Interface to ecCodes to request a \c string valued keyword
-    string getGribKeyValueString(const string& key, bool throwOnError = false, bool quiet = false)
+    std::string getGribKeyValueString(const std::string& key, bool throwOnError = false, bool quiet = false)
     {
         return mvgrid_->getString(key.c_str(), throwOnError, quiet);
     }
 
     //! Interface to ecCodes to request a \c long valued array keyword
-    long getGribKeyArrayLong(const string& key, long** lvals, bool throwOnError = false, bool quiet = false)
+    long getGribKeyArrayLong(const std::string& key, long** lvals, bool throwOnError = false, bool quiet = false)
     {
         return mvgrid_->getLongArray(key.c_str(), lvals, throwOnError, quiet);
     }
 
     //! Interface to ecCodes to request a \c double valued array keyword
-    long getGribKeyArrayDouble(const string& key, double** dvals, bool throwOnError = false, bool quiet = false)
+    long getGribKeyArrayDouble(const std::string& key, double** dvals, bool throwOnError = false, bool quiet = false)
     {
         return mvgrid_->getDoubleArray(key.c_str(), dvals, throwOnError, quiet);
     }
 
     //! Interface to ecCodes to set a \c long valued keyword
-    bool setGribKeyValueLong(const string& key, long value)
+    bool setGribKeyValueLong(const std::string& key, long value)
     {
         return mvgrid_->setLong(key.c_str(), value);
     }
 
     //! Interface to ecCodes to set a \c double valued keyword
-    bool setGribKeyValueDouble(const string& key, double value)
+    bool setGribKeyValueDouble(const std::string& key, double value)
     {
         return mvgrid_->setDouble(key.c_str(), value);
     }
 
     //! Interface to ecCodes to set a \c string valued keyword
-    bool setGribKeyValueString(const string& key, string& value)
+    bool setGribKeyValueString(const std::string& key, std::string& value)
     {
         return mvgrid_->setString(key.c_str(), value);
     }
@@ -418,11 +417,11 @@ public:
     //! Returns \c true if the level type is depth level (e.g. ocean, soil)
     bool isDepth();
 
-    // Compare with NULL
+    // Compare with nullptr
     //! Operator for testing the validity of MvField object
     /*! This operator returns the pointer of the internal libMars
 	 *  GRIB structure as a \c void* .
-	 *  It is useful to compare the contents of a MvField to NULL
+	 *  It is useful to compare the contents of a MvField to nullptr
 	 *  in a \c while or \c if statements.\n \n
 	 *  Usage:
 	 * <PRE>
@@ -434,7 +433,7 @@ public:
 
     //! Operator for testing the validity of MvField object
     /*! This operator compares the pointer of the internal libMars
-	 *  GRIB structure to NULL and returns the result.\n \n
+	 *  GRIB structure to nullptr and returns the result.\n \n
 	 *  Usage:
 	 * <PRE>
 	 *       MvField f;
@@ -494,8 +493,6 @@ public:
     static int stepRangeDecoder(const char* stepString);
 
 
-
-
     //! Returns the embedded grib_handle
     /*! This method is for "lower" level GRIB access, for cases
 	 *  not available in MvField class
@@ -504,12 +501,11 @@ public:
 
     //! Returns a list of locations (lat/long pairs), where the values of the input field
     //! are within the interval [a, b]. This function is similar to Macro function Find.
-    int find(double min, double max, vector<double>& lat, vector<double>& lon);
+    int find(double min, double max, std::vector<double>& lat, std::vector<double>& lon);
 
-    void setValueAtToMissing(int index) {mvgrid_->setValueAtToMissing(index);}
+    void setValueAtToMissing(int index) { mvgrid_->setValueAtToMissing(index); }
     bool isSpectral();
     long pressureLevelInPa();
-
 };
 
 // Stack based objects to change the state of gribs ....
@@ -718,4 +714,3 @@ public:
     //! Rewinds the iterator
     void rewind() { Current = 0; }
 };
-#endif
