@@ -11,18 +11,23 @@
 
 
 #include "MvGeoPoints.h"
+
+#include <algorithm>
+#include <fstream>
+#include <sstream>
+#include <string>
+
+#include "fstream_mars_fix.h"
+
 #include "MvLocation.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "mars.h"
-#include "inc_stl.h"
 #include "Tokenizer.h"
 
 // the precision with which we write geopoints values
 #define VALUE_PRECISION (10)
 
 
-
-
 bool MvGeoPointColumnInfo::operator==(const MvGeoPointColumnInfo& in)
 {
     if (colNames_ != in.colNames_)
@@ -46,7 +51,7 @@ bool MvGeoPointColumnInfo::operator==(const MvGeoPointColumnInfo& in)
 void MvGeoPointColumnInfo::ensureOnlyOneValueColumn()
 {
     // resize the column arrays to have only one elment, 'value'
-    nvalcols_ = 1;
+    nvalcols_           = 1;
     nvalcolsforcompute_ = 1;
     colTypes_.resize(ncoordcols_ + nvalcols_);
     colNames_.resize(ncoordcols_);
@@ -54,8 +59,6 @@ void MvGeoPointColumnInfo::ensureOnlyOneValueColumn()
 }
 
 
-
-
 //_____________________________________________________________________
 bool MvGeoPoints::extract(const char* line, size_t r)
 {
@@ -64,10 +67,10 @@ bool MvGeoPoints::extract(const char* line, size_t r)
     double d_longitude;
     double d_height;
 
-    set_rowIndex(r); // all params will be set on this row
+    set_rowIndex(r);  // all params will be set on this row
     set_strValue("");
 
-    istringstream myInput(line);
+    std::istringstream myInput(line);
     if (gfmt_ == eGeoXYV)  //-- XYV is 'X_lon,Y _lat, Val' format
     {
         myInput >> d_longitude >> d_latitude >> buf;
@@ -92,15 +95,15 @@ bool MvGeoPoints::extract(const char* line, size_t r)
             myInput >> d_latitude >> d_longitude >> d_height >> d_date >> d_time >> d_val1 >> d_val2;
             set_value(d_val1);
             set_value2(d_val2);
-       }
-       else  //-- TRADITIONAL: Lat/Lon/lev/dat/tim/Val
-       {
-           myInput >> d_latitude >> d_longitude >> d_height >> d_date >> d_time >> buf;
+        }
+        else  //-- TRADITIONAL: Lat/Lon/lev/dat/tim/Val
+        {
+            myInput >> d_latitude >> d_longitude >> d_height >> d_date >> d_time >> buf;
 
-           _stringOrNumber(buf);
+            _stringOrNumber(buf);
 
-           //if (gfmt_ == eGeoString)  // update the 'global' geo format?
-           //    geoFmt = eGeoString;
+            //if (gfmt_ == eGeoString)  // update the 'global' geo format?
+            //    geoFmt = eGeoString;
         }
 
         set_lat_y(d_latitude);
@@ -115,7 +118,7 @@ bool MvGeoPoints::extract(const char* line, size_t r)
         double d_date;  //-- in case user has floating point valued dates
         double d_time;
         double d_elevation;
-        string s_string;
+        std::string s_string;
 
         // read the co-ordinate values
         for (size_t c = 0; c < nCoordCols(); c++) {
@@ -157,7 +160,7 @@ bool MvGeoPoints::extract(const char* line, size_t r)
         while (myInput >> d) {
             set_ivalue(d, vi++);
         }
-        myInput.clear(); // myInput will be in an error state by the end of the row
+        myInput.clear();  // myInput will be in an error state by the end of the row
 
         // first time round, we store the number of columns; subsequently, we check that all rows have the same number of columns
         if (nValCols() == 0) {
@@ -242,7 +245,7 @@ int MvGeoPoints::_countDigits(char*& p)
 }
 
 
-string
+std::string
 MvGeoPoints::column(size_t row, size_t col, MvGeoPointColumnInfo& colinfo, int& type)
 {
     size_t totalcols = colinfo.ncoordcols_ + colinfo.nvalcols_;
@@ -256,7 +259,7 @@ MvGeoPoints::column(size_t row, size_t col, MvGeoPointColumnInfo& colinfo, int&
     if (!MvGeoPoints::colTypeIsCoord(et)) {
         col -= colinfo.ncoordcols_;  // index into value columns now
         if (col < (size_t)colinfo.nvalcols_) {
-            return metview::toString(ivalue(row, col));
+            return std::to_string(ivalue(row, col));
         }
     }
     else {
@@ -267,31 +270,30 @@ MvGeoPoints::column(size_t row, size_t col, MvGeoPointColumnInfo& colinfo, int&
                 type = eGeoVString;
                 return strValue(row);
             case eGeoColLat:
-                return metview::toString(lat_y(row));
+                return std::to_string(lat_y(row));
             case eGeoColLon:
-                return metview::toString(lon_x(row));
+                return std::to_string(lon_x(row));
             case eGeoColLevel:
-                return metview::toString(height(row));
+                return std::to_string(height(row));
             case eGeoColElevation:
-                return metview::toString(elevation(row));
+                return std::to_string(elevation(row));
             case eGeoColDate: {
                 type = eGeoVLong;
-                return metview::toString(date(row));
+                return std::to_string(date(row));
             }
             case eGeoColTime: {
                 type = eGeoVLong;
-                return metview::toString(time(row));
+                return std::to_string(time(row));
             }
             default:
                 return "UNKNOWN";
         }
     }
 
-    return string("FORMAT NOT DEFINED");
+    return std::string("FORMAT NOT DEFINED");
 }
 
 
-
 //_____________________________________________________________________
 void MvGeoPoints::location(double lat, double lon)
 {
@@ -317,7 +319,6 @@ void MvGeoPoints::location(double lat, double lon)
 }
 
 
-
 bool MvGeoPoints::isLocationValid() const
 {
     return (lat_y() <= 90. && lat_y() >= -90. && lon_x() <= 360. && lon_x() >= -360.);
@@ -332,12 +333,12 @@ bool MvGeoPoints::isLocationValid() const
 class MvGeop1Writer
 {
     //! Friend function to write one point (one line) into a MvGeoPoints file
-    friend ostream& operator<<(ostream& aStream, const MvGeop1Writer& gpw);
+    friend std::ostream& operator<<(std::ostream& aStream, const MvGeop1Writer& gpw);
 
 public:
     MvGeop1Writer(MvGeoPoints& gpIn, size_t r) :
         gp_(gpIn),
-        r_(r) {};
+        r_(r) {}
 
     MvGeoPoints& gp_;
     size_t r_;
@@ -346,7 +347,7 @@ public:
 
 //_____________________________________________________________________
 
-ostream& operator<<(ostream& aStream, const MvGeop1Writer& gpw)
+std::ostream& operator<<(std::ostream& aStream, const MvGeop1Writer& gpw)
 {
     MvGeoPoints& gp         = gpw.gp_;
     const char cSeparator[] = "\t";
@@ -403,7 +404,7 @@ ostream& operator<<(ostream& aStream, const MvGeop1Writer& gpw)
                     break;
                 case eGeoColStnId:
                     if (gp.hasStnIds())
-                        aStream << metview::stationIdForWritingToFile(gp.strValue())  << cSeparator;
+                        aStream << metview::stationIdForWritingToFile(gp.strValue()) << cSeparator;
                     break;
                 default:
                     break;
@@ -524,8 +525,8 @@ MvGeoPoints::MvGeoPoints(size_t count, int numvals, eGeoFormat efmt, bool init)
 
 //_____________________________________________________________________
 
-MvGeoPoints::MvGeoPoints(size_t count, const MvGeoPointColumnInfo &colInfo, eGeoFormat efmt, bool init) :
-    MvGeoPoints(count, colInfo.nvalcols_, efmt, init) // C++11
+MvGeoPoints::MvGeoPoints(size_t count, const MvGeoPointColumnInfo& colInfo, eGeoFormat efmt, bool init) :
+    MvGeoPoints(count, colInfo.nvalcols_, efmt, init)  // C++11
 {
     // do the same as the above constructor, but also copy across all the column information
     colInfo_ = colInfo;
@@ -543,7 +544,7 @@ MvGeoPoints::MvGeoPoints(size_t ncount, bool init) :
     dbSystem_(""),
     dbPath_("")
 {
-   newReservedSize(count());
+    newReservedSize(count());
     if (!init) {
         newReservedSize(count());
         setColumnsForFormat();
@@ -571,20 +572,18 @@ MvGeoPoints::MvGeoPoints(const char* name, const size_t nmax) :
 
 //_____________________________________________________________________
 
-MvGeoPoints::~MvGeoPoints()
-{
-}
+MvGeoPoints::~MvGeoPoints() = default;
 //_____________________________________________________________________
 void MvGeoPoints::copy(const MvGeoPoints& gp, eGeoCopyMode mode)
 {
     unload();
 
-    gfmt_          = gp.format();
-    count_         = gp.count();
-    sgfmt_         = gp.format();
-    colInfo_       = gp.colInfo_;
-    vi_            = 0;
-    r_             = 0;
+    gfmt_    = gp.format();
+    count_   = gp.count();
+    sgfmt_   = gp.format();
+    colInfo_ = gp.colInfo_;
+    vi_      = 0;
+    r_       = 0;
 
     if (mode == eGeoCopyAll) {
         dbSystem_      = gp.dbSystem();
@@ -599,13 +598,13 @@ void MvGeoPoints::copy(const MvGeoPoints& gp, eGeoCopyMode mode)
     }
 
     if (count() > 0) {
-        strings_ = gp.strings_;
-        latitudes_ = gp.latitudes_;
-        longitudes_ = gp.longitudes_;
-        heights_ = gp.heights_;
-        elevations_ = gp.elevations_;
-        dates_ = gp.dates_;
-        times_ = gp.times_;
+        strings_     = gp.strings_;
+        latitudes_   = gp.latitudes_;
+        longitudes_  = gp.longitudes_;
+        heights_     = gp.heights_;
+        elevations_  = gp.elevations_;
+        dates_       = gp.dates_;
+        times_       = gp.times_;
         bool copyAll = (mode == eGeoCopyAll);
         if (copyAll) {
             values_ = gp.values_;
@@ -622,15 +621,15 @@ void MvGeoPoints::copy(const MvGeoPoints& gp, eGeoCopyMode mode)
 
 void MvGeoPoints::copyRow(const MvGeoPoints& src, size_t srcRow, size_t destRow)
 {
-    strings_[destRow] = src.strings_[srcRow];  // XXX do we always need to copy this?
-    latitudes_[destRow] = src.latitudes_[srcRow];
+    strings_[destRow]    = src.strings_[srcRow];  // XXX do we always need to copy this?
+    latitudes_[destRow]  = src.latitudes_[srcRow];
     longitudes_[destRow] = src.longitudes_[srcRow];
-    heights_[destRow] = src.heights_[srcRow];
+    heights_[destRow]    = src.heights_[srcRow];
     elevations_[destRow] = src.elevations_[srcRow];
-    dates_[destRow] = src.dates_[srcRow];
-    times_[destRow] = src.times_[srcRow];
+    dates_[destRow]      = src.dates_[srcRow];
+    times_[destRow]      = src.times_[srcRow];
 
-    for (size_t i=0; i < nValCols(); i++) {
+    for (size_t i = 0; i < nValCols(); i++) {
         values_[i][destRow] = src.values_[i][srcRow];
     }
 }
@@ -639,43 +638,42 @@ void MvGeoPoints::copyRow(const MvGeoPoints& src, size_t srcRow, size_t destRow)
 // optimised version of copyRow for copying multiple rows in one go
 void MvGeoPoints::copyRows(const MvGeoPoints& src, size_t srcRowFirst, size_t numRows, size_t destRow)
 {
-    std::copy(std::begin(src.strings_)+srcRowFirst,
-              std::begin(src.strings_)+srcRowFirst+numRows,
-              std::begin(strings_)+destRow);
+    std::copy(std::begin(src.strings_) + srcRowFirst,
+              std::begin(src.strings_) + srcRowFirst + numRows,
+              std::begin(strings_) + destRow);
 
-    std::copy(std::begin(src.latitudes_)+srcRowFirst,
-              std::begin(src.latitudes_)+srcRowFirst+numRows,
-              std::begin(latitudes_)+destRow);
+    std::copy(std::begin(src.latitudes_) + srcRowFirst,
+              std::begin(src.latitudes_) + srcRowFirst + numRows,
+              std::begin(latitudes_) + destRow);
 
-    std::copy(std::begin(src.longitudes_)+srcRowFirst,
-              std::begin(src.longitudes_)+srcRowFirst+numRows,
-              std::begin(longitudes_)+destRow);
+    std::copy(std::begin(src.longitudes_) + srcRowFirst,
+              std::begin(src.longitudes_) + srcRowFirst + numRows,
+              std::begin(longitudes_) + destRow);
 
-    std::copy(std::begin(src.heights_)+srcRowFirst,
-              std::begin(src.heights_)+srcRowFirst+numRows,
-              std::begin(heights_)+destRow);
+    std::copy(std::begin(src.heights_) + srcRowFirst,
+              std::begin(src.heights_) + srcRowFirst + numRows,
+              std::begin(heights_) + destRow);
 
-    std::copy(std::begin(src.elevations_)+srcRowFirst,
-              std::begin(src.elevations_)+srcRowFirst+numRows,
-              std::begin(elevations_)+destRow);
+    std::copy(std::begin(src.elevations_) + srcRowFirst,
+              std::begin(src.elevations_) + srcRowFirst + numRows,
+              std::begin(elevations_) + destRow);
 
-    std::copy(std::begin(src.dates_)+srcRowFirst,
-              std::begin(src.dates_)+srcRowFirst+numRows,
-              std::begin(dates_)+destRow);
+    std::copy(std::begin(src.dates_) + srcRowFirst,
+              std::begin(src.dates_) + srcRowFirst + numRows,
+              std::begin(dates_) + destRow);
 
-    std::copy(std::begin(src.times_)+srcRowFirst,
-              std::begin(src.times_)+srcRowFirst+numRows,
-              std::begin(times_)+destRow);
+    std::copy(std::begin(src.times_) + srcRowFirst,
+              std::begin(src.times_) + srcRowFirst + numRows,
+              std::begin(times_) + destRow);
 
-    for (size_t i=0; i < nValCols(); i++) {
-        std::copy(std::begin(src.values_[i])+srcRowFirst,
-                  std::begin(src.values_[i])+srcRowFirst+numRows,
-                  std::begin(values_[i])+destRow);
+    for (size_t i = 0; i < nValCols(); i++) {
+        std::copy(std::begin(src.values_[i]) + srcRowFirst,
+                  std::begin(src.values_[i]) + srcRowFirst + numRows,
+                  std::begin(values_[i]) + destRow);
     }
 }
 
 
-
 //_____________________________________________________________________
 bool MvGeoPoints::areRowsEqual(size_t r1, size_t r2)
 {
@@ -704,7 +702,6 @@ bool MvGeoPoints::areRowsEqual(size_t r1, size_t r2)
 }
 
 
-
 //_____________________________________________________________________
 MvGeoPoints&
 MvGeoPoints::operator=(const MvGeoPoints& gp)
@@ -725,13 +722,13 @@ void MvGeoPoints::resizeValueColumns()
     if ((nValCols()) > 0 && (nValCols() != values_.size()))
         values_.resize(nValCols());
 
-    for (size_t i=0; i < values_.size(); i++)
-        values_[i].resize(count_);
+    for (auto& value : values_)
+        value.resize(count_);
 }
 
 
 //_____________________________________________________________________
-void MvGeoPoints::newReservedSize(size_t size, bool init)
+void MvGeoPoints::newReservedSize(size_t size, bool /*init*/)
 {
     unload();
     set_count(size);
@@ -746,7 +743,7 @@ void MvGeoPoints::newReservedSize(size_t size, bool init)
 
     resizeValueColumns();
 
-/*
+    /*
     if (init)
         pts_.resize(count_);  // calls constructors
     else
@@ -832,12 +829,12 @@ bool MvGeoPoints::load(const char* path)
 }
 
 //_____________________________________________________________________
-bool MvGeoPoints::load(const size_t nmax)
+bool MvGeoPoints::load(const size_t /*nmax*/)
 {
     if (count_)
         return true;
 
-    ifstream f(path_.c_str());
+    std::ifstream f(path_.c_str());
     if (!f) {
         marslog(LOG_EROR, "Could not open geopoints file: %s", path_.c_str());
         return false;
@@ -870,7 +867,6 @@ void MvGeoPoints::addColType(eGeoColType t, bool addToFront)
 }
 
 
-
 //_____________________________________________________________________
 // The line should be something like this:
 // stnid   lat   time  long    date
@@ -882,8 +878,8 @@ bool MvGeoPoints::parseColumnNames(char* line)
     // populate colNames_, ncols_ and nvalcols_
 
     // tokenise into a list of strings
-    string sbuf(line);
-    vector<string> sv;
+    std::string sbuf(line);
+    std::vector<std::string> sv;
     Tokenizer parse(" \t");
     parse(sbuf, sv);
 
@@ -893,8 +889,7 @@ bool MvGeoPoints::parseColumnNames(char* line)
     clearColNames();
     clearColTypes();
 
-    for (size_t i = 0; i < sv.size(); i++) {
-        std::string& name = sv[i];
+    for (auto& name : sv) {
         addColName(name, true, true);
 
         // is this a standard co-ordinate column name?
@@ -930,8 +925,8 @@ bool MvGeoPoints::parseColumnNames(char* line)
 int MvGeoPoints::countValueColumns(char* line, int numCoordCols)
 {
     // tokenise into a list of strings
-    string sbuf(line);
-    vector<string> sv;
+    std::string sbuf(line);
+    std::vector<std::string> sv;
     Tokenizer parse(" \t");
     parse(sbuf, sv);
     return (int)sv.size() - numCoordCols;
@@ -946,7 +941,7 @@ void MvGeoPoints::fillValueColumnNames()
     for (int i = 0; i < numUnnamedCols; i++) {
         char buf[128];
         sprintf(buf, "_v%d", i + 1);  // first unnamed col is _v1, next is _v2
-        addColName(string(buf));
+        addColName(std::string(buf));
     }
 }
 
@@ -955,20 +950,20 @@ void MvGeoPoints::ensureNColsHasStnIds()
 {
     // if NCOLS format, and no stnid, then add to front of list
     if (gfmt_ == eGeoNCols &&
-       (std::find(colInfo_.colTypes_.begin(), colInfo_.colTypes_.end(), eGeoColStnId) == colInfo_.colTypes_.end())) {
+        (std::find(colInfo_.colTypes_.begin(), colInfo_.colTypes_.end(), eGeoColStnId) == colInfo_.colTypes_.end())) {
         addColName("stnid", false, false, true);
         colInfo_.ncoordcols_++;
-       }
+    }
 }
 
 
 //_____________________________________________________________________
-bool MvGeoPoints::load(ifstream& f, const size_t nmax)
+bool MvGeoPoints::load(std::ifstream& f, const size_t nmax)
 {
     char line[10240];
-    size_t n     = 0;
-    int numPts   = 0;
-    streampos sp = f.tellg();
+    size_t n          = 0;
+    int numPts        = 0;
+    std::streampos sp = f.tellg();
 
 
     if (nmax == 0) {
@@ -983,7 +978,7 @@ bool MvGeoPoints::load(ifstream& f, const size_t nmax)
 
     f.clear();
     f.seekg(sp);
-    //f.seekg(0, ios::beg);
+    //f.seekg(0, std::ios::beg);
 
     gfmt_ = eGeoTraditional;
 
@@ -1045,8 +1040,8 @@ bool MvGeoPoints::load(ifstream& f, const size_t nmax)
 
         else if (metadata == true)  // within the meta-data block
         {
-            string sbuf(line);
-            vector<string> sv;
+            std::string sbuf(line);
+            std::vector<std::string> sv;
             Tokenizer parse("=");
             parse(sbuf, sv);
             if (sv.size() == 2)
@@ -1062,17 +1057,17 @@ bool MvGeoPoints::load(ifstream& f, const size_t nmax)
         }
 
         else if (db_info == true && strstr(line, "DB_SYSTEM:") != 0) {
-            string sbuf(line);
-            string::size_type pos = sbuf.find("DB_SYSTEM:");
-            sbuf                  = sbuf.substr(pos + 10);
-            dbSystem_             = sbuf;
+            std::string sbuf(line);
+            std::string::size_type pos = sbuf.find("DB_SYSTEM:");
+            sbuf                       = sbuf.substr(pos + 10);
+            dbSystem_                  = sbuf;
         }
 
         else if (db_info == true && strstr(line, "DB_COLUMN:") != 0) {
-            string sbuf(line);
-            string::size_type pos = sbuf.find("DB_COLUMN:");
-            sbuf                  = sbuf.substr(pos + 10);
-            vector<string> sv;
+            std::string sbuf(line);
+            std::string::size_type pos = sbuf.find("DB_COLUMN:");
+            sbuf                       = sbuf.substr(pos + 10);
+            std::vector<std::string> sv;
 
             Tokenizer parse(";");
             parse(sbuf, sv);
@@ -1102,11 +1097,11 @@ bool MvGeoPoints::load(ifstream& f, const size_t nmax)
         }
 
         else if (db_info == true && strstr(line, "DB_COLUMN_ALIAS:") != 0) {
-            string sbuf(line);
-            string::size_type pos = sbuf.find("DB_COLUMN_ALIAS:");
-            sbuf                  = sbuf.substr(pos + 16);
+            std::string sbuf(line);
+            std::string::size_type pos = sbuf.find("DB_COLUMN_ALIAS:");
+            sbuf                       = sbuf.substr(pos + 16);
 
-            vector<string> sv;
+            std::vector<std::string> sv;
             Tokenizer parse(";");
             parse(sbuf, sv);
 
@@ -1135,10 +1130,10 @@ bool MvGeoPoints::load(ifstream& f, const size_t nmax)
         }
 
         else if (db_info == true && strstr(line, "DB_PATH:") != 0) {
-            string sbuf(line);
-            string::size_type pos = sbuf.find("DB_PATH:");
-            sbuf                  = sbuf.substr(pos + 8);
-            dbPath_               = sbuf;
+            std::string sbuf(line);
+            std::string::size_type pos = sbuf.find("DB_PATH:");
+            sbuf                       = sbuf.substr(pos + 8);
+            dbPath_                    = sbuf;
         }
 
         else if (db_info == true && strstr(line, "DB_QUERY_BEGIN") != 0) {
@@ -1178,7 +1173,7 @@ bool MvGeoPoints::load(ifstream& f, const size_t nmax)
                 }
 
                 if (!extract(line, n)) {
-                    marslog(LOG_EROR, "Error parsing geopoints file %s at value line %d", path_.c_str(), n+1);
+                    marslog(LOG_EROR, "Error parsing geopoints file %s at value line %d", path_.c_str(), n + 1);
                     return false;
                 }
                 n++;
@@ -1199,7 +1194,7 @@ bool MvGeoPoints::load(ifstream& f, const size_t nmax)
 
             if ((*line != '#') && (strlen(line) > 4)) {
                 if (!extract(line, i)) {
-                    marslog(LOG_EROR, "Error parsing geopoints file %s at value line %d", path_.c_str(), n+1);
+                    marslog(LOG_EROR, "Error parsing geopoints file %s at value line %d", path_.c_str(), n + 1);
                     return false;
                 }
                 n++;
@@ -1228,8 +1223,8 @@ void MvGeoPoints::unload()
     dates_.destroyVals();
     times_.destroyVals();
 
-    for (size_t i=0; i < values_.size(); i++)
-        values_[i].destroyVals();
+    for (auto& value : values_)
+        value.destroyVals();
 
     set_count(0);
 }
@@ -1239,7 +1234,7 @@ bool MvGeoPoints::write(const char* filename)
 {
     int nPreviousPrecision;
 
-    ofstream fout(filename);
+    std::ofstream fout(filename);
     if (!fout) {
         marslog(LOG_EROR, "Unable to open geopoints file for writing: %s", filename);
         return false;
@@ -1297,7 +1292,7 @@ bool MvGeoPoints::write(const char* filename)
     nPreviousPrecision = fout.precision();
     fout.precision(VALUE_PRECISION);
     fout << "# Missing values represented by " << GEOPOINTS_MISSING_VALUE
-         << " (not user-changeable)" << endl;
+         << " (not user-changeable)" << std::endl;
     fout.precision(nPreviousPrecision);
 
 
@@ -1305,26 +1300,26 @@ bool MvGeoPoints::write(const char* filename)
 
     const metadata_t md = metadataConst();
     if (!md.empty()) {
-        fout << "#METADATA" << endl;
-        metadata_t::const_iterator it = md.begin();
+        fout << "#METADATA" << std::endl;
+        auto it = md.begin();
         while (it != md.end()) {
             std::string key = it->first;
             MvVariant val   = it->second;
-            fout << key << "=" << val.toString() << endl;
+            fout << key << "=" << val.toString() << std::endl;
             it++;
         }
     }
 
     // start the data section
 
-    fout << "#DATA" << endl;
+    fout << "#DATA" << std::endl;
 
     MvGeop1Writer gpw(*this, 0);
 
     for (size_t r = 0; r < count_; ++r) {
         gpw.r_ = r;
         fout << gpw
-             << endl;
+             << std::endl;
     }
 
     return true;
@@ -1385,22 +1380,22 @@ size_t MvGeoPoints::indexOfFirstValidPoint(size_t c) const
 
 class MvGeoPointIndex
 {
-    public:
-        MvGeoPointIndex(size_t index, MvGeoPoints *gpt);
-        bool operator<(const MvGeoPointIndex& rhs) const;
+public:
+    MvGeoPointIndex(size_t index, MvGeoPoints* gpt);
+    bool operator<(const MvGeoPointIndex& rhs) const;
 
-        double latitude() const { return gpt_->lat_y(index_); }
-        double longitude() const { return gpt_->lon_x(index_); }
-        double height() const { return gpt_->height(index_); }
-        double elevation() const { return gpt_->elevation(index_); }
-        double value() const { return gpt_->value(index_); }
+    double latitude() const { return gpt_->lat_y(index_); }
+    double longitude() const { return gpt_->lon_x(index_); }
+    double height() const { return gpt_->height(index_); }
+    double elevation() const { return gpt_->elevation(index_); }
+    double value() const { return gpt_->value(index_); }
 
-        size_t index_;
-        MvGeoPoints *gpt_;
+    size_t index_;
+    MvGeoPoints* gpt_;
 };
 
 
-MvGeoPointIndex::MvGeoPointIndex(size_t index, MvGeoPoints *gpt) :
+MvGeoPointIndex::MvGeoPointIndex(size_t index, MvGeoPoints* gpt) :
     index_(index),
     gpt_(gpt)
 {
@@ -1444,7 +1439,6 @@ bool MvGeoPointIndex::operator<(const MvGeoPointIndex& rhs) const
 //_____________________________________________________________________
 
 
-
 void MvGeoPoints::sort()
 {
     if (count() < 2)  //-- no need to sort if empty or only one point
@@ -1454,7 +1448,6 @@ void MvGeoPoints::sort()
     MvGeoPoints tempCopy(*this);
 
 
-
     //-- to make sort faster for huge files, copy input geopoints into
     //-- several latitude band lists;
     //-- here we define the width and the number of these latitude bands
@@ -1462,8 +1455,8 @@ void MvGeoPoints::sort()
     const int cLatBandCount   = (int)(180.0 / cLatBandSize) + 1;
 
     //-- STL provides tools for sorting
-    vector<vector<MvGeoPointIndex> > LatListVec;
-    vector<MvGeoPointIndex> emptyList;
+    std::vector<std::vector<MvGeoPointIndex> > LatListVec;
+    std::vector<MvGeoPointIndex> emptyList;
     LatListVec.assign(cLatBandCount + 1, emptyList);
 
     //-- first coarse distribution into STL lists that are stored in STL vector
@@ -1479,17 +1472,17 @@ void MvGeoPoints::sort()
         LatListVec[band].push_back(MvGeoPointIndex(s, &tempCopy));
     }
 
-    vector<MvGeoPointIndex> work;
+    std::vector<MvGeoPointIndex> work;
     work.reserve(count_);  // reserve so that we don't call default constructor unnecessarily
 
     //-- sort each latitude band STL list and copy to output
     for (int vecList = 0; vecList < cLatBandCount + 1; ++vecList) {
-        vector<MvGeoPointIndex> curList = LatListVec[vecList];
+        std::vector<MvGeoPointIndex> curList = LatListVec[vecList];
         if (!curList.empty()) {
-            std::sort (curList.begin(), curList.end());
+            std::sort(curList.begin(), curList.end());
 
-            for (auto p = curList.begin(); p != curList.end(); ++p) {
-                work.push_back(*p);
+            for (auto& p : curList) {
+                work.push_back(p);
             }
 
             curList.clear();
@@ -1516,9 +1509,8 @@ void MvGeoPoints::removeDuplicates()
 
         for (size_t p = 1; p < count_; ++p)  //-- start from the second point
         {
-            curr = p;        //-- current geopoint
-            if (!tempCopy.areRowsEqual(curr, prev))
-            {
+            curr = p;  //-- current geopoint
+            if (!tempCopy.areRowsEqual(curr, prev)) {
                 copyRow(tempCopy, prev, dest++);  //-- points non-equal => copy prev
             }
             prev = curr;  //-- store current as previous
@@ -1557,9 +1549,9 @@ int MvGeoPoints::indexOfNamedValue(std::string& name)
         return -1;
 }
 
-vector<string> MvGeoPoints::valueColNames() const
+std::vector<std::string> MvGeoPoints::valueColNames() const
 {
-    vector<string> result;
+    std::vector<std::string> result;
     for (size_t i = 0; i < colInfo_.colTypes_.size(); i++) {
         eGeoColType colType = colInfo_.colTypes_[i];
         if (!colTypeIsCoord(colType)) {
@@ -1570,15 +1562,15 @@ vector<string> MvGeoPoints::valueColNames() const
     return result;
 }
 
-vector<string> MvGeoPoints::usedColNames() const
+std::vector<std::string> MvGeoPoints::usedColNames() const
 {
     // get the complete list of column names, and then remove those that
     // are not actually used (possible: elevation)
-    vector<string> cnames(colNames());
+    std::vector<std::string> cnames(colNames());
     if ((format() == eGeoNCols) && !hasElevations()) {
-        cnames.erase(std::remove_if(cnames.begin(),  cnames.end(),
-                   [](string colname){return colname == "elevation";}),
-               cnames.end());
+        cnames.erase(std::remove_if(cnames.begin(), cnames.end(),
+                                    [](std::string colname) { return colname == "elevation"; }),
+                     cnames.end());
     }
     return cnames;
 }
@@ -1668,8 +1660,7 @@ void MvGeoPoints::setColumnsForFormat()
     return;
 }
 
-string MvGeoPoints::value(size_t row, size_t col, int& type)
+std::string MvGeoPoints::value(size_t row, size_t col, int& type)
 {
     return column(row, col, colInfo_, type);
 }
-
