@@ -9,15 +9,13 @@
 
 // MvGeoPoints.h,   apr03/vk
 
+#pragma once
 
-#include <string>
-#include "inc_iostream.h"
-#include <map>
-#include <vector>
+#include <iosfwd>
 #include <limits>
-#include "MvVariant.h"
+#include <map>
 
-using namespace std;
+#include "MvVariant.h"
 
 //! Geopoint missing value indicator
 /*! Background: the choice of value depended on three things:
@@ -92,31 +90,29 @@ enum eGeoCopyMode
 class MvGeoPointColumnInfo
 {
 public:
-
     bool operator==(const MvGeoPointColumnInfo& in);
     void ensureOnlyOneValueColumn();
 
-    vector<string> colNames_;
+    std::vector<std::string> colNames_;
     int ncols_;
     int ncoordcols_;
     int nvalcols_;
     int nvalcolsforcompute_;
     bool hasStnIds_;
     bool hasElevations_;
-    vector<eGeoColType> colTypes_;
+    std::vector<eGeoColType> colTypes_;
 };
 
 
-
 // the intention was to put the column info into each column,
 // but this can be a later refactoring
 class MvGeoColumn
 {
-/*
+    /*
 public:
 
-    void name(string &s) { name_ = s; }
-    string & name() { return name_; }
+    void name(std::string &s) { name_ = s; }
+    std::string & name() { return name_; }
 
     void isCoordinate(bool b) { isCoordinate_ = b; }
     bool isCoordinate() { return isCoordinate_; }
@@ -126,44 +122,55 @@ public:
 
 
 private:
-    string name_;
+    std::string name_;
     eGeoColType colType_;
     bool isCoordinate_;
 */
 };
 
 
-class MvGeoColumnString : public MvGeoColumn, public vector<string>
+class MvGeoColumnString : public MvGeoColumn, public std::vector<std::string>
 {
 public:
-    void destroyVals() {MvGeoColumnString empty; this->swap(empty);}
+    void destroyVals()
+    {
+        MvGeoColumnString empty;
+        this->swap(empty);
+    }
 };
 
-class MvGeoColumnDouble : public MvGeoColumn, public vector<double>
+class MvGeoColumnDouble : public MvGeoColumn, public std::vector<double>
 {
 public:
-    void destroyVals() {MvGeoColumnDouble empty; this->swap(empty);}
+    void destroyVals()
+    {
+        MvGeoColumnDouble empty;
+        this->swap(empty);
+    }
 };
 
-class MvGeoColumnLong : public MvGeoColumn, public vector<long>
+class MvGeoColumnLong : public MvGeoColumn, public std::vector<long>
 {
 public:
-    void destroyVals() {MvGeoColumnLong empty; this->swap(empty);}
+    void destroyVals()
+    {
+        MvGeoColumnLong empty;
+        this->swap(empty);
+    }
 };
 
 
 class MvGeoPoints
 {
 public:
-
     static const size_t INVALID_INDEX = std::numeric_limits<size_t>::max();
 
-    typedef map<string, MvVariant> metadata_t;
+    typedef std::map<std::string, MvVariant> metadata_t;
 
 
     // constructors
     MvGeoPoints(size_t count = 0, int numvals = 1, eGeoFormat efmt = eGeoTraditional, bool init = true);
-    MvGeoPoints(size_t count, const MvGeoPointColumnInfo &colInfo, eGeoFormat efmt, bool init);
+    MvGeoPoints(size_t count, const MvGeoPointColumnInfo& colInfo, eGeoFormat efmt, bool init);
     MvGeoPoints(size_t count, bool init = true);
     MvGeoPoints(const char* name, const size_t nmax = 0);
     MvGeoPoints(const MvGeoPoints&);  // copy constructor
@@ -173,18 +180,17 @@ public:
 
     // destructor
     ~MvGeoPoints();
-    void unload(); // Releases points data from memory
-
+    void unload();  // Releases points data from memory
 
 
     eGeoFormat format() const { return gfmt_; }
-    string sFormat() const { return sgfmt_; }
+    std::string sFormat() const { return sgfmt_; }
 
     void set_format(eGeoFormat f) { gfmt_ = f; }
     void set_format(eGeoFormat fmt, size_t numvals);
 
-    string path() const { return path_; }
-    void set_path(string p) { path_ = p; }
+    std::string path() const { return path_; }
+    void set_path(std::string p) { path_ = p; }
 
 
     size_t count() const { return count_; }
@@ -233,16 +239,24 @@ public:
     void set_time(long d, size_t r) { times_[r] = d; }
 
     // possible optimisation - remove const and return a reference
-    string strValue(size_t r) const { return strings_[r]; }
-    string strValue() const { return strings_[r_]; }
+    std::string strValue(size_t r) const { return strings_[r]; }
+    std::string strValue() const { return strings_[r_]; }
     void set_strValue(const char* d) { strings_[r_] = d; }
     void set_strValue(const char* d, size_t r) { strings_[r] = d; }
-    void set_strValue(const string &s) { strings_[r_] = s; }
-    void set_strValue(const string &s, size_t r) { strings_[r] = s; }
-    bool isStnIdEmpty() const { static std::string empty("?"); return (strValue().empty() || strValue() == empty); }
-    bool isStnIdEmpty(size_t r) const { static std::string empty("?"); return (strValue(r).empty() || strValue(r) == empty); }
-    string stnid() { return strValue(); }
-    string stnid(size_t r) { return strValue(r); }
+    void set_strValue(const std::string& s) { strings_[r_] = s; }
+    void set_strValue(const std::string& s, size_t r) { strings_[r] = s; }
+    bool isStnIdEmpty() const
+    {
+        static std::string empty("?");
+        return (strValue().empty() || strValue() == empty);
+    }
+    bool isStnIdEmpty(size_t r) const
+    {
+        static std::string empty("?");
+        return (strValue(r).empty() || strValue(r) == empty);
+    }
+    std::string stnid() { return strValue(); }
+    std::string stnid(size_t r) { return strValue(r); }
     void set_stnid(const char* id) { set_strValue(id); }
 
 
@@ -250,16 +264,16 @@ public:
     double value() const { return values_[vi_][r_]; }
     void set_value(double d, size_t r) { values_[vi_][r] = d; }
     void set_value(double d) { values_[vi_][r_] = d; }
-    double speed() const { return value(); }  //-- alias for value()
+    double speed() const { return value(); }      //-- alias for value()
     void set_speed(double d) const { value(d); }  //-- alias for value()
 
     double value2(size_t r) const { return values_[1][r]; }
     double value2() const { return values_[1][r_]; }
     void set_value2(double d, size_t r) { values_[1][r] = d; }
     void set_value2(double d) { values_[1][r_] = d; }
-    double direc() const { return value2(); }  //-- alias for value2()
+    double direc() const { return value2(); }           //-- alias for value2()
     double direc(size_t r) const { return value2(r); }  //-- alias for value2()
-    void set_direc(double d) { set_value2(d); }  //-- alias for value2()
+    void set_direc(double d) { set_value2(d); }         //-- alias for value2()
     bool direc_missing() const { return (values_[1][r_] == GEOPOINTS_MISSING_VALUE); }
     void set_direc_missing(size_t r) { values_[1][r] = GEOPOINTS_MISSING_VALUE; }
     bool have_direc() { return (nValCols() > 1); }
@@ -269,29 +283,28 @@ public:
     void set_ivalue(double d, size_t c) { values_[c][r_] = d; }
     void set_ivalue(double d, size_t r, size_t c) { values_[c][r] = d; }
 
-    string value(size_t row, size_t col, int& type);
+    std::string value(size_t row, size_t col, int& type);
 
     bool value_missing() const { return (values_[vi_][r_] == GEOPOINTS_MISSING_VALUE); }
     bool value_missing(size_t c) const { return (ivalue(r_, c) == GEOPOINTS_MISSING_VALUE); }
     bool value_missing(size_t r, size_t c) const { return (ivalue(r, c) == GEOPOINTS_MISSING_VALUE); }
 
 
-
     //! Returns \c true if either of the values is missing
-    bool any_missing(size_t r) const {
-        return ((values_[vi_][r] == GEOPOINTS_MISSING_VALUE) || ((nValCols() > 1)&&(values_[1][r] == GEOPOINTS_MISSING_VALUE)));
+    bool any_missing(size_t r) const
+    {
+        return ((values_[vi_][r] == GEOPOINTS_MISSING_VALUE) || ((nValCols() > 1) && (values_[1][r] == GEOPOINTS_MISSING_VALUE)));
     }
 
 
     //void set_value_missing(size_t r, size_t c) { value(c, r, GEOPOINTS_MISSING_VALUE); }
-    void set_value_missing() { set_value(GEOPOINTS_MISSING_VALUE); } // use row r_ and default val col
+    void set_value_missing() { set_value(GEOPOINTS_MISSING_VALUE); }  // use row r_ and default val col
     void set_value_missing(size_t c) { set_ivalue(GEOPOINTS_MISSING_VALUE, c); }
     void set_value_missing(size_t r, size_t c) { set_ivalue(GEOPOINTS_MISSING_VALUE, r, c); }
 
     bool hasVectors() const { return gfmt_ == eGeoVectorPolar || gfmt_ == eGeoVectorXY; }
 
 
-
     //! latLonHeightBefore, cut-down version of less-than operator
     bool latLonHeightBefore(const MvGeoPoints& in, size_t r_this, size_t r_in) const;
 
@@ -308,10 +321,10 @@ public:
 	 */
     void newReservedSize(size_t n, bool init = true);
 
-    void copy(const MvGeoPoints& gp, eGeoCopyMode mode=eGeoCopyAll);
+    void copy(const MvGeoPoints& gp, eGeoCopyMode mode = eGeoCopyAll);
 
     bool load(const char* filename);
-    bool load(ifstream& fstr, const size_t nmax = 0);
+    bool load(std::ifstream& fstr, const size_t nmax = 0);
 
     bool extract(const char* line, size_t r);
     bool parseColumnNames(char* line);
@@ -327,20 +340,20 @@ public:
     }
 
 
-     //! Returns the column information
+    //! Returns the column information
     size_t ncols() const { return colInfo_.ncols_; }
     size_t totalcols() const { return colInfo_.ncoordcols_ + colInfo_.nvalcols_; }
-    vector<string> colNames() const { return colInfo_.colNames_; }
-    string colName(size_t i) const
+    std::vector<std::string> colNames() const { return colInfo_.colNames_; }
+    std::string colName(size_t i) const
     {
         if (i >= 0 && i < colInfo_.colNames_.size())
             return colInfo_.colNames_[i];
         else
             return "";
     }
-    vector<string> valueColNames() const;
-    string valueColName(size_t i) const {return colInfo_.colNames_[colInfo_.ncoordcols_+i]; }
-    vector<string> usedColNames() const;
+    std::vector<std::string> valueColNames() const;
+    std::string valueColName(size_t i) const { return colInfo_.colNames_[colInfo_.ncoordcols_ + i]; }
+    std::vector<std::string> usedColNames() const;
     size_t nValCols() const { return colInfo_.nvalcols_; }
     size_t nCoordCols() const { return colInfo_.ncoordcols_; }
     size_t nValColsForCompute() const { return colInfo_.nvalcolsforcompute_; }
@@ -362,14 +375,14 @@ public:
     void addColName(std::string name, bool markStnIdAsUsed = false, bool markElevationAsUsed = false, bool addToFront = false);
     void addColType(eGeoColType t, bool addToFront = false);
     void clearColTypes() { colInfo_.colTypes_.clear(); }
-    MvGeoPointColumnInfo &columnInfo() { return colInfo_; }
+    MvGeoPointColumnInfo& columnInfo() { return colInfo_; }
 
 
-    string column(size_t row, size_t col, MvGeoPointColumnInfo& colinfo, int&);
+    std::string column(size_t row, size_t col, MvGeoPointColumnInfo& colinfo, int&);
 
 
     //! Returns whether another geopoints variable is compatible with this one in terms of columns
-    bool isCompatible(const MvGeoPoints &in) {return colInfo_ == in.colInfo_;}
+    bool isCompatible(const MvGeoPoints& in) { return colInfo_ == in.colInfo_; }
 
 
     //! Returns index of the named value (e.g. 'temperature'), or -1 if it does not exist for this data
@@ -384,22 +397,20 @@ public:
     metadata_t const& metadataConst() const { return metadata_; }
 
 
-
     //! Information about the database, query etc. that generated the geopoints data
-    string dbSystem() const { return dbSystem_; }
-    const map<string, string>& dbColumn() const { return dbColumn_; }
-    string dbColumn(string col)
+    std::string dbSystem() const { return dbSystem_; }
+    const std::map<std::string, std::string>& dbColumn() const { return dbColumn_; }
+    std::string dbColumn(std::string col)
     {
         return (dbColumn_.find(col) != dbColumn_.end()) ? dbColumn_[col] : "";
     }
-    const map<string, string>& dbColumnAlias() const { return dbColumnAlias_; }
-    string dbColumnAlias(string col)
+    const std::map<std::string, std::string>& dbColumnAlias() const { return dbColumnAlias_; }
+    std::string dbColumnAlias(std::string col)
     {
         return (dbColumnAlias_.find(col) != dbColumnAlias_.end()) ? dbColumnAlias_[col] : "";
     }
-    string dbPath() const { return dbPath_; }
-    const vector<string>& dbQuery() const { return dbQuery_; }
-
+    std::string dbPath() const { return dbPath_; }
+    const std::vector<std::string>& dbQuery() const { return dbQuery_; }
 
 
     //! Writes geopoints to file \c filename
@@ -440,11 +451,9 @@ public:
     bool areRowsEqual(size_t r1, size_t r2);
 
 
-
     MvGeoColumnDouble& valuesColumn(size_t c) { return values_[c]; }
 
 
-
     //! Returns whether the given column type is a coordinate(true) or value(false)
     static bool colTypeIsCoord(eGeoColType t);
 
@@ -464,12 +473,11 @@ private:
     bool load(const size_t nmax = 0);
 
 
-
     eGeoFormat gfmt_;
     size_t count_;
-    string path_;
-    size_t vi_;        //-- index for the currently used value column
-    size_t r_;         //-- row to use if not suppied in fn args
+    std::string path_;
+    size_t vi_;  //-- index for the currently used value column
+    size_t r_;   //-- row to use if not suppied in fn args
 
     MvGeoPointColumnInfo colInfo_;
 
@@ -478,23 +486,21 @@ private:
     MvGeoColumnDouble longitudes_;
     MvGeoColumnDouble heights_;
     MvGeoColumnDouble elevations_;
-    MvGeoColumnLong   dates_;
-    MvGeoColumnLong   times_;
+    MvGeoColumnLong dates_;
+    MvGeoColumnLong times_;
 
-    vector<MvGeoColumnDouble> values_;
+    std::vector<MvGeoColumnDouble> values_;
 
 
-    string sgfmt_;
-    string dbSystem_;
-    map<string, string> dbColumn_;
-    map<string, string> dbColumnAlias_;
-    string dbPath_;
-    vector<string> dbQuery_;
+    std::string sgfmt_;
+    std::string dbSystem_;
+    std::map<std::string, std::string> dbColumn_;
+    std::map<std::string, std::string> dbColumnAlias_;
+    std::string dbPath_;
+    std::vector<std::string> dbQuery_;
 
     metadata_t metadata_;
 
 
     static std::map<std::string, eGeoColType> coordColMap_;
 };
-
-
