@@ -9,14 +9,15 @@
 
 // MvGrid.h,    vk Aug-98
 
-#ifndef MvGrid_DEFINED
-#define MvGrid_DEFINED
+#pragma once
 
 #include <float.h>
 
-#include "mars.h"
 #include <string>
-using std::string;
+#include <map>
+#include <vector>
+
+#include "mars.h"
 
 #include "MvLocation.h"
 #include "MvMatrix.h"
@@ -31,16 +32,16 @@ enum eGribHeaderType
     GRIB_TYPE_ERROR
 };
 
-const string cLatLonGrid("regular_ll");
-const string cLatLonRotatedGrid("rotated_ll");
-const string cLatLonReducedGrid("reduced_ll");
-const string cGaussianGrid("regular_gg");
-const string cGaussianReducedGrid("reduced_gg");
-const string cPolarStereoGrid("polar_stereographic");
-const string cLambertGrid("lambert");
-const string cLambertAzEqGrid("lambert_azimuthal_equal_area");
-const string cMercatorGrid("mercator");
-const string cSatelliteImage("space_view");
+const std::string cLatLonGrid("regular_ll");
+const std::string cLatLonRotatedGrid("rotated_ll");
+const std::string cLatLonReducedGrid("reduced_ll");
+const std::string cGaussianGrid("regular_gg");
+const std::string cGaussianReducedGrid("reduced_gg");
+const std::string cPolarStereoGrid("polar_stereographic");
+const std::string cLambertGrid("lambert");
+const std::string cLambertAzEqGrid("lambert_azimuthal_equal_area");
+const std::string cMercatorGrid("mercator");
+const std::string cSatelliteImage("space_view");
 
 const double cGridScaling = 1000.0;
 //const int    cLevelNotGiven    = -999;
@@ -174,7 +175,7 @@ public:
     virtual ~MvGridBase();
 
     //! sets whether to restore the field's original shape when destroyed
-    void restoreShapeOnDestroy(bool b) {restoreShapeOnDestroy_ = b;}
+    void restoreShapeOnDestroy(bool b) { restoreShapeOnDestroy_ = b; }
 
     //! Returns the \c index:th value
     double operator[](int index);
@@ -198,13 +199,13 @@ public:
 
     // Collects the surrounding grid point around the specified location
     virtual bool surroundingGridpoints(double /*lat_y*/, double /*lon_x*/, std::vector<MvGridPoint>& /*points*/,
-                                       bool /*canHaveMissing*/, bool /*doSort*/) {return false;}
+                                       bool /*canHaveMissing*/, bool /*doSort*/) { return false; }
 
     //! Returns the nearest grid point value and location
     virtual MvGridPoint nearestGridpoint(double lat_y, double lon_x, bool nearestValid);
 
     //! Returns the value interpolated into the given point
-    virtual double interpolatePoint(double lat_y, double lon_x, std::vector<MvGridPoint>* surroundingPoints = NULL);
+    virtual double interpolatePoint(double lat_y, double lon_x, std::vector<MvGridPoint>* surroundingPoints = nullptr);
 
     //! Returns a matrix around the given point
     virtual bool getMatrixNN(double lat_y, double lon_x, MvMatrix& mat);
@@ -232,7 +233,7 @@ public:
     //	bool   isSimilar( const MvGridBase* g ) const { return isEqual(g); }
 
     //! Returns the grid type as a string
-    string gridType() const { return gridType_; }
+    std::string gridType() const { return gridType_; }
 
     //! Check grid type (implement for the other grids, if it is needed)
     bool isRegularLatLongGrid()
@@ -268,7 +269,7 @@ public:
     {
         if (field_) {
             field_->values[index] = mars.grib_missing_value;
-            field_->bitmap                = true;
+            field_->bitmap        = true;
         }
     }
 
@@ -309,7 +310,7 @@ public:
     //! Returns the value and the location of the current grid point [iterator]
     MvGridPoint gridPoint() const { return MvGridPoint(value(), lat_y(), lon_x(), currentIndex_); }
 
-    virtual vector<double> averageCalc(bool ew, double N, double W, double S, double E, double gridInterval);
+    virtual std::vector<double> averageCalc(bool ew, double N, double W, double S, double E, double gridInterval);
 
     virtual void firstDerivativeX(MvGridBase*) {}
     virtual void firstDerivativeY(MvGridBase*) {}
@@ -318,14 +319,14 @@ public:
 
     // computes the grid cell area for each gridpoint
     virtual void gridCellArea(MvGridBase*) {}
-    virtual bool isGridCellAreaSupported() const {return false;}
+    virtual bool isGridCellAreaSupported() const { return false; }
 
     virtual void boundingBox(std::vector<double>&) {}
 
-    eGribHeaderType getNativeType(const char *name) const;
+    eGribHeaderType getNativeType(const char* name) const;
     long getLong(const char* name, bool throwOnError = false, bool quiet = false) const;
     double getDouble(const char* name, bool throwOnError = false, bool quiet = false) const;
-    string getString(const char* name, bool throwOnError = false, bool quiet = false) const;
+    std::string getString(const char* name, bool throwOnError = false, bool quiet = false) const;
 
     long getLongArray(const char* name, long** lvals, bool throwOnError = false, bool quiet = false) const;
     long getDoubleArray(const char* name, double** lvals, bool throwOnError = false, bool quiet = false) const;
@@ -333,7 +334,7 @@ public:
 
     bool setLong(const char* name, long val);
     bool setDouble(const char* name, double val);
-    bool setString(const char* name, string& val);
+    bool setString(const char* name, std::string& val);
 
     long vertCoordCoefPairCount();
     bool vertCoordCoefs(double& C1, double& C2, int level);
@@ -346,7 +347,7 @@ protected:
     field* field_;
     double* vertCoord_;
     long vertCoordPairCount_;
-    string gridType_;
+    std::string gridType_;
     long horisLines_;   //-- points_meridian
     long horisPoints_;  //-- points_parallel
     int horisPointCount_;
@@ -395,7 +396,7 @@ public:
     {
         return DBL_MAX;
     }
-    vector<double> averageCalc(bool ew, double N, double W, double S, double E, double grid);
+    std::vector<double> averageCalc(bool ew, double N, double W, double S, double E, double grid);
 };
 
 
@@ -419,7 +420,7 @@ public:
     bool advance();
 
     //! We may/may not have the iterator for this projection
-    bool hasIterator() const { return (iter_ != NULL); }
+    bool hasIterator() const { return (iter_ != nullptr); }
 
     double value() const;
 
@@ -453,7 +454,7 @@ public:
     bool surroundingGridpoints(double lat_y, double lon_x, std::vector<MvGridPoint>& points,
                                bool canHaveMissing, bool doSort) override;
     virtual bool surroundingGridpointsForExtrapolation(double lat_y, double lon_x, std::vector<MvGridPoint>& points,
-                               bool canHaveMissing, bool doSort);
+                                                       bool canHaveMissing, bool doSort);
     virtual MvGridPoint nearestGridpoint(double lat_y, double lon_x, bool nearestValid) override;
     virtual double interpolatePoint(double lat_y, double lon_x, std::vector<MvGridPoint>* surroundingPoints) override;
     void firstDerivativeX(MvGridBase*) override;
@@ -461,7 +462,7 @@ public:
     void secondDerivativeX(MvGridBase*) override;
     void secondDerivativeY(MvGridBase*) override;
     void gridCellArea(MvGridBase*) override;
-    bool isGridCellAreaSupported() const override {return true;}
+    bool isGridCellAreaSupported() const override { return true; }
     void boundingBox(std::vector<double>&) override;
 
 protected:
@@ -624,7 +625,6 @@ public:
 };
 
 
-
 //===================================================================
 //
 // MvIrregularGrid:
@@ -645,11 +645,11 @@ public:
     virtual double firstLatY() override;
     virtual double firstLonXInArea(int row);
     virtual double lastLonXInArea(int row);
-    void currentBoundingLats(double &lat1,double &lat2);
+    void currentBoundingLats(double& lat1, double& lat2);
     bool surroundingGridpoints(double lat_y, double lon_x, std::vector<MvGridPoint>& points,
                                bool canHaveMissing, bool doSort) override;
     virtual bool surroundingGridpointsForExtrapolation(double lat_y, double lon_x, std::vector<MvGridPoint>& points,
-                               bool canHaveMissing, bool doSort) = 0;
+                                                       bool canHaveMissing, bool doSort) = 0;
     virtual MvGridPoint nearestGridpoint(double lat_y, double lon_x, bool nearestValid) override;
     virtual double interpolatePoint(double lat_y, double lon_x, std::vector<MvGridPoint>* surroundingPoints) override;
     virtual int pointsInRow(int row) = 0;
@@ -659,7 +659,7 @@ public:
     double lastLonX();
     double lastLatY();
     void gridCellArea(MvGridBase*) override;
-    bool isGridCellAreaSupported() const override {return true;}
+    bool isGridCellAreaSupported() const override { return true; }
     void boundingBox(std::vector<double>& v) override;
 
 protected:
@@ -698,7 +698,7 @@ public:
     virtual bool advance();
     virtual int pointsInRow(int row);
     bool surroundingGridpointsForExtrapolation(double /*lat_y*/, double /*lon_x*/, std::vector<MvGridPoint>& /*points*/,
-                               bool /*canHaveMissing*/, bool /*doSort*/) {return false;}
+                                               bool /*canHaveMissing*/, bool /*doSort*/) { return false; }
 
     virtual double extrapolatePoint(double, double, std::vector<MvGridPoint>*)
     {
@@ -720,12 +720,12 @@ protected:
 class GaussianLatitudes
 {
 public:
-    GaussianLatitudes(){};
-    ~GaussianLatitudes(){};
+    GaussianLatitudes()  = default;
+    ~GaussianLatitudes() = default;
     int latitudes(long trunc, double* v, unsigned int numLatitudes);
 
 private:
-    map<long, vector<double> > cachedLatitudes_;
+    std::map<long, std::vector<double> > cachedLatitudes_;
 };
 
 
@@ -742,10 +742,10 @@ class MvGaussianGridBase : public MvIrregularGrid
 {
 public:
     MvGaussianGridBase(field* myfield, field_state oldState, bool memoryToBeReleased);
-    ~MvGaussianGridBase(){};
+    ~MvGaussianGridBase() = default;
 
     bool surroundingGridpointsForExtrapolation(double lat_y, double lon_x, std::vector<MvGridPoint>& points,
-                               bool canHaveMissing, bool doSort);
+                                               bool canHaveMissing, bool doSort);
     double extrapolatePoint(double lat_y, double lon_x, std::vector<MvGridPoint>* surroundingPoints);
     static GaussianLatitudes gLatitudes_;
 };
@@ -834,5 +834,4 @@ protected:
 };
 
 
-#endif
 // MvGrid_DEFINED
