@@ -8,9 +8,13 @@
  ***************************** LICENSE END
  *************************************/
 
+#include "MvNetCDF.h"
+
+#include <iomanip>
+#include <sstream>
+
 #include <assert.h>
 
-#include "MvNetCDF.h"
 #include "Tokenizer.h"
 
 // Decimal precision to convert float/double number to string
@@ -27,7 +31,7 @@ MvNetCDFBehaviour MvNetCDF::options_;
 //-----------------------------------------------------------
 
 // Constructor
-MvNcFile::MvNcFile(const string& path, int mode)
+MvNcFile::MvNcFile(const std::string& path, int mode)
 {
     // mode options:
     // a) open: NC_NOWRITE(0)/NC_WRITE/NC_SHARE/NC_WRITE|NC_SHARE
@@ -189,15 +193,15 @@ MvNcValues::~MvNcValues()
             delete[](double*) values_;
             break;
         case NC_STRING:
-            delete[](string*) values_;
+            delete[](std::string*) values_;
             break;
     }
 }
 
-string MvNcValues::as_string(long n) const  // NC_CHAR 2
+std::string MvNcValues::as_string(long n) const  // NC_CHAR 2
 {
     if (vchar_ && n == 0)
-        return string(vchar_);
+        return std::string(vchar_);
 
     assert(vstring_ != 0);
     return vstring_[n];
@@ -320,7 +324,7 @@ int MvNcValues::allocateMemory()
         }
         case NC_USHORT: {
             vushort_ = new ushort[nvalues_];
-            values_ = (void*)vushort_;
+            values_  = (void*)vushort_;
             break;
         }
 
@@ -349,10 +353,10 @@ int MvNcValues::allocateMemory()
         case NC_BYTE:
             vschar_           = new signed char[nvalues_ + 1];
             vschar_[nvalues_] = 0;
-            values_          = (void*)vschar_;
+            values_           = (void*)vschar_;
             break;
         case NC_STRING:
-            vstring_ = new string[nvalues_];
+            vstring_ = new std::string[nvalues_];
             values_  = (void*)vstring_;
             break;
         default:
@@ -377,7 +381,7 @@ MvNcBase::MvNcBase() :
     type_(0),
     ncStatus_(NC_NOERR){};
 
-MvNcBase::MvNcBase(int ncid, int id, const string& name, nc_type type) :
+MvNcBase::MvNcBase(int ncid, int id, const std::string& name, nc_type type) :
     hasMissingValueIndicator_(false),
     missingValueIndicator_(-999),
     scaleFactor_(1),
@@ -396,10 +400,10 @@ MvNcBase::MvNcBase(int ncid, int id, const string& name, nc_type type) :
 MvNcAtt::MvNcAtt(NcAtt *ncAtt) : ncAtt_(ncAtt)
 {
   if ( ncAtt_ ) values_ = new MvNcValues(ncAtt_->values());
-  else values_ = NULL;
+  else values_ = nullptr;
 }
 #else
-MvNcAtt::MvNcAtt(int ncid, int id, const string& name) :
+MvNcAtt::MvNcAtt(int ncid, int id, const std::string& name) :
     MvNcBase(ncid, id, name, -1)
 {
     // Check if it is a new or an existent attribute
@@ -407,7 +411,7 @@ MvNcAtt::MvNcAtt(int ncid, int id, const string& name) :
     size_t len;
     int ret = nc_inq_att(ncId_, id_, name_.c_str(), &type, &len);
     if (ret == NC_ENOTATT) {
-        values_ = NULL;  // new attribute
+        values_ = nullptr;  // new attribute
         return;
     }
     else if (ret != NC_NOERR) {
@@ -434,7 +438,7 @@ MvNcAtt::~MvNcAtt()
 }
 
 // Return a string with the values separated by '/'.
-NcBool MvNcAtt::getValues(string& str)
+NcBool MvNcAtt::getValues(std::string& str)
 {
     if (!isValid())
         return false;
@@ -456,9 +460,9 @@ NcBool MvNcAtt::getValues(string& str)
 // Over-ride the base function when dealing with floating-point
 // numbers because the in-built netCDF as_string function chops off
 // any significant figures after about 10^6
-string MvNcAtt::as_string(long n)
+std::string MvNcAtt::as_string(long n)
 {
-    ostringstream oss;
+    std::ostringstream oss;
     switch (type()) {
         case NC_FLOAT: {
             oss << std::setprecision(MV_NC_PRECISION) << values()->as_float(n);
@@ -495,7 +499,7 @@ string MvNcAtt::as_string(long n)
 }
 
 // Format attribute values in a sensible way
-void MvNcAtt::printValue(string& str, double value)
+void MvNcAtt::printValue(std::string& str, double value)
 {
     unsigned char uc;
     short ss;
@@ -536,7 +540,7 @@ void MvNcAtt::printValue(string& str, double value)
             tztrim(buf);
             break;
         default:
-            cerr << "Invalid type !!" << endl;
+            std::cerr << "Invalid type !!" << std::endl;
     }
 
     str += buf;
@@ -574,7 +578,7 @@ void MvNcAtt::tztrim(char* ss)
 
 #if 0  // F
 MvNcVar::MvNcVar(NcVar *ncvar, bool is_global, MvNetCDF *parent): 
-  edges_(NULL),ncVar_(ncvar),values_(NULL), isGlobal_(is_global), parent_(parent), isTime_(false)
+  edges_(nullptr),ncVar_(ncvar),values_(nullptr), isGlobal_(is_global), parent_(parent), isTime_(false)
 { 
   fillAttributes();
   storeFillValue();
@@ -582,11 +586,11 @@ MvNcVar::MvNcVar(NcVar *ncvar, bool is_global, MvNetCDF *parent):
   storeTimeInformation();
 }
 #else
-MvNcVar::MvNcVar(int varId, const string& name, nc_type type,
+MvNcVar::MvNcVar(int varId, const std::string& name, nc_type type,
                  bool is_global, MvNetCDF* parent) :
     MvNcBase(parent->ncId(), varId, name, type),
-    edges_(NULL),
-    values_(NULL),
+    edges_(nullptr),
+    values_(nullptr),
     isGlobal_(is_global),
     parent_(parent),
     isTime_(false)
@@ -621,8 +625,8 @@ MvNcVar::MvNcVar(const MvNcVar& aa)
 
 MvNcVar::~MvNcVar()
 {
-    // cout << "In var destructor " << ncVar_->name() << endl;
-    vector<MvNcAtt*>::iterator ii;
+    // std::cout << "In var destructor " << ncVar_->name() << std::endl;
+    std::vector<MvNcAtt*>::iterator ii;
     for (ii = attributes_.begin(); ii != attributes_.end(); ii++)
         delete (*ii);
 
@@ -638,7 +642,7 @@ void MvNcVar::storeFillValue()
 {
     // if (options().detectMissingValues())
     MvNcAtt* att = getAttribute(options().missingValuesAttribute());
-    if (att != NULL) {
+    if (att != nullptr) {
         missingValueIndicator_    = att->as_double(0);
         hasMissingValueIndicator_ = true;
     }
@@ -649,12 +653,12 @@ void MvNcVar::storeScaleFactorAndOffset()
     // if (options().scaleValues())
     {
         MvNcAtt* attScale = getAttribute("scale_factor");
-        if (attScale != NULL) {
+        if (attScale != nullptr) {
             scaleFactor_ = attScale->as_double(0);
         }
 
         MvNcAtt* attOffset = getAttribute("add_offset");
-        if (attOffset != NULL) {
+        if (attOffset != nullptr) {
             addOffset_ = attOffset->as_double(0);
         }
     }
@@ -670,13 +674,13 @@ bool MvNcVar::parseDate(const std::string& dateAndTimeString, MvDate& date)
     // do some parsing here and construct a 'nice' date and time for it
 
     // split into <date> <time>
-    vector<std::string> tDateAndTime;
+    std::vector<std::string> tDateAndTime;
     Tokenizer tokenizer1(" T");
     tokenizer1(dateAndTimeString, tDateAndTime);
     std::string dateString = tDateAndTime[0];
 
     // split date into YMD
-    vector<std::string> tDate;
+    std::vector<std::string> tDate;
     Tokenizer tokenizer2("-");
     tokenizer2(dateString, tDate);
 
@@ -695,7 +699,7 @@ bool MvNcVar::parseDate(const std::string& dateAndTimeString, MvDate& date)
         // there could be a time zone offset (e.g. 12:30:00+00:00), so remove what's
         // after the '+'
         std::string timeAndZoneString = tDateAndTime[1];
-        vector<std::string> tTimeAndZone;
+        std::vector<std::string> tTimeAndZone;
         Tokenizer tokenizer3("+");
         tokenizer3(timeAndZoneString, tTimeAndZone);
         std::string timeString =
@@ -704,7 +708,7 @@ bool MvNcVar::parseDate(const std::string& dateAndTimeString, MvDate& date)
         // split time into HMS
         // some netCDFs can have the time as, e.g., 00:00.0, which causes problems
         // with the parser so we use 'atof' for parsing the seconds
-        vector<std::string> tTime;
+        std::vector<std::string> tTime;
         Tokenizer tokenizer4(":");
         tokenizer4(timeString, tTime);
 
@@ -738,10 +742,10 @@ void MvNcVar::storeTimeInformation()
 
     // look first in standard_name, then in long_name
     MvNcAtt* nameAtt = getAttribute("standard_name");
-    if (nameAtt == NULL)
+    if (nameAtt == nullptr)
         nameAtt = getAttribute("long_name");
 
-    if (nameAtt != NULL) {
+    if (nameAtt != nullptr) {
         // has the attribute got the right value?
         std::string standardName = nameAtt->as_string(0);
         if (standardName == "time" || standardName == "Time")
@@ -757,10 +761,10 @@ void MvNcVar::storeTimeInformation()
     if (isTimeVar) {
         // the information we need to decode the time is in the units
         MvNcAtt* units = getAttribute("units");
-        if (units != NULL) {
+        if (units != nullptr) {
             // parse the string
             std::string unitsString = units->as_string(0);
-            vector<std::string> tokens;
+            std::vector<std::string> tokens;
             Tokenizer tokenizer(" ");
             tokenizer(unitsString, tokens);
 
@@ -772,9 +776,9 @@ void MvNcVar::storeTimeInformation()
             // parsing
             if (tokens.size() == 1) {
                 MvNcAtt* refDateAtt = getAttribute("reference_date");
-                if (refDateAtt != NULL) {
+                if (refDateAtt != nullptr) {
                     std::string refDateString = refDateAtt->as_string(0);
-                    vector<std::string> refDateTokens;
+                    std::vector<std::string> refDateTokens;
                     Tokenizer tokenizer1(" ");
                     tokenizer1(refDateString, refDateTokens);
                     tokens.push_back("since");
@@ -869,11 +873,12 @@ void MvNcVar::fillAttributes()
             return;
 
         // Save info
-        string sname    = cname;
-        MvNcAtt* tmpatt = new MvNcAtt(ncId_, id_, sname);
+        std::string sname = cname;
+        auto* tmpatt      = new MvNcAtt(ncId_, id_, sname);
         if (!tmpatt) {
             return;
-        } else if (!tmpatt->isValid()) {
+        }
+        else if (!tmpatt->isValid()) {
             delete tmpatt;
             return;
         }
@@ -881,30 +886,24 @@ void MvNcVar::fillAttributes()
     }
 }
 
-MvNcAtt* MvNcVar::getAttribute(const string& name)
+MvNcAtt* MvNcVar::getAttribute(const std::string& name)
 {
     if (!isValid())
-        return NULL;
+        return nullptr;
 
-    for (unsigned int i = 0; i < attributes_.size(); i++)
-        if (name == attributes_[i]->name())
-            return attributes_[i];
+    for (auto& attribute : attributes_)
+        if (name == attribute->name())
+            return attribute;
 
-    return NULL;
+    return nullptr;
 }
 
 MvNcAtt* MvNcVar::getAttribute(unsigned int index)
 {
-    if (!isValid())
-        return NULL;
-
-    if (index <= (attributes_.size() - 1))
-        return attributes_[index];
-    else
-        return NULL;
+    return isValid() && index < attributes_.size() ? attributes_[index] : nullptr;
 }
 
-bool MvNcVar::getAttributeValues(MvNcAtt* att, vector<string>& vec)
+bool MvNcVar::getAttributeValues(MvNcAtt* att, std::vector<std::string>& vec)
 {
     // Wipe out the vector
     vec.erase(vec.begin(), vec.end());
@@ -914,7 +913,7 @@ bool MvNcVar::getAttributeValues(MvNcAtt* att, vector<string>& vec)
     return att->getNumberOfValues() > 0;
 }
 
-bool MvNcVar::getAttributeValues(MvNcAtt* att, vector<double>& vec)
+bool MvNcVar::getAttributeValues(MvNcAtt* att, std::vector<double>& vec)
 {
     // Wipe out the vector
     vec.erase(vec.begin(), vec.end());
@@ -924,7 +923,7 @@ bool MvNcVar::getAttributeValues(MvNcAtt* att, vector<double>& vec)
     return att->getNumberOfValues() > 0;
 }
 
-bool MvNcVar::getAttributeValues(MvNcAtt* att, vector<long>& vec)
+bool MvNcVar::getAttributeValues(MvNcAtt* att, std::vector<long>& vec)
 {
     // Wipe out the vector
     vec.erase(vec.begin(), vec.end());
@@ -950,27 +949,27 @@ bool MvNcVar::addAttribute(MvNcAtt* att)
             addAttribute(att->name(), att->values()->getNumberOfValues(), vals, type);
     }
     else if (type == NC_SHORT) {
-        const short* vals = (const short*)att->values()->base();
+        const auto* vals = (const short*)att->values()->base();
         ret_code =
             addAttribute(att->name(), att->values()->getNumberOfValues(), vals, type);
     }
     else if (type == NC_USHORT) {
-        const ushort* vals = (const ushort*)att->values()->base();
+        const auto* vals = (const ushort*)att->values()->base();
         ret_code =
             addAttribute(att->name(), att->values()->getNumberOfValues(), vals, type);
     }
     else if (type == NC_LONG) {
-        const nclong* vals = (const nclong*)att->values()->base();
+        const auto* vals = (const nclong*)att->values()->base();
         ret_code =
             addAttribute(att->name(), att->values()->getNumberOfValues(), vals, type);
     }
     else if (type == NC_FLOAT) {
-        const float* vals = (const float*)att->values()->base();
+        const auto* vals = (const float*)att->values()->base();
         ret_code =
             addAttribute(att->name(), att->values()->getNumberOfValues(), vals, type);
     }
     else if (type == NC_DOUBLE) {
-        const double* vals = (const double*)att->values()->base();
+        const auto* vals = (const double*)att->values()->base();
         ret_code =
             addAttribute(att->name(), att->values()->getNumberOfValues(), vals, type);
     }
@@ -978,7 +977,7 @@ bool MvNcVar::addAttribute(MvNcAtt* att)
     return ret_code;
 }
 
-bool MvNcVar::put_att(const string& name, const char* val)
+bool MvNcVar::put_att(const std::string& name, const char* val)
 {
     if (!parent_->defineMode())
         return false;
@@ -988,7 +987,7 @@ bool MvNcVar::put_att(const string& name, const char* val)
     return ncStatus_ == NC_NOERR;
 }
 
-bool MvNcVar::put_att(const string& name, short val)
+bool MvNcVar::put_att(const std::string& name, short val)
 {
     if (!parent_->defineMode())
         return false;
@@ -998,7 +997,7 @@ bool MvNcVar::put_att(const string& name, short val)
     return ncStatus_ == NC_NOERR;
 }
 
-bool MvNcVar::put_att(const string& name, int val)
+bool MvNcVar::put_att(const std::string& name, int val)
 {
     if (!parent_->defineMode())
         return false;
@@ -1008,7 +1007,7 @@ bool MvNcVar::put_att(const string& name, int val)
     return ncStatus_ == NC_NOERR;
 }
 
-bool MvNcVar::put_att(const string& name, long val)
+bool MvNcVar::put_att(const std::string& name, long val)
 {
     if (!parent_->defineMode())
         return false;
@@ -1018,7 +1017,7 @@ bool MvNcVar::put_att(const string& name, long val)
     return ncStatus_ == NC_NOERR;
 }
 
-bool MvNcVar::put_att(const string& name, float val)
+bool MvNcVar::put_att(const std::string& name, float val)
 {
     if (!parent_->defineMode())
         return false;
@@ -1028,7 +1027,7 @@ bool MvNcVar::put_att(const string& name, float val)
     return ncStatus_ == NC_NOERR;
 }
 
-bool MvNcVar::put_att(const string& name, double val)
+bool MvNcVar::put_att(const std::string& name, double val)
 {
     if (!parent_->defineMode())
         return false;
@@ -1156,7 +1155,7 @@ bool MvNcVar::put_vara(const double* vals, size_t* counts)
 // Cached when retrieving string variables, but it most be treated
 // differently than the primitive types.
 template <>
-NcBool MvNcVar::get(vector<Cached>& vals, const long* counts, long nvals)
+NcBool MvNcVar::get(std::vector<Cached>& vals, const long* counts, long nvals)
 {
     if (!isValid())
         return false;
@@ -1242,7 +1241,8 @@ bool MvNcVar::setCurrent(long c0, long c1, long c2, long c3, long c4)
                 MvNcDim* ncdim = getDimension(i);
                 if (!ncdim) {
                     return false;
-                } else if (t[i] >= ncdim->size() && !ncdim->isUnlimited()) {
+                }
+                else if (t[i] >= ncdim->size() && !ncdim->isUnlimited()) {
                     return false;  // too big for dimension
                 }
                 the_cur_[i] = t[i];
@@ -1275,20 +1275,20 @@ bool MvNcVar::setCurrent(long* cur)
     return true;
 }
 
-NcBool MvNcVar::attributeExists(const string& name)
+NcBool MvNcVar::attributeExists(const std::string& name)
 {
     if (!isValid())
         return false;
 
-    for (unsigned int i = 0; i < attributes_.size(); i++) {
-        if (name == attributes_[i]->name())
+    for (auto& attribute : attributes_) {
+        if (name == attribute->name())
             return TRUE;
     }
 
     return FALSE;
 }
 
-void MvNcVar::getStringType(string& strtype)
+void MvNcVar::getStringType(std::string& strtype)
 {
     if (type() == NC_BYTE)
         strtype = "ncbyte ( signed char )";
@@ -1311,44 +1311,44 @@ void MvNcVar::getStringType(string& strtype)
 // e.g. short, with that value Adapted from ecCodes, tools/grib_to_netcdf.c,
 // also Apache 2.0 Licence
 
-bool MvNcVar::putAttributeWithType(const string& name, NcType nctype,
+bool MvNcVar::putAttributeWithType(const std::string& name, NcType nctype,
                                    double value)
 {
     bool r = false;
     switch (nctype) {
         case NC_BYTE: {
             if (value < 0) {
-                signed char val_char = (signed char)value;
+                auto val_char = (signed char)value;
                 // F            r = ncVar_->add_att(name.c_str(), val_char);
                 r = this->addAttribute(name, val_char);
             }
             else {
-                unsigned char val_uchar = (unsigned char)value;
+                auto val_uchar = (unsigned char)value;
                 //            r = ncVar_->add_att(name.c_str(), val_uchar);
                 r = this->addAttribute(name, val_uchar);
             }
             break;
         }
         case NC_SHORT: {
-            short int val_short = (short int)value;
+            auto val_short = (short int)value;
             //        r = ncVar_->add_att(name.c_str(), val_short);
             r = this->addAttribute(name, val_short);
             break;
         }
         case NC_INT: {
-            int val_int = (int)value;
+            auto val_int = (int)value;
             //        r = ncVar_->add_att(name.c_str(), val_int);
             r = this->addAttribute(name, val_int);
             break;
         }
         case NC_FLOAT: {
-            float val_flt = (float)value;
+            auto val_flt = (float)value;
             //        r = ncVar_->add_att(name.c_str(), val_flt);
             r = this->addAttribute(name, val_flt);
             break;
         }
         case NC_DOUBLE: {
-            double val_dbl = (double)value;
+            auto val_dbl = (double)value;
             // F        r = ncVar_->add_att(name.c_str(), val_dbl);
             r = addAttribute(name, val_dbl);
             break;
@@ -1467,9 +1467,9 @@ void MvNcVar::recomputeScalingIfNecessary(T* vals, long n)
                 int natts;
                 ncStatus_ = nc_inq_natts(id_, &natts);
                 char cname[NC_MAX_NAME];
-                ncStatus_       = nc_inq_attname(ncId_, id_, natts - 1, cname);
-                string sname    = cname;
-                MvNcAtt* tmpatt = new MvNcAtt(ncId_, id_, sname);
+                ncStatus_         = nc_inq_attname(ncId_, id_, natts - 1, cname);
+                std::string sname = cname;
+                auto* tmpatt      = new MvNcAtt(ncId_, id_, sname);
                 attributes_.push_back(tmpatt);
             }
         }
@@ -1484,11 +1484,11 @@ MvDate MvNcVar::processDate(double val)
 }
 
 // Values as dates
-NcBool MvNcVar::getDates(vector<MvDate>& dates, const long* counts,
+NcBool MvNcVar::getDates(std::vector<MvDate>& dates, const long* counts,
                          long nvals1)
 {
     // get the values as doubles, then convert to dates
-    vector<double> vals;
+    std::vector<double> vals;
     NcBool ret = get(vals, counts, nvals1);
     dates.resize(vals.size());
 
@@ -1543,11 +1543,11 @@ long* MvNcVar::edges()
         // get dimension IDs
         int ndim = getNumberOfDimensions();
         if (ncStatus_ != NC_NOERR)
-            return NULL;
+            return nullptr;
 
         int* dimIds = new int[ndim];
         if ((ncStatus_ = nc_inq_vardimid(ncId_, id_, dimIds)) != NC_NOERR)
-            return NULL;
+            return nullptr;
 
         // Get dimension lenghts
         edges_ = new long[ndim];
@@ -1556,7 +1556,7 @@ long* MvNcVar::edges()
             if ((ncStatus_ = nc_inq_dimlen(ncId_, dimIds[i], &len)) != NC_NOERR) {
                 delete[] edges_;
                 edges_ = 0;
-                return NULL;
+                return nullptr;
             }
             edges_[i] = len;
         }
@@ -1628,25 +1628,25 @@ MvNetCDFBehaviour::MvNetCDFBehaviour()
 // Empty constructor
 MvNetCDF::MvNetCDF() :
     ncStatus_(NC_NOERR),
-    ncFile_(NULL),
-    globalVar_(NULL)
+    ncFile_(nullptr),
+    globalVar_(nullptr)
 {
 }
 
 // Construct from a path and char opening mode ('r' by default)
-MvNetCDF::MvNetCDF(const string& path, const char mode) :
+MvNetCDF::MvNetCDF(const std::string& path, const char mode) :
     ncStatus_(NC_NOERR),
-    ncFile_(NULL),
-    globalVar_(NULL)
+    ncFile_(nullptr),
+    globalVar_(nullptr)
 {
     init(path, mode);
 }
 
 // Construct from a path and int opening mode (e.g. NC_NOWRITE)
-MvNetCDF::MvNetCDF(const string& path, int mode) :
+MvNetCDF::MvNetCDF(const std::string& path, int mode) :
     ncStatus_(NC_NOERR),
-    ncFile_(NULL),
-    globalVar_(NULL)
+    ncFile_(nullptr),
+    globalVar_(nullptr)
 {
     init(path, mode);
 }
@@ -1654,8 +1654,8 @@ MvNetCDF::MvNetCDF(const string& path, int mode) :
 // Construct from request
 MvNetCDF::MvNetCDF(const MvRequest& r, const char mode) :
     ncStatus_(NC_NOERR),
-    ncFile_(NULL),
-    globalVar_(NULL)
+    ncFile_(nullptr),
+    globalVar_(nullptr)
 {
     // Get the PATH from request
     const char* path = get_value(r, "PATH", 0);
@@ -1664,14 +1664,14 @@ MvNetCDF::MvNetCDF(const MvRequest& r, const char mode) :
 }
 
 // Function to initialize MvNetCDF using mode as char
-void MvNetCDF::init(const string& path, const char mode)
+void MvNetCDF::init(const std::string& path, const char mode)
 {
     int imode = (mode == 'w' || mode == 'u') ? NC_WRITE : NC_NOWRITE;
     init(path, imode);
 }
 
 // Function to initialize MvNetCDF
-void MvNetCDF::init(const string& path, int imode)
+void MvNetCDF::init(const std::string& path, int imode)
 {
     ncFile_ = new MvNcFile(path, imode);
 
@@ -1698,7 +1698,7 @@ MvNetCDF::~MvNetCDF()
         return;
 
     // Clean memory
-    vector<MvNcVar*>::iterator ii;
+    std::vector<MvNcVar*>::iterator ii;
     for (ii = variables_.begin(); ii != variables_.end(); ii++)
         delete (*ii);
 
@@ -1727,7 +1727,7 @@ int MvNetCDF::defineMode()
     }
 }
 
-MvNcVar* MvNetCDF::addVariable(const string& name, int type, int size,
+MvNcVar* MvNetCDF::addVariable(const std::string& name, int type, int size,
                                const MvNcDim** dim)
 {
     // If variable already exists then return it
@@ -1743,7 +1743,7 @@ MvNcVar* MvNetCDF::addVariable(const string& name, int type, int size,
             if (dim[i] != nullptr)
                 dimIds[i] = dim[i]->id();
             else {
-                delete [] dimIds;
+                delete[] dimIds;
                 return nullptr;
             }
         }
@@ -1756,32 +1756,31 @@ MvNcVar* MvNetCDF::addVariable(const string& name, int type, int size,
     int varId;
     int status = nc_def_var(ncId(), name.c_str(), type, size, dimIds, &varId);
     if (status != NC_NOERR) {
-
         if (dimIds) {
-            delete [] dimIds;
+            delete[] dimIds;
         }
         return nullptr;
     }
 
     // Create and save variable internal structure
-    string sname    = name;
-    MvNcVar* tmpvar = new MvNcVar(varId, sname, type, false, this);
+    std::string sname = name;
+    auto* tmpvar      = new MvNcVar(varId, sname, type, false, this);
     variables_.push_back(tmpvar);
 
     if (dimIds) {
-        delete [] dimIds;
+        delete[] dimIds;
     }
 
     return tmpvar;
 }
 
 // Convenience function, add a variable by given name,type and dimension(s)
-MvNcVar* MvNetCDF::addVariable(const string& name, NcType type, long dimsize0,
+MvNcVar* MvNetCDF::addVariable(const std::string& name, NcType type, long dimsize0,
                                long dimsize1, long dimsize2, long dimsize3,
                                long dimsize4)
 {
     if (!isValid())
-        return NULL;
+        return nullptr;
 
     if (variableExists(name))
         return getVariable(name);
@@ -1816,8 +1815,8 @@ MvNcVar* MvNetCDF::addVariable(const string& name, NcType type, long dimsize0,
 
 // Convenience function, add a variable by given name,type,
 // dimension(s) and dimension(s)'s names
-MvNcVar* MvNetCDF::addVariable(const string& name, NcType type,
-                               vector<long>& dimsize, vector<string>& vname)
+MvNcVar* MvNetCDF::addVariable(const std::string& name, NcType type,
+                               std::vector<long>& dimsize, std::vector<std::string>& vname)
 {
     if (!isValid())
         return nullptr;
@@ -1836,7 +1835,7 @@ MvNcVar* MvNetCDF::addVariable(const string& name, NcType type,
     for (size_t num = 0; num < dimsize.size(); num++) {
         MvNcDim* pdim = addDimension(vname[num], dimsize[num]);
         if (!pdim) {
-            for (auto v: dim) {
+            for (auto v : dim) {
                 if (v != nullptr) {
                     delete v;
                 }
@@ -1850,20 +1849,20 @@ MvNcVar* MvNetCDF::addVariable(const string& name, NcType type,
 }
 
 // Get variable by name
-MvNcVar* MvNetCDF::getVariable(const string& name)
+MvNcVar* MvNetCDF::getVariable(const std::string& name)
 {
     if (!isValid())
-        return NULL;
+        return nullptr;
 
-    for (unsigned int i = 0; i < variables_.size(); i++)
-        if (name == variables_[i]->name())
-            return variables_[i];
+    for (auto& variable : variables_)
+        if (name == variable->name())
+            return variable;
 
-    return NULL;
+    return nullptr;
 }
 
 // Convenience function. Get a variable's type by giving the name.
-NcType MvNetCDF::getTypeForVariable(const string& name)
+NcType MvNetCDF::getTypeForVariable(const std::string& name)
 {
     if (!isValid())
         return (NcType)0;
@@ -1876,7 +1875,7 @@ NcType MvNetCDF::getTypeForVariable(const string& name)
     return var->type();
 }
 
-void MvNetCDF::getStringTypeForVariable(const string& name, string& strtype)
+void MvNetCDF::getStringTypeForVariable(const std::string& name, std::string& strtype)
 {
     if (!isValid())
         return;
@@ -1895,7 +1894,7 @@ void MvNetCDF::getStringTypeForVariable(const string& name, string& strtype)
 MvRequest MvNetCDF::getRequest()
 {
     if (!isValid())
-        return MvRequest(NULL, false);
+        return MvRequest(nullptr, false);
 
     MvRequest r("NETCDF");
 
@@ -1944,7 +1943,7 @@ void MvNetCDF::fillVariables()
 
     // Inquire number of variable from the file
     int nvars;
-    ncStatus_ = nc_inq(ncId(), NULL, &nvars, NULL, NULL);
+    ncStatus_ = nc_inq(ncId(), nullptr, &nvars, nullptr, nullptr);
     if (ncStatus_ != NC_NOERR)
         return;
 
@@ -1962,14 +1961,14 @@ void MvNetCDF::fillVariables()
     nc_type type;
     for (int i = 0; i < nvars; i++) {
         // Inquire about a variable name and type
-        ncStatus_ = nc_inq_var(ncId(), varids[i], name, &type, NULL, NULL, NULL);
+        ncStatus_ = nc_inq_var(ncId(), varids[i], name, &type, nullptr, nullptr, nullptr);
         if (ncStatus_ != NC_NOERR) {
             delete[] varids;
             return;
         }
 
-        string sname    = name;
-        MvNcVar* tmpvar = new MvNcVar(varids[i], sname, type, false, this);
+        std::string sname = name;
+        auto* tmpvar      = new MvNcVar(varids[i], sname, type, false, this);
         variables_.push_back(tmpvar);
     }
 
@@ -1991,8 +1990,8 @@ void MvNetCDF::reqGetVariables(MvRequest& r)
     MvNcAtt* tmpatt;
     MvNcDim* tmpdim;
 
-    for (unsigned int i = 0; i < variables_.size(); i++) {
-        tmpvar   = variables_[i];
+    for (auto& variable : variables_) {
+        tmpvar   = variable;
         num_dim  = tmpvar->getNumberOfDimensions();
         num_attr = tmpvar->getNumberOfAttributes();
 
@@ -2041,20 +2040,20 @@ void MvNetCDF::reqGetAttributes(MvRequest& r)
     }
 }
 
-NcBool MvNetCDF::variableExists(const string& name)
+NcBool MvNetCDF::variableExists(const std::string& name)
 {
     if (!isValid())
         return false;
 
-    for (unsigned int i = 0; i < variables_.size(); i++) {
-        if (name == variables_[i]->name())
+    for (auto& variable : variables_) {
+        if (name == variable->name())
             return 1;
     }
 
     return 0;
 }
 
-MvNcDim* MvNetCDF::addDimension(const string& name, long size)
+MvNcDim* MvNetCDF::addDimension(const std::string& name, long size)
 {
     // Dimension already exists?
     if (dimensionExists(name))
@@ -2065,17 +2064,17 @@ MvNcDim* MvNetCDF::addDimension(const string& name, long size)
 
     // Create a dimension
     if (!ncFile_->defineMode())
-        return NULL;
+        return nullptr;
 
     int dimId;
     if ((ncStatus_ = nc_def_dim(ncId(), name.c_str(), len, &dimId)) != NC_NOERR)
-        return NULL;
+        return nullptr;
 
     // Create an internal dimension structure
     return new MvNcDim(ncId(), dimId, name, len);
 }
 
-NcBool MvNetCDF::dimensionExists(const string& name)
+NcBool MvNetCDF::dimensionExists(const std::string& name)
 {
     if (!isValid())
         return false;
@@ -2096,18 +2095,18 @@ int MvNetCDF::getNumberOfDimensions()
     return ndim;
 }
 
-MvNcDim* MvNetCDF::getDimension(const string& name)
+MvNcDim* MvNetCDF::getDimension(const std::string& name)
 {
     int dimId;
     size_t lenp;
 
     // Get dimension id
     if ((ncStatus_ = nc_inq_dimid(ncId(), name.c_str(), &dimId)) != NC_NOERR)
-        return NULL;
+        return nullptr;
 
     // Get dimension length
     if ((ncStatus_ = nc_inq_dimlen(ncId(), dimId, &lenp)) != NC_NOERR)
-        return NULL;
+        return nullptr;
 
     return new MvNcDim(ncId(), dimId, name, lenp);
 }
@@ -2118,10 +2117,10 @@ MvNcDim* MvNetCDF::getDimension(int index)
     char cname[NC_MAX_NAME + 1];
     size_t lenp;
     if ((ncStatus_ = nc_inq_dim(ncId(), index, cname, &lenp)) != NC_NOERR)
-        return NULL;
+        return nullptr;
 
     // return the dimension structure
-    return new MvNcDim(ncId(), index, string(cname), lenp);
+    return new MvNcDim(ncId(), index, std::string(cname), lenp);
 }
 
 int MvNetCDF::getNumberOfAttributes()
@@ -2135,8 +2134,8 @@ int MvNetCDF::getNumberOfAttributes()
 int MvNetCDF::globalVariable()
 {
     // Create a variable structure
-    string name = "global_attr";
-    globalVar_  = new MvNcVar(NC_GLOBAL, name, 0, true, this);
+    std::string name = "global_attr";
+    globalVar_       = new MvNcVar(NC_GLOBAL, name, 0, true, this);
 
     return ncStatus_;
 }
@@ -2146,7 +2145,7 @@ int MvNetCDF::globalVariable()
 // Wrapper for NcDim
 //--------------------------------------------------------------
 
-MvNcDim::MvNcDim(int ncId, int dimId, const string& name, int size) :
+MvNcDim::MvNcDim(int ncId, int dimId, const std::string& name, int size) :
     ncId_(ncId),
     dimId_(dimId),
     size_(size),
