@@ -12,8 +12,7 @@
    Metview class interface to NetCDF.
 */
 
-#ifndef MV_NETCDF_H
-#define MV_NETCDF_H
+#pragma once
 
 #ifdef AIX
 /* There is a name clash with xlc own include files */
@@ -22,6 +21,8 @@
 #undef declare
 #endif
 
+#include <iostream>
+
 #include "Metview.h"
 #include "netcdf.h"
 
@@ -65,7 +66,7 @@ enum
     CDF_NOFILL = NC_NOFILL
 };
 
-typedef map<string, int> CountMap;
+typedef std::map<std::string, int> CountMap;
 
 // Wrapper to handle netcdf files.
 // Only done to get global "variable" for the global attributes.
@@ -74,11 +75,11 @@ class MvNcFile
 {
 public:
     // Constructor
-    // F   MvNcFile(const string &path,FileMode xx = ReadOnly) :
+    // F   MvNcFile(const std::string &path,FileMode xx = ReadOnly) :
     // F            NcFile(path.c_str(),xx) {}
     // Constructor
     // "mode = 0" means NC_NOWRITE for opening or NC_CLOBBER for creating
-    MvNcFile(const string&, int mode = 0);
+    MvNcFile(const std::string&, int mode = 0);
 
     // Destructor
     virtual ~MvNcFile() {}
@@ -116,8 +117,8 @@ class MvNcDim
 {
 public:
     // Constructos/Destructors
-    MvNcDim(int, int, const string&, int);
-    ~MvNcDim(){};
+    MvNcDim(int, int, const std::string&, int);
+    ~MvNcDim() = default;
 
     // Class functions
     int ncId() { return ncId_; }
@@ -127,15 +128,15 @@ public:
     int size() { return size_; }
 
     const char* name() { return name_.c_str(); }
-    string sname() { return name_; }
+    std::string sname() { return name_; }
 
     bool isUnlimited() const;
 
 private:
-    int ncId_;     // netcdf id
-    int dimId_;    // dimension id
-    int size_;     // dimension length
-    string name_;  // dimension name
+    int ncId_;          // netcdf id
+    int dimId_;         // dimension id
+    int size_;          // dimension length
+    std::string name_;  // dimension name
 };
 
 //--------------------------------------------------------------
@@ -190,7 +191,7 @@ public:
     int as_int(long) const;
     float as_float(long) const;
     double as_double(long) const;
-    string as_string(long) const;
+    std::string as_string(long) const;
 
     int as_long(long n) const
     {
@@ -209,7 +210,7 @@ private:
     int type_;
     int ncId_;
     int id_;
-    string name_;
+    std::string name_;
 
     size_t nvalues_;
     void* values_;
@@ -221,7 +222,7 @@ private:
     //   long* vlong_;
     float* vfloat_;
     double* vdouble_;
-    string* vstring_;
+    std::string* vstring_;
 };
 #endif
 
@@ -235,7 +236,7 @@ class MvNcBase
 public:
     // Constructors
     MvNcBase();
-    MvNcBase(int, int, const string&, nc_type);
+    MvNcBase(int, int, const std::string&, nc_type);
 
     // Destructors
     ~MvNcBase() {}
@@ -244,7 +245,7 @@ public:
     // F  const char *name() { return delegate()->name(); }
     // F  NcType type() { return delegate()->type(); }
     // F  virtual NcBool isValid() { return delegate()->is_valid(); }
-    string sname() const { return name_; }
+    std::string sname() const { return name_; }
     const char* name() const { return name_.c_str(); }
     nc_type type() const { return type_; }
     int ncId() const { return ncId_; }
@@ -266,11 +267,11 @@ public:
     float as_float(long n) { return values()->as_float(n); }
     double as_double(long n) { return processValue(values()->as_double(n)); }
     // char*  as_string( long n ) { return values()->as_string(n); }
-    string as_string(long n) { return values()->as_string(n); }
+    std::string as_string(long n) { return values()->as_string(n); }
     MvDate as_date(long n) { return processDate(values()->as_double(n)); }
 
     //template <class T>
-    //int get(vector<T> &vec) { return values()->get(vec); }
+    //int get(std::vector<T> &vec) { return values()->get(vec); }
 
     virtual MvNcValues* values() = 0;
     // F  virtual NcTypedComponent *delegate() = 0;
@@ -283,7 +284,7 @@ protected:
 
     int ncId_;
     int id_;
-    string name_;
+    std::string name_;
     nc_type type_;
     int ncStatus_;
 
@@ -306,11 +307,11 @@ public:
 
     // Values
     MvNcValues* values() { return values_; }
-    NcBool getValues(string&);
-    string as_string(long);
+    NcBool getValues(std::string&);
+    std::string as_string(long);
 
 protected:
-    double processValue(double val) { return val; }      // dummy function
+    double processValue(double val) { return val; }          // dummy function
     MvDate processDate(double /*val*/) { return MvDate(); }  // dummy function
 
 private:
@@ -318,11 +319,11 @@ private:
 
     // Constructors
     // F  MvNcAtt(NcAtt *ncAtt);
-    MvNcAtt(int, int, const string&);
+    MvNcAtt(int, int, const std::string&);
     MvNcAtt(const MvNcAtt& aa);
 
     void tztrim(char*);
-    void printValue(string&, double);
+    void printValue(std::string&, double);
 
     // F  NcAtt *ncAtt_;
     MvNcValues* values_;
@@ -338,7 +339,7 @@ class MvNetCDFBehaviour
 {
 public:
     MvNetCDFBehaviour();
-    ~MvNetCDFBehaviour(){};
+    ~MvNetCDFBehaviour() = default;
 
     void detectMissingValues(bool d) { detectMissingValues_ = d; }
     bool detectMissingValues() { return detectMissingValues_; }
@@ -346,8 +347,8 @@ public:
     void scaleValues(bool s) { scaleValues_ = s; }
     bool scaleValues() { return scaleValues_; }
 
-    void missingValuesAttribute(string a) { missingValueAttribute_ = a; }
-    string missingValuesAttribute() { return missingValueAttribute_; }
+    void missingValuesAttribute(std::string a) { missingValueAttribute_ = a; }
+    std::string missingValuesAttribute() { return missingValueAttribute_; }
 
     void rescaleToFit(bool r) { rescaleToFit_ = r; }
     bool rescaleToFit() { return rescaleToFit_; }
@@ -360,7 +361,7 @@ private:
     bool scaleValues_;
     bool rescaleToFit_;
     bool translateTime_;
-    string missingValueAttribute_;
+    std::string missingValueAttribute_;
 };
 
 // ---------------------------------------------------------------------
@@ -393,7 +394,7 @@ public:
     void storeScaleFactorAndOffset();
     void storeTimeInformation();
 
-    void getStringType(string&);
+    void getStringType(std::string&);
     bool isTime() { return isTime_; }
 
     MvNetCDFBehaviour& options();
@@ -417,11 +418,11 @@ public:
     // F  int getNumberOfAttributes() { return ncVar_->num_atts(); }
     int getNumberOfAttributes();
 
-    MvNcAtt* getAttribute(const string&);
+    MvNcAtt* getAttribute(const std::string&);
     MvNcAtt* getAttribute(unsigned int index);
 
     template <class T>
-    bool getAttributeValues(const string& name, vector<T>& vec)
+    bool getAttributeValues(const std::string& name, std::vector<T>& vec)
     {
         if (!isValid())
             return false;
@@ -433,7 +434,7 @@ public:
     }
 
     template <class T>
-    bool getAttributeValues(unsigned int index, vector<T>& vec)
+    bool getAttributeValues(unsigned int index, std::vector<T>& vec)
     {
         if (!isValid())
             return false;
@@ -447,7 +448,7 @@ public:
     // Two following functions inlined because of gcc template
     // instantiation problems. Should really be in cc file.
     template <class T>
-    bool addAttribute(const string& name, T value)
+    bool addAttribute(const std::string& name, T value)
     {
         if (!isValid())
             return false;
@@ -470,7 +471,7 @@ public:
     }
 
     template <class T>
-    bool addAttribute(const string& name, int nr, T* values, NcType attrType)
+    bool addAttribute(const std::string& name, int nr, T* values, NcType attrType)
     {
         if (!isValid())
             return false;
@@ -479,9 +480,9 @@ public:
             return true;
         }
 
-        // Add attribute to the netcdf file     
+        // Add attribute to the netcdf file
         int ret_code = nc_put_att(ncId_, id_, name.c_str(), attrType, nr, values);
-        if (ret_code == NC_NOERR) {          
+        if (ret_code == NC_NOERR) {
             MvNcAtt* attr = new MvNcAtt(ncId_, id_, name);
             attributes_.push_back(attr);
         }
@@ -491,14 +492,14 @@ public:
 
     bool addAttribute(MvNcAtt* att);
 
-    bool put_att(const string&, const char*);
-    bool put_att(const string&, const short);
-    bool put_att(const string&, const int);
-    bool put_att(const string&, const long);
-    bool put_att(const string&, const float);
-    bool put_att(const string&, const double);
+    bool put_att(const std::string&, const char*);
+    bool put_att(const std::string&, const short);
+    bool put_att(const std::string&, const int);
+    bool put_att(const std::string&, const long);
+    bool put_att(const std::string&, const float);
+    bool put_att(const std::string&, const double);
 
-    NcBool attributeExists(const string& name);
+    NcBool attributeExists(const std::string& name);
 
     // Dimensions
     // F  int   getNumberOfDimensions() { return ncVar_->num_dims(); }
@@ -522,7 +523,7 @@ public:
 
     // Values
     template <class T>
-    int get(vector<T>& vals, const long* counts, long nvals1 = 0L)
+    int get(std::vector<T>& vals, const long* counts, long nvals1 = 0L)
     {
         if (!isValid())
             return false;
@@ -592,7 +593,7 @@ public:
     }
 
     template <class T>
-    int get(vector<T>& vals, long c0 = 0, long c1 = 0, long c2 = 0,
+    int get(std::vector<T>& vals, long c0 = 0, long c1 = 0, long c2 = 0,
             long c3 = 0, long c4 = 0)
     {
         // Save input dimensions
@@ -616,47 +617,47 @@ public:
         return get_vara(vals, counts);
     }
 
-    int get(vector<double>& vals)
+    int get(std::vector<double>& vals)
     {
         return nc_get_var_double(ncId_, id_, &vals.front());
     }
 
-    int get_vara(vector<char>& vals, size_t* counts)
+    int get_vara(std::vector<char>& vals, size_t* counts)
     {
         return nc_get_vara_text(ncId_, id_, the_cur_, counts, (char*)&vals.front());
     }
 
-    int get_vara(vector<signed char>& vals, size_t* counts)
+    int get_vara(std::vector<signed char>& vals, size_t* counts)
     {
         return nc_get_vara_schar(ncId_, id_, the_cur_, counts, (signed char*)&vals.front());
     }
 
-    int get_vara(vector<short>& vals, size_t* counts)
+    int get_vara(std::vector<short>& vals, size_t* counts)
     {
         return nc_get_vara_short(ncId_, id_, the_cur_, counts, (short*)&vals.front());
     }
 
-    int get_vara(vector<int>& vals, size_t* counts)
+    int get_vara(std::vector<int>& vals, size_t* counts)
     {
         return nc_get_vara_int(ncId_, id_, the_cur_, counts, (int*)&vals.front());
     }
 
-    int get_vara(vector<float>& vals, size_t* counts)
+    int get_vara(std::vector<float>& vals, size_t* counts)
     {
         return nc_get_vara_float(ncId_, id_, the_cur_, counts, (float*)&vals.front());
     }
 
-    int get_vara(vector<double>& vals, size_t* counts)
+    int get_vara(std::vector<double>& vals, size_t* counts)
     {
         return nc_get_vara_double(ncId_, id_, the_cur_, counts, (double*)&vals.front());
     }
 
     /*
    template <class T>
-   int get_vara1(vector<T> &vals, size_t *counts)
+   int get_vara1(std::vector<T> &vals, size_t *counts)
    {
 for (int i = 0; i < getNumberOfDimensions(); i++)
-cout << the_cur_[i] << " " << counts[i] << endl;
+std::cout << the_cur_[i] << " " << counts[i] << std::endl;
 ncStatus_=nc_get_var_double(ncId_,id_,(double*)&vals.front()); 
       switch(type_)
       {
@@ -681,7 +682,7 @@ ncStatus_=nc_get_var_double(ncId_,id_,(double*)&vals.front());
 */
 
     // Values as dates
-    NcBool getDates(vector<MvDate>&, const long*, long nvals1 = 0L);
+    NcBool getDates(std::vector<MvDate>&, const long*, long nvals1 = 0L);
 
     MvNcValues* values()
     {
@@ -733,16 +734,16 @@ ncStatus_=nc_get_var_double(ncId_,id_,(double*)&vals.front());
     template <class T>
     void recomputeScalingIfNecessary(T* vals, long n);
 
-    bool putAttributeWithType(const string&, NcType, double);
+    bool putAttributeWithType(const std::string&, NcType, double);
 
 #if 0
   template <class T> NcBool put(const T *vals, const long *counts) {
       return ncVar_->put(vals,counts);
   }
 #else
-    //   int putv(vector<short>& vals)
+    //   int putv(std::vector<short>& vals)
     //      { return nc_put_var_short(ncId_,id_,&vals.front()); }
-    //   int putv(vector<double>& vals)
+    //   int putv(std::vector<double>& vals)
     //      { return nc_put_var_double(ncId_,id_,&vals.front()); }
     int putv(const char* vals)
     {
@@ -810,11 +811,11 @@ ncStatus_=nc_get_var_double(ncId_,id_,(double*)&vals.front());
     bool put_vara(const double*, size_t*);
 
     template <class T>
-    bool put(const vector<T>& vecvals, long c0 = 0, long c1 = 0,
+    bool put(const std::vector<T>& vecvals, long c0 = 0, long c1 = 0,
              long c2 = 0, long c3 = 0, long c4 = 0)
     {
         T* vals = new T[vecvals.size()];
-        for (typename vector<T>::size_type i = 0; i < vecvals.size(); i++)
+        for (typename std::vector<T>::size_type i = 0; i < vecvals.size(); i++)
             vals[i] = vecvals[i];
 
         // F bool retVal = ncVar_->put(vals,c0,c1,c2,c3,c4);
@@ -831,7 +832,7 @@ private:
 
     // Constructors
     // F  MvNcVar(NcVar *ncvar, bool is_global, MvNetCDF *parent);
-    MvNcVar(int, const string&, nc_type, bool, MvNetCDF*);  // F
+    MvNcVar(int, const std::string&, nc_type, bool, MvNetCDF*);  // F
     MvNcVar(const MvNcVar&);
 
     // Handle attributes
@@ -839,9 +840,9 @@ private:
     // Initialize attributes structure from the netcdf file
     void fillAttributes();
 
-    bool getAttributeValues(MvNcAtt*, vector<string>&);
-    bool getAttributeValues(MvNcAtt*, vector<double>&);
-    bool getAttributeValues(MvNcAtt*, vector<long>&);
+    bool getAttributeValues(MvNcAtt*, std::vector<std::string>&);
+    bool getAttributeValues(MvNcAtt*, std::vector<double>&);
+    bool getAttributeValues(MvNcAtt*, std::vector<long>&);
 
     bool parseDate(const std::string& dateAndTimeString, MvDate& date);
 
@@ -860,7 +861,7 @@ private:
         // F      if ( i >= 0 ) return ncVar_->put_rec(vals,i);
         // F      else return ncVar_->put_rec(vals);
         if (i >= 0) {
-            cout << "MvNetCDF ERROR: IMPLEMENT THIS FUNCTION" << endl;
+            std::cout << "MvNetCDF ERROR: IMPLEMENT THIS FUNCTION" << std::endl;
             // return ncVar_->put_rec(vals,i);
             return 0;
         }
@@ -871,7 +872,7 @@ private:
     // Variables
     long* edges_;
     size_t* the_cur_;
-    vector<MvNcAtt*> attributes_;
+    std::vector<MvNcAtt*> attributes_;
     MvNcValues* values_;
     bool isGlobal_;
     MvNetCDF* parent_;
@@ -883,7 +884,7 @@ private:
   NcVar *ncVar_;
 #else
     //  int varType_;
-    //  string varName_;
+    //  std::string varName_;
 
 #endif
 
@@ -907,9 +908,9 @@ class MvNetCDF
 public:
     // Constructors
     MvNetCDF();
-    MvNetCDF(const string&, const char mode = 'r');     // from file name
-    MvNetCDF(const string&, int mode);                  // e.g. NC_NOWRITE
-    MvNetCDF(const MvRequest&, const char mode = 'r');  // from request
+    MvNetCDF(const std::string&, const char mode = 'r');  // from file name
+    MvNetCDF(const std::string&, int mode);               // e.g. NC_NOWRITE
+    MvNetCDF(const MvRequest&, const char mode = 'r');    // from request
 
     // Destructor
     virtual ~MvNetCDF();
@@ -941,7 +942,7 @@ public:
     // Variables
     int getNumberOfVariables() { return variables_.size(); }
 
-    MvNcVar* getVariable(const string&);
+    MvNcVar* getVariable(const std::string&);
     MvNcVar* getVariable(int index)
     {
         if (index == -1)
@@ -952,23 +953,23 @@ public:
 
     MvNcVar* getGlobalVariable() { return globalVar_; }
 
-    // F  MvNcVar *addVariable(const string & name,NcType type, int size, const
+    // F  MvNcVar *addVariable(const std::string & name,NcType type, int size, const
     // NcDim **dim);
-    MvNcVar* addVariable(const string& name, int type, int size,
+    MvNcVar* addVariable(const std::string& name, int type, int size,
                          const MvNcDim** dim);
 
     // Will create a dimension of same name, with value dim, and
     // use this when adding the variable. Used for normal one-dim variables where
     // dimsize2 = 0, or for strings, where dimsize2 is length of string.
-    MvNcVar* addVariable(const string& name, int type, long dimsize0,
+    MvNcVar* addVariable(const std::string& name, int type, long dimsize0,
                          long dimsize1 = -1, long dimsize2 = -1,
                          long dimsize3 = -1, long dimsize4 = -1);
 
-    MvNcVar* addVariable(const string& name, int type, vector<long>& dimsize,
-                         vector<string>& vname);
+    MvNcVar* addVariable(const std::string& name, int type, std::vector<long>& dimsize,
+                         std::vector<std::string>& vname);
 
     template <class T>
-    MvNcVar* addVariableWithData(const string& name, int type, vector<T>& vec)
+    MvNcVar* addVariableWithData(const std::string& name, int type, std::vector<T>& vec)
     {
         MvNcVar* currVar = addVariable(name, type, vec.size());
         if (!currVar)
@@ -986,7 +987,7 @@ public:
     }
 
     template <class T>
-    NcBool getDataForVariable(vector<T>& vec, const string& name,
+    NcBool getDataForVariable(std::vector<T>& vec, const std::string& name,
                               long* given_edges = 0)
     {
         if (!isValid())
@@ -1005,23 +1006,23 @@ public:
         return var->get(vec, edges);
     }
 
-    NcType getTypeForVariable(const string&);
-    void getStringTypeForVariable(const string&, string&);
+    NcType getTypeForVariable(const std::string&);
+    void getStringTypeForVariable(const std::string&, std::string&);
 
     //-------------------- Dimensions ---------------------------
     // F  int getNumberOfDimensions() { return ncFile_->num_dims(); }
     int getNumberOfDimensions();
 
-    // F  NcDim *getDimension(const string &name) { return
+    // F  NcDim *getDimension(const std::string &name) { return
     // ncFile_->get_dim(name.c_str() ); }
-    MvNcDim* getDimension(const string&);
+    MvNcDim* getDimension(const std::string&);
 
     // F  NcDim *getDimension(int index) { return ncFile_->get_dim(index); }
     MvNcDim* getDimension(int);
 
-    // F  NcDim *addDimension(const string&,long s=0);
-    MvNcDim* addDimension(const string&, long s = 0);
-    NcBool dimensionExists(const string&);
+    // F  NcDim *addDimension(const std::string&,long s=0);
+    MvNcDim* addDimension(const std::string&, long s = 0);
+    NcBool dimensionExists(const std::string&);
 
 
     //-------------------- Attributes ---------------------------
@@ -1030,38 +1031,38 @@ public:
 
     MvNcAtt* getAttribute(int i) { return globalVar_->getAttribute(i); }
 
-    MvNcAtt* getAttribute(const string& name)
+    MvNcAtt* getAttribute(const std::string& name)
     {
         return globalVar_->getAttribute(name);
     }
 
     template <class T>
-    bool getAttributeValues(const string& name, vector<T>& vec)
+    bool getAttributeValues(const std::string& name, std::vector<T>& vec)
     {
         return globalVar_->getAttributeValues(name, vec);
     }
 
     template <class T>
-    bool getAttributeValues(unsigned int index, vector<T>& vec)
+    bool getAttributeValues(unsigned int index, std::vector<T>& vec)
     {
         return globalVar_->getAttributeValues(index, vec);
     }
 
     template <class T>
-    bool addAttribute(const string& name, T val)
+    bool addAttribute(const std::string& name, T val)
     {
         return globalVar_->addAttribute(name, val);
     }
 
     template <class T>
-    bool addAttribute(const string& name, int n, const T* val)
+    bool addAttribute(const std::string& name, int n, const T* val)
     {
         return globalVar_->addAttribute(name, n, val);
     }
 
     bool addAttribute(MvNcAtt* att) { return globalVar_->addAttribute(att); }
 
-    NcBool attributeExists(const string& name)
+    NcBool attributeExists(const std::string& name)
     {
         return globalVar_->attributeExists(name);
     }
@@ -1070,21 +1071,21 @@ public:
     int globalVariable();
 
     // File operations
-    const string& path() { return path_; }
+    const std::string& path() { return path_; }
     int sync() { return ncFile_->sync(); }
-    int close() { return (ncFile_)?ncFile_->close():0; }
+    int close() { return (ncFile_) ? ncFile_->close() : 0; }
 
     int getFillMode() { return ncFile_->getFillMode(); }
 
     int setFillMode(int mode = NC_FILL) { return ncFile_->setFillMode(mode); }
 
     // Initialize/create netcdf file
-    void init(const string& path, const char mode = 'r');
-    void init(const string& path, int mode = NC_NOWRITE);
+    void init(const std::string& path, const char mode = 'r');
+    void init(const std::string& path, int mode = NC_NOWRITE);
 
 private:
     void fillVariables();
-    NcBool variableExists(const string& name);
+    NcBool variableExists(const std::string& name);
 
     // Used to fill in the request and check it against predefined values.
     void reqGetDimensions(MvRequest&);
@@ -1094,8 +1095,8 @@ private:
     // Variables
     int ncStatus_;
     MvNcFile* ncFile_;
-    string path_;
-    vector<MvNcVar*> variables_;
+    std::string path_;
+    std::vector<MvNcVar*> variables_;
     MvNcVar* globalVar_;
 
     // To find out if more than one MvNetCDF accesses the same NetCDF file.
@@ -1108,6 +1109,4 @@ private:
 
 // Define specialization
 template <>
-NcBool MvNcVar::get(vector<Cached>& vals, const long* counts, long nvals);
-
-#endif
+NcBool MvNcVar::get(std::vector<Cached>& vals, const long* counts, long nvals);
