@@ -7,9 +7,11 @@
 
  ***************************** LICENSE END *************************************/
 
+#include <iostream>
 #include <string>
-#include "inc_iostream.h"
-#include "inc_stl.h"
+#include <unordered_map>
+#include <unordered_set>
+
 #include "mars.h"
 
 #include "MvScanFileType.h"
@@ -19,6 +21,9 @@
 #include <dirent.h>
 #include <errno.h>
 
+#include "MvLog.h"
+#include "MvMiscellaneous.h"
+
 //#include "netcdfcpp.h"
 
 
@@ -67,15 +72,17 @@ static bool isValidForNumbersOnly(int c)
 struct File
 {  //-- wrapper function always closes the file
 
-    FILE* f_;
+    FILE* f_{nullptr};
 
 public:
-    File(const char* name, const char* mode) { f_ = fopen(name, mode); };
-    ~File()
+    File(const char* name, const char* mode) { f_ = fopen(name, mode); }
+    ~File() { close(); }
+    void close()
     {
         if (f_)
             fclose(f_);
-    };
+        f_ = nullptr;
+    }
 };
 #endif
 
@@ -130,16 +137,89 @@ static eFileType SearchMarsParserBreakers(const char* fileName)
 }
 
 
-// scan_file_extension
-// - checks whether the extension on the given file matches the given
-//   extension, and returns the corresponding Metview class name
-//   if it does
-
-inline static bool scan_file_extension(const char* file, int length, const char* ext)
+static const char* isWeatherSymbolJson(const File& f)
 {
-    int ext_length = strlen(ext);
+    // TODO: initialise it from the WsItems file or IconClass
+    static std::unordered_set<std::string> clsSet = {
+        "WS_COLDFRONT", "WS_CONVERGENCELINE", "WS_HIGH", "WS_IMAGE",
+        "WS_INSTABILITYLINE", "WS_ITCZ", "WS_ITTDISCONTINUITY",
+        "WS_LOW", "WS_OCCLUDED", "WS_QUASISTATIONARY",
+        "WS_PLACEMARK", "WS_RIDGE",
+        "WS_MARKER", "WS_SHAPE", "WS_SHEARLINE", "WS_STORM", "WS_TEXT", "WS_TROPICALWAVE",
+        "WS_TROUGH", "WS_WARMFRONT", "WS_WMOSYMBOL",
+        "WS_COLLECTION"};
+    static char startBraceCh    = '{';
+    static std::string quoteCh  = "\"";
+    static std::string classStr = "\"class_ws\":";
+    static std::string conv     = "metview-ws";
+    if (!f.f_)
+        return nullptr;
 
-    return (length >= ext_length && !strcasecmp(&file[length - ext_length], ext));
+    // We suppose that the json file has the following structure and the
+    // "class_ws" and "convention" keys are located towards the beginning of the file:
+    //
+    // {
+    //    "class_ws": "...",
+    //    "convention": "metview-ws"
+    //
+    //
+    // When the file is generated via the Metview Qt Json interface this seems
+    // to be the case because the keys are always sorted alphabetically when
+    // written to a file. Therefore we only read the first 200 bytes from the file!
+    // The goal is to extract value for "class_ws".
+
+    char asciiBuf[200];
+    memset(&asciiBuf[0], '\0', 200);
+    fread(&asciiBuf[0], 1, 99, f.f_);
+    rewind(f.f_);
+
+    MvLog().dbg() << __func__ << " asciiBuf=" << asciiBuf;
+    std::string t(asciiBuf);
+    if (metview::startsWith(t, startBraceCh, true) && t.find(conv) != std::string::npos) {
+        // the file is probably a metview ws json file
+        MvLog().dbg() << " match 1";
+        auto pos = t.find(classStr);
+        if (pos != std::string::npos) {
+            MvLog().dbg() << " match2";
+            auto sp = t.find(quoteCh, pos + classStr.length());
+            if (sp != std::string::npos) {
+                MvLog().dbg() << " match3";
+                auto ep = t.find(quoteCh, sp + 1);
+                if (ep != std::string::npos) {
+                    auto cls = t.substr(sp + 1, ep - sp - 1);
+                    auto it  = clsSet.find(cls);
+                    MvLog().dbg() << " cls=" << cls;
+                    if (it != clsSet.end()) {
+                        return (*it).c_str();
+                    }
+                }
+            }
+        }
+    }
+    return nullptr;
+}
+
+//inline static bool scan_file_extension(const char* file, int length, const char* ext)
+//{
+//    int ext_length = strlen(ext);
+
+//    return (length >= ext_length && !strcasecmp(&file[length - ext_length], ext));
+//}
+
+static bool get_file_extension(const char* file, std::string& suffix1,
+                               std::string& suffix2)
+{
+    std::string fn(file);
+    auto pos = fn.find_last_of(".");
+    if (pos != 0 && pos != std::string::npos && pos + 1 != fn.size()) {
+        suffix1   = fn.substr(pos);
+        auto pos2 = fn.find_last_of(".", pos - 1);
+        if (pos != 0 && pos2 != std::string::npos && pos2 + 1 != pos) {
+            suffix2 = fn.substr(pos2);
+        }
+        return true;
+    }
+    return false;
 }
 
 // Checks if a directory is an ODB database
@@ -148,18 +228,18 @@ static bool scanDirForOdb(const char* dir)
 {
     DIR* dp;
     struct dirent* dirp;
-    if ((dp = opendir(dir)) == NULL) {
-        cout << "scanDirForOdb() --> Error(" << errno << ") opening " << dir << endl;
+    if ((dp = opendir(dir)) == nullptr) {
+        std::cout << "scanDirForOdb() --> Error(" << errno << ") opening " << dir << std::endl;
         return false;
     }
 
     bool retval = false;
-    string::size_type pos;
-    while ((dirp = readdir(dp)) != NULL) {
-        string name(dirp->d_name);
+    std::string::size_type pos;
+    while ((dirp = readdir(dp)) != nullptr) {
+        std::string name(dirp->d_name);
 
-        //cout << "dir: " << name;
-        if ((pos = name.find(".sch")) != string::npos &&
+        //std::cout << "dir: " << name;
+        if ((pos = name.find(".sch")) != std::string::npos &&
             name.size() >= 5 && pos > 0 && pos + 4 == name.size()) {
             retval = true;
             break;
@@ -169,26 +249,106 @@ static bool scanDirForOdb(const char* dir)
     return retval;
 }
 
-
+// scan_file_extension
+// - checks whether the extension on the given file matches the given
+//   extension, and returns the corresponding Metview class name
+//   if it does
 //_______________________________________________________________________
 
 //
-// NOTE: a close cousin of scan_file(...) is in ./src/libMars/guess.c !!!
+// NOTE: originally it was a  close cousin of scan_file(...) is in
+// ./src/libMars/guess.c !!!
 //
 
+// store the suffix based mappings in hash tables
+static std::unordered_map<std::string, const char*> doubleSuffixMap = {
+    {".tar.gz", "TAR_GZ"},
+    {".tar.bz", "TAR_BZ"},
+    {".tar.bz2", "TAR_BZ2"}};
+
+static std::unordered_map<std::string, const char*> singleSuffixMap = {
+    {".tar", "TAR"},
+    {".magml", "MAGML"},
+    {".html", "ZIP"},
+    {".pdf", "PDF"},
+    {".png", "PNG"},
+    {".gif", "GIF"},
+    {".ps", "PSFILE"},
+    {".tiff", "TIFF"},
+    {".tif", "TIFF"},
+    {".svg", "SVG"},
+    {".kml", "KML"},
+    {".kmz", "KML"},
+    {".mv", "MACRO"},
+    {".csv", "TABLE"},
+    {".tsv", "TABLE"},
+    {".vdf", "VAPOR_VDF_FILE"},
+    {".xpif", "XPIF"},
+    {".gtif", "GEOTIFF"},
+    {".jpg", "JPEG"},
+    {".jpeg", "JPEG"},
+    {".py", "PYTHON"}};
+
 static const char* scan_file(const char* file)
 {
-    const int cMAXSHIFT = 8;  //-- search tolerance for word "GRIB" or "BUFR"
-    const int cMINREAD  = 4;  //-- need to be able to read at least this much
-    int length          = (file != NULL) ? strlen(file) : 0;
-
-    eFileType fileType = SearchMarsParserBreakers(file);  //-- binary? only numeric values?
+    static const int cMAXSHIFT        = 8;  //-- search tolerance for word "GRIB" or "BUFR"
+    static const int cMINREAD         = 4;  //-- need to be able to read at least this much
+    static const std::string cGEOJSON = ".geojson";
 
     File f(file, "r");
-    if (!f.f_)
+    if (!f.f_) {
         return "BAD";  //-- missing or non-readable file
+    }
 
+    // Determine type by the suffixes
+    std::string suffix1, suffix2;
+    if (get_file_extension(file, suffix1, suffix2)) {
+        if (!suffix2.empty()) {
+            metview::toLower(suffix2);
+            auto it = doubleSuffixMap.find(suffix2);
+            if (it != doubleSuffixMap.end()) {
+                return it->second;
+            }
+        }
+        if (!suffix1.empty()) {
+            metview::toLower(suffix1);
+            auto it = singleSuffixMap.find(suffix1);
+            if (it != singleSuffixMap.end()) {
+                return it->second;
+            }
+        }
+    }
 
+    // Weather symbols with geojson suffix
+    if (suffix1 == cGEOJSON) {
+        auto ws = isWeatherSymbolJson(f);
+        if (ws) {
+            return ws;
+        }
+    }
+#if 0
+    std::map<std::string, std::pair<std::string, std::string>> testVals = {
+        {"", {"",""}},
+        {"somename",{"",""}},
+        {"some.", {"",""}},
+        {"some..", {"",""}},
+        {".a", {"",""}},
+        {"some.a", {".a",""}},
+        {"some.jpeg", {".jpeg",""}},
+        {"some.TAR", {".TAR",""}},
+        {"some.tar.bz2", {".bz2", ".tar.bz2"}}
+    };
+    for (auto v: testVals) {
+        get_file_extension(v.first.c_str(), suffix1, suffix2);
+        MvLog().dbg() << v.first << " -> 1=" << suffix1 << " 2=" << suffix2;
+        assert (suffix1 == v.second.first);
+        assert (suffix2 == v.second.second);
+        suffix1.clear();
+        suffix2.clear();
+    }
+    exit(0);
+#endif
+#if 0
     // check the file extension first - remember to put the longest
     // ones at the start.
     if (scan_file_extension(file, length, ".tar.gz"))
@@ -241,14 +401,14 @@ static const char* scan_file(const char* file)
         return "JPEG";
     if (scan_file_extension(file, length, ".py"))
         return "PYTHON";
-
+#endif
     //if (scan_file_extension (file, length, ".odb"))     return "ODB_DB";
 
     // check the file extension for known types
     /*
   char *ext = strrchr (filename, '.');
   
-  if (ext != NULL)
+  if (ext != nullptr)
   {
     ext++;  // proceed to the first character after the dot
 
@@ -266,7 +426,7 @@ static const char* scan_file(const char* file)
 
       prev_ext = strrchr (filename, '.');
       
-      if (prev_ext != NULL && prev_ext >= file)
+      if (prev_ext != nullptr && prev_ext >= file)
       {
         prev_ext++;
         if (!strcasecmp (prev_ext, "tar")) return "TAR_GZ";
@@ -279,29 +439,29 @@ static const char* scan_file(const char* file)
     }
   }
 */
-
+    //-- binary? only numeric values?
+    eFileType fileType = SearchMarsParserBreakers(file);
 
     union
     {
         char c;
         short s;
         long l;
-        char ch[cMAXSHIFT + 6]; //-- must be at least 14 chars
+        char ch[cMAXSHIFT + 6];  //-- must be at least 14 chars
     } buf;
     memset(&buf, 0, sizeof(buf));
 
+    // read the first few bytes
     int readCount = fread((char*)&buf, 1, sizeof(buf), f.f_);
 
-    if (readCount < cMINREAD)  //-- if not enough bytes for safe tests
-    {
+    // not enough bytes for safe tests
+    if (readCount < cMINREAD) {
         return fileType == eBinaryFile ? "BINARY" : "NOTE";
+        // first check for binary types
     }
-
-
-    if (fileType == eBinaryFile)  //-- first check for binary types
-    {
-        for (int s = 0; s <= cMAXSHIFT; ++s)  //-- for GRIB & BUFR allow some leading rubbish
-        {
+    else if (fileType == eBinaryFile) {
+        // for GRIB & BUFR allow some leading rubbish
+        for (int s = 0; s <= cMAXSHIFT; ++s) {
             if (strncmp(buf.ch + s, "GRIB", 4) == 0)
                 return "GRIB";
 
@@ -331,62 +491,60 @@ static const char* scan_file(const char* file)
             return "PNG";
 
         if (strncmp(buf.ch + 6, "JFIF", 4) == 0)
-            return "JPEG";  //--  JPEG - JFIF
+            return "JPEG";
 
         if (strncmp(buf.ch + 6, "Exif", 4) == 0)
-            return "JPEG";  //--  JPEG - EXIF/DCF
+            return "JPEG";
 
-        if (strncmp(buf.ch, "%PDF", 4) == 0)  // PDF can be binary
+        // PDF can be binary
+        if (strncmp(buf.ch, "%PDF", 4) == 0)
             return "PDF";
+
+        //"NUMERIC" - need to avoid MARS parser!
+    }
+    else if (fileType == eNumericTextFile) {
+        return "NOTE";
+        // check for non-request text formats
+    }
+    else if (fileType == eOtherTextFile) {
+        if (strncmp(buf.ch, "%!", 2) == 0) {
+            return "PSFILE";
+            // PDF can be text
+        }
+        else if (strncmp(buf.ch, "%PDF", 4) == 0) {
+            return "PDF";
+        }
+        else if (strncmp(buf.ch, "#!", 2) == 0) {
+            return "SHELL";
+        }
+        else if (strncmp(buf.ch, "#GEOPOINTSET", 12) == 0) {
+            return "GEOPOINTSET";
+        }
+        else if (strncmp(buf.ch, "#GEO", 4) == 0) {
+            return "GEOPOINTS";
+        }
+        else if (strncmp(buf.ch, "#LLM", 4) == 0) {
+            return "LLMATRIX";
+        }
+        else if (strncmp(buf.ch, "#LLV", 4) == 0) {
+            return "LLVALUE";
+        }
+        else if (strncmp(buf.ch, "#MACRO", 6) == 0 ||
+                 strncmp(buf.ch, "# Macro", 7) == 0 ||
+                 strncmp(buf.ch, "#Metview", 8) == 0 ||
+                 strncmp(buf.ch, "# Metview", 9) == 0) {
+            return "MACRO";
+        }
+        else if (strncmp(buf.ch, "<magics", 7) == 0) {
+            return "MAGML";
+        }
+        else if (strncmp(buf.ch, "#obstat scatter", 15) == 0) {
+            return "OBSTAT_SCATTER";
+        }
+        else if (strncmp(buf.ch, "#obstat", 7) == 0) {
+            return "OBSTAT_CURVE";
+        }
     }
-
-    //We have to call it after FLEXTRA (see belows) since
-    //FLEXTRA v5 generates ASCII files with some rubbish in them and
-    //we identify them as BINARY files!!
-
-    //if( fileType == eBinaryFile )   //-- rest of the known types are all text files
-    //    return "BINARY";            //-- thus this one is of unknown binary type
-
-    if (fileType == eNumericTextFile)
-        return "NOTE";  //"NUMERIC"; //-- need to avoid MARS parser!
-
-    //-- check for text types that cannot be requests
-    //-- fileType must be eOtherTextFile
-    if (strncmp(buf.ch, "%!", 2) == 0)
-        return "PSFILE";
-
-    if (strncmp(buf.ch, "%PDF", 4) == 0)  // PDF can be text
-        return "PDF";
-
-    if (strncmp(buf.ch, "#!", 2) == 0)
-        return "SHELL";
-
-    if (strncmp(buf.ch, "#GEOPOINTSET", 12) == 0)
-        return "GEOPOINTSET";
-
-    if (strncmp(buf.ch, "#GEO", 4) == 0)
-        return "GEOPOINTS";
-
-    if (strncmp(buf.ch, "#LLM", 4) == 0)
-        return "LLMATRIX";
-
-    if (strncmp(buf.ch, "#LLV", 4) == 0)
-        return "LLVALUE";
-
-    if (strncmp(buf.ch, "#MACRO", 6) == 0 || strncmp(buf.ch, "# Macro", 7) == 0)
-        return "MACRO";
-    if (strncmp(buf.ch, "#Metview", 8) == 0 || strncmp(buf.ch, "# Metview", 9) == 0)
-        return "MACRO";
-
-    if (strncmp(buf.ch, "<magics", 7) == 0)
-        return "MAGML";
-
-    if (strncmp(buf.ch, "#obstat scatter", 15) == 0)
-        return "OBSTAT_SCATTER";
-
-    if (strncmp(buf.ch, "#obstat", 7) == 0)
-        return "OBSTAT_CURVE";
-
 
 #if 0
                                   //-- check if a Metview request
@@ -395,10 +553,10 @@ static const char* scan_file(const char* file)
   request *r = read_request_file(file);//-- a file NOT ending in CR can crash parser!!!
   if(r != 0)
     {
-      string name = r->name?r->name:"";
+      std::string name = r->name?r->name:"";
       free_all_requests(r);
 
-      map<string,const IconClass*>::iterator j = classes.find(name);
+      auto j = classes.find(name);
       if(j != classes.end())
         {
     return (*j).second->name().c_str();  //-- it is Metview request
@@ -408,7 +566,17 @@ static const char* scan_file(const char* file)
 
     rewind(f.f_);
 
-    //-- Check for custom ASCII files
+    // Check for custom ASCII files
+
+    // Weather symbols when we do not have a geojson suffix
+    if (fileType == eOtherTextFile && suffix1 != cGEOJSON) {
+        auto ws = isWeatherSymbolJson(f);
+        if (ws) {
+            return ws;
+        }
+    }
+
+    // FLEXTRA
     // We need at least 311 characters for flextra!
     char asciiBuf[400];
     memset(&asciiBuf[0], '\0', 400);
@@ -416,23 +584,19 @@ static const char* scan_file(const char* file)
     //Flextra output files
     if (strstr(asciiBuf, "FLEXTRA MODEL OUTPUT") != 0) {
         return "FLEXTRA_FILE";
+        //IFS namelist file
     }
-    //IFS namelist file
-    else if (strstr(asciiBuf, "&NAM") != 0 ||
-             strstr(asciiBuf, "&NAE") != 0 ||
+    else if (strstr(asciiBuf, "&NAM") != 0 || strstr(asciiBuf, "&NAE") != 0 ||
              strstr(asciiBuf, "&NEM") != 0) {
         return "NAMELIST";
+        // RTTOV output files - we may need to adjust this test in the future
     }
-    // RTTOV output files - we may need to adjust this test in the future
     else if (strstr(asciiBuf, "# RTTOV OUTPUT") != 0) {
         return "RTTOV_OUTPUT_FILE";
     }
 
     rewind(f.f_);
 
-    //-- Check for IFS fortran namelists
-
-
     // if it's binary then it might actually be a GRIB file with some extra
     // header bits at the start e.g. GTS). ecCodes has functionality to
     // bypass these, so if it can get a GRIB handle then it must be a GRIB file.
@@ -441,31 +605,28 @@ static const char* scan_file(const char* file)
     if (fileType == eBinaryFile) {
         grib_handle* gh;
         int ge;
-        gh = grib_handle_new_from_file(NULL, f.f_, &ge);
-        if (gh != NULL) {
+        gh = grib_handle_new_from_file(nullptr, f.f_, &ge);
+        if (gh != nullptr) {
             grib_handle_delete(gh);
             return "GRIB";
         }
     }
 
-
     //We have to do this check at this point, after
-    //FLEXTRA was checked!
+    //FLEXTRA was checked! FLEXTRA v5 generates ASCII files
+    //with some rubbish in them and we identify them as BINARY files!!
     if (fileType == eBinaryFile)
         return "BINARY";
 
-
-    fclose(f.f_);  //-- destructor will not close (end-of-file => !f.f_)
-    f.f_ = 0;      //-- but after fclose destructor would try and...
+    fclose(f.f_);    //-- destructor will not close (end-of-file => !f.f_)
+    f.f_ = nullptr;  //-- but after fclose destructor would try and...
 
     return "NOTE";  //-- unknown text file; make it NOTE
 }
 
 //_______________________________________________________________________
 
-//static string guess_file(const char* file) //-- old name in MetviewUI
-
-string ScanFileType(const char* file)
+std::string ScanFileType(const char* file)
 {
     struct stat buf;
 
@@ -520,9 +681,9 @@ int MvGribVersion(const char* fileName)
 //
 //----------------------------------------------------------------------------
 
-string MvOdbType(const char* file, bool scanBeforeCheck)
+std::string MvOdbType(const char* file, bool scanBeforeCheck)
 {
-    string t;
+    std::string t;
 
     if (scanBeforeCheck) {
         t = ScanFileType(file);
@@ -567,7 +728,7 @@ const char* MvNetcdfType(const char* file, bool checkStatus)
     }
 
     //F	NcFile nc(file);
-    MvNetCDF nc(string(file), NC_NOWRITE);
+    MvNetCDF nc(std::string(file), NC_NOWRITE);
     if (!nc.isValid()) {
         return "BINARY";
     }
@@ -577,7 +738,7 @@ const char* MvNetcdfType(const char* file, bool checkStatus)
     for (int i = 0; i < n; i++) {
         //F NcAtt* att=nc.get_att(i);
         MvNcAtt* att = nc.getAttribute(i);
-        if (att != NULL && att->name() != NULL &&
+        if (att != nullptr && att->name() != nullptr &&
             strcmp(att->name(), "dataID") == 0 && att->getNumberOfValues() > 0)  //F num_vals()
         {
             auto vStr = att->as_string(0);
@@ -593,7 +754,7 @@ const char* MvNetcdfType(const char* file, bool checkStatus)
                 }
             }
         }
-        //F		if(att != NULL)
+        //F		if(att != nullptr)
         //F			delete att;
     }
 
