@@ -22,37 +22,37 @@ inline double exp10(const double r)
 
 const double MvSci::cEarthRadiusInKm = 6378.388;  // Earth radius in km
 
-const double cTMELT  = 273.16;
-const double cR3LES  = 17.502;
-const double cR3IES  = 22.587;
-const double cR4LES  = 32.19;
-const double cR4IES  = -0.7;
-const double cRD     = 287.05;
+const double cTMELT = 273.16;
+const double cR3LES = 17.502;
+const double cR3IES = 22.587;
+const double cR4LES = 32.19;
+const double cR4IES = -0.7;
+const double cRD    = 287.05;
 //specific heat of air on constant volume
-const double cRV     = 461.51;
+const double cRV = 461.51;
 //specific heat of air on constant pressure
 const double cRP     = 1005.46;
-const double cKAPPA  = cRD/cRP;
-const double cEP     = cRD/cRV;
+const double cKAPPA  = cRD / cRP;
+const double cEP     = cRD / cRV;
 const double cCI     = 2710.;
 const double cRESTT  = 611.21;
 const double cR2ES   = cRESTT * cRD / cRV;
 const double cVTMPC1 = cRV / cRD - 1.;
 const double RAD     = 180. / M_PI;
-const double DEG     = 1/RAD;
-const double RAD2    = 2*RAD; // 360/pi
+const double DEG     = 1 / RAD;
+const double RAD2    = 2 * RAD;  // 360/pi
 
 
 //const double cEPSILON = 0.621981;
 
 double MvSci::degToRad(double d)
 {
-    return d*DEG;
+    return d * DEG;
 }
 
 double MvSci::radToDeg(double r)
 {
-    return r*RAD;
+    return r * RAD;
 }
 
 // Computes the distance on Earth in km
@@ -311,15 +311,14 @@ double MvSci::saturationSpecHumidity(double t, double p, bool flag)
     if (t >= cTMELT || flag) {
         A = 17.269;
         B = 35.86;
-    } else {
+    }
+    else {
         A = 21.875;
         B = 7.66;
     }
 
-    double v = 610.78*exp(A*(t-cTMELT)/(t-B));
-    return (flag)?
-                (cEP*v/p):
-                ((cEP*v)/(p - (1.-cEP)*v));
+    double v = 610.78 * exp(A * (t - cTMELT) / (t - B));
+    return (flag) ? (cEP * v / p) : ((cEP * v) / (p - (1. - cEP) * v));
 }
 
 
@@ -327,31 +326,31 @@ double MvSci::saturationSpecHumidity(double t, double p, bool flag)
 // t temperature in K
 // p pressure in Pa
 // q specific humidity in kg/kg
-bool MvSci::saturationLevel(double t, double p, double q, double &tSat, double &pSat, bool flag)
+bool MvSci::saturationLevel(double t, double p, double q, double& tSat, double& pSat, bool flag)
 {
-    int count = 0;
+    int count         = 0;
     const int maxIter = 20;
 
     if (q < 0.000002 && p > 10000.)
-        q=0.000002;
+        q = 0.000002;
 
-    double pSatLimit=p*0.2;
-    pSat = p*0.98;
-    tSat = t;
+    double pSatLimit = p * 0.2;
+    pSat             = p * 0.98;
+    tSat             = t;
 
-    while ( count < maxIter ) {
-        tSat = t*pow(pSat/p, cKAPPA) ;
-        double qSat = saturationSpecHumidity(tSat, pSat, flag);
-        double tSatTop = t*pow((pSat-100.)/p, cKAPPA);
-        double qSatTop = saturationSpecHumidity(tSatTop, (pSat-100.),flag);
-        double ratio =(qSat-q)/(qSat-qSatTop);
+    while (count < maxIter) {
+        tSat           = t * pow(pSat / p, cKAPPA);
+        double qSat    = saturationSpecHumidity(tSat, pSat, flag);
+        double tSatTop = t * pow((pSat - 100.) / p, cKAPPA);
+        double qSatTop = saturationSpecHumidity(tSatTop, (pSat - 100.), flag);
+        double ratio   = (qSat - q) / (qSat - qSatTop);
         //dp = p - pSat;
         if (fabs(ratio) < 1.) {
             return true;
         }
-        pSat -= ratio*100;
+        pSat -= ratio * 100;
         if (pSat < pSatLimit) {
-            pSat += ratio*100;
+            pSat += ratio * 100;
             return true;
         }
 
@@ -366,12 +365,12 @@ bool MvSci::saturationLevel(double t, double p, double q, double &tSat, double &
 // p pressure in Pa
 double MvSci::potentialTemperature(double t, double p)
 {
-    return t*pow(100000./p, cKAPPA);
+    return t * pow(100000. / p, cKAPPA);
 }
 
 double MvSci::potentialTemperaturePressureTerm(double p)
 {
-    return pow(100000./p, cKAPPA);
+    return pow(100000. / p, cKAPPA);
 }
 
 // As used in Pott.cc
@@ -383,7 +382,7 @@ double MvSci::equivalentPotentialTemperature(double t, double p, double q, bool
     double pSat, tSat;
     if (saturationLevel(t, p, q, tSat, pSat, flag)) {
         double qSat = saturationSpecHumidity(tSat, pSat, flag);
-        return tSat * pow(100000./pSat, cKAPPA)*exp(qSat*cCI/tSat);
+        return tSat * pow(100000. / pSat, cKAPPA) * exp(qSat * cCI / tSat);
     }
 
     return -1.;
@@ -395,7 +394,7 @@ double MvSci::equivalentPotentialTemperature(double t, double p, double q, bool
 double MvSci::saturatedEquivalentPotentialTemperature(double t, double p, bool flag)
 {
     double qSat = saturationSpecHumidity(t, p, flag);
-    return t * pow(100000./p, cKAPPA)*exp(qSat*cCI/t);
+    return t * pow(100000. / p, cKAPPA) * exp(qSat * cCI / t);
 }
 
 // As used in Pott.cc
@@ -405,7 +404,7 @@ double MvSci::saturatedEquivalentPotentialTemperature(double t, double p, bool f
 double MvSci::saturatedEquivalentPotentialTemperatureWithPTerm(double t, double p, double pTerm, bool flag)
 {
     double qSat = saturationSpecHumidity(t, p, flag);
-    return t * pTerm*exp(qSat*cCI/t);
+    return t * pTerm * exp(qSat * cCI / t);
 }
 
 #if 0
@@ -489,19 +488,21 @@ double MvSci::lifted_condensation_level(double t, double td, double p, double& t
 
 double MvSci::solarDeclinationInRad(double dateTime)
 {
-    static const double cSOLARDEC1 = sin(-DEG*23.44);
-    static const double cSOLARDEC2 = 360.0/365.24;
-    static double cSOLARDEC3 = RAD2*0.0167;
+    static const double cSOLARDEC1 = sin(-DEG * 23.44);
+    static const double cSOLARDEC2 = 360.0 / 365.24;
+    static double cSOLARDEC3       = RAD2 * 0.0167;
 
     MvDate vdt(dateTime);
     auto N = vdt.dayOfTheYear();
-    auto v = cSOLARDEC1 * cos(degToRad(cSOLARDEC2 *(N+10) + cSOLARDEC3*sin(degToRad(cSOLARDEC2*(N-2)))));
+    auto v = cSOLARDEC1 * cos(degToRad(cSOLARDEC2 * (N + 10) + cSOLARDEC3 * sin(degToRad(cSOLARDEC2 * (N - 2)))));
     if (fabs(v) <= 1.0) {
         return asin(v);
-    } else if (fabs(v-1.) < 1e-9) {
-        return M_PI/2.;
-    } else if (fabs(v+1.) < 1e-9) {
-       return -M_PI/2.;
+    }
+    else if (fabs(v - 1.) < 1e-9) {
+        return M_PI / 2.;
+    }
+    else if (fabs(v + 1.) < 1e-9) {
+        return -M_PI / 2.;
     }
     return -999.;
     //return MvSci::degToRad(23.44 * cos(MvSci::degToRad((360./365.)*(N+10.))));
@@ -512,5 +513,5 @@ double MvSci::cosineSolarZenithAngle(double lat, double lon, double declInRad, d
     auto latRad = degToRad(lat);
     //local hour angle
     auto h = MvSci::degToRad(hourAngleGM + lon);
-    return sin(latRad)*sin(declInRad) + cos(latRad)*cos(declInRad)*cos(h);
+    return sin(latRad) * sin(declInRad) + cos(latRad) * cos(declInRad) * cos(h);
 }
