@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVSCI_H
-#define MVSCI_H
+#pragma once
 
 #include <string>
 
@@ -33,7 +32,7 @@ public:
     static double speed(double u, double v);
     static double direction(double u, double v);
     static double saturationSpecHumidity(double t, double p, bool flag);
-    static bool saturationLevel(double t, double p, double q, double &pSat, double &tSat, bool flag);
+    static bool saturationLevel(double t, double p, double q, double& pSat, double& tSat, bool flag);
     static double potentialTemperature(double t, double p);
     static double potentialTemperaturePressureTerm(double p);
     static double equivalentPotentialTemperature(double t, double p, double q, bool flag);
@@ -42,5 +41,3 @@ public:
     static double solarDeclinationInRad(double dateTime);
     static double cosineSolarZenithAngle(double lat, double lon, double declInRad, double hourAngleGM);
 };
-
-#endif  // MVSCI_H
