@@ -23,7 +23,7 @@ void TableReader::resizeDecoders(unsigned int numNeeded)
 }
 
 
-void TableReader::setFieldContainer(int index, string& name, vector<double>& container, double outputMissingIndicator)
+void TableReader::setFieldContainer(int index, std::string& name, std::vector<double>& container, double outputMissingIndicator)
 {
     if (index == -1)  // is the user wanting to find a field with the given name?
     {
@@ -48,14 +48,14 @@ void TableReader::setFieldContainer(int index, string& name, vector<double>& con
 
     // add the decoder to the appropriate place in our list
 
-    TableDoubleVectorElementDecoder* decoder = new TableDoubleVectorElementDecoder(container, outputMissingIndicator);
-    TableElementDecoder* genericDecoder      = dynamic_cast<TableElementDecoder*>(decoder);
+    auto* decoder        = new TableDoubleVectorElementDecoder(container, outputMissingIndicator);
+    auto* genericDecoder = dynamic_cast<TableElementDecoder*>(decoder);
     decoderSets_[index].push_back(genericDecoder);  //.push_back(genericDecoder);
     names_[index] = &name;
 }
 
 
-void TableReader::setFieldContainer(int index, string& name, vector<string>& container, string outputMissingIndicator)
+void TableReader::setFieldContainer(int index, std::string& name, std::vector<std::string>& container, std::string outputMissingIndicator)
 {
     if (index == -1)  // is the user wanting to find a field with the given name?
     {
@@ -79,8 +79,8 @@ void TableReader::setFieldContainer(int index, string& name, vector<string>& con
 
     // add the decoder to the appropriate place in our list
 
-    TableStringVectorElementDecoder* decoder = new TableStringVectorElementDecoder(container, outputMissingIndicator);
-    TableElementDecoder* genericDecoder      = dynamic_cast<TableElementDecoder*>(decoder);
+    auto* decoder        = new TableStringVectorElementDecoder(container, outputMissingIndicator);
+    auto* genericDecoder = dynamic_cast<TableElementDecoder*>(decoder);
     decoderSets_[index].push_back(genericDecoder);  //.push_back(genericDecoder);
     names_[index] = &name;
 }
@@ -92,7 +92,7 @@ void TableReader::setFieldContainer(int index, string& name, vector<string>& con
 //  NOTE: this function is destructive to the input string!
 // ---------------------------------------------------------------------------
 
-void TableReader::splitLine(char* line, vector<char*>& tokens)
+void TableReader::splitLine(char* line, std::vector<char*>& tokens)
 {
     char* current = line;
     char* token   = current;
@@ -119,7 +119,7 @@ void TableReader::splitLine(char* line, vector<char*>& tokens)
 //  NOTE: this function is destructive to the input string!
 // ---------------------------------------------------------------------------
 
-void TableReader::splitLineConsecutiveDelimiters(char* line, vector<char*>& tokens)
+void TableReader::splitLineConsecutiveDelimiters(char* line, std::vector<char*>& tokens)
 {
     char* current = line;
     char* token   = current;
@@ -155,7 +155,7 @@ void TableReader::ensureHaveMetaData()
 {
     if (!gotMetaData_)  // caller should have retrieved the meta-data already
     {
-        string msg;
+        std::string msg;
 
         if (!getMetaData(msg)) {
             setError(msg);
@@ -163,7 +163,7 @@ void TableReader::ensureHaveMetaData()
     }
 }
 
-vector<TableReader::eTableReaderFieldType>& TableReader::fieldTypes()
+std::vector<TableReader::eTableReaderFieldType>& TableReader::fieldTypes()
 {
     ensureHaveMetaData();
 
@@ -171,7 +171,7 @@ vector<TableReader::eTableReaderFieldType>& TableReader::fieldTypes()
 }
 
 
-vector<string>& TableReader::fieldNames()
+std::vector<std::string>& TableReader::fieldNames()
 {
     ensureHaveMetaData();
 
@@ -179,7 +179,7 @@ vector<string>& TableReader::fieldNames()
 }
 
 
-map<string, string>& TableReader::userMetaData()
+std::map<std::string, std::string>& TableReader::userMetaData()
 {
     ensureHaveMetaData();
 
@@ -195,14 +195,14 @@ int TableReader::numRecords()
 }
 
 
-int TableReader::indexOfField(string& name)
+int TableReader::indexOfField(std::string& name)
 {
     ensureHaveMetaData();
 
 
     // find which field has the name we're looking for
 
-    for (vector<string*>::size_type i = 0; i < names_.size(); i++) {
+    for (std::vector<std::string*>::size_type i = 0; i < names_.size(); i++) {
         if (namesAll_[i] == name)
             return i;  // found it - return its index
     }
@@ -238,7 +238,7 @@ TableReader::eTableReaderFieldType TableReader::guessFieldType(char* str)
 }
 
 
-int TableReader::nextLineTokens(char* line, size_t sizeOfLine, vector<char*>& tokens)
+int TableReader::nextLineTokens(char* line, size_t sizeOfLine, std::vector<char*>& tokens)
 {
     // skip blank lines
 
@@ -258,7 +258,7 @@ int TableReader::nextLineTokens(char* line, size_t sizeOfLine, vector<char*>& to
     if (f_.getline(line, sizeOfLine)) {
         // parse the line into tokens
 
-        streamsize numread = f_.gcount();
+        std::streamsize numread = f_.gcount();
 
         if ((numread >= 2) && (line[numread - 1] == '\0') && (line[numread - 2] == '\r'))  // remove extraneous newline characters from Windows
             line[numread - 2] = '\0';
@@ -284,7 +284,7 @@ int TableReader::nextLineTokens(char* line, size_t sizeOfLine, vector<char*>& to
 // PARAM1=VALUE1 PARAM2=VALUE2
 // ---------------------------------------------------------------------------
 
-bool TableReader::readUserMetaData(char* line, size_t sizeOfLine, string& errorMessage)
+bool TableReader::readUserMetaData(char* line, size_t sizeOfLine, std::string& errorMessage)
 {
     int currentRow      = 1;
     char oldDelimiter   = delimiter_;                   // store because we will over-ride it
@@ -296,21 +296,21 @@ bool TableReader::readUserMetaData(char* line, size_t sizeOfLine, string& errorM
 
     setConsecutiveDelimitersAsOne(true);  // allows the user more flexibility
 
-    for (vector<int>::size_type r = 0; r < userMetaDataRows_.size(); r++)  // for each line of meta-data...
+    for (int userMetaDataRow : userMetaDataRows_)  // for each line of meta-data...
     {
-        skipLines(userMetaDataRows_[r] - currentRow, line, sizeOfLine);  // get to the right line
+        skipLines(userMetaDataRow - currentRow, line, sizeOfLine);  // get to the right line
         setDelimiter(' ');
 
 
-        vector<char*> tokens;
+        std::vector<char*> tokens;
 
         if (nextLineTokens(line, sizeOfLine, tokens) > 0) {
             // now have one token per PARAM=VALUE - split each one into a pair
 
             setDelimiter('=');
 
-            for (vector<string*>::size_type j = 0; j < tokens.size(); j++) {
-                vector<char*> tokens2;
+            for (std::vector<std::string*>::size_type j = 0; j < tokens.size(); j++) {
+                std::vector<char*> tokens2;
 
                 splitLineConsecutiveDelimiters(tokens[j], tokens2);
 
@@ -328,7 +328,7 @@ bool TableReader::readUserMetaData(char* line, size_t sizeOfLine, string& errorM
         }
 
 
-        currentRow = userMetaDataRows_[r] + 1;  // store which line we're at
+        currentRow = userMetaDataRow + 1;  // store which line we're at
     }
 
 
@@ -360,7 +360,7 @@ void TableReader::skipLines(int linesToSkip, char* line, size_t sizeOfLine)
 // file.
 // ---------------------------------------------------------------------------
 
-bool TableReader::getMetaData(string& errorMessage)
+bool TableReader::getMetaData(std::string& errorMessage)
 {
     if (gotMetaData_)  // we should only need to get the meta-data once
         return true;
@@ -410,7 +410,7 @@ bool TableReader::getMetaData(string& errorMessage)
     // rewind the file pointer before we start again
 
     f_.clear();
-    f_.seekg(0, ios::beg);
+    f_.seekg(0, std::ios::beg);
 
 
     // read the user meta-data if it exists
@@ -424,7 +424,7 @@ bool TableReader::getMetaData(string& errorMessage)
         // rewind the file pointer before we start again
 
         f_.clear();
-        f_.seekg(0, ios::beg);
+        f_.seekg(0, std::ios::beg);
     }
 
 
@@ -448,7 +448,7 @@ bool TableReader::getMetaData(string& errorMessage)
     for (int i = 0; i < numLinesToCheck; i++) {
         // read the line into a buffer and split it into tokens
 
-        vector<char*> tokens;
+        std::vector<char*> tokens;
 
         if (nextLineTokens(line, sizeof(line), tokens) > 0) {
             if (i == 0) {
@@ -457,7 +457,7 @@ bool TableReader::getMetaData(string& errorMessage)
 
             if ((i == 0) && headerRow() > 0)  // parse a header row?
             {
-                for (vector<string*>::size_type j = 0; j < tokens.size(); j++) {
+                for (std::vector<std::string*>::size_type j = 0; j < tokens.size(); j++) {
                     namesAll_[j] = tokens[j];
                 }
 
@@ -476,7 +476,7 @@ bool TableReader::getMetaData(string& errorMessage)
 
                 // determine which data type each token is
 
-                for (vector<eTableReaderFieldType>::size_type j = 0; j < tokens.size(); j++) {
+                for (std::vector<eTableReaderFieldType>::size_type j = 0; j < tokens.size(); j++) {
                     types_[j] = guessFieldType(tokens[j]);
                 }
             }
@@ -490,7 +490,7 @@ bool TableReader::getMetaData(string& errorMessage)
 }
 
 
-bool TableReader::read(string& errorMessage)
+bool TableReader::read(std::string& errorMessage)
 {
     const int MAX_CHARS_IN_LINE = 1024 * 100;
     char line[MAX_CHARS_IN_LINE];
@@ -524,7 +524,7 @@ bool TableReader::read(string& errorMessage)
 
     // set the header names?
 
-    for (vector<string*>::size_type j = 0; j < namesAll_.size(); j++) {
+    for (std::vector<std::string*>::size_type j = 0; j < namesAll_.size(); j++) {
         if (names_[j] != nullptr) {
             *(names_[j]) = namesAll_[j];
         }
@@ -534,9 +534,9 @@ bool TableReader::read(string& errorMessage)
     // initialise our containers to hold the correct number of elements
 
     //    for (i = 0 ; i < decoders_.size(); i++)
-    for (vector<TableElementDecoders>::iterator decoderSet = decoderSets_.begin(); decoderSet != decoderSets_.end(); ++decoderSet) {
-        for (TableElementDecoders::iterator decoder = (*decoderSet).begin(); decoder != (*decoderSet).end(); ++decoder) {
-            if (*decoder != NULL) {
+    for (auto& decoderSet : decoderSets_) {
+        for (auto decoder = decoderSet.begin(); decoder != decoderSet.end(); ++decoder) {
+            if (*decoder != nullptr) {
                 (*decoder)->initialise(numRecords_);
             }
         }
@@ -546,10 +546,10 @@ bool TableReader::read(string& errorMessage)
     // rewind the file pointer before we start again
 
     f_.clear();
-    f_.seekg(dataStart_, ios::beg);  // set to start of the data (determined by getMetaData())
+    f_.seekg(dataStart_, std::ios::beg);  // set to start of the data (determined by getMetaData())
 
 
-    vector<char*> tokens;
+    std::vector<char*> tokens;
     char empty[1];
     empty[0] = '\0';
 
@@ -563,7 +563,6 @@ bool TableReader::read(string& errorMessage)
             {
                 if (tokens.size() == 0)  // blank line?
                 {
-
                     // if we are only reading one column, then it could be a missing value
                     if (decoderSets_.size() == 1) {
                         tokens.push_back(empty);
@@ -587,12 +586,12 @@ bool TableReader::read(string& errorMessage)
 
             // decode the data with their various decoders - one set of decoders for each field
 
-            vector<char*>::iterator s = tokens.begin();
+            auto s = tokens.begin();
 
-            for (vector<TableElementDecoders>::iterator decoderSet = decoderSets_.begin(); decoderSet != decoderSets_.end(); ++decoderSet) {
-                for (TableElementDecoders::iterator decoder = (*decoderSet).begin(); decoder != (*decoderSet).end(); ++decoder) {
-                    if (*decoder != NULL) {
-                        //string str(*s);
+            for (auto& decoderSet : decoderSets_) {
+                for (auto decoder = decoderSet.begin(); decoder != decoderSet.end(); ++decoder) {
+                    if (*decoder != nullptr) {
+                        //std::string str(*s);
                         (*decoder)->addValue(*s);
                     }
                 }
