@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef COLOURWIDGET_H
-#define COLOURWIDGET_H
+#pragma once
 
 #include "MvQPalette.h"
 
@@ -31,20 +30,20 @@ struct MvQColourItem
     MvQColourItem(QColor col, QString name, const std::vector<int>& shades = {}) :
         col_(col),
         name_(name),
-        shades_(shades){}
+        shades_(shades) {}
     QColor col_;
     QString name_;
     std::vector<int> shades_;
 };
 
-class  MvQCompactColourGrid : public QWidget
+class MvQCompactColourGrid : public QWidget
 {
-     Q_OBJECT
+    Q_OBJECT
 
 public:
-    MvQCompactColourGrid(int minSize,  QList<MvQColourItem> items, bool singleRow, QWidget* parent = 0);
+    MvQCompactColourGrid(int minSize, QList<MvQColourItem> items, bool singleRow, QWidget* parent = 0);
     void replace(QList<QColor>);
-    int itemCount() const {return items_.count();}
+    int itemCount() const { return items_.count(); }
 
 signals:
     void selected(QColor);
@@ -71,8 +70,8 @@ protected:
     int cellSize_{12};
     int cellsPerRow_{10};
     QPixmap pix_;
-    QColor highlightCol_{QColor(21,95,207)};
-    QColor gridCol_{QColor(170,170,170)};
+    QColor highlightCol_{QColor(21, 95, 207)};
+    QColor gridCol_{QColor(170, 170, 170)};
     int highlightIndex_{-1};
 };
 
@@ -83,7 +82,7 @@ class MvQColourGrid : public QWidget, public PaletteScanner
 
 public:
     MvQColourGrid(int minSize, QWidget* parent = 0);
-    void next(const string&, QColor, bool);
+    void next(const std::string&, QColor, bool);
 
 signals:
     void selected(QColor);
@@ -237,13 +236,13 @@ class MvQColourCombo : public QComboBox, public PaletteScanner
     Q_OBJECT
 
 public:
-    MvQColourCombo(QWidget *parent = nullptr);
+    MvQColourCombo(QWidget* parent = nullptr);
     ~MvQColourCombo() {}
 
     QString currentValue() { return QString(); }
     void addValue(QString) {}
 
-    //void refresh(const std::vector<string>&);
+    //void refresh(const std::vector<std::string>&);
 
 public slots:
     void changeSelection(QString);
@@ -258,7 +257,7 @@ signals:
     void colourSelected(QString);
 
 protected:
-    void next(const string&, QColor, bool);
+    void next(const std::string&, QColor, bool);
     void addColour(QColor, QString, QString, bool setCurrent = false);
     void setCustomColour(QColor, QString, QString, bool setCurrent = false);
     //void updateHelper();
@@ -274,7 +273,7 @@ class MvQColourWidget : public QWidget
     Q_OBJECT
 
 public:
-    MvQColourWidget(QWidget * parent);
+    MvQColourWidget(QWidget* parent);
     ~MvQColourWidget() {}
 
     void initColour(QString);
@@ -295,5 +294,3 @@ private:
     MvQColourSelectionWidget* selector_;
     QString oriName_;
 };
-
-#endif // COLOURWIDGET_H
