@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQFileDialog_H
-#define MvQFileDialog_H
+#pragma once
 
 #include <QFileSystemModel>
 #include <QFileIconProvider>
@@ -18,7 +17,6 @@
 #include <QSortFilterProxyModel>
 #include <QString>
 
-using namespace std;
 
 class MvQPixmapCache;
 
@@ -48,5 +46,3 @@ class MvQFileDialog : public QFileDialog
 public:
     MvQFileDialog(QString, QString, QWidget* parent = 0);
 };
-
-#endif
