@@ -34,8 +34,8 @@ void MvQScmTableViewDelegate::paint(QPainter* painter, const QStyleOptionViewIte
     painter->save();
     QVariant va = index.data(Qt::UserRole);
     if (va.isValid()) {
-        painter->setPen(QPen(va.value<QColor>(),2));
-        painter->drawRect(option.rect.adjusted(2,2,-2,-2));
+        painter->setPen(QPen(va.value<QColor>(), 2));
+        painter->drawRect(option.rect.adjusted(2, 2, -2, -2));
     }
     painter->restore();
 }
@@ -49,8 +49,8 @@ void MvQScmTableViewDelegate::paint(QPainter* painter, const QStyleOptionViewIte
 MvQScmDataModel::MvQScmDataModel(QObject* parent) :
     QAbstractItemModel(parent)
 {
-    step_ = -1;
-    editCol_     = MvQTheme::colour("scmview", "edited_cell");
+    step_    = -1;
+    editCol_ = MvQTheme::colour("scmview", "edited_cell");
 }
 
 void MvQScmDataModel::dataIsAboutToChange()
@@ -77,7 +77,7 @@ QModelIndex MvQScmDataModel::index(int row, int column, const QModelIndex& /*par
         return QModelIndex();
     }
 
-    return createIndex(row, column, (void*)0);
+    return createIndex(row, column, (void*)nullptr);
 }
 
 QModelIndex MvQScmDataModel::indexForChange(const MvScmProfileChange& item) const
@@ -127,7 +127,7 @@ int MvQScmSurfaceModel::rowCount(const QModelIndex& parent) const
 QVariant MvQScmSurfaceModel::data(const QModelIndex& index, int role) const
 {
     if (role != Qt::DisplayRole && role != Qt::BackgroundRole && role != Qt::EditRole &&
-            role != Qt::UserRole) {
+        role != Qt::UserRole) {
         return QVariant();
     }
 
@@ -173,7 +173,7 @@ bool MvQScmSurfaceModel::setData(const QModelIndex& index, const QVariant& value
     return true;
 }
 
-void MvQScmSurfaceModel::setData(const vector<MvScmVar*>& data, int step)
+void MvQScmSurfaceModel::setData(const std::vector<MvScmVar*>& data, int step)
 {
     beginResetModel();
 
@@ -220,7 +220,7 @@ QModelIndex MvQScmSurfaceModel::indexForVar(MvScmVar* var, int step, int /*level
     if (step == step_) {
         for (unsigned int i = 0; i < data_.size(); i++) {
             if (data_.at(i) == var) {
-                return createIndex(i, 0, (void*)0);
+                return createIndex(i, 0, (void*)nullptr);
             }
         }
     }
@@ -277,7 +277,7 @@ int MvQScmProfileModel::rowCount(const QModelIndex& parent) const
 QVariant MvQScmProfileModel::data(const QModelIndex& index, int role) const
 {
     if (role != Qt::DisplayRole && role != Qt::BackgroundRole && role != Qt::EditRole &&
-            role != Qt::UserRole) {
+        role != Qt::UserRole) {
         return QVariant();
     }
 
@@ -318,7 +318,7 @@ bool MvQScmProfileModel::setData(const QModelIndex& index, const QVariant& value
     return true;
 }
 
-void MvQScmProfileModel::setData(const vector<MvScmVar*>& data, int step, const vector<float>& levels, const string& levelName)
+void MvQScmProfileModel::setData(const std::vector<MvScmVar*>& data, int step, const std::vector<float>& levels, const std::string& levelName)
 {
     beginResetModel();
 
@@ -377,7 +377,7 @@ QModelIndex MvQScmProfileModel::indexForVar(MvScmVar* var, int step, int level)
     if (step == step_) {
         for (unsigned int i = 0; i < data_.size(); i++) {
             if (data_.at(i) == var) {
-                return createIndex(level, i, (void*)0);
+                return createIndex(level, i, (void*)nullptr);
             }
         }
     }
