@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQBUFRMESSAGESCANNER_H
-#define MVQBUFRMESSAGESCANNER_H
+#pragma once
 
 #include "MvQAbstractMessageScanner.h"
 
@@ -46,5 +45,3 @@ protected:
 
     BufrMetaData* bufrData_;
 };
-
-#endif
