@@ -12,6 +12,7 @@
 #include "CartesianView.h"
 #include "DataObject.h"
 #include "MvDecoder.h"
+#include "MvLog.h"
 #include "ObjectList.h"
 #include "Page.h"
 #include "PlotMod.h"
@@ -43,9 +44,9 @@ static CartesianViewFactory CartesianViewFactoryInstance;
 CartesianView::CartesianView(Page& owner,
                              const MvRequest& viewRequest,
                              const MvRequest& setupRequest,
-                             const string& hAxisName,
-                             const string& vAxisName,
-                             const string& viewName) :
+                             const std::string& hAxisName,
+                             const std::string& vAxisName,
+                             const std::string& viewName) :
     PlotModView(owner, viewRequest, setupRequest),
     hAxisName_(hAxisName),
     vAxisName_(vAxisName),
@@ -84,17 +85,14 @@ CartesianView::CartesianView(const CartesianView& old) :
 {
 }
 
-CartesianView::~CartesianView()
-{
-    // Empty
-}
+CartesianView::~CartesianView() = default;
 
-void CartesianView::GetBackgroundParameters(vector<string>& vback)
+void CartesianView::GetBackgroundParameters(std::vector<std::string>& vback)
 {
     // Get map projection
-    string sproj;
+    std::string sproj;
     if (const char* prCh = (const char*)viewRequest_("MAP_PROJECTION"))
-        sproj = string(prCh);
+        sproj = std::string(prCh);
 
     if (sproj.empty())
         sproj = "cartesian";
@@ -113,7 +111,7 @@ void CartesianView::GetBackgroundParameters(vector<string>& vback)
     return;
 }
 
-string
+std::string
 CartesianView::Name()
 {
     int id = Owner().Id();
@@ -175,7 +173,7 @@ void CartesianView::Drop(PmContext& context)
 
         // Replace the view (if applicable)
         else if (ObjectList::IsView(verb) == true)
-            this->UpdateView(request);
+            this->UpdateViewWithReq(request);
 
         else if ((const char*)verb == PLOTSUPERPAGE) {
             context.AdvanceTo(PLOTSUPERPAGE);
@@ -221,7 +219,7 @@ void CartesianView::UpdateAxisTypeView(MvRequest& reqData)
     // Update X axis type. Assumes that there is only one parameter
     // with sufix equals to "_X_TYPE"
     MvRequest reqAux("XY_TYPE");
-    string sufix = "_X_TYPE";
+    std::string sufix = "_X_TYPE";
     CopySomeParameters(reqData, reqAux, sufix);
     const char* param = (const char*)reqAux.getParameter(0);
     if (param && strcmp(reqAux(param), "DATE") == 0)
@@ -276,8 +274,8 @@ void CartesianView::ReplaceAxis(MvRequest& axisRequest)
         cori = "HORIZONTAL";  //default
 
     // Unset previous axis definition from the view, if exists
-    string sorient    = cori + (string) "_AXIS";
-    MvRequest newView = viewRequest_;
+    std::string sorient = cori + (std::string) "_AXIS";
+    MvRequest newView   = viewRequest_;
     newView.unsetParam(sorient.c_str());
 
     // Add new axis definition and update the view
@@ -327,7 +325,7 @@ void CartesianView::DecodeDataUnit(MvIcon& givenUnit)
 void CartesianView::DescribeYourself(ObjectInfo& description)
 {
     // Convert my request to macro
-    set<Cached> skipSet;
+    std::set<Cached> skipSet;
     description.ConvertRequestToMacro(viewRequest_, PUT_END, MacroName().c_str(), viewName_.c_str(), skipSet);
 }
 
@@ -347,7 +345,7 @@ CartesianView::InsertDataRequest(MvRequest& dropRequest)
     MvIconList duList;
     while (dropRequest) {
         MvRequest dataUnitRequest = dropRequest.justOneRequest();
-        string verb               = dataUnitRequest.getVerb();
+        std::string verb          = dataUnitRequest.getVerb();
 
         if (verb == NETCDF) {
             MvIcon tmpIcon(dataUnitRequest);
@@ -415,18 +413,18 @@ void CartesianView::Draw(SubPage* subPage)
     DrawingPriority& tmpDrawingPriority = Owner().GetDrawPriority();  // Get from Page
 
     // Get the data units for this subpage.
-    list<DataObject*> doList;
+    std::list<DataObject*> doList;
     subPage->GetDataObjects(doList);
-    list<DataObject*>::iterator ii;
+    std::list<DataObject*>::iterator ii;
     DataObject* dataObject = 0;
     DrawPriorMap drawPriorMap;
     DrawPriorMap::iterator j;
 
     //  MvIconList  duList;
-    multimap<int, MvIcon> duMap;
+    std::multimap<int, MvIcon> duMap;
     MvIcon dataUnit;
 
-    map<int, MvRequest> reqMap;
+    std::map<int, MvRequest> reqMap;
     //	AxisInfoMap::iterator axisii;
     //	double MinX,MaxX,MinY,MaxY;
     //	bool first = true;
@@ -454,10 +452,10 @@ void CartesianView::Draw(SubPage* subPage)
         // to set the correct values ( BAR...VALUES, CURVE..VALUES etc).
         // So we need to add a GRAPH_TYPE field to dataunit request
         // for the benefit of the translator.
-        string type = "PGRAPH_GRAPH_TYPE_";
+        std::string type = "PGRAPH_GRAPH_TYPE_";
         type += CheckDataRequest(dataUnit, vdList);
         int drawPrior = tmpDrawingPriority.GetPriority(type);
-        duMap.insert(pair<const int, MvIcon>(drawPrior, dataUnit));
+        duMap.insert(std::pair<const int, MvIcon>(drawPrior, dataUnit));
 
         DrawPriorMap tmpMap = dataObject->DrawPriority(vdList);
         for (j = tmpMap.begin(); j != tmpMap.end(); ++j)
@@ -485,7 +483,7 @@ void CartesianView::Draw(SubPage* subPage)
 
 #if 0  //F0410
 	first = true;
-	for (  multimap<int,MvIcon>::iterator jj = duMap.begin(); jj != duMap.end(); jj++ )
+	for (  std::multimap<int,MvIcon>::iterator jj = duMap.begin(); jj != duMap.end(); jj++ )
 	{
 		bool addAxis = ( first || subPage->IsAWindow() );
 		MergeAxisInfo((*jj).second, fullAxisRequest,addAxis);
@@ -499,7 +497,7 @@ void CartesianView::Draw(SubPage* subPage)
 #if 0  //FAMI 20100922 Is this needed in Metview 4?
 	CommonDraw(subPage, drawPriorMap, reqMap);
 	// Reset the data requests
-	map<int,MvRequest>::iterator kk;
+	std::map<int,MvRequest>::iterator kk;
 	for ( kk = reqMap.begin(); kk != reqMap.end(); kk++ )
 	{
 		if ( ! dataBase.RetrieveDataUnit ((*kk).first, dataUnit) )
@@ -537,14 +535,14 @@ void CartesianView::DrawBackground()
 int CartesianView::RetrieveBackground(MvRequest& backReq)
 {
     // Inquire the background parameters according to the projection
-    vector<string> vback;
+    std::vector<std::string> vback;
     this->GetBackgroundParameters(vback);
     if (vback.size() == 0)
         return 0;  // no background parameters
 
     // Get icons using the following order: View, DataBase, default
     // Retrieve icons from the View
-    vector<string> vbackAux;
+    std::vector<std::string> vbackAux;
     int ncount = 0;
     int nc     = vback.size();
     for (int i = 0; i < nc; i++) {
@@ -626,7 +624,7 @@ CartesianView::RetrieveBackForeground( const char* stype, MvRequest& req )
       if ( ObjectList::IsVisDefBackForeground(currentReq.getVerb()) )
       {
          if ( (const char*)currentReq("_PLOTTING_ORDER") &&
-              (string(stype) == (const char*)currentReq("_PLOTTING_ORDER")) )
+              (std::string(stype) == (const char*)currentReq("_PLOTTING_ORDER")) )
          {
             req = req + currentReq;
             ncount++;
@@ -758,7 +756,7 @@ void CartesianView::UpdateAxisInfo()
 // different data units.
 const char* CartesianView::CheckDataRequest(MvIcon& dataUnit, MvIconList& vdList)
 {
-    MvListCursor ii       = vdList.begin();
+    auto ii               = vdList.begin();
     const char* graphType = 0;
     for (; ii != vdList.end(); ii++) {
         MvIcon visdef = *ii;
@@ -780,14 +778,13 @@ const char* CartesianView::CheckDataRequest(MvIcon& dataUnit, MvIconList& vdList
     return graphType ? graphType : "CURVE";
 }
 
-bool CartesianView::UpdateView(MvRequest& viewRequest)
+bool CartesianView::UpdateViewWithReq(MvRequest& viewRequest)
 {
     // Changing to another View is not allowed
     if (strcmp(viewRequest_.getVerb(), viewRequest.getVerb())) {
         // Changing View is disabled at the moment
-        char text[128];
-        sprintf(text, "Changing View (%s to %s) is currently disabled", viewRequest_.getVerb(), viewRequest.getVerb());
-        PlotMod::Instance().UserErrorMessage(text);
+        MvLog().popup().err() << "Changing View (" << viewRequest_.getVerb() << " to "
+                              << viewRequest.getVerb() << ") is currently disabled";
         return false;
     }
 
