@@ -20,6 +20,7 @@
 #include "PmContext.h"
 #include "SubPage.h"
 #include "MvRequestUtil.hpp"
+#include "MvLog.h"
 
 CommonXSectView::CommonXSectView(Page& owner,
                                  const MvRequest& viewRequest,
@@ -56,21 +57,18 @@ CommonXSectView::CommonXSectView(const CommonXSectView& old) :
     //empty
 }
 
-CommonXSectView::~CommonXSectView()
-{
-    // Empty
-}
+CommonXSectView::~CommonXSectView() = default;
 
-string CommonXSectView::Name()
+std::string CommonXSectView::Name()
 {
     char tmp[32];
     sprintf(tmp, "CommonXSectView%d", Owner().Id());
 
-    return string(tmp);
+    return std::string(tmp);
 }
 
 // Synchronous call service. Calls a service and wait its return.
-bool CommonXSectView::CallService(const MvRequest& dataReq, PmContext& context, MvRequest& replyReq)
+bool CommonXSectView::callServiceInternal(const MvRequest& dataReq, PmContext& context, MvRequest& replyReq)
 {
     if (dataReq.getVerb() != GRIB && dataReq.getVerb() != NETCDF && dataReq.getVerb() != BUFR)
         return false;
@@ -94,7 +92,7 @@ bool CommonXSectView::CallService(const MvRequest& dataReq, PmContext& context,
     appRequest("_CLASS")   = (const char*)dataReq("_CLASS") ? (const char*)dataReq("_CLASS") : "";
 
     //( new PlotModTask (this, context, serviceName_.c_str(), appRequest ) )->run();
-    PlotModTask* pmt = new PlotModTask(this, context, serviceName_.c_str(), appRequest);
+    auto* pmt = new PlotModTask(this, context, serviceName_.c_str(), appRequest);
     int err;
     replyReq = pmt->run(err);
     if (!replyReq || err != 0)
@@ -146,7 +144,7 @@ void CommonXSectView::Drop(PmContext& context)
 
         // Process a dataUnit
         MvRequest request = dropRequest.justOneRequest();
-        string verb       = request.getVerb();
+        std::string verb  = request.getVerb();
         if (ObjectList::IsDataUnit(verb.c_str()) == true) {
             // Call the service to process the request
 
@@ -160,17 +158,16 @@ void CommonXSectView::Drop(PmContext& context)
             // If returns false, it means that either:
             // a) this is a dataUnit and no need to be processed by a external service
             // b) error on processing the external service
-            if (!CallService(request, context, replyRequest)) {
+            if (!callServiceInternal(request, context, replyRequest)) {
                 // The external service sent an error message
                 if (replyRequest && strcmp(replyRequest.getVerb(), "ERROR") == 0) {
-                    string error_message;
+                    std::string error_message;
                     if ((const char*)replyRequest("MESSAGE"))
                         error_message = (const char*)replyRequest("MESSAGE");
                     else
                         error_message = "Error";
 
-                    PlotMod::Instance().MetviewError(error_message.c_str(), "Error");
-
+                    MvLog().popup().err() << error_message;
                     dropRequest.advance();
                     continue;
                 }
@@ -264,7 +261,7 @@ bool CommonXSectView::DropFromModule(MvRequest& dropRequest, MvRequest& replyReq
 
     // Process option A
     consistency_check = true;  // by default the consistency check returns true
-    if ((const char*)dropRequest.getVerb() == string("NETCDF")) {
+    if ((const char*)dropRequest.getVerb() == std::string("NETCDF")) {
         replyRequest = dropRequest.getSubrequest("_VISUALISE");
 
         // Consistency check
@@ -330,9 +327,9 @@ CommonXSectView::InsertDataRequest(MvRequest& dropRequest)
                 break;
         }
 
-        MvRequest req = dropRequest.justOneRequest();
-        string verb   = req.getVerb();
-        if (verb.find(NETCDF) != string::npos || verb.find("INPUT") != string::npos) {
+        MvRequest req    = dropRequest.justOneRequest();
+        std::string verb = req.getVerb();
+        if (verb.find(NETCDF) != std::string::npos || verb.find("INPUT") != std::string::npos) {
             // Insert the dataunit in the data base at the Page level
             //  request("_PARENT_DATAUNIT") = 1;
             MvIcon dataUnit = dataBase.InsertDataUnit(req, Owner().Id());
@@ -397,9 +394,9 @@ void CommonXSectView::Draw(SubPage* subPage)
     MvIconDataBase& dataBase = Owner().IconDataBase();
 
     // Get the data units for this subpage
-    list<DataObject*> doList;
+    std::list<DataObject*> doList;
     subPage->GetDataObjects(doList);
-    list<DataObject*>::iterator ii;
+    std::list<DataObject*>::iterator ii;
     DataObject* dataObject = 0;
     DrawPriorMap drawPriorMap;
     DrawPriorMap::iterator j;
@@ -427,8 +424,8 @@ void CommonXSectView::Draw(SubPage* subPage)
 
 #if 0
 void CommonXSectView::GenerateData(FILE *fp,int startIndex,double yMin,
-				   double yMax,vector<double> &xvector,
-				   vector<double> &yvector, int nrPoints, bool logax, bool modlev)
+				   double yMax,std::vector<double> &xvector,
+				   std::vector<double> &yvector, int nrPoints, bool logax, bool modlev)
 {
 
   int nrLevels = 85; // Hardcoded, same as in xsection application.
@@ -491,7 +488,7 @@ void CommonXSectView::GenerateData(FILE *fp,int startIndex,double yMin,
 	  fprintf(fp,"%e ", DONTCARE);
     }
 }
-bool CommonXSectView::CheckLatLon(const string& name,double minVal, double maxVal,
+bool CommonXSectView::CheckLatLon(const std::string& name,double minVal, double maxVal,
 				  MvRequest& axisRequest, const char *param)
 
 {
@@ -534,7 +531,7 @@ bool CommonXSectView::CheckLatLon(const string& name,double minVal, double maxVa
   return retVal;
 }
 
-bool CommonXSectView::FindPressure(vector<double> &yvector,double pk,int &firstindex,int &nextindex,int scale)
+bool CommonXSectView::FindPressure(std::vector<double> &yvector,double pk,int &firstindex,int &nextindex,int scale)
 {
   int i  = 0;
 
