@@ -16,6 +16,7 @@
 #include "MvLayer.h"
 #include "ObjectList.h"
 #include "PlotMod.h"
+#include "MvLog.h"
 
 DataObject::DataObject(int dataUnitId, long offset, long offset2,
                        const MvRequest& dataInfo) :
@@ -135,7 +136,7 @@ DataObject::DrawPriority(MvIconList& visdefList)
     Cached drawPrior = tmpDrawingPriority.DrawSegmentName(myDataUnitId_,
                                                           visRequest,
                                                           visDefId);
-    string dataString((const char*)drawPrior);
+    std::string dataString((const char*)drawPrior);
     pair<int, int> tmpPair(this->Id(), visDefId);
     drawPriorMap[dataString] = tmpPair;
 
@@ -168,7 +169,7 @@ DataObject::DrawPriority()
 
 #if 0
 // Don't attempt to get visdefs, they're given as input
-void DataObject::DrawVisDef(MvIcon& visDef, string& /* segmentName */)
+void DataObject::DrawVisDef(MvIcon& visDef, std::string& /* segmentName */)
 {
   // Retrieve the Graphics Engine
   GraphicsEngine& ge = this->GetGraphicsEngine();
@@ -178,7 +179,7 @@ void DataObject::DrawVisDef(MvIcon& visDef, string& /* segmentName */)
   MvIcon  dataUnit;
   if ( dataBase.RetrieveDataUnit (myDataUnitId_, dataUnit) == false)
     {
-      COUT << "DataObject::Draw() -> No Data Unit" << endl;
+      COUT << "DataObject::Draw() -> No Data Unit" << std::endl;
       return;
     }
 
@@ -198,7 +199,7 @@ void DataObject::DrawDataVisDef()
     // Retrieve the DataUnit
     MvIcon dataUnit;
     if (dataBase.RetrieveIconFromList(DB_DATAUNIT, myDataUnitId_, dataUnit) == false) {
-        PlotMod::Instance().MetviewError("uPlot DataObject::DrawDataVisDef-> No Data Unit", "Error");
+        MvLog().popup().err() << "uPlot DataObject::DrawDataVisDef-> No Data Unit";
         return;
     }
 
@@ -265,7 +266,7 @@ DataObject::EraseDraw( int visDefId )
       int visId = (*ii).first; 
       if ( visDefId && (visDefId != visId ) ) continue;
       
-      string dataString = (*ii).second;
+      std::string dataString = (*ii).second;
       
 //D      if ( canvas.RemoveForAll(myParent_->Id(),dataString) ) 
 	{
@@ -353,7 +354,7 @@ DataObject::SetTitle ( const MvRequest& treq )
 
 		// Save Text information related to Grib ('GRIB_TEXT_...')
 		MvRequest auxReq = rqst.getSubrequest("$METVIEW_TITLE_PACKAGE_1_REQUEST");
-                titleRequest_ = empty_request(NULL); 
+                titleRequest_ = empty_request(nullptr); 
                 CopySomeParameters (auxReq,titleRequest_,"GRIB_TEXT");
 	}
 	else if ( IsParameterSet ( rqst, "TEXT_LINE_1" ) )
@@ -434,7 +435,7 @@ void DataObject::SetTextOrigin(MvRequest& request)
 {
     // If TEXT_ORIGIN has already been set, return.
     if (IsParameterSet(request, "TEXT_ORIGIN")) {
-        string val = (const char*)request("TEXT_ORIGIN");
+        std::string val = (const char*)request("TEXT_ORIGIN");
         if (val != "NOTSET")
             return;
     }
@@ -505,8 +506,8 @@ DataObject::SetLegend ( const MvRequest& rqst )
 		Cached fileStoreName = Cached ( "METVIEW_LEGEND_STORE_FILE_" ) +
 				       nPackages;
 		Cached fileName = rqst ( fileStoreName );
-		string name = (const char *) fileName;
-		string typeName = (const char* ) rqst ("TYPE");
+        std::string name = (const char *) fileName;
+        std::string typeName = (const char* ) rqst ("TYPE");
 		legends_ [ typeName ] = LegendPackage ( name, values );
 	}
 }
@@ -519,13 +520,12 @@ bool DataObject::GetLegend(MvRequest& rqst, int* order)
         return false;
 
     if (legends_.size()) {
-        for (LegendsMap::iterator j = legends_.begin();
-             j != legends_.end(); ++j) {
+        for (auto& legend : legends_) {
             Cached titlePackageName = Cached("$METVIEW_LEGEND_PACKAGE_") +
                                       *order;
             rqst("$METVIEW_LEGEND_PACKAGE_COUNT") = *order;
 
-            LegendPackage legendPackage = (*j).second;
+            LegendPackage legendPackage = legend.second;
 
             rqst(titlePackageName) = (legendPackage.second)[0];
             for (unsigned int i = 1; i < (legendPackage.second).size(); i++)
@@ -546,7 +546,7 @@ bool DataObject::GetLegend(MvRequest& rqst, int* order)
 
 #if 0
 bool
-DataObject::RemoveLegend ( string name )
+DataObject::RemoveLegend ( std::string name )
 {
 	// Only one legend per data allowed
 	legends_.clear ();
@@ -643,7 +643,7 @@ void DataObject::DataUnit(MvIcon& dataUnit)
     // Retrieve the DataUnit
     //if (dataBase.RetrieveDataUnit (myDataUnitId_, dataUnit) == false)
     if (dataBase.RetrieveIconFromList(DB_DATAUNIT, myDataUnitId_, dataUnit) == false) {
-        PlotMod::Instance().MetviewError("uPlot DataObject::DataUnit-> No Data Unit", "Error");
+        MvLog().popup().err() << "uPlot DataObject::DataUnit-> No Data Unit";
         return;
     }
 }
@@ -656,17 +656,17 @@ void DataObject::DataUnit(MvIcon& dataUnit)
 void DataObject::UpdateVisDef(MvRequest dataUnit, MvIconList& iconList)
 {
     // Get application name without the prefix
-    string verb   = dataUnit.getVerb();
-    size_t ipos   = verb.find("_");
-    string sapp   = verb.substr(ipos + 1);
-    string prefix = verb.substr(0, ipos);
+    std::string verb   = dataUnit.getVerb();
+    size_t ipos        = verb.find("_");
+    std::string sapp   = verb.substr(ipos + 1);
+    std::string prefix = verb.substr(0, ipos);
 
     // Update visdef parameters only for the following applications
     if (sapp == "XY_POINTS" || sapp == "GEO_POINTS") {
         // Update only if parameter *_VALUES or *_VARIABLE_NAME is given
-        string param1 = prefix + "_VALUES";
-        string param2 = prefix + "_VARIABLE_NAME";
-        string param2Sval;
+        std::string param1 = prefix + "_VALUES";
+        std::string param2 = prefix + "_VARIABLE_NAME";
+        std::string param2Sval;
         if ((const char*)dataUnit(param2.c_str()))
             param2Sval = (const char*)dataUnit(param2.c_str());
 
@@ -685,9 +685,9 @@ void DataObject::UpdateVisDef(MvRequest dataUnit, MvIconList& iconList)
     }
     else if (sapp == "XY_VECTORS" || sapp == "GEO_VECTORS") {
         // Update only if parameter *_VALUES or *_VARIABLE_NAME is given
-        string param1 = prefix + "_VALUES";
-        string param2 = prefix + "_VARIABLE_NAME";
-        string param2Sval;
+        std::string param1 = prefix + "_VALUES";
+        std::string param2 = prefix + "_VARIABLE_NAME";
+        std::string param2Sval;
         if ((const char*)dataUnit(param2.c_str()))
             param2Sval = (const char*)dataUnit(param2.c_str());
 
