@@ -8,6 +8,7 @@
  ***************************** LICENSE END *************************************/
 
 #include <algorithm>
+#include <sstream>
 
 #include <QtGlobal>
 #include <QLabel>
@@ -38,7 +39,7 @@
 #include <QDebug>
 
 ExportDialog::ExportDialog(int currentFrame, int totalFrames,
-                           const string& sdir, bool export_qt,
+                           const std::string& sdir, bool export_qt,
                            QWidget* parent) :
     QFileDialog(parent, "Export"),
     current_(currentFrame),
@@ -62,19 +63,19 @@ ExportDialog::ExportDialog(int currentFrame, int totalFrames,
     if (!sdir.empty()) {
         QStringList lstr = path_fn.split(QLatin1Char('/'));
         if (sdir.back() == '/')
-            path_fn = QString(sdir.c_str()) + lstr[lstr.count()-1];
+            path_fn = QString(sdir.c_str()) + lstr[lstr.count() - 1];
         else
-            path_fn = QString(sdir.c_str()) + "/" + lstr[lstr.count()-1];
+            path_fn = QString(sdir.c_str()) + "/" + lstr[lstr.count() - 1];
     }
     selectFile(path_fn);
 
     int fIndex = settings.value("formatIndex").toInt();
 
-    std::vector<bool> frameSelRB;   // frame selection radio buttons
+    std::vector<bool> frameSelRB;  // frame selection radio buttons
     frameSelRB.push_back(settings.value("frameSelection1").toBool());
     frameSelRB.push_back(settings.value("frameSelection2").toBool());
     frameSelRB.push_back(settings.value("frameSelection3").toBool());
-    if (!frameSelRB[0] && !frameSelRB[1] && !frameSelRB[2]) // very first time
+    if (!frameSelRB[0] && !frameSelRB[1] && !frameSelRB[2])  // very first time
         frameSelRB[0] = true;
 
     QString frameSelLE = settings.value("lineEditor").toString();
@@ -89,12 +90,12 @@ ExportDialog::ExportDialog(int currentFrame, int totalFrames,
 #endif
 
     // Get the main layout
-    QGridLayout* mainLayout = static_cast<QGridLayout*>(layout());
-    int row                 = mainLayout->rowCount();
-    int col                 = mainLayout->columnCount();
+    auto* mainLayout = static_cast<QGridLayout*>(layout());
+    int row          = mainLayout->rowCount();
+    int col          = mainLayout->columnCount();
 
     // Build label for the Output format
-    QLabel* label = new QLabel(this);
+    auto* label = new QLabel(this);
     label->setText(tr("Output format:"));
     mainLayout->addWidget(label, row, 0);
 
@@ -125,7 +126,7 @@ ExportDialog::ExportDialog(int currentFrame, int totalFrames,
     bEdit_->setPopupMode(QToolButton::InstantPopup);
 
     // Buil a horizontal layout to hold the combobox and the toolbutton
-    QHBoxLayout* hb = new QHBoxLayout;
+    auto* hb = new QHBoxLayout;
     hb->addWidget(comboBox_);
     hb->addWidget(bEdit_);
     mainLayout->addLayout(hb, row, 1, 1, 1);
@@ -143,7 +144,7 @@ ExportDialog::ExportDialog(int currentFrame, int totalFrames,
     row++;
     QLayoutItem* liCancel = mainLayout->itemAtPosition(row - 3, col - 1);
     mainLayout->removeItem(liCancel);
-    QDialogButtonBox* bb = static_cast<QDialogButtonBox*>(liCancel->widget());
+    auto* bb = static_cast<QDialogButtonBox*>(liCancel->widget());
     bb->setOrientation(Qt::Horizontal);
     mainLayout->addItem(liCancel, row, col - 1);
 }
@@ -176,19 +177,19 @@ void ExportDialog::accept()
         return;
 
     // Get filename from the user interface
-    QStringList s   = selectedFiles();
-    string filename = s.at(0).toStdString();
+    QStringList s        = selectedFiles();
+    std::string filename = s.at(0).toStdString();
 
     // Get output format name from the user interface
-    string format = comboBox_->currentText().toStdString();
+    std::string format = comboBox_->currentText().toStdString();
 
     // Get the output format request from the Metview/Defaults directory.
     // If it does not exist, create a default request.
     // Get the output format verb name
     const char* verb = this->getFormatVerb(format);
     if (!verb) {
-        ostringstream info;
-        info << "Format name not found: " << format << ends;
+        std::ostringstream info;
+        info << "Format name not found: " << format << std::ends;
         errorMessage((const char*)info.str().c_str());
         QDialog::reject();
         return;
@@ -196,7 +197,7 @@ void ExportDialog::accept()
 
     // Read the selected output format request from the Metview/Defaults directory and expand it.
     reqOut_ = ObjectList::UserDefaultRequest(verb);
-    reqOut_ = ObjectList::ExpandRequest ( reqOut_, EXPAND_DEFAULTS );
+    reqOut_ = ObjectList::ExpandRequest(reqOut_, EXPAND_DEFAULTS);
 
     // Add output filename
     reqOut_("OUTPUT_NAME") = filename.c_str();
@@ -214,7 +215,7 @@ void ExportDialog::accept()
 void ExportDialog::slotEditFormat()
 {
     // Get short format name
-    string format = comboBox_->currentText().toStdString();
+    std::string format = comboBox_->currentText().toStdString();
 
     // Get output format request
     MvRequest reqFormat;
@@ -241,20 +242,20 @@ void ExportDialog::slotEditFormat()
     }
 
     // If it is a new default request, then remove characters '<' and '>'
-    string name = mbasename((const char*)reqOut("_NAME"));
+    std::string name = mbasename((const char*)reqOut("_NAME"));
     if (name[0] == '<')  // it is a default filename, remove the brackets
         name = name.substr(1, name.size() - 2);
 
     // Get the prefix path (METVIEW_USER_DIRECTORY) and check it againt the filename
-    string userDir    = GetUserDirectory();
-    string path       = mdirname((const char*)reqOut("_NAME"));
-    std::size_t found = path.find(userDir);
+    std::string userDir = GetUserDirectory();
+    std::string path    = mdirname((const char*)reqOut("_NAME"));
+    std::size_t found   = path.find(userDir);
     if (found != std::string::npos)
         path = path.substr(userDir.size());  // remove the prefix path
 
     // Compose the filename
-    string filename = path + '/' + name;
-    reqOut("_NAME") = filename.c_str();
+    std::string filename = path + '/' + name;
+    reqOut("_NAME")      = filename.c_str();
 
     // Call Metview user interface's editor
     CallGenAppService(*this, &ExportDialog::edited, reqOut);
@@ -282,10 +283,10 @@ void ExportDialog::buildFrameSelection(int row, int col,
                                        bool enabled)
 {
     // Group Box with radio buttons and one line edit
-    QGroupBox* gbFs = new QGroupBox(tr("Frame Selection"), this);
-    cbFs1_          = new QRadioButton(tr("&Current"), this);
-    cbFs2_          = new QRadioButton(tr("&All"), this);
-    cbFs3_          = new QRadioButton(tr("&Range"), this);
+    auto* gbFs = new QGroupBox(tr("Frame Selection"), this);
+    cbFs1_     = new QRadioButton(tr("&Current"), this);
+    cbFs2_     = new QRadioButton(tr("&All"), this);
+    cbFs3_     = new QRadioButton(tr("&Range"), this);
     cbFs1_->setChecked(frameSelRB[0]);
     cbFs2_->setChecked(frameSelRB[1]);
     cbFs3_->setChecked(frameSelRB[2]);
@@ -307,7 +308,7 @@ void ExportDialog::buildFrameSelection(int row, int col,
     cbFs3_->isChecked() ? leFs3_->setEnabled(true) : leFs3_->setEnabled(false);
 
     // Set layout
-    QGridLayout* glFs = new QGridLayout(gbFs);
+    auto* glFs = new QGridLayout(gbFs);
     glFs->addWidget(cbFs1_, 0, 0);
     glFs->addWidget(cbFs2_, 1, 0);
     glFs->addWidget(cbFs3_, 2, 0);
@@ -341,9 +342,9 @@ bool ExportDialog::getFrameSelection(MvRequest& req)
         // Get the list of range entries (split by comma)
         QStringList list1 = leFs3_->text().split(",",
 #if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-            Qt::SkipEmptyParts);
+                                                 Qt::SkipEmptyParts);
 #else
-            QString::SkipEmptyParts);
+                                                 QString::SkipEmptyParts);
 #endif
 
         // Analyse all entries
@@ -351,9 +352,9 @@ bool ExportDialog::getFrameSelection(MvRequest& req)
             // Check if it is a single value or a range of values
             QStringList list2 = list1.at(i).split("-",
 #if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-                Qt::SkipEmptyParts);
+                                                  Qt::SkipEmptyParts);
 #else
-                QString::SkipEmptyParts);
+                                                  QString::SkipEmptyParts);
 #endif
 
             if (list2.size() == 1)  // single value
@@ -375,8 +376,8 @@ bool ExportDialog::getFrameSelection(MvRequest& req)
         // Check if the range of values is valid
         std::sort(list.begin(), list.end());
         if (list.at(list.size() - 1) > total_) {
-            ostringstream info;
-            info << "Enter values from 1 to " << total_ << ends;
+            std::ostringstream info;
+            info << "Enter values from 1 to " << total_ << std::ends;
             errorMessage("Invalid range!", (const char*)info.str().c_str());
             return false;
         }
@@ -407,7 +408,7 @@ void ExportDialog::errorMessage(const char* msg, const char* info)
     msgBox.exec();
 }
 
-const char* ExportDialog::getFormatVerb(string shortName)
+const char* ExportDialog::getFormatVerb(std::string shortName)
 {
     reqFormats_.rewind();
     while (reqFormats_) {
