@@ -7,8 +7,10 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef ExportDialog_H
-#define ExportDialog_H
+#pragma once
+
+#include <string>
+#include <vector>
 
 #include <QComboBox>
 #include <QFileDialog>
@@ -19,18 +21,16 @@
 
 #include "MvRequest.h"
 
-using namespace std;
-
 class ExportDialog : public QFileDialog
 {
     Q_OBJECT
 
 public:
-    ExportDialog(int, int, const string&, bool, QWidget* parent = 0);
+    ExportDialog(int, int, const std::string&, bool, QWidget* parent = 0);
     ~ExportDialog();
 
     void edited(MvRequest&);
-    const MvRequest& reqOut() const {return reqOut_;}
+    const MvRequest& reqOut() const { return reqOut_; }
 
 public slots:
     void accept();
@@ -38,23 +38,21 @@ public slots:
     void slotRangeFrameSelection(bool);
 
 private:
-    const char* getFormatVerb(string);
+    const char* getFormatVerb(std::string);
     bool getFrameSelection(MvRequest&);
     void buildFrameSelection(int, int, QGridLayout*,
                              const std::vector<bool>&, const QString&, bool);
     void errorMessage(const char*, const char* = 0);
 
-    int current_;           // Current frame
-    int total_;             // Total number of frames
-    bool export_qt_{false}; // qt driver
-    MvRequest reqFormats_;  // list of output formats requests
-    QComboBox* comboBox_;   // List of output formats
-    QToolButton* bEdit_;    // Edit button
-    QLineEdit* leFs3_;      // Frame selection: line edit
-    QRadioButton* cbFs1_;   // Frame selection: Current radio button
-    QRadioButton* cbFs2_;   // Frame selection: All radio button
-    QRadioButton* cbFs3_;   // Frame selection: Range radio button
+    int current_;            // Current frame
+    int total_;              // Total number of frames
+    bool export_qt_{false};  // qt driver
+    MvRequest reqFormats_;   // list of output formats requests
+    QComboBox* comboBox_;    // List of output formats
+    QToolButton* bEdit_;     // Edit button
+    QLineEdit* leFs3_;       // Frame selection: line edit
+    QRadioButton* cbFs1_;    // Frame selection: Current radio button
+    QRadioButton* cbFs2_;    // Frame selection: All radio button
+    QRadioButton* cbFs3_;    // Frame selection: Range radio button
     MvRequest reqOut_;
 };
-
-#endif
