@@ -8,6 +8,9 @@
  ***************************** LICENSE END *************************************/
 
 #include "GeoToolManager.h"
+
+#include <iostream>
+
 #include <MvApplication.h>
 #include "MvServiceTask.h"
 
@@ -20,7 +23,7 @@ int main(int argc, char** argv)
                      (char*)"-debug", (char*)"1", t_boolean,
                      sizeof(boolean), OFFSET(globals, debug)};
 
-    MvApplication theApp(argc, argv, NULL, &mars, 1, opts);
+    MvApplication theApp(argc, argv, nullptr, &mars, 1, opts);
 
     GeoToolManager gt("EDIT_MAP");
 
@@ -41,13 +44,13 @@ GeoToolManager::GeoToolManager(const char* kw) :
 
 void GeoToolManager::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "GeoToolManager::serve in" << endl;
+    std::cout << "GeoToolManager::serve in" << std::endl;
     in.print();
 
     // Call function to process the request
     GeoToolService::Instance().CallGeoTool(in, out);
 
-    cout << "GeoToolManager::serve out" << endl;
+    std::cout << "GeoToolManager::serve out" << std::endl;
     out.print();
 
     return;
@@ -70,15 +73,9 @@ GeoToolService::Instance()
     return GeoToolServiceInstance_;
 }
 
-GeoToolService::GeoToolService()
-{
-    // Empty
-}
+GeoToolService::GeoToolService() = default;
 
-GeoToolService::~GeoToolService()
-{
-    // Empty
-}
+GeoToolService::~GeoToolService() = default;
 
 // --- METHOD:  CallGeoTool
 //
@@ -105,12 +102,11 @@ void GeoToolService::CallGeoTool(MvRequest& in, MvRequest& out)
     // Create a new task
     char* desktop = getenv("MV_DESKTOP_NAME");
     if (desktop == 0) {
-        cout << "GeoToolService-> Environmental variable MV_DESKTOP_NAME not defined" << endl;
-        ;
+        std::cout << "GeoToolService-> Environmental variable MV_DESKTOP_NAME not defined" << std::endl;
         return;
     }
 
-    string desktopName(desktop);
+    std::string desktopName(desktop);
     out("TARGET") = desktopName.c_str();
 
     // Start the approriate service
@@ -128,11 +124,11 @@ void GeoToolService::endOfTask(MvTask* task)
         //while ( msg = task->getMessage (i++ ) )
 
         //		PlotMod::MetviewError ( "uPlot crashed" );
-        //		COUT << "GeoTool crashed" << endl;
+        //		COUT << "GeoTool crashed" << std::endl;
     }
 
     // Retrieve the reply request
-    MvServiceTask* serviceTask = (MvServiceTask*)task;
+    auto* serviceTask = (MvServiceTask*)task;
 
     MvRequest replyRequest = serviceTask->getReply();
     replyRequest.print();
