@@ -13,11 +13,12 @@
 
 #include "MagPlusService.h"
 #include "MagicsTranslator.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "ObjectList.h"
 #include "PlotMod.h"
 #include "PlotModConst.h"
 #include "Path.h"
+#include "MvLog.h"
 
 // =========================================================
 //
@@ -111,10 +112,7 @@ MagicsTranslatorTraits::DefaultObject()
 //
 //  Methods for the MagicsTranslator class
 //
-MagicsTranslator::~MagicsTranslator()
-{
-    // Empty
-}
+MagicsTranslator::~MagicsTranslator() = default;
 
 //=================================================
 // GRIB Translator
@@ -218,7 +216,7 @@ ImageTranslator::Execute ( const MvRequest& dataUnitRequest,
 	MvRequest magicsRequest;
 	const char *dataIdent = dataInfoRequest ("IDENT");
 
-	require ( dataIdent != NULL );	// this is  an IMAGE
+	require ( dataIdent != nullptr );	// this is  an IMAGE
 
 	magicsRequest.setVerb("PGRIB");
 
@@ -412,7 +410,7 @@ PageTranslator::Execute(const MvRequest& viewRequest)
     // Set zoom definition
     if ((const char*)metviewRequest("_ZOOM_DEFINITION")) {
         MvRequest req;
-        string sjson = (const char*)metviewRequest("_ZOOM_DEFINITION");
+        std::string sjson = (const char*)metviewRequest("_ZOOM_DEFINITION");
         MagPlusService::Instance().decode(req, sjson);
 
         magicsRequest("SUBPAGE_LOWER_LEFT_LATITUDE")   = req("subpage_lower_left_latitude");
@@ -443,7 +441,7 @@ PageTranslator::Execute(const MvRequest& viewRequest)
 
     // Predefined areas
     bool predefArea = false;
-    if(const char* predef = metviewRequest("AREA_MODE")) {
+    if (const char* predef = metviewRequest("AREA_MODE")) {
         if (strcmp(predef, "NAME") == 0) {
             if (!predefAreas_) {
                 loadPredefAreas();
@@ -451,20 +449,20 @@ PageTranslator::Execute(const MvRequest& viewRequest)
 
             std::string str_name("europe");
             if (const char* predef_name = metviewRequest("AREA_NAME")) {
-               str_name = std::string(predef_name);
+                str_name = std::string(predef_name);
             }
 
-            if(!str_name.empty()) {
+            if (!str_name.empty()) {
                 metview::toLower(str_name);
                 MvRequest req = findPredefArea(str_name);
 
                 if (req) {
-                    magicsRequest("SUBPAGE_MAP_PROJECTION") =  req("subpage_map_projection");
+                    magicsRequest("SUBPAGE_MAP_PROJECTION")      = req("subpage_map_projection");
                     magicsRequest("SUBPAGE_MAP_AREA_DEFINITION") = "CORNERS";
-                    if (const char *chv = req("subpage_vertical_longitude")) {
+                    if (const char* chv = req("subpage_vertical_longitude")) {
                         magicsRequest("SUBPAGE_MAP_VERTICAL_LONGITUDE") = chv;
                     }
-                    if (const char *chv = req("subpage_map_hemisphere")) {
+                    if (const char* chv = req("subpage_map_hemisphere")) {
                         magicsRequest("SUBPAGE_MAP_HEMISPHERE") = chv;
                     }
 
@@ -476,8 +474,8 @@ PageTranslator::Execute(const MvRequest& viewRequest)
                         magicsRequest("SUBPAGE_UPPER_RIGHT_LONGITUDE") = req("subpage_upper_right_longitude");
                     }
                 }
-             }
-             predefArea = true;
+            }
+            predefArea = true;
         }
     }
 
@@ -492,7 +490,7 @@ PageTranslator::Execute(const MvRequest& viewRequest)
         MvRequest tmpReq;
         if (!projection) {
             tmpReq     = ObjectList::ExpandRequest(metviewRequest, EXPAND_DEFAULTS);
-            projection = tmpReq("MAP_PROJECTION");         
+            projection = tmpReq("MAP_PROJECTION");
         }
         if (projection) {
             // Temporary solution to draw cartesian view
@@ -534,8 +532,9 @@ PageTranslator::Execute(const MvRequest& viewRequest)
 
                 // Translate MAP to SUBPAGE_MAP parameters
                 CopySomeParameters(metviewRequest, magicsRequest, "MAP_", "SUBPAGE_MAP_");
-           }
-        } else {
+            }
+        }
+        else {
             // In case of a non MapView this parameter should be set
             magicsRequest("SUBPAGE_MAP_PROJECTION") = "NONE";
         }
@@ -546,12 +545,12 @@ PageTranslator::Execute(const MvRequest& viewRequest)
 
 void PageTranslator::loadPredefAreas()
 {
-     std::string fName = metview::etcDirFile("PredefinedAreaList");
-     Path fp(fName);
-     if (fp.exists()) {
-         predefAreas_.read(fName.c_str());
-     }
-     // TODO: print warning when file does not exsist
+    std::string fName = metview::etcDirFile("PredefinedAreaList");
+    Path fp(fName);
+    if (fp.exists()) {
+        predefAreas_.read(fName.c_str());
+    }
+    // TODO: print warning when file does not exsist
 }
 
 MvRequest PageTranslator::findPredefArea(const std::string& name)
@@ -562,7 +561,7 @@ MvRequest PageTranslator::findPredefArea(const std::string& name)
 
     MvRequest r = predefAreas_;
     do {
-        if(strcmp(r.getVerb(), name.c_str()) == 0) {
+        if (strcmp(r.getVerb(), name.c_str()) == 0) {
             return r;
         }
     } while (r.advance());
@@ -606,7 +605,7 @@ AxisTranslator::Execute(const MvRequest& metviewRequest)
 
     tmpRequest.rewind();
     while (tmpRequest) {
-        if (tmpRequest.getVerb() == string("PAXIS"))
+        if (tmpRequest.getVerb() == std::string("PAXIS"))
             magicsRequest = magicsRequest + tmpRequest.justOneRequest();
 
         tmpRequest.advance();
@@ -621,7 +620,7 @@ AxisTranslator::Execute(const MvRequest& metviewRequest)
 MvRequest
 GraphTranslator::Execute(const MvRequest& metviewRequest)
 {
-    ensure(metviewRequest.getVerb() == string("PGRAPH"));
+    ensure(metviewRequest.getVerb() == std::string("PGRAPH"));
 
     MvRequest magicsRequest("PGRAPH");
     CopyAndRemoveParameters(metviewRequest, magicsRequest, "LEGEND_ENTRY");
@@ -688,25 +687,26 @@ MWindTranslator::Execute(const MvRequest& metviewRequest)
     if (v == "DENSITY") {
         std::string dv;
         magRequest("WIND_THINNING_METHOD") = "AUTOMATIC";
-        if ((const char*) magRequest("WIND_DENSITY")) {
+        if ((const char*)magRequest("WIND_DENSITY")) {
             magRequest("WIND_THINNING_FACTOR") = magRequest("WIND_DENSITY");
-        } else {
+        }
+        else {
             magRequest("WIND_THINNING_FACTOR") = 5;
         }
         magRequest.unsetParam("WIND_DENSITY");
-    } else {
-        magRequest("WIND_THINNING_METHOD") = "USER";        
+    }
+    else {
+        magRequest("WIND_THINNING_METHOD") = "USER";
     }
 
     return magRequest;
 }
 
 
-
 MvRequest
 WindTranslator::Execute(const MvRequest& metviewRequest)
 {
-    ensure(metviewRequest.getVerb() == string("PWIND"));
+    ensure(metviewRequest.getVerb() == std::string("PWIND"));
 
     return metviewRequest;
 }
@@ -738,7 +738,7 @@ return magicsRequest;
 MvRequest
 SymbolTranslator::Execute(const MvRequest& visdefRequest)
 {
-    ensure(visdefRequest.getVerb() == string("PSYMB"));
+    ensure(visdefRequest.getVerb() == std::string("PSYMB"));
 
     // Copy request
     MvRequest magicsRequest("PSYMB");
@@ -761,7 +761,7 @@ GeopointsTranslator::Execute(const MvRequest& dataUnitRequest, const MvRequest&,
 
     const char* symbType  = psymb("SYMBOL_TYPE");
     const char* tableMode = psymb("SYMBOL_TABLE_MODE");
-    string type           = "NUMBER";
+    std::string type      = "NUMBER";
 
     // If SYMBOL_TYPE is set, use the value. If SYMBOL_TABLE_MODE is also
     // set, type needs to be number, whatever SYMBOL_TYPE is set to.
@@ -788,22 +788,23 @@ NetCDFTranslator::Execute(const MvRequest& dataUnitRequest, const MvRequest&, co
 {
     std::string plot_type = dataUnitRequest.getVerb();
 
-    if(plot_type == "NETCDF_GEO_MATRIX_VECTORS") {
-        MvRequest mag =  dataUnitRequest;
+    if (plot_type == "NETCDF_GEO_MATRIX_VECTORS") {
+        MvRequest mag = dataUnitRequest;
         mag.setVerb("NETCDF_GEO_MATRIX");
-        const char *ch =mag("NETCDF_VALUE_VARIABLE");
-        if(!ch || std::string(ch).empty()) {
-            if(const char *chx =mag("NETCDF_X_COMPONENT_VARIABLE")) {
+        const char* ch = mag("NETCDF_VALUE_VARIABLE");
+        if (!ch || std::string(ch).empty()) {
+            if (const char* chx = mag("NETCDF_X_COMPONENT_VARIABLE")) {
                 mag("NETCDF_VALUE_VARIABLE") = chx;
             }
         }
         return mag;
-    } else if(plot_type == "NETCDF_XY_MATRIX_VECTORS") {
-        MvRequest mag =  dataUnitRequest;
+    }
+    else if (plot_type == "NETCDF_XY_MATRIX_VECTORS") {
+        MvRequest mag = dataUnitRequest;
         mag.setVerb("NETCDF_XY_MATRIX");
-        const char *ch =mag("NETCDF_VALUE_VARIABLE");
-        if(!ch || std::string(ch).empty()) {
-            if(const char *chx =mag("NETCDF_X_COMPONENT_VARIABLE")) {
+        const char* ch = mag("NETCDF_VALUE_VARIABLE");
+        if (!ch || std::string(ch).empty()) {
+            if (const char* chx = mag("NETCDF_X_COMPONENT_VARIABLE")) {
                 mag("NETCDF_VALUE_VARIABLE") = chx;
             }
         }
@@ -873,11 +874,11 @@ ThermoTranslator::Execute(const MvRequest& visdefRequest, const MvRequest& duReq
 {
     // This is a very specific translator. The acceptable thermo data variables are:
     // t (temperature) and td (dewpoint)
-    ensure(visdefRequest.getVerb() == string("MTHERMO"));
+    ensure(visdefRequest.getVerb() == std::string("MTHERMO"));
     ensure((const char*)duRequest("NETCDF_X_VARIABLE"));
 
     // Get variable and make sure it is lower case
-    string svar = (const char*)duRequest("NETCDF_X_VARIABLE");
+    std::string svar = (const char*)duRequest("NETCDF_X_VARIABLE");
     std::transform(svar.begin(), svar.end(), svar.begin(), ::tolower);
 
     // Convert to Magics request
@@ -888,7 +889,7 @@ ThermoTranslator::Execute(const MvRequest& visdefRequest, const MvRequest& duReq
     // Convert remaining parameters accordingly.
     // There are a few MTHERMO parameters whose default values are different from
     // the equivalent MGRAPH parameters.
-    if (svar == string("t")) {
+    if (svar == std::string("t")) {
         CopySomeParameters(visdefRequest, magicsRequest, "THERMO_TEMPERATURE", "GRAPH");
 
         if (!(const char*)magicsRequest("GRAPH_LINE_COLOUR"))
@@ -902,7 +903,7 @@ ThermoTranslator::Execute(const MvRequest& visdefRequest, const MvRequest& duReq
         if (!(const char*)magicsRequest("GRAPH_MISSING_DATA_THICKNESS"))
             magicsRequest("GRAPH_MISSING_DATA_THICKNESS") = 8;
     }
-    else if (svar == string("td")) {
+    else if (svar == std::string("td")) {
         CopySomeParameters(visdefRequest, magicsRequest, "THERMO_DEWPOINT", "GRAPH");
 
         if (!(const char*)magicsRequest("GRAPH_LINE_STYLE"))
@@ -917,9 +918,7 @@ ThermoTranslator::Execute(const MvRequest& visdefRequest, const MvRequest& duReq
             magicsRequest("GRAPH_MISSING_DATA_THICKNESS") = 8;
     }
     else {
-        ostringstream oss;
-        oss << "uPlot ThermoTranslator::Execute-> NETCDF_X_VARIABLE not implemented: " << svar;
-        PlotMod::Instance().MetviewError(oss.str(), "Warning");
+        MvLog().popup().warn() << "uPlot ThermoTranslator::Execute-> NETCDF_X_VARIABLE not implemented: " << svar;
         return MvRequest("EMPTY");
     }
 
@@ -931,7 +930,7 @@ ThermoGridTranslator::Execute(const MvRequest& req)
 {
     assert(strcmp(req.getVerb(), "MTHERMOGRID") == 0);
     MvRequest magicsRequest = req;
-    const char* ch = magicsRequest("THERMO_GRID_LAYER_MODE");
+    const char* ch          = magicsRequest("THERMO_GRID_LAYER_MODE");
     if (ch) {
         magicsRequest.unsetParam("THERMO_GRID_LAYER_MODE");
     }
@@ -950,11 +949,11 @@ TableTranslator::Execute(const MvRequest& request)
         return request;
 
     // Get absolute path from the input request
-    string spath = ObjectInfo::ObjectFullPath(request);
+    std::string spath = ObjectInfo::ObjectFullPath(request);
 
     // Update input request
     MvRequest magicsRequest = request;
-    spath += "/" + string(path);
+    spath += "/" + std::string(path);
     magicsRequest("TABLE_FILENAME") = spath.c_str();
 
     return magicsRequest;
