@@ -37,8 +37,7 @@
 // .REFERENCES:
 //
 //
-#ifndef MagicsTranslator_H
-#define MagicsTranslator_H
+#pragma once
 
 #include <Prototype.hpp>
 #include <MvRequest.h>
@@ -497,13 +496,12 @@ public:
 
     ~ThermoGridTranslator() {}
 
-    MvRequest Execute(const MvRequest&, const MvRequest&) override {return MvRequest("EMPTY");}
+    MvRequest Execute(const MvRequest&, const MvRequest&) override { return MvRequest("EMPTY"); }
     MvRequest Execute(const MvRequest&) override;
-    MvRequest Execute(const MvRequest&, const MvRequest&, const MvRequest&) override {return MvRequest("EMPTY");}
+    MvRequest Execute(const MvRequest&, const MvRequest&, const MvRequest&) override { return MvRequest("EMPTY"); }
 };
 
 
-
 class TableTranslator : public MagicsTranslator
 {
 public:
@@ -524,5 +522,3 @@ public:
         return this->Execute(req);
     }
 };
-
-#endif
