@@ -26,6 +26,7 @@
 #include "MvDecoder.h"
 #include "PlotMod.h"
 #include "PlotModTask.h"
+#include "MvLog.h"
 
 class MapViewFactory : public PlotModViewFactory
 {
@@ -79,6 +80,7 @@ MapView::Name()
 // VisDefs are always after each DataUnit
 void MapView::Drop(PmContext& context)
 {
+    MvLog().dbg() << "MapView::Drop";
     MvIconDataBase& dataBase = Owner().IconDataBase();
 
     // Process the drop
@@ -118,7 +120,7 @@ void MapView::Drop(PmContext& context)
 
         // Update view (if applicable)
         if (ObjectList::IsView(verb) == true)
-            this->UpdateView(request);
+            this->UpdateViewWithReq(request);
 
         else if (ObjectList::IsVisDefCoastlines(verb))
             Owner().ProcessCoastlines(request, PlotMod::Instance().CalledFromMacro(), foundDU);
@@ -151,6 +153,8 @@ void MapView::Drop(PmContext& context)
                 Owner().RedrawIfWindow();
             }
         }
+        else if (ObjectList::IsWeatherSymbol(verb))
+            PlotMod::Instance().addWeatherSymbol(request);
         else
             Owner().InsertCommonIcons(request);
 
@@ -202,7 +206,7 @@ void MapView::DecodeDataUnit(MvIcon& dataUnit)
     // Build a new data decoder, which will provide information
     // about the data
     std::unique_ptr<Decoder> decoder(DecoderFactory::Make(dataUnit.Request()));
-    ensure(decoder.get() != 0);
+    ensure(decoder.get() != nullptr);
 
     // Inquire if this Page is empty
     bool empty = Owner().ChildHasData() ? false : true;
@@ -273,7 +277,7 @@ void MapView::DecodeDataUnit(MvIcon& dataUnit)
 
         const char* repres = decRequest("REPRES");
         if (ObjectList::IsImage(repres)) {
-            string myName = this->Name();
+            std::string myName = this->Name();
             if (myName != "Satellite") {
                 MvRequest ownerReq = Owner().Request();
 
@@ -323,10 +327,10 @@ void MapView::ConvertToSatellite(MvRequest& decRequest)
     newViewReq("SUBPAGE_MAP_GRID_ORIENTATION")  = decRequest("_IMAGE_MAP_GRID_ORIENTATION");
     newViewReq("SUBPAGE_MAP_CAMERA_ALTITUDE")   = decRequest("_IMAGE_MAP_CAMERA_ALTITUDE");
 
-    this->UpdateView(newViewReq);
+    this->UpdateViewWithReq(newViewReq);
 }
 
-void MapView::UpdateView(MvRequest& viewReq)
+void MapView::UpdateViewWithReq(MvRequest& viewReq)
 {
     // uPlot recognises that MapView and GeoView are basically the same thing
     if (ObjectList::IsGeographicalView(viewReq.getVerb())) {
@@ -357,9 +361,7 @@ void MapView::UpdateView(MvRequest& viewReq)
     }
     else {
         // Changing View is disabled at the moment
-        char text[128];
-        sprintf(text, "Changing View (%s to %s) is currently disabled", viewRequest_.getVerb(), viewReq.getVerb());
-        PlotMod::Instance().UserErrorMessage(text);
+        MvLog().popup().err() << "Changing View (" << viewRequest_.getVerb() << " to " << viewReq.getVerb() << ") is currently disabled";
     }
 }
 
@@ -398,8 +400,8 @@ void MapView::DrawBackground()
     GraphicsEngine& ge = Owner().GetGraphicsEngine();
     while (backList) {
         // Draw the layer info
-        MvRequest req    = backList.justOneRequest();
-        string icon_name = (const char*)req("_NAME") ? mbasename((const char*)req("_NAME")) : "<coastlines>";
+        MvRequest req         = backList.justOneRequest();
+        std::string icon_name = (const char*)req("_NAME") ? mbasename((const char*)req("_NAME")) : "<coastlines>";
         Owner().DrawLayerInfo((int)req("_ID"), icon_name.c_str());
 
         // Ask the graphics engine to draw the coastlines
@@ -420,8 +422,8 @@ void MapView::DrawForeground()
     GraphicsEngine& ge = Owner().GetGraphicsEngine();
     while (foreList) {
         // Draw the layer info
-        MvRequest req    = foreList.justOneRequest();
-        string icon_name = (const char*)req("_NAME") ? mbasename((const char*)req("_NAME")) : "<coastlines>";
+        MvRequest req         = foreList.justOneRequest();
+        std::string icon_name = (const char*)req("_NAME") ? mbasename((const char*)req("_NAME")) : "<coastlines>";
         Owner().DrawLayerInfo((int)req("_ID"), icon_name.c_str());
 
         // Ask the graphics engine to draw the coastlines
@@ -443,7 +445,7 @@ void MapView::DescribeYourself(ObjectInfo& description)
     // Translate json zoom definition to a Magics request
     if ((const char*)tmpRequest("_ZOOM_DEFINITION")) {
         MvRequest req;
-        string sjson = (const char*)tmpRequest("_ZOOM_DEFINITION");
+        std::string sjson = (const char*)tmpRequest("_ZOOM_DEFINITION");
         MagPlusService::Instance().decode(req, sjson);
 
         // in zoom mode we cannot have these params
@@ -464,9 +466,9 @@ void MapView::DescribeYourself(ObjectInfo& description)
     }
 
     // Convert my request to macro
-    string defView = DEFAULTVIEW;
+    std::string defView = DEFAULTVIEW;
     std::transform(defView.begin(), defView.end(), defView.begin(), ::tolower);
-    set<Cached> skipSet;
+    std::set<Cached> skipSet;
     description.ConvertRequestToMacro(tmpRequest, PUT_END, MacroName().c_str(), defView.c_str(), skipSet);
 }
 
@@ -476,7 +478,7 @@ bool MapView::CallService(const MvRequest& req, PmContext& context)
     appRequest("_CONTEXT") = viewRequest_;
 
     // Find service name
-    string service = ObjectList::FindService(appRequest.getVerb(), "visualise");
+    std::string service = ObjectList::FindService(appRequest.getVerb(), "visualise");
 
     // Call service
     if (service.size()) {
@@ -484,7 +486,7 @@ bool MapView::CallService(const MvRequest& req, PmContext& context)
         return true;
     }
     else {
-        PlotMod::Instance().MetviewError("uPlot MapView::CallService-> Service name not found", "Error");
+        MvLog().popup().err() << "uPlot MapView::CallService-> Service name not found";
         return false;
     }
 }
