@@ -21,10 +21,12 @@
 //  and a m:n relation between a DataUnit and a VisDef
 //
 //
+#include "MvIconDataBase.h"
+
+#include <iostream>
+
 #include <Assertions.hpp>
 #include <MvPath.hpp>
-
-#include "MvIconDataBase.h"
 #include "MvLayer.h"
 #include "MvRequestUtil.hpp"
 #include "PlotModConst.h"
@@ -121,7 +123,7 @@ bool MvIconDataBase::RemoveAllVisDefsByDataUnit(MvIcon& theDataUnit, const MvReq
 {
     bool found = false;
 
-    MvRelationCursor duvdCursor = dataUnitVisDefRelation_.begin();
+    auto duvdCursor = dataUnitVisDefRelation_.begin();
     MvRelationCursor foundCursor;
 
     MvIcon currentDataUnit;
@@ -180,7 +182,7 @@ void MvIconDataBase::RemoveDataUnit(const int presentableId)
     RetrieveIcon(PRES_DATAUNIT_REL, presentableId, dataUnitList);
 
     // Remove DataUnits
-    MvListCursor duListCursor = dataUnitList.begin();
+    auto duListCursor = dataUnitList.begin();
     while (duListCursor != dataUnitList.end()) {
         RemoveDataUnit(*duListCursor);
         ++duListCursor;
@@ -190,7 +192,7 @@ void MvIconDataBase::RemoveDataUnit(const int presentableId)
 void MvIconDataBase::RemoveDataUnit()
 {
     // Remove all DataUnits
-    MvListCursor duListCursor = dataunitList_.begin();
+    auto duListCursor = dataunitList_.begin();
     MvListCursor foundCursor;
 
     while (duListCursor != dataunitList_.end()) {
@@ -214,7 +216,7 @@ bool MvIconDataBase::RemoveAllDataUnitsFromPresRel(MvIcon& theDataUnit)
 {
     bool found = false;
 
-    MvRelationCursor prduCursor = presentableDataUnitRelation_.begin();
+    auto prduCursor = presentableDataUnitRelation_.begin();
     MvRelationCursor foundCursor;
 
     MvIcon currentDataUnit;
@@ -246,7 +248,7 @@ bool MvIconDataBase::RemoveDataUnitFromPresRel(MvIcon& theDataUnit, int presenta
 {
     bool found = false;
 
-    MvRelationCursor prduCursor = presentableDataUnitRelation_.begin();
+    auto prduCursor = presentableDataUnitRelation_.begin();
     MvRelationCursor foundCursor;
 
     MvIcon currentDataUnit;
@@ -286,7 +288,7 @@ void MvIconDataBase::RemoveVisDef(const int presentableId, const MvRequest* vd)
 
 void MvIconDataBase::RemoveVisDefFromPresRel(const int presentableId, const MvRequest* vd)
 {
-    MvRelationCursor prvdCursor = presentableVisDefRelation_.begin();
+    auto prvdCursor = presentableVisDefRelation_.begin();
     MvRelationCursor foundCursor;
 
     while (prvdCursor != presentableVisDefRelation_.end()) {
@@ -323,7 +325,7 @@ void MvIconDataBase::RemoveVisDef()
     bool found;
 
     // Remove all VisDefs
-    MvListCursor vdListCursor = visdefList_.begin();
+    auto vdListCursor = visdefList_.begin();
     MvListCursor foundCursor;
     while (vdListCursor != visdefList_.end()) {
         // Keep a copy of the found iterator
@@ -347,7 +349,7 @@ void MvIconDataBase::RemoveVisDef()
 
 void MvIconDataBase::RemoveAllVisDefsByDataUnitList(MvIconList& dataUnitList, const MvRequest* vd)
 {
-    MvListCursor duListCursor = dataUnitList.begin();
+    auto duListCursor = dataUnitList.begin();
     MvIcon theDataUnit;
 
     while (duListCursor != dataUnitList.end()) {
@@ -585,7 +587,7 @@ int MvIconDataBase::IconInfo(int iconId, const char* param)
 bool MvIconDataBase::RetrieveIconFromLayer(int layerId, MvIcon& icon)
 {
     // Find the unique icon associated to the input layer
-    MvRelationCursor relCursor = iconLayerRelation_.begin();
+    auto relCursor = iconLayerRelation_.begin();
     while (relCursor != iconLayerRelation_.end()) {
         // Icon has a unique id; find the one on the list
         if ((*relCursor).second == layerId) {
@@ -628,54 +630,54 @@ void MvIconDataBase::RemovePresentable(const int presentableId)
 void MvIconDataBase::Print()
 {
     // Print lists
-    cout << "MvIconDataBase Contents" << endl;
-    string mlist[DB_COUNT__] = {"DB_DATAUNIT", "DB_VISDEF", "DB_TEXT", "DB_LEGEND", "DB_LAYER", "DB_IMPORT", "DB_VIEW"};
+    std::cout << "MvIconDataBase Contents" << std::endl;
+    std::string mlist[DB_COUNT__] = {"DB_DATAUNIT", "DB_VISDEF", "DB_TEXT", "DB_LEGEND", "DB_LAYER", "DB_IMPORT", "DB_VIEW"};
     for (unsigned int i = 0; i < DB_COUNT__; i++) {
-        cout << mlist[i] << endl;
+        std::cout << mlist[i] << std::endl;
         MvIconList* iconList = this->IconList(i);
-        MvListCursor lCursor = iconList->begin();
+        auto lCursor         = iconList->begin();
         while (lCursor != iconList->end()) {
-            cout << " " << (*lCursor).Id();
+            std::cout << " " << (*lCursor).Id();
             ++lCursor;
         }
-        cout << " " << endl;
+        std::cout << " " << std::endl;
     }
 
     // Print relations
-    cout << " " << endl;
-    string mrel[REL_COUNT__] = {"PRES_DATAUNIT_REL", "PRES_VISDEF_REL", "PRES_TEXT_REL", "PRES_LEGEND_REL", "PRES_IMPORT_REL", "PRES_VIEW_REL", "PRES_LAYER_REL", "DATAUNIT_VISDEF_REL", "ICON_LAYER_REL"};
+    std::cout << " " << std::endl;
+    std::string mrel[REL_COUNT__] = {"PRES_DATAUNIT_REL", "PRES_VISDEF_REL", "PRES_TEXT_REL", "PRES_LEGEND_REL", "PRES_IMPORT_REL", "PRES_VIEW_REL", "PRES_LAYER_REL", "DATAUNIT_VISDEF_REL", "ICON_LAYER_REL"};
     for (unsigned int i = 0; i < REL_COUNT__; i++) {
         if (i == PRES_LAYER_REL)  // print this 'special' relation later
             continue;
 
-        cout << mrel[i] << endl;
-        MvRelation* rel          = this->IconRelation(i);
-        MvRelationCursor rCursor = rel->begin();
+        std::cout << mrel[i] << std::endl;
+        MvRelation* rel = this->IconRelation(i);
+        auto rCursor    = rel->begin();
         while (rCursor != rel->end()) {
-            cout << " " << (*rCursor).first;
-            cout << " " << (*rCursor).second << endl;
+            std::cout << " " << (*rCursor).first;
+            std::cout << " " << (*rCursor).second << std::endl;
             ++rCursor;
         }
-        cout << " " << endl;
+        std::cout << " " << std::endl;
     }
 
     // Print Presentable-Layer relation
-    cout << mrel[PRES_LAYER_REL] << endl;
-    MvMapRelationCursor mCursor = presentableLayerRelation_.begin();
+    std::cout << mrel[PRES_LAYER_REL] << std::endl;
+    auto mCursor = presentableLayerRelation_.begin();
     while (mCursor != presentableLayerRelation_.end()) {
-        cout << " " << (*mCursor).first;
-        MvIconList iconList     = (*mCursor).second;
-        MvListCursor listCursor = iconList.begin();
+        std::cout << " " << (*mCursor).first;
+        MvIconList iconList = (*mCursor).second;
+        auto listCursor     = iconList.begin();
         while (listCursor != iconList.end()) {
             MvIcon tmpIcon = *listCursor;
-            cout << tmpIcon.Id();
+            std::cout << tmpIcon.Id();
             ++listCursor;
         }
-        cout << endl;
+        std::cout << std::endl;
         ++mCursor;
     }
 
-    cout << " " << endl;
+    std::cout << " " << std::endl;
 }
 
 bool MvIconDataBase::InsertIfNew(MvIcon& icon, MvIconList& list,
@@ -697,8 +699,8 @@ bool MvIconDataBase::InsertIfNew(MvIcon& icon, MvIconList& list,
     }
 
     // Loop through the list to find a match
-    bool found      = false;
-    MvListCursor ii = list.begin();
+    bool found = false;
+    auto ii    = list.begin();
     for (; ii != list.end(); ii++) {
         MvIcon currentIcon       = *ii;
         MvRequest currentRequest = currentIcon.Request();
@@ -741,8 +743,8 @@ void MvIconDataBase::RelationInsertIfNew(MvRelation& relation,
 bool MvIconDataBase::ExistsInRelation(MvRelation& relation, const int firstId, const int secondId)
 {
     // Check if this key and value is already there
-    MvRelationCursor lower_ii = relation.lower_bound(firstId);
-    MvRelationCursor upper_ii = relation.upper_bound(firstId);
+    auto lower_ii = relation.lower_bound(firstId);
+    auto upper_ii = relation.upper_bound(firstId);
 
     bool found = false;
     while (lower_ii != relation.end() && lower_ii != upper_ii) {
@@ -768,8 +770,8 @@ void MvIconDataBase::CreateLink(MvRequest& req)
     if (createLink && strcmp(createLink, "NO") == 0)
         return;
 
-    string spath = (const char*)mpath;
-    string slink = tempnam(getenv("METVIEW_TMPDIR"), "link");
+    std::string spath = (const char*)mpath;
+    std::string slink = tempnam(getenv("METVIEW_TMPDIR"), "link");
 
     if (symlink(spath.c_str(), slink.c_str()) != 0)  //-- create a soft link
     {
@@ -806,10 +808,10 @@ void MvIconDataBase::CreateLink(MvRequest& req)
 
 void MvIconDataBase::DeleteLink()
 {
-    list<string>::iterator listIter = linkList_.begin();
+    auto listIter = linkList_.begin();
 
     while (listIter != linkList_.end()) {
-        string mpath = (*listIter);
+        std::string mpath = (*listIter);
         if (unlink(mpath.c_str()))
             marslog(LOG_WARN, (char*)"MvIconDataBase::DeleteLink : Error : Try to unlink a non existing file : %s", mpath.c_str());
 
@@ -842,7 +844,7 @@ MvRelation* MvIconDataBase::IconRelation(const int iconType)
         return &presentableViewRelation_;
     else {
         marslog(LOG_WARN, (char*)"Wrong type value for Icon Relation: %d", iconType);
-        return NULL;
+        return nullptr;
     }
 }
 
@@ -865,7 +867,7 @@ MvIconList* MvIconDataBase::IconList(const int iconType)
         return &viewList_;
     else {
         marslog(LOG_WARN, (char*)"Wrong type value for Icon List: %d", iconType);
-        return NULL;
+        return nullptr;
     }
 }
 
@@ -928,8 +930,8 @@ void MvIconDataBase::InsertLayerIcon(const int presId, MvIcon& layer, int index)
         else if (index > size)
             layerList.push_back(layer);
         else if (index < 0) {
-            bool found      = false;
-            MvListCursor it = layerList.end();
+            bool found = false;
+            auto it    = layerList.end();
             for (int i = size; i != 0; --i) {
                 --it;
                 if (this->LayerStackingOrder((*it).Id()) != 999) {
@@ -942,7 +944,7 @@ void MvIconDataBase::InsertLayerIcon(const int presId, MvIcon& layer, int index)
                 layerList.push_front(layer);
         }
         else {
-            MvListCursor it = layerList.begin();
+            auto it = layerList.begin();
             for (int i = 1; i < index; i++)
                 ++it;
             layerList.insert(it, layer);
@@ -968,7 +970,7 @@ void MvIconDataBase::InsertIcon(const int iconRelType, const int iconRelId, MvIc
             // this->RemoveIcon(iconRelType,iconRelId);
 
             // Scan list of icons checking icons with same Class
-            MvListCursor listCursor = iconList.begin();
+            auto listCursor = iconList.begin();
             while (listCursor != iconList.end()) {
                 MvIcon tmpIcon      = *listCursor;
                 const char* iclass1 = tmpIcon.Request()("_CLASS");
@@ -982,7 +984,7 @@ void MvIconDataBase::InsertIcon(const int iconRelType, const int iconRelId, MvIc
         }
         else {
             // Scan list of icons to check if icon already exists
-            MvListCursor listCursor = iconList.begin();
+            auto listCursor = iconList.begin();
             while (listCursor != iconList.end()) {
                 MvIcon tmpIcon = *listCursor;
                 if (tmpIcon == icon) {
@@ -1021,8 +1023,8 @@ void MvIconDataBase::InsertIcon(const int iconType, const MvIcon& icon, int inde
     else if (index > size)
         list->push_back(icon);
     else if (index < 0) {
-        bool found      = false;
-        MvListCursor it = list->end();
+        bool found = false;
+        auto it    = list->end();
         for (int i = size; i != 0; --i) {
             --it;
             if (this->IconStackingOrder((*it).Id()) != 999) {
@@ -1035,7 +1037,7 @@ void MvIconDataBase::InsertIcon(const int iconType, const MvIcon& icon, int inde
             list->push_front(icon);
     }
     else {
-        MvListCursor it = list->begin();
+        auto it = list->begin();
         for (int i = 1; i < index; i++)
             ++it;
         list->insert(it, icon);
@@ -1061,7 +1063,7 @@ void MvIconDataBase::InsertIconText(const int iconRelId, MvIcon& icon, int index
     MvIconList iconList;
     if (this->RetrieveIcon(iconRelType, iconRelId, iconList)) {
         // Find the icon on the list that is Text-Title
-        MvListCursor listCursor = iconList.begin();
+        auto listCursor = iconList.begin();
         while (listCursor != iconList.end()) {
             MvIcon tmpIcon       = *listCursor;
             MvRequest tmpRequest = tmpIcon.Request();
@@ -1115,7 +1117,7 @@ bool MvIconDataBase::RetrieveIcon(const int iconRelType, const int relId, MvIcon
     int iconType = IconType(iconRelType);
 
     // Loop through the database and find the unique Layer associated to the Icon
-    MvRelationCursor relCursor = iconRelation->begin();
+    auto relCursor = iconRelation->begin();
     while (relCursor != iconRelation->end()) {
         // Icon has a unique id; find the one on the list
         if ((*relCursor).first == relId) {
@@ -1140,7 +1142,7 @@ int MvIconDataBase::RetrieveIcon(const int iconRelType, const int iconRelId, MvI
     int iconType = IconType(iconRelType);
 
     // Loop through the database and find all icons associated to the Presentable
-    MvRelationCursor relCursor = iconRelation->begin();
+    auto relCursor = iconRelation->begin();
     while (relCursor != iconRelation->end()) {
         // Find the Presentable
         if ((*relCursor).first == iconRelId) {
@@ -1166,7 +1168,7 @@ bool MvIconDataBase::RetrieveIconFromList(const int iconType, const int iconId,
     MvIconList* iconList = this->IconList(iconType);
 
     // Icons have a unique id; find the one on the list
-    MvListCursor listCursor = iconList->begin();
+    auto listCursor = iconList->begin();
     while (listCursor != iconList->end()) {
         if ((*listCursor).Id() == iconId) {
             theIcon = *listCursor;
@@ -1177,7 +1179,7 @@ bool MvIconDataBase::RetrieveIconFromList(const int iconType, const int iconId,
     return false;
 }
 
-int MvIconDataBase::RetrieveIcon1(const int ii, MvIconList& iconList)
+int MvIconDataBase::RetrieveIcon1(const int /*ii*/, MvIconList& /*iconList*/)
 {
     return 1;
 }
@@ -1204,7 +1206,7 @@ bool MvIconDataBase::CheckIcon(const int iconRelType, const int relId)
     MvRelation* iconRelation = this->IconRelation(iconRelType);
 
     // Loop through the database and find the unique Layer associated to the Icon
-    MvRelationCursor relCursor = iconRelation->begin();
+    auto relCursor = iconRelation->begin();
     while (relCursor != iconRelation->end()) {
         // Icon has a unique id; find the one on the list
         if ((*relCursor).first == relId)
@@ -1294,7 +1296,7 @@ void MvIconDataBase::RemoveIcon(const int iconRelType, const int iconRelId, cons
     bool deleteOne = (iconIdIn >= 0) ? true : false;
 
     // Loop through the database and find all icons associated to the Relation icon
-    MvRelationCursor relCursor = iconRelation->begin();
+    auto relCursor = iconRelation->begin();
     MvRelationCursor foundCursor;
     while (relCursor != iconRelation->end()) {
         if ((*relCursor).first == iconRelId) {
@@ -1348,7 +1350,7 @@ bool MvIconDataBase::RemoveIconFromRel(const int iconRelType, const int iconId)
     MvRelation* iconRelation = this->IconRelation(iconRelType);
 
     // Loop through the database and find all icons associated to the Relation icon
-    MvRelationCursor relCursor = iconRelation->begin();
+    auto relCursor = iconRelation->begin();
     MvRelationCursor foundCursor;
     while (relCursor != iconRelation->end()) {
         if ((*relCursor).second == iconId) {
@@ -1378,7 +1380,7 @@ bool MvIconDataBase::UpdateIcon(const int iconType, const int iconId, const MvRe
     MvIconList* iconList = this->IconList(iconType);
 
     // Icons have a unique id; find the one on the list
-    MvListCursor listCursor = iconList->begin();
+    auto listCursor = iconList->begin();
     while (listCursor != iconList->end()) {
         if ((*listCursor).Id() == iconId) {
             (*listCursor).SaveRequest(iconRequest);
@@ -1397,12 +1399,12 @@ bool MvIconDataBase::UpdateIcon(const int iconId, MvRequest& iconRequest)
     // Find the correspondent icon list
     int iconType         = this->FindIconTypeId(iconId);
     MvIconList* iconList = this->IconList(iconType);
-    if (iconList == NULL)
+    if (iconList == nullptr)
         return false;
 
     // Icons have a unique id.
     // Find the one on the list and update its request
-    MvListCursor listCursor = iconList->begin();
+    auto listCursor = iconList->begin();
     while (listCursor != iconList->end()) {
         if ((*listCursor).Id() == iconId) {
             // Save the ID value to the new request
@@ -1421,7 +1423,7 @@ int MvIconDataBase::FindIconTypeId(int id)
     // Loop over all icon list types
     for (int i = 0; i < DB_COUNT__; i++) {
         MvIconList* iconList = this->IconList(i);
-        MvListCursor lCursor = iconList->begin();
+        auto lCursor         = iconList->begin();
         while (lCursor != iconList->end()) {
             if (id == (*lCursor).Id())
                 return i;
@@ -1438,7 +1440,7 @@ bool MvIconDataBase::FindIcon(int id, MvIcon& icon)
     // Loop over all icon list types
     for (unsigned int i = 0; i < DB_COUNT__; i++) {
         MvIconList* iconList = this->IconList(i);
-        MvListCursor lCursor = iconList->begin();
+        auto lCursor         = iconList->begin();
         while (lCursor != iconList->end()) {
             if (id == (*lCursor).Id()) {
                 icon = *lCursor;
@@ -1452,12 +1454,12 @@ bool MvIconDataBase::FindIcon(int id, MvIcon& icon)
     return false;
 }
 
-bool MvIconDataBase::FindIcon(const string& name, MvIcon& icon)
+bool MvIconDataBase::FindIcon(const std::string& name, MvIcon& icon)
 {
     // Loop over all icon list types
     for (unsigned int i = 0; i < DB_COUNT__; i++) {
         MvIconList* iconList = this->IconList(i);
-        MvListCursor lCursor = iconList->begin();
+        auto lCursor         = iconList->begin();
         while (lCursor != iconList->end()) {
             if (name == (*lCursor).IconName()) {
                 icon = *lCursor;
@@ -1478,8 +1480,8 @@ int MvIconDataBase::FindPresentableId(int iconId, int& dataUnitId)
         if (i == PRES_LAYER_REL)  // ignore this 'special' relation
             continue;
 
-        MvRelation* rel          = this->IconRelation(i);
-        MvRelationCursor rCursor = rel->begin();
+        MvRelation* rel = this->IconRelation(i);
+        auto rCursor    = rel->begin();
         while (rCursor != rel->end()) {
             if (iconId == (*rCursor).second)
                 return (*rCursor).first;
@@ -1495,7 +1497,7 @@ int MvIconDataBase::FindPresentableId(int iconId, int& dataUnitId)
     // Find the dataunit associated to this visdef
     bool found = false;
     int duId;
-    MvRelationCursor relCursor = dataUnitVisDefRelation_.begin();
+    auto relCursor = dataUnitVisDefRelation_.begin();
     while (relCursor != dataUnitVisDefRelation_.end()) {
         // Icon has a unique id; find the one on the list
         if ((*relCursor).second == iconId) {
