@@ -32,9 +32,9 @@ MvQLayerContentsIcon::MvQLayerContentsIcon(const QString& path, const QString& t
     isData_(false)
 {
     // Initialise first variables
-    path_ = path;
-    type_ = type;
-    id_   = id;
+    path_            = path;
+    type_            = type;
+    id_              = id;
     calledFromMacro_ = fromMacro;
 
     //qDebug() << "Constructor MvQLayerContentsIcon " << path_ << type_ << id_;
@@ -44,7 +44,7 @@ MvQLayerContentsIcon::MvQLayerContentsIcon(const QString& path, const QString& t
         name_ = lst.last();
 
     // Get the pixmap full path&name and update the interface
-    string fullName = this->getPixmapPath(type_.toStdString());
+    std::string fullName = this->getPixmapPath(type_.toStdString());
     if (!fullName.empty()) {
         std::size_t found = fullName.find_last_of(".");
         if (found != std::string::npos) {
@@ -60,7 +60,7 @@ MvQLayerContentsIcon::MvQLayerContentsIcon(const QString& path, const QString& t
     // Icon in this format, <icon_name> , means that this icon is a default
     // icon and it does not exist in directory ~/System/Defaults (Metview
     // icons default directory). Therefore, it can not be saved.
-    string sclass = type_.toStdString();
+    std::string sclass = type_.toStdString();
     if (ObjectList::IsDataUnit(sclass.c_str())) {
         canBeDeleted_ = true;
         canBeEdited_  = false;
@@ -100,22 +100,19 @@ MvQLayerContentsIcon::MvQLayerContentsIcon(const QString& path, const QString& t
     }
 
     // If an icon came from a Macro then it can not be edited
-    if ( calledFromMacro_ )
+    if (calledFromMacro_)
         canBeSaved_ = false;
 }
 
-MvQLayerContentsIcon::~MvQLayerContentsIcon()
-{
-    //   qDebug() << "deleting " << path_;
-}
+MvQLayerContentsIcon::~MvQLayerContentsIcon() = default;
 
 MvQLayerContentsIcon& MvQLayerContentsIcon::operator=(const MvQLayerContentsIcon& icon)
 {
-    path_ = icon.path_;
-    type_ = icon.type_;
-    id_   = icon.id_;
-    name_ = icon.name_;
-    pix_  = icon.pix_;
+    path_            = icon.path_;
+    type_            = icon.type_;
+    id_              = icon.id_;
+    name_            = icon.name_;
+    pix_             = icon.pix_;
     calledFromMacro_ = icon.calledFromMacro_;
 
     canBeDeleted_ = icon.canBeDeleted_;
@@ -158,13 +155,13 @@ void MvQLayerContentsIcon::startEditor()
 
     // Add parameter indicating the name of the uPlot Temporary Directory.
     // This will be used by the Desktop  Editor
-    MvRequest req   = mvIcon.Request();
-    string uTempDir = uPlotBase::tempDir();
+    MvRequest req        = mvIcon.Request();
+    std::string uTempDir = uPlotBase::tempDir();
     if (uTempDir[uTempDir.size() - 1] == '/')  // remove last '/'
         uTempDir = uTempDir.substr(0, uTempDir.size() - 1);
 
     std::size_t ipos       = uTempDir.find_last_of("/");
-    string uTempName       = (ipos != std::string::npos) ? uTempDir.substr(ipos + 1) : uTempDir;
+    std::string uTempName  = (ipos != std::string::npos) ? uTempDir.substr(ipos + 1) : uTempDir;
     req("_UPLOT_TEMP_DIR") = uTempName.c_str();
 
     // Save information stored in the hidden parameters because, after this
@@ -183,13 +180,13 @@ void MvQLayerContentsIcon::startEditor()
     // The Desktop editor will use this temporary file.
     if (!(const char*)req("_CONTENTS_ICON_EDITED")) {
         // Get full filename to be edited (temporary directory + filename)
-        string fname = uPlotBase::tempDir() + name_.toStdString();
+        std::string fname = uPlotBase::tempDir() + name_.toStdString();
 
         // Parameter _NAME is the full filename without the Metview user directory
-        string userDir   = GetUserDirectory();  // Metview user directory
-        std::size_t ipos = fname.find(userDir);
-        ipos             = (ipos != std::string::npos) ? ipos + userDir.size() : 0;
-        req("_NAME")     = fname.substr(ipos).c_str();
+        std::string userDir = GetUserDirectory();  // Metview user directory
+        std::size_t ipos    = fname.find(userDir);
+        ipos                = (ipos != std::string::npos) ? ipos + userDir.size() : 0;
+        req("_NAME")        = fname.substr(ipos).c_str();
 
         // If this is a default icon then remove the _DEFAULT parameter.
         // A new clone icon will be created in the temporary directory
@@ -236,7 +233,7 @@ void MvQLayerContentsIcon::edited(MvRequest& newIconRequest)
     // Call myself to process the request
     std::ostringstream appName;
     appName << "uPlot" << (long int)getpid();
-    MvApplication::callService(appName.str().c_str(), dropRequest, 0);
+    MvApplication::callService(appName.str().c_str(), dropRequest, nullptr);
 }
 
 void MvQLayerContentsIcon::deleteIcon()
@@ -248,7 +245,7 @@ void MvQLayerContentsIcon::deleteIcon()
     Presentable* pres = Root::Instance().FindSuperPage();
 
     // Delete icon and rebuild the plot
-    pres->RemoveIcon(id_.toInt());
+    pres->RemoveIconWithId(id_.toInt());
 }
 
 void MvQLayerContentsIcon::saveIcon()
@@ -270,7 +267,7 @@ void MvQLayerContentsIcon::saveIcon()
             marslog(LOG_WARN, "Icon file not available on disk");
             return;
         }
-        string fullPath = MakeUserPath(string(cname));
+        std::string fullPath = MakeUserPath(string(cname));
 
         // Remove all hiden parameters before saving the icon
         RemoveParameters(iconReq, "_");
@@ -301,28 +298,28 @@ void MvQLayerContentsIcon::saveAsIcon()
 //
 // This function should be updated after icons are moved to subdirectory /icons/
 // and the pixmap filenames' suffix are updated to .svg or .xpm
-string MvQLayerContentsIcon::getPixmapPath(const string& sclass)
+std::string MvQLayerContentsIcon::getPixmapPath(const std::string& sclass)
 {
     // Get the pixmap file name given the class name
-    string fname = ObjectList::FindPlusChildren("object", sclass, "pixmap");
+    std::string fname = ObjectList::FindPlusChildren("object", sclass, "pixmap");
     if (fname.empty())
         return fname;
 
     // Get path and filename
-    std::size_t pos = fname.find_last_of("/\\");
-    string path     = fname.substr(0, pos);
-    string filename = fname.substr(pos + 1);
+    std::size_t pos      = fname.find_last_of("/\\");
+    std::string path     = fname.substr(0, pos);
+    std::string filename = fname.substr(pos + 1);
 
     // Remove suffix .icon from the filename
     pos = filename.rfind(".icon");
-    if (pos != string::npos)
+    if (pos != std::string::npos)
         filename = filename.substr(0, pos);
 
     // Replace subdirectoy /icons by /icons_mv5
     path += "_mv5/";
 
     // Build the pixmap filename. Try to find the filename suffix.
-    string fullName = path + filename + ".svg";
+    std::string fullName = path + filename + ".svg";
     if (FileCanBeOpened(fullName.c_str(), "r"))
         return fullName;
     else {
@@ -331,5 +328,5 @@ string MvQLayerContentsIcon::getPixmapPath(const string& sclass)
             return fullName;
     }
 
-    return string("");  // empty string
+    return {};
 }
