@@ -7,25 +7,22 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQLayerDialog_H
-#define MvQLayerDialog_H
+#pragma once
 
 #include <QFileDialog>
 
 class MvQLayerDialog : public QFileDialog
 {
-   Q_OBJECT
+    Q_OBJECT
 
 public:
-   MvQLayerDialog(int, QWidget* parent = 0);
-   ~MvQLayerDialog();
+    MvQLayerDialog(int, QWidget* parent = 0);
+    ~MvQLayerDialog();
 
 public slots:
-   void accept();
-   void reject();
+    void accept();
+    void reject();
 
 private:
-   int iconId_;
+    int iconId_;
 };
-
-#endif
