@@ -28,6 +28,7 @@
 #include "ObjectList.h"
 #include "PlotMod.h"
 #include "Root.h"
+#include "MvLog.h"
 
 //======================================
 // Item delegate
@@ -317,7 +318,7 @@ QVariant MvQLayerModel::data(const QModelIndex& index, int role) const
 	{
  		MgQLayerItem* layer=rowToLayer(index.row());
 		
-		map<string,string>::const_iterator it=layer->layer().getInfos().find("Desc");
+		map<std::string,string>::const_iterator it=layer->layer().getInfos().find("Desc");
 
 		if( it!= layer->layer().getInfos().end())
 		{
@@ -385,18 +386,15 @@ QVariant MvQLayerModel::headerData( const int section, const Qt::Orientation ori
 
 QString MvQLayerModel::label(MgQLayerItem* layer, const int /*row*/, const int column) const
 {
-    switch (column) {
-        case 0: {
-            QString str(layer->layer().name().c_str());
-            QStringList lst = str.split("/");
-            if (!lst.isEmpty()) {
-                return lst.last();
-            }
-            return QString();
+    if (column == 0) {
+        QString str(layer->layer().name().c_str());
+        QStringList lst = str.split("/");
+        if (!lst.isEmpty()) {
+            return lst.last();
         }
-        default:
-            return QString();
     }
+
+    return QString();
 }
 
 MvQLayerContentsIcon* MvQLayerModel::layerIcon(MgQLayerItem* layer, int index) const
@@ -428,8 +426,8 @@ MvQLayerContentsIcon* MvQLayerModel::layerIcon(MgQLayerItem* layer, int index) c
     // a) data will be shown
     // b) visdef will be shown if it is connected to the data,
     //    not to the presentable
-    int dataId           = -1;
-    MvListCursor lCursor = iconList.begin();
+    int dataId   = -1;
+    auto lCursor = iconList.begin();
     while (lCursor != iconList.end()) {
         //qDebug() << "YYYYYYYYY" << iconList.size() << (*lCursor).IconName() << (*lCursor).IconClass() << (*lCursor).Id();
         // Create icon structure
@@ -437,13 +435,13 @@ MvQLayerContentsIcon* MvQLayerModel::layerIcon(MgQLayerItem* layer, int index) c
         sprintf(sId, "%d", (*lCursor).Id());
 
         // Check if this icon came from a Macro
-        MvRequest req = (*lCursor).Request();
+        MvRequest req  = (*lCursor).Request();
         bool fromMacro = false;
-        if ( ((const char*)req("_APPL") && strcmp((const char*)req("_APPL"),"macro") == 0) ||
-             ((const char*)req("_CALLED_FROM_MACRO") && (int)req("_CALLED_FROM_MACRO") == 1) )
+        if (((const char*)req("_APPL") && strcmp((const char*)req("_APPL"), "macro") == 0) ||
+            ((const char*)req("_CALLED_FROM_MACRO") && (int)req("_CALLED_FROM_MACRO") == 1))
             fromMacro = true;
 
-        MvQLayerContentsIcon* icon = new MvQLayerContentsIcon((*lCursor).IconName(), (*lCursor).IconClass(), sId, fromMacro);
+        auto* icon = new MvQLayerContentsIcon((*lCursor).IconName(), (*lCursor).IconClass(), sId, fromMacro);
 
         // Check if icon is to be shown
         bool bvis = this->checkIconVisibility(icon, dataId);
@@ -514,7 +512,7 @@ bool MvQLayerModel::checkIconVisibility(MvQLayerContentsIcon* icon, int& dataId)
     else if (ObjectList::IsVisDefAxis(cclass))
         return false;  // FAMI20161021 temporary while axis handling is not implemented
     else if (ObjectList::IsVisDef(cclass))
-        return (dataId == newDataId ? true : false); // is visdef connected to the current data?
+        return (dataId == newDataId ? true : false);  // is visdef connected to the current data?
     else
         return false;
 }
@@ -531,7 +529,7 @@ bool MvQLayerModel::checkLayerVisibility(MgQLayerItem* layer) const
     //qDebug() << layer->name();
 
     // Do not show AXES layers
-    string name = layer->name().toStdString();
+    std::string name = layer->name().toStdString();
     if (name.empty() || name == "VERTICAL_AXIS" || name == "HORIZONTAL_AXIS" || name == "UNKNOW")
         return false;
 
@@ -724,7 +722,7 @@ void MvQLayerModel::moveLayer(int sourceRow, int targetRow)
             }
         }
         if (found == false) {
-            PlotMod::Instance().MetviewError("uPlot MvQLayerModel::moveLayer-> Inconsistency in stackLevels", "Error");
+            MvLog().popup().warn() << "uPlot MvQLayerModel::moveLayer-> Inconsistency in stackLevels";
             return;
         }
     }
@@ -776,12 +774,12 @@ void MvQLayerModel::moveLayer(int sourceRow, int targetRow)
     endResetModel();
 }
 
-string MvQLayerModel::layerId(const QModelIndex& index)
+std::string MvQLayerModel::layerId(const QModelIndex& index)
 {
     MgQLayerItem* item = layer(index);
 
     if (!item)
-        return string();
+        return {};
 
     return item->layer().id();
 }
@@ -832,8 +830,8 @@ QString MvQLayerModel::layerMetaData(const QModelIndex& index, QString key)
         return QString();
 
     MetaDataCollector md;
-    string keyStr = key.toStdString();
-    md[keyStr]    = "";
+    std::string keyStr = key.toStdString();
+    md[keyStr]         = "";
 
     sceneItem_->layerMetaDataForCurrentStep(item, md);
 
@@ -842,9 +840,9 @@ QString MvQLayerModel::layerMetaData(const QModelIndex& index, QString key)
 
 
 /*
-const map<string,string>& MvQLayerModel::layerInfo(const QModelIndex& index) 
+const std::map<std::string,string>& MvQLayerModel::layerInfo(const QModelIndex& index) 
 {
-	static const map<string,string> emptyMap;
+	static const std::map<std::string,string> emptyMap;
 
 	MgQLayerItem* item=layer(index);
 	if(!item)
@@ -860,11 +858,11 @@ QString MvQLayerModel::layerInfo(const QModelIndex& index,QString key)
 	if(!item)
 		return QString();
 
-	const map<string, string>& itemInfo=scene_->getLayerInfoForCurrentStep(item);		
-	//const map<string, string>& itemInfo=item->layer().getInfos();
+	const std::map<std::string, std::string>& itemInfo=scene_->getLayerInfoForCurrentStep(item);		
+	//const std::map<std::string, std::string>& itemInfo=item->layer().getInfos();
 	if(!itemInfo.empty())
 	{
-		map<string,string>::const_iterator it=item->layer().getInfos().find(key.toStdString());
+		map<std::string,string>::const_iterator it=item->layer().getInfos().find(key.toStdString());
 		if(it !=  itemInfo.end())
 		{
 			return QString::fromStdString(it->second);
@@ -889,7 +887,7 @@ QStringList MvQLayerModel::mimeTypes() const
 
 QMimeData* MvQLayerModel::mimeData(const QModelIndexList& indexes) const
 {
-    QMimeData* mimeData = new QMimeData();
+    auto* mimeData = new QMimeData();
     QByteArray encodedData;
 
     QDataStream stream(&encodedData, QIODevice::WriteOnly);
@@ -1062,7 +1060,7 @@ void MvQLayerView::dropEvent(QDropEvent* event)
         // Get index from the dropped position (the target icon)
         QModelIndex index = filterModel_->mapToSource(this->indexAt(event->pos()));
         if (!index.isValid()) {
-            PlotMod::Instance().MetviewError("uPlot MvQLayerView::dropEvent-> Drop not accepted", "Error");
+            MvLog().popup().warn() << "uPlot MvQLayerView::dropEvent-> Drop not accepted";
             return;
         }
 
