@@ -103,10 +103,10 @@ void MvQLayerViewLevelModel::setIcons(MvIconList& iconList)
     icons_.clear();
 
     // Add new icons
-    MvListCursor lCursor = iconList.begin();
+    auto lCursor = iconList.begin();
     while (lCursor != iconList.end()) {
         MvIcon mvicon = *lCursor;
-        MvQLayerContentsIcon icon(QString(mvicon.IconName()), QString(mvicon.IconClass()), QString::number(mvicon.Id()),false);
+        MvQLayerContentsIcon icon(QString(mvicon.IconName()), QString(mvicon.IconClass()), QString::number(mvicon.Id()), false);
 
         icons_ << icon;
         ++lCursor;
@@ -176,7 +176,7 @@ int MvQLayerViewLevelModel::getIconsFromDB(int presId, MvIconList& iconList)
     dataBase.RetrieveIcon(presentableId(), iconList);
 
     // Remove dataUnit icons
-    MvListCursor listCursor = iconList.begin();
+    auto listCursor = iconList.begin();
     MvListCursor foundCursor;
     while (listCursor != iconList.end()) {
         MvRequest req = (*listCursor).Request();
@@ -492,7 +492,7 @@ void MvQLayerViewLevelView::dropEvent(QDropEvent* event)
         //      QModelIndex index = this->indexAt(event->pos());
         //      if( !index.isValid() )
         //      {
-        //         COUT << "Drop not accepted: MvQLayerView::dropEvent" << endl;
+        //         COUT << "Drop not accepted: MvQLayerView::dropEvent" << std::endl;
         //         return;
         //      }
 
