@@ -27,27 +27,29 @@
 #include "MvQLayerSuperPage.h"
 #include "MvQLayerViewLevel.h"
 #include "MvQMethods.h"
+#include "MvQStreamOper.h"
 
 #include "ObjectList.h"
 #include "PlotMod.h"
 #include "Root.h"
+#include "MvLog.h"
 
 MvQLayerWidget::MvQLayerWidget(MgQPlotScene* scene, QWidget* parent) :
     QWidget(parent)
 {
-    QVBoxLayout* layerVb = new QVBoxLayout;
+    auto* layerVb = new QVBoxLayout;
     layerVb->setContentsMargins(2, 2, 2, 2);
     setLayout(layerVb);
 
     // Top level: model and view initializations
-    spModel_        = new MvQLayerSuperPageModel(this);
-    spView_         = new MvQLayerSuperPageView(spModel_, this);
+    spModel_ = new MvQLayerSuperPageModel(this);
+    spView_  = new MvQLayerSuperPageView(spModel_, this);
     layerVb->addWidget(MvQ::makeLabelPanel(tr("Top Level"), this, -1));
     layerVb->addWidget(spView_);
 
     // View level: model and view initializations
-    vlModel_        = new MvQLayerViewLevelModel(this);
-    vlView_         = new MvQLayerViewLevelView(vlModel_, this);
+    vlModel_ = new MvQLayerViewLevelModel(this);
+    vlView_  = new MvQLayerViewLevelView(vlModel_, this);
     layerVb->addWidget(MvQ::makeLabelPanel(tr("View Level"), this, -1));
     layerVb->addWidget(vlView_);
 
@@ -76,10 +78,10 @@ MvQLayerWidget::MvQLayerWidget(MgQPlotScene* scene, QWidget* parent) :
     connect(view_, SIGNAL(customContextMenuRequested(const QPoint&)),
             this, SLOT(slotContextMenu(const QPoint&)));
     //Slider
-    QHBoxLayout* hb = new QHBoxLayout;
+    auto* hb = new QHBoxLayout;
     layerVb->addLayout(hb);
 
-    QLabel* label = new QLabel(tr("Transparency (%)"));
+    auto* label = new QLabel(tr("Transparency (%)"));
     hb->addWidget(label);
 
     trSlider_ = new QSlider;
@@ -184,7 +186,6 @@ MvQLayerWidget::MvQLayerWidget(MgQPlotScene* scene, QWidget* parent) :
 }
 
 
-
 MgQLayerItem* MvQLayerWidget::currentLayer()
 {
     QModelIndex modelIndex = filterModel_->mapToSource(view_->currentIndex());
@@ -385,7 +386,7 @@ void MvQLayerWidget::slotContextMenu(const QPoint& position)
         return;
 
     QList<QAction*> actions;
-    QAction* actionInfo = new QAction(this);
+    auto* actionInfo = new QAction(this);
     actionInfo->setObjectName(QString::fromUtf8("actionInfo"));
     actionInfo->setText(tr("Details"));
     actionInfo->setIcon(QPixmap(QString::fromUtf8(":/uPlot/info_light.svg")));
@@ -397,15 +398,15 @@ void MvQLayerWidget::slotContextMenu(const QPoint& position)
     if (model_->indexToLevel(index) == 0) {
         QAction* res = QMenu::exec(actions, view_->mapToGlobal(position));
         if (res == actionInfo)
-               slotShowInfo();
-    } else if (MvQLayerContentsIcon* icon = model_->indexToIcon(index)) {
-
-        QAction *sep = new QAction(this);
+            slotShowInfo();
+    }
+    else if (MvQLayerContentsIcon* icon = model_->indexToIcon(index)) {
+        auto* sep = new QAction(this);
         sep->setSeparator(true);
         actions << sep;
 
         // Insert Edit key
-        QAction* actionEdit = new QAction(this);
+        auto* actionEdit = new QAction(this);
         actionEdit->setObjectName(QString::fromUtf8("actionEdit"));
         actionEdit->setText(tr("Edit in Plot"));
         //QFont font = actionEdit->font();
@@ -417,7 +418,7 @@ void MvQLayerWidget::slotContextMenu(const QPoint& position)
             actionEdit->setEnabled(false);
 
         //Insert Save key
-        QAction* actionSave = new QAction(this);
+        auto* actionSave = new QAction(this);
         actionSave->setObjectName(QString::fromUtf8("actionSave"));
         actionSave->setText(tr("Save to Disk"));
         actionSave->setShortcut(QKeySequence::Save);
@@ -426,7 +427,7 @@ void MvQLayerWidget::slotContextMenu(const QPoint& position)
             actionSave->setEnabled(false);
 
         //Insert Save As key
-        QAction* actionSaveAs = new QAction(this);
+        auto* actionSaveAs = new QAction(this);
         actionSaveAs->setObjectName(QString::fromUtf8("actionSaveAs"));
         actionSaveAs->setText(tr("Save As"));
         actionSaveAs->setShortcut(QKeySequence::SaveAs);
@@ -435,7 +436,7 @@ void MvQLayerWidget::slotContextMenu(const QPoint& position)
             actionSaveAs->setEnabled(false);
 
         //Insert Delete key
-        QAction* actionDelete = new QAction(this);
+        auto* actionDelete = new QAction(this);
         actionDelete->setObjectName(QString::fromUtf8("actionDelete"));
         actionDelete->setText(tr("Remove from Plot"));
         actionDelete->setShortcuts(QKeySequence::Delete);
@@ -595,16 +596,14 @@ void MvQLayerWidget::slotIconDropped(const MvQDrop& source, const QModelIndex& t
     // Get the layer information
     MgQLayerItem* layer = model_->layerFromAnyLevel(target);
     if (!layer) {
-        PlotMod::Instance().UserWarningMessage("Invalid icon drop\n\nDrop icon over Layers     \n");
+        MvLog().popup().warn() << "Invalid icon drop! Drop target must be a layer!";
         return;
     }
 
     // Consistency check
     int duId;
     if (!checkDroppedIcon(source, layer, duId)) {
-        string text = "Invalid icon drop.\n\nThis icon cannot be applied to layer ";
-        text += layer->name().toStdString();
-        PlotMod::Instance().UserWarningMessage(text);
+        MvLog().popup().warn() << "Invalid icon drop! This icon cannot be applied to layer=" << layer->name();
         return;
     }
     // Therefore, if the target icon is a dataunit and all the dropped
@@ -625,13 +624,13 @@ void MvQLayerWidget::slotIconDropped(const MvQDrop& source, const QModelIndex& t
 #if 0
 // Redraw uPlot: option 1: calls the uPlot redraw function
    // Analyse the dropping to determine the type of action to be taken
-   string classSource = source.iconClass(0).toStdString();
-   string classTarget = icon->type().toStdString();
+   std::string classSource = source.iconClass(0).toStdString();
+   std::string classTarget = icon->type().toStdString();
    if ( classSource == classTarget )  // icons have the same type
    {
       // Read source icon request
       const char* cname = source.iconPath(0).toStdString().c_str();
-      string sname = MakeUserPath(cname);
+      std::string sname = MakeUserPath(cname);
       MvRequest iconRequest;
       iconRequest.read(sname.c_str());
 
@@ -662,8 +661,8 @@ void MvQLayerWidget::slotIconDropped(const MvQDrop& source, const QModelIndex& t
 
    // Add the target dataunit request
    MvRequest iconRequest;
-   string cname;
-   string sname;
+   std::string cname;
+   std::string sname;
 
 #if 0
    if ( addDU )
@@ -856,20 +855,20 @@ bool MvQLayerWidget::checkDroppedIcon(const MvQDrop& source, MgQLayerItem* layer
 
     // Get the target icon class by taking the first icon from the list.
     // If there is a dataUnit, it is the first in the list
-    MvListCursor lCursor = iconList.begin();
+    auto lCursor = iconList.begin();
     //qDebug() << iconList.size() << (*lCursor).IconName() << (*lCursor).IconClass() << (*lCursor).Id();
-    string targetClass = (*lCursor).IconClass();
+    std::string targetClass = (*lCursor).IconClass();
 #else
     // Get the target icon class by taking the first icon from the list
-    duId                                   = -1;
-    vector<MetviewIcon>::const_iterator it = layer->layer().iconsBegin();
+    duId                                        = -1;
+    std::vector<MetviewIcon>::const_iterator it = layer->layer().iconsBegin();
     assert(it != layer->layer().iconsEnd());  //must have at least one icon
-    string targetClass = (*it).iconClass();
+    std::string targetClass = (*it).iconClass();
 #endif
 
     // First, check if target and source icons have all the same "class"
     // (e.g., READ and GRIB are both dataunits).
-    string sourceClass;
+    std::string sourceClass;
     bool targetDu = ObjectList::IsDataUnit(targetClass.c_str());
     bool flag     = true;
     for (int i = 0; i < source.iconNum(); i++) {
