@@ -7,6 +7,10 @@
 
  ***************************** LICENSE END *************************************/
 
+#include "ObjectInfo.h"
+
+#include <sstream>
+
 #include <dirent.h>
 #include <MvRequest.h>
 #include <MvPath.hpp>
@@ -14,14 +18,13 @@
 #include <MvScanFileType.h>
 #include <MvRequestUtil.hpp>
 
-#include "ObjectInfo.h"
 #include "ObjectList.h"
 #include "PlotModConst.h"
 #include "MacroConverter.h"
 #include "MvIcon.h"
 
-typedef map<Cached, Cached> ExpandedMap;
-typedef ExpandedMap::iterator ExpandedIterator;
+using ExpandedMap      = std::map<Cached, Cached>;
+using ExpandedIterator = ExpandedMap::iterator;
 
 NamesMap ObjectInfo::namesMap_;
 
@@ -39,7 +42,7 @@ void ObjectInfo::PutNewLine(const Cached& newLine)
 
 void ObjectInfo::ConvertRequestToMacro(MvRequest& inRequest,
                                        MacroConversion lastComma, Cached varName,
-                                       Cached macroName, set<Cached> skipSet,
+                                       Cached macroName, std::set<Cached> skipSet,
                                        bool onlySub)
 {
     // Initializations
@@ -86,7 +89,7 @@ void ObjectInfo::ConvertRequestToMacro(MvRequest& inRequest,
 
             // Can we follow subRequest also ?
             if ((const char*)subRequest("_NAME")) {
-                string fullName = MakeUserPath((const char*)subRequest("_NAME"));
+                std::string fullName = MakeUserPath((const char*)subRequest("_NAME"));
                 if (FileCanBeOpened(fullName.c_str(), "r")) {
                     Cached returnName = Convert(subRequest);
                     if (strcmp(returnName, "")) {
@@ -108,13 +111,13 @@ void ObjectInfo::ConvertRequestToMacro(MvRequest& inRequest,
         }
 
         else if (ObjectInfo::IsAName(value)) {
-            // Try to find out if this is a file reference.
+            // Try to std::find out if this is a file reference.
             // We need to get the full path
-            string tmpName = value;
+            std::string tmpName = value;
             if (IsParameterSet(inRequest, "_NAME"))
-                tmpName = string(mdirname(inRequest("_NAME"))) + "/" + value;
+                tmpName = std::string(mdirname(inRequest("_NAME"))) + "/" + value;
 
-            string refName = MakeUserPath(tmpName);
+            std::string refName = MakeUserPath(tmpName);
             if (access(refName.c_str(), R_OK) == 0) {
                 // If it is a DATA (binary) file, creates a dummy request.
                 // The crucial information needed is parameter _NAME
@@ -191,8 +194,8 @@ void ObjectInfo::ConvertRequestToMacro(MvRequest& inRequest,
         }
 
         // At last print out the fields that has been expanded
-        int j               = 0;
-        ExpandedIterator ii = expandedMap.begin();
+        int j   = 0;
+        auto ii = expandedMap.begin();
         for (; ii != expandedMap.end(); ii++, j++) {
             Cached comma = ",";
             if (j == (signed)(expandedMap.size() - 1)) {
@@ -315,7 +318,7 @@ void ObjectInfo::WriteDescription(FILE* filePtr)
 {
     require(filePtr != 0);
 
-    CachedList::iterator line = description_.begin();
+    auto line = description_.begin();
 
     while (line != description_.end()) {
         Cached newLine = (*line);
@@ -381,10 +384,10 @@ ObjectInfo::ObjectPath(const MvRequest& request)
     return path;
 }
 
-string
+std::string
 ObjectInfo::ObjectFullPath(const MvRequest& request)
 {
-    string path;
+    std::string path;
     DIR* metDir = 0;
 
     // In certain cases, _PATH contains file name, it shouldn't but .....
@@ -393,7 +396,7 @@ ObjectInfo::ObjectFullPath(const MvRequest& request)
         // Try to open a directory
         if ((metDir = opendir(mPath)) != 0) {
             closedir(metDir);
-            return string(mPath);
+            return std::string(mPath);
         }
 
         // _PATH is not a directory, maybe it contains file name.
@@ -652,13 +655,13 @@ ObjectInfo::Convert(MvRequest& req)
 
     while (req) {
         // Select converter
-        string iconClass          = (const char*)ObjectInfo::IconClass(req);
+        std::string iconClass     = (const char*)ObjectInfo::IconClass(req);
         MacroConverter& converter = MacroConverter::Find(iconClass.c_str());
 
         // Convert an ascii file that is not a LLMATRIX
         oneReqName = "";
-        if (iconClass != string("LLMATRIX")) {
-            string fileName = this->FileName(req);
+        if (iconClass != std::string("LLMATRIX")) {
+            std::string fileName = this->FileName(req);
             if (!IsBinaryOrMissingFile(fileName.c_str())) {
                 MvRequest fileReq;
                 fileReq.read(fileName.c_str(), true);
@@ -703,13 +706,13 @@ ObjectInfo::Convert(MvRequest& req)
 // First guess: _PATH & _NAME
 // Second guess: METVIEW_USER_DIRECTORY & _NAME
 // If filename does not exist, returns an empty string
-string
+std::string
 ObjectInfo::FileName(const MvRequest& req)
 {
     // Build first filename guess: _PATH & _NAME
-    string name     = (const char*)ObjectInfo::ObjectName(req, "", 0, false, false);
-    string path     = ObjectInfo::ObjectFullPath(req);
-    string fileName = path + ((path[path.size() - 1] == '/') ? name : "/" + name);
+    std::string name     = (const char*)ObjectInfo::ObjectName(req, "", 0, false, false);
+    std::string path     = ObjectInfo::ObjectFullPath(req);
+    std::string fileName = path + ((path[path.size() - 1] == '/') ? name : "/" + name);
     if (FileCanBeOpened(fileName.c_str(), "r"))
         return fileName;
 
@@ -726,19 +729,19 @@ ObjectInfo::FileName(const MvRequest& req)
 
 void ObjectInfo::FormatLine(const Cached& param, const Cached& val, const Cached& comma, int width)
 {
-    ostringstream str;
-    str.setf(ios::left);
+    std::ostringstream str;
+    str.setf(std::ios::left);
     str << "   ";
     str.width(width);
     str << param;
-    str << ": " << val << comma << ends;
+    str << ": " << val << comma << std::ends;
 
     PutNewLine(str.str().c_str());
 }
 
 Cached ObjectInfo::FormatValue(const char* val, const char* param, const Cached& macroName)
 {
-    string sval;
+    std::string sval;
     bool addQuotes = false;
 
     // Multiple lines
@@ -751,9 +754,9 @@ Cached ObjectInfo::FormatValue(const char* val, const char* param, const Cached&
             pch  = strtok(buff, "\n");
             sval = sval + "\"" + pch + " \"";
 
-            while (pch != NULL) {
-                pch = strtok(NULL, "\n");
-                if (pch != NULL) {
+            while (pch != nullptr) {
+                pch = strtok(nullptr, "\n");
+                if (pch != nullptr) {
                     sval += " &\n";
                     sval = sval + "            \"" + pch + " \"";
                 }
