@@ -25,7 +25,7 @@ ObjectList::Instance()
 	MvRequest reqObj = mars.setup; // hides the global "mars.setup"
 
 	// Reads uPlot resources
-	string filename(getenv("METVIEW_DIR_SHARE"));
+	std::string filename(getenv("METVIEW_DIR_SHARE"));
 	filename += "/etc/uPlotTable";
 	MvRequest uPlotRes;
 	uPlotRes.read(filename.c_str());
@@ -39,7 +39,7 @@ objectList.rewind();
 		i++;
 		objectList.advance();
 	}
-	COUT << "Number total resources = " << i << endl;
+	COUT << "Number total resources = " << i << std::endl;
 
 
 	i = 0;
@@ -50,7 +50,7 @@ uPlotRes.save("/tmp/dummy-user/data/uPlotTable.txt");
 		i++;
 		uPlotRes.advance();
 	}
-	COUT << "Number total resources = " << i << endl;
+	COUT << "Number total resources = " << i << std::endl;
 
 i = 0;
 objectList.rewind();
@@ -62,7 +62,7 @@ objectList.rewind();
 		i++;
 		objectList.advance();
 	}
-	COUT << "Number total resources = " << i << endl;
+	COUT << "Number total resources = " << i << std::endl;
 
 objectList.rewind();
 objectList.save("/tmp/dummy-user/data/ObjectList1.txt");
@@ -103,7 +103,7 @@ ObjectList::FindPlusChildren(const char* name, const char* sclass)
 {
     // Request founded
     MvRequest req = Find(Cached(name), Cached(sclass));
-    if (req.getVerb() != string("EMPTY"))
+    if (req.getVerb() != std::string("EMPTY"))
         return req;
 
     // Try to find if "sclass" is defined in the "children" parameter
@@ -188,8 +188,8 @@ ObjectList::Find(const Cached& name, const Cached& sclass, const Cached& param)
 // parameters are not found then check if this "class" is defined in the
 // "children" parameter. If yes, return the values related to "param".
 // Otherwise, return an empty string.
-string
-ObjectList::FindPlusChildren(const string& sname, const string& sclass, const string& sparam)
+std::string
+ObjectList::FindPlusChildren(const std::string& sname, const std::string& sclass, const std::string& sparam)
 {
     // Value founded
     const char* cname  = sname.c_str();
@@ -197,13 +197,13 @@ ObjectList::FindPlusChildren(const string& sname, const string& sclass, const st
     const char* cparam = sparam.c_str();
     const char* str    = (const char*)Find(cname, cclass, cparam);
     if (str)
-        return string(str);
+        return std::string(str);
 
     // Try to find if "sclass" is defined in the "children" parameter
     MvRequest& objectList = ObjectList::Instance();
     objectList.rewind();
     int i, j;
-    string sout;
+    std::string sout;
     while (objectList) {
         if (strcmp(objectList.getVerb(), cname) == 0) {
             if ((const char*)objectList("children")) {
@@ -263,7 +263,7 @@ ObjectList::FindGraphicsEngine(const MvRequest& request)
 
     // Option 2. Look for the default in the PM Table
     geName = Find("graphics_engine", "Default", "choice");
-    ensure((const char*)geName != 0);
+    ensure((const char*)geName != nullptr);
 
     return geName;
 }
@@ -314,15 +314,15 @@ ObjectList::FindReqService(const char* classe, const char* action)
     return MvRequest();
 }
 
-string
+std::string
 ObjectList::FindService(const char* classe, const char* action)
 {
     // Find request
     MvRequest req = FindReqService(classe, action);
     if (req)
-        return string(req("service"));
+        return std::string(req("service"));
 
-    return string("");
+    return std::string("");
 }
 
 // -- METHOD :
@@ -335,12 +335,12 @@ ObjectList::FindService(const char* classe, const char* action)
 Cached
 ObjectList::DefaultVisDefClass(const char* dataUnitVerb)
 {
-    require(dataUnitVerb != 0);
+    require(dataUnitVerb != nullptr);
 
     // Find out the name of the VisDef from the Plot Mod Table which
     // contains the relation between DataUnits and VisDefs
     Cached defaultVisDefClass = Find("dataunit", dataUnitVerb, "defaultVisDef");
-    ensure((const char*)defaultVisDefClass != 0);
+    ensure((const char*)defaultVisDefClass != nullptr);
 
     return defaultVisDefClass;
 }
@@ -357,18 +357,18 @@ ObjectList::DefaultVisDefClass(const char* dataUnitVerb)
 //             No -  The VisDef does not match the data unit
 bool ObjectList::CheckValidVisDef(const char* duClass, const char* vdClass, const char* vdPar)
 {
-    require(duClass != 0);
-    require(vdClass != 0);
+    require(duClass != nullptr);
+    require(vdClass != nullptr);
 
     // Retrieve the list of acceptable visdefs in the Object List
     const char* param = (vdPar) ? vdPar : "listVisDef";
     Cached listVisDef = Find("dataunit", duClass, param);
 
     // If no visdefs found, try the default key "listVisDef"
-    if ((const char*)listVisDef == 0 && vdPar)
+    if ((const char*)listVisDef == nullptr && vdPar)
         listVisDef = Find("dataunit", duClass, "listVisDef");
 
-    ensure((const char*)listVisDef != 0);
+    ensure((const char*)listVisDef != nullptr);
 
     // Verify if the visDefClass belongs to the VisDefList
     return strstr((const char*)listVisDef, vdClass);
@@ -376,11 +376,11 @@ bool ObjectList::CheckValidVisDef(const char* duClass, const char* vdClass, cons
 
 bool ObjectList::CheckValidVisDef(const char* duClass, const char* vdClass, int ndimFlag)
 {
-    require(duClass != 0);
-    require(vdClass != 0);
+    require(duClass != nullptr);
+    require(vdClass != nullptr);
 
     // Get visdef's key strings according to the input flag
-    vector<string> vstr;
+    std::vector<std::string> vstr;
     VisDefNDimFlags(ndimFlag, vstr);
 
     // Check if visdef is valid
@@ -444,8 +444,8 @@ bool ObjectList::CheckValidVisDefList(const char* duClass, MvIconList& visdefLis
 {
     MvIconList tmplist;
     MvIcon oneIcon;
-    for (MvListCursor jj = visdefList.begin(); jj != visdefList.end(); jj++) {
-        oneIcon = *jj;
+    for (auto& jj : visdefList) {
+        oneIcon = jj;
         if (ObjectList::CheckValidVisDef(duClass, oneIcon.Request().getVerb(), vdpar))
             tmplist.push_back(oneIcon);
     }
@@ -455,7 +455,7 @@ bool ObjectList::CheckValidVisDefList(const char* duClass, MvIconList& visdefLis
     return (visdefList.size() > 0) ? true : false;
 }
 
-void ObjectList::VisDefNDimFlags(int dimFlag, vector<string>& vstr)
+void ObjectList::VisDefNDimFlags(int dimFlag, std::vector<std::string>& vstr)
 {
     // No info about data dimension
     vstr.clear();
@@ -480,7 +480,7 @@ ObjectList::UserPreferencesRequest(const char* name)
     const char* requestFileName = Find("object", name)("default_name");
 
     // Get the filename full path
-    string tt            = MakeUserPrefPath(requestFileName);
+    std::string tt       = MakeUserPrefPath(requestFileName);
     const char* filename = tt.c_str();
 
     // Do we have a preference ?
@@ -513,16 +513,16 @@ ObjectList::UserPreferencesRequest(const char* name)
 MvRequest
 ObjectList::UserDefaultRequest(const char* requestName, bool expand)
 {
-    require(requestName != 0);
+    require(requestName != nullptr);
 
     // Read the objectFileName in the METVIEW ObjectList
     const char* requestFileName = Find("object", requestName)("default_name");
-    ensure(requestFileName != 0);
+    ensure(requestFileName != nullptr);
 
     // Determine  the default path for the icon
     // Find the file which contains the request
-    string fullName = MakeUserDefPath(requestFileName);
-    string path     = mdirname(fullName.c_str());
+    std::string fullName = MakeUserDefPath(requestFileName);
+    std::string path     = mdirname(fullName.c_str());
 
     // Create a new request and read its contents
     // for the file in the default directory
@@ -590,7 +590,7 @@ ObjectList::CreateDefaultRequest(const char* requestName, int expandFlag, const
 
     // Add parameter _NAME, including the path if it is given
     const char* name = (const char*)Find("object", requestName)("default_name");
-    string defName;
+    std::string defName;
     if (name) {
         defName = "<";
         defName += name;
@@ -600,7 +600,7 @@ ObjectList::CreateDefaultRequest(const char* requestName, int expandFlag, const
         defName = "<default>";
 
     if (path) {
-        string relName      = path + string("/") + defName;
+        std::string relName = path + std::string("/") + defName;
         expRequest("_NAME") = relName.c_str();
     }
     else
@@ -660,7 +660,7 @@ bool ObjectList::IsView(const Cached& requestVerb)
     return objectDef("class") == requestVerb;
 }
 
-bool ObjectList::IsGeographicalView(const string& verb)
+bool ObjectList::IsGeographicalView(const std::string& verb)
 {
     if (verb.empty())
         return false;
@@ -669,7 +669,7 @@ bool ObjectList::IsGeographicalView(const string& verb)
     MvRequest objectDef = Find("view", verb.c_str());
 
     // Check if this is a geographical view
-    string class1 = (const char*)objectDef("class");
+    std::string class1 = (const char*)objectDef("class");
     return (!class1.empty() && (class1 == GEOVIEW || class1 == MAPVIEW));
 }
 
@@ -752,7 +752,7 @@ bool ObjectList::IsVisDefTextTitle(const MvRequest& request)
 
     // Check if it is a Text title
     if ((const char*)request("TEXT_MODE") &&
-        ((const char*)request("TEXT_MODE") == string("POSITIONAL")))
+        ((const char*)request("TEXT_MODE") == std::string("POSITIONAL")))
         return false;
 
     return true;
@@ -767,7 +767,7 @@ bool ObjectList::IsVisDefTextAnnotation(const MvRequest& request)
 
     // Check if it is a Text annotation
     if ((const char*)request("TEXT_MODE") &&
-        ((const char*)request("TEXT_MODE") == string("POSITIONAL")))
+        ((const char*)request("TEXT_MODE") == std::string("POSITIONAL")))
         return true;
 
     return false;
@@ -805,6 +805,11 @@ bool ObjectList::IsLayer(const char* verb)
     return (strcmp(verb, "LAYER") == 0 || strcmp(verb, "layer") == 0);
 }
 
+bool ObjectList::IsWeatherSymbol(const Cached& requestVerb)
+{
+    return strncmp((const char*)requestVerb, "WS_", 3) == 0;
+}
+
 // -- METHOD :  MacroName
 //
 // -- PURPOSE:  Find the macro name associated to a METVIEW object
@@ -851,12 +856,12 @@ bool ObjectList::CalledFromMacro(const MvRequest& request)
 //              first: true - if there is a companion and the input parameter
 //                            is the primarely/first element, i.e. it is not
 //                            the friend element
-void ObjectList::GetCompanion(const string& param, string& pair, string& mode, bool& first)
+void ObjectList::GetCompanion(const std::string& param, std::string& pair, std::string& mode, bool& first)
 {
     MvRequest& objectList = ObjectList::Instance();
     objectList.rewind();
 
-    string comp("companion");
+    std::string comp("companion");
     while (objectList) {
         if (objectList.getVerb() == comp) {
             if ((const char*)objectList("class") == param) {
@@ -882,14 +887,14 @@ void ObjectList::GetCompanion(const string& param, string& pair, string& mode, b
 }
 
 // Check if two variables are companions
-bool ObjectList::AreCompanions(const string& pair1, const string& pair2)
+bool ObjectList::AreCompanions(const std::string& pair1, const std::string& pair2)
 {
     // Get the object list
     MvRequest& objectList = ObjectList::Instance();
     objectList.rewind();
 
     // Loop the list doing the checking
-    string comp("companion");
+    std::string comp("companion");
     while (objectList) {
         if (objectList.getVerb() == comp && ((((const char*)objectList("class") == pair1) && ((const char*)objectList("friend") == pair2)) ||
                                              (((const char*)objectList("class") == pair2) && ((const char*)objectList("friend") == pair1))))
@@ -909,9 +914,9 @@ bool ObjectList::AreCompanions(const string& pair1, const string& pair2)
 //                            now we don't want or need to distinguish between
 //                            satellite and non-satellite GRIB fields.
 
-bool ObjectList::IsImage(const char* repres)
+bool ObjectList::IsImage(const char* /*repres*/)
 {
-    //(repres != NULL && !strcmp(repres, "SV"));
+    //(repres != nullptr && !strcmp(repres, "SV"));
     return false;
 }
 
