@@ -21,6 +21,7 @@
 #include "PlotMod.h"
 #include "PmContext.h"
 #include "SubPage.h"
+#include "MvLog.h"
 
 Page::Page(MvRequest& pageRequest) :
     Presentable(pageRequest),
@@ -30,26 +31,26 @@ Page::Page(MvRequest& pageRequest) :
     dropShouldStay_(false)
 {
     // Each page has its own graphics engine
-    engine_ =  std::unique_ptr<GraphicsEngine>(GraphicsEngineFactory::Make(*this));
+    engine_ = std::unique_ptr<GraphicsEngine>(GraphicsEngineFactory::Make(*this));
 
     // Find out if there is a view associated with the request
     MvRequest viewRequest = pageRequest.getSubrequest("VIEW");
     const char* viewClass = (const char*)viewRequest.getVerb();
-    if (viewClass && ObjectList::IsGeographicalView(viewClass)) {        
+    if (viewClass && ObjectList::IsGeographicalView(viewClass)) {
         // If AREA is not given, Magics will use the default value
         if ((const char*)viewRequest("AREA")) {
             Location area;
             std::unique_ptr<PmProjection> proj(PmProjectionFactory::Make(viewRequest));
 
-            const char *proj_name = viewRequest("MAP_PROJECTION");
+            const char* proj_name = viewRequest("MAP_PROJECTION");
 
-            if (proj_name && strcmp(proj_name,"CYLINDRICAL") == 0) {
+            if (proj_name && strcmp(proj_name, "CYLINDRICAL") == 0) {
                 std::unique_ptr<PmProjection> projCyl(PmProjectionFactory::Make(viewRequest));
                 if (!projCyl.get()->CheckGeodeticCoordinates(area)) {
-                    PlotMod::Instance().MetviewError("Some/All area coordinates are invalid! Replaced by default values");
+                    MvLog().warn() << "Some/All area coordinates are invalid! Replaced by default values";
                 }
-            } else {
-
+            }
+            else {
                 // Initialize the bounding box in geodetic coordinates
                 double lat1  = viewRequest("AREA", 0);
                 double long1 = viewRequest("AREA", 1);
@@ -122,9 +123,9 @@ Page::~Page()
     revertedChildList.reverse();
 
     // Get Last and previous to last in child list
-    for (MvChildIterator j = revertedChildList.begin(); j != revertedChildList.end(); ++j) {
-        if (!((*j)->GetDeviceData()))
-            this->RemovePresentable(*j);
+    for (auto& j : revertedChildList) {
+        if (!(j->GetDeviceData()))
+            this->RemovePresentable(j);
     }
 
     // Remove Page from DataBase
@@ -151,18 +152,19 @@ void Page::Draw()
 
 void Page::DrawProlog()
 {
-    MvChildIterator child = childList_.begin();
+    auto child = childList_.begin();
     (*child)->DrawProlog();
 }
 
 void Page::DrawPageHeader()
 {
-    MvChildIterator child = childList_.begin();
+    auto child = childList_.begin();
     (*child)->DrawPageHeader();
 }
 
 void Page::Drop(PmContext& context)
 {
+    MvLog().dbg() << "Page::Drop";
     // Skip the first request if it's a drop ( it normally is).
     // If visualize is done directly on a data object, the
     // data request is the first, and should not be skipped.
@@ -292,7 +294,7 @@ bool Page::InsertVisDefToDataUnit(MvRequest& vdRequestList, MvIcon& du)
     while (vdRequestList) {
         MvRequest reqVd = vdRequestList.justOneRequest();
         MvIconList duList;
-        if (CheckValidVisDef(du, reqVd, duList)) {
+        if (CheckValidVisDefWithIcl(du, reqVd, duList)) {
             MvListCursor duCursor;
             for (duCursor = duList.begin(); duCursor != duList.end(); ++duCursor) {
                 MvIcon& theDataUnit = *(duCursor);
@@ -308,7 +310,7 @@ bool Page::InsertVisDefToDataUnit(MvRequest& vdRequestList, MvIcon& du)
     while (vdRequestList) {
         MvRequest reqVd = vdRequestList.justOneRequest();
         MvIconList duList;
-        if (CheckValidVisDef(du, reqVd, duList)) {
+        if (CheckValidVisDefWithIcl(du, reqVd, duList)) {
             MvListCursor duCursor;
             for (duCursor = duList.begin(); duCursor != duList.end(); ++duCursor)
                 dataBase.InsertVisDef(reqVd, Id(), du);
@@ -404,18 +406,16 @@ void Page::RemoveAllData()
     this->InitMatching();
 }
 
-void Page::UpdateDataForZoom(const string& /*zoomInfo*/)
+void Page::UpdateDataForZoom(const std::string& /*zoomInfo*/)
 {
     bool updateWmsForZoom = true;
     if (!updateWmsForZoom)
         return;
 
-    vector<Presentable*> presVec;
+    std::vector<Presentable*> presVec;
     FindBranchesByRequest("PRASTERLOOP", presVec);
 
-    for (int i = 0; i < (int)presVec.size(); i++) {
-        Presentable* pres = presVec.at(i);
-
+    for (auto pres : presVec) {
         MvIcon dataUnit;
         pres->DataUnit(dataUnit);
         if (strcmp(dataUnit.Request().getVerb(), "PRASTERLOOP") == 0) {
@@ -449,7 +449,7 @@ void Page::ZoomRequest(int izoom)
     if (stacks == 0)
         return;
 
-    string zoomInfo;
+    std::string zoomInfo;
 
     //If zoom level is 0 then send the original message to Magics
     if (izoom == 0) {
@@ -470,7 +470,7 @@ void Page::ZoomRequest(int izoom)
     this->UpdateDataForZoom(zoomInfo);
 }
 
-void Page::ZoomRequest(const string& zoomInfo)
+void Page::ZoomRequest(const std::string& zoomInfo)
 {
     // Check if Zoom operation can be performed in this Page
     if (this->CanDoZoom() == false)
@@ -484,7 +484,7 @@ void Page::ZoomRequest(const string& zoomInfo)
     // Save new coordinates
     if (stacks->Size() == 0) {
         // Save initial zoom info
-        string cc1("Zoom 0");
+        std::string cc1("Zoom 0");
         stacks->GeodeticPush(cc1);
     }
     stacks->GeodeticPush(zoomInfo);
@@ -526,13 +526,13 @@ void Page::DescribeYourself(ObjectInfo& description)
     myRequest.unsetParam("PAGE_Y_GAP");
 
     // Convert the page description to the macro syntax
-    set<Cached> skipSet;
+    std::set<Cached> skipSet;
     skipSet.insert("VIEW");
     description.ConvertRequestToMacro(myRequest, PUT_LAST_COMMA, MacroName().c_str(), "plot_page", skipSet);
 
     // Include the view information
-    int size        = description.MaximumParameterNameLength(myRequest);
-    string viewName = myView_->MacroName();
+    int size             = description.MaximumParameterNameLength(myRequest);
+    std::string viewName = myView_->MacroName();
     description.FormatLine("VIEW", viewName.c_str(), "", size);
 
     // Close the page description
@@ -582,7 +582,7 @@ bool Page::RemovePresentable(Presentable* subpage)
     revertedChildList.reverse();
 
     // Get Last and previous to last in child list
-    MvChildIterator j            = revertedChildList.begin();
+    auto j                       = revertedChildList.begin();
     Presentable* lastSubPage     = *j;
     Presentable* previousSubPage = *(++j);
 
@@ -632,7 +632,7 @@ bool Page::RemovePresentable(Presentable* subpage)
             subpage->NeedsRedrawing(true);
 
             // Make SubPage the last of child list
-            MvChildIterator i = find(childList_.begin(), childList_.end(), subpage);
+            auto i = find(childList_.begin(), childList_.end(), subpage);
             ensure((*i) == subpage);
 
             childList_.erase(i);
@@ -735,7 +735,7 @@ Page::GetNextCanvas(MvRequest& subpageReq)
     return canvas;
 }
 
-bool Page::CheckValidVisDef(MvIcon& dataUnit, MvRequest& vdRequest, MvIconList& dataUnitList)
+bool Page::CheckValidVisDefWithIcl(MvIcon& dataUnit, MvRequest& vdRequest, MvIconList& dataUnitList)
 {
     // Check only if a visdef is being wrongly applied to a 1D or 2D fields
     // Get the dimension flag
@@ -751,8 +751,8 @@ bool Page::CheckValidVisDef(MvIcon& dataUnit, MvRequest& vdRequest, MvIconList&
     bool found = false;
     MvChildIterator child;
     for (child = childList_.begin(); child != childList_.end(); ++child) {
-        SubPage* subpage = (SubPage*)(*child);
-        if (subpage->CheckValidVisDef(dataUnit, vdRequest, dataUnitList, iflag))
+        auto* subpage = (SubPage*)(*child);
+        if (subpage->CheckValidVisDefWithIcl(dataUnit, vdRequest, dataUnitList, iflag))
             found = true;
     }
 
