@@ -13,6 +13,7 @@
 #include "PlotMod.h"
 #include "PmContext.h"
 #include "Root.h"
+#include "MvLog.h"
 
 // Thermo types
 static const std::string THERMOTEPHI   = "TEPHIGRAM";
@@ -68,8 +69,8 @@ ThermoView::ThermoView(const ThermoView& old) :
 
 string ThermoView::Name()
 {
-    int id      = Owner().Id();
-    string name = (const char*)ObjectInfo::ObjectName(viewRequest_, "ThermoView", id);
+    int id           = Owner().Id();
+    std::string name = (const char*)ObjectInfo::ObjectName(viewRequest_, "ThermoView", id);
 
     return name;
 }
@@ -77,7 +78,7 @@ string ThermoView::Name()
 void ThermoView::DescribeYourself(ObjectInfo& description)
 {
     // Convert my request to Macro
-    set<Cached> skipSet;
+    std::set<Cached> skipSet;
     description.ConvertRequestToMacro(appViewReq_, PUT_END, MacroName().c_str(), "thermoview", skipSet);
     description.PutNewLine(" ");
 }
@@ -98,7 +99,7 @@ bool ThermoView::UpdateView()
     // Magics requires that the value for parameter map_projection be
     // in lower case
     MvRequest cartView("CARTESIANVIEW");
-    string sdata = type_;
+    std::string sdata = type_;
     std::transform(sdata.begin(), sdata.end(), sdata.begin(), ::tolower);
     cartView("MAP_PROJECTION") = sdata.c_str();
 
@@ -161,7 +162,7 @@ bool ThermoView::UpdateView()
     return true;
 }
 
-bool ThermoView::UpdateView(MvRequest& viewRequest)
+bool ThermoView::UpdateViewWithReq(MvRequest& viewRequest)
 {
     // Get the original ThermoView request in case it has already
     // been translated to a CartesianView request
@@ -177,9 +178,7 @@ bool ThermoView::UpdateView(MvRequest& viewRequest)
     // Changing to another View is not allowed
     if (!ObjectList::IsThermoView(viewRequest.getVerb())) {
         // Changing View is disabled at the moment
-        char text[128];
-        sprintf(text, "Changing View (%s to %s) is currently disabled", tview.getVerb(), viewRequest.getVerb());
-        PlotMod::Instance().UserErrorMessage(text);
+        MvLog().popup().err() << "Changing View (" << tview.getVerb() << " to " << viewRequest.getVerb() << ") is currently disabled";
         return false;
     }
 
@@ -256,7 +255,7 @@ void ThermoView::Drop(PmContext& context)
             // First: check and update the internal ThermoView structure
             // Second: ask CommonXSectView::Drop to update the Page
             MvRequest req = dropRequest.justOneRequest();
-            if (!this->UpdateView(req))
+            if (!this->UpdateViewWithReq(req))
                 return;
         }
 
@@ -274,14 +273,15 @@ void ThermoView::updateThermoGrid(const MvRequest& req)
     thermoGridReq_ = req;
     if (!isThermoGridForeground()) {
         viewRequest_("THERMO_GRID") = req;
-    } else {        
+    }
+    else {
         MvRequest gr("MTHERMOGRID");
-        gr("THERMO_ISOTHERM_GRID") = "OFF";
-        gr("THERMO_ISOBAR_GRID") = "OFF";
-        gr("THERMO_DRY_ADIABATIC_GRID") = "OFF";
+        gr("THERMO_ISOTHERM_GRID")            = "OFF";
+        gr("THERMO_ISOBAR_GRID")              = "OFF";
+        gr("THERMO_DRY_ADIABATIC_GRID")       = "OFF";
         gr("THERMO_SATURATED_ADIABATIC_GRID") = "OFF";
-        gr("THERMO_MIXING_RATIO_GRID") = "OFF";
-        viewRequest_("THERMO_GRID") = gr;
+        gr("THERMO_MIXING_RATIO_GRID")        = "OFF";
+        viewRequest_("THERMO_GRID")           = gr;
     }
 }
 
@@ -300,9 +300,7 @@ bool ThermoView::SetThermoType(MvRequest& req)
             thermoType = (const char*)req("_CLASS");
         else {
             // Thermo type not found
-            char text[128];
-            sprintf(text, "Suitable thermo type not found: %s ", verb.c_str());
-            PlotMod::Instance().UserErrorMessage(text);
+            MvLog().popup().err() << "Suitable thermo type not found: " << verb;
             return false;
         }
     }
@@ -322,9 +320,7 @@ bool ThermoView::SetThermoType(MvRequest& req)
     }
     else {
         // Thermo type not found
-        char text[128];
-        sprintf(text, "Suitable thermo type not found: %s ", verb.c_str());
-        PlotMod::Instance().UserErrorMessage(text);
+        MvLog().popup().err() << "Suitable thermo type not found:" << verb;
         return false;
     }
 
@@ -332,7 +328,7 @@ bool ThermoView::SetThermoType(MvRequest& req)
     return true;
 }
 
-bool ThermoView::ConsistencyCheck(MvRequest& req1, MvRequest& req2, std::string& param)
+bool ThermoView::ConsistencyCheckWithStr(MvRequest& req1, MvRequest& req2, std::string& param)
 {
     // Build a list of parameters to be checked
     std::vector<std::string> vparam;
