@@ -9,6 +9,12 @@
 
 #include "uPlotBase.h"
 
+#include <fstream>
+#include <sstream>
+#include <string>
+
+#include "fstream_mars_fix.h"
+
 // Qt include files
 #include <QtGlobal>
 #include <QAbstractPrintDialog>
@@ -63,7 +69,7 @@
 
 #include "MagPlusService.h"
 #include "../libMetview/Path.h"  // path given to disambiguate from Magics Path.h
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "MvPath.hpp"
 #include "MvQPalette.h"
 #include "MvQTheme.h"
@@ -71,6 +77,7 @@
 #include "PlotMod.h"
 #include "PlotModView.h"
 #include "Root.h"
+#include "MvLog.h"
 
 #define PLACEMARK
 
@@ -82,9 +89,10 @@ ExportMessageBox::ExportMessageBox(uPlotBase* owner) :
     QMessageBox(owner),
     owner_(owner)
 {
-    setText("<big><center>Generating plot - please wait...</big></center>"
-                   "<br>This window will disappear as soon as the output file"
-                   " is generated");
+    setText(
+        "<big><center>Generating plot - please wait...</big></center>"
+        "<br>This window will disappear as soon as the output file"
+        " is generated");
     setStandardButtons(QMessageBox::NoButton);
     setWindowModality(Qt::WindowModal);
 
@@ -125,7 +133,7 @@ uPlotBase::uPlotBase(QWidget* parent) :
     plotScene_->setHighlightStyle(QBrush(Qt::NoBrush),
                                   MvQTheme::pen("uplot", "scene_highlight_border", 3.));
     plotScene_->setHighlightBriefStyle(MvQTheme::brush("uplot", "scene_highlight_brief"),
-                                  MvQTheme::pen("uplot", "scene_highlight_brief_border", 3., Qt::SolidLine));
+                                       MvQTheme::pen("uplot", "scene_highlight_brief_border", 3., Qt::SolidLine));
 
     activeScene_ = 0;
 
@@ -143,8 +151,8 @@ uPlotBase::uPlotBase(QWidget* parent) :
     connect(plotView_, SIGNAL(resizeEventHappened(const QSize&)),
             this, SLOT(slotResizeEvent(const QSize&)));
 
-    connect(plotView_, SIGNAL(zoomRectangleIsDefined(const string&, const string&)),
-            this, SLOT(slotPerformZoom(const string&, const string&)));
+    connect(plotView_, SIGNAL(zoomRectangleIsDefined(const std::string&, const std::string&)),
+            this, SLOT(slotPerformZoom(const std::string&, const std::string&)));
 
     connect(plotView_, SIGNAL(iconDropped(const MvQDrop&, QPoint)),
             this, SLOT(slotProcessDropInView(const MvQDrop&, QPoint)));
@@ -235,7 +243,7 @@ void uPlotBase::setupViewActions()
     connect(actionSizeUp_, SIGNAL(triggered()),
             this, SLOT(slotSizeUp()));
 
-    QAction* sep = new QAction(this);
+    auto* sep = new QAction(this);
     sep->setSeparator(true);
 
     MvQMainWindow::MenuType menuType = MvQMainWindow::ViewMenu;
@@ -248,7 +256,7 @@ void uPlotBase::setupViewActions()
 void uPlotBase::setupZoomActions()
 {
     //Zoom
-    QAction* actionZoom = new QAction(this);
+    auto* actionZoom = new QAction(this);
     actionZoom->setObjectName(QString::fromUtf8("actionZoom"));
     actionZoom->setCheckable(true);
     QIcon icon;
@@ -278,7 +286,7 @@ void uPlotBase::setupZoomActions()
     actionZoomDown_->setShortcut(tr("Ctrl+Down"));
 
     //Zoomstack
-    QToolButton* zoomStackPb = new QToolButton;
+    auto* zoomStackPb = new QToolButton;
     QIcon icon11;
     icon11.addPixmap(QPixmap(QString::fromUtf8(":/uPlot/zoom_stack.svg")), QIcon::Normal, QIcon::Off);
     zoomStackPb->setIcon(icon11);
@@ -289,7 +297,7 @@ void uPlotBase::setupZoomActions()
     //QMenu *zoomStackMenu = new QMenu("&ZoomStack");
 
     zoomStackWidget_ = new MvQZoomStackWidget(plotScene_);
-    auto wa = new QWidgetAction(this);
+    auto wa          = new QWidgetAction(this);
     wa->setDefaultWidget(zoomStackWidget_);
     zoomStackPb->addAction(wa);
 
@@ -335,7 +343,7 @@ void uPlotBase::setupZoomActions()
 void uPlotBase::setupHelpActions()
 {
     // About
-    QAction* actionAbout = new QAction(this);
+    auto* actionAbout = new QAction(this);
     actionAbout->setObjectName(QString::fromUtf8("actionAbout"));
     actionAbout->setText(tr("&About uPlot"));
 
@@ -403,7 +411,7 @@ void uPlotBase::SetupResources()
         i++;
         tt.advance();
     }
-    //COUT << "Number total resources = " << i << endl;
+    //COUT << "Number total resources = " << i << std::endl;
 }
 
 void uPlotBase::setPlot(float hor, float ver)
@@ -429,7 +437,7 @@ void uPlotBase::slotProcessDropInView(const MvQDrop& drop, QPoint pos)
     //	sPageId = activeScene_->layout().id();
     // WE WILL ASK SYLVIE TO IMPLEMENT THIS FUNCTION
 
-    string sPageId;
+    std::string sPageId;
 
     if (activeScene_) {
         sPageId = activeScene_->layout().id();
@@ -441,7 +449,7 @@ void uPlotBase::slotProcessDropInView(const MvQDrop& drop, QPoint pos)
 
     // Build request to be sent back to source
     int pageId = 0;
-    istringstream sst(sPageId);
+    std::istringstream sst(sPageId);
     sst >> pageId;
 
     MvRequest req("DROP_REQUEST");
@@ -515,7 +523,7 @@ void uPlotBase::slotEnableAntialias(bool status)
 
 void uPlotBase::slotZoomStackLevelChanged(QString layoutId, int actLevel)
 {
-    owner_->ZoomRequest(layoutId.toInt(), actLevel);
+    owner_->ZoomRequestByLevel(layoutId.toInt(), actLevel);
 }
 
 void uPlotBase::updateZoomActionState()
@@ -541,7 +549,7 @@ void uPlotBase::updateZoomActionState()
     }
 }
 
-void uPlotBase::slotPerformZoom(const string& sid, const string& def)
+void uPlotBase::slotPerformZoom(const std::string& sid, const std::string& def)
 {
     //Location stores the bottom-left,top-right corners.
     //Its constructor is requeres the following order:
@@ -563,7 +571,7 @@ void uPlotBase::slotPerformZoom(const string& sid, const string& def)
 
     //Location zoomCoord(tr_y,bl_x,bl_y,tr_x);
     int id = QString(sid.c_str()).toInt();
-    owner_->ZoomRequest(id, def);
+    owner_->ZoomRequestByDef(id, def);
 }
 
 
@@ -592,7 +600,7 @@ void uPlotBase::slotLoadExportDialog()
     }
 
     // Get current working directory
-    string sdir;
+    std::string sdir;
     if (owner_)
         sdir = ObjectInfo::ObjectFullPath(owner_->Request());
 
@@ -601,7 +609,7 @@ void uPlotBase::slotLoadExportDialog()
 
     ExportDialog exportDialog(currentStep(), stepNum(), sdir, export_qt_);
     if (exportDialog.exec() == QDialog::Accepted) {
-        delayedExportDialogRequest_  = exportDialog.reqOut();
+        delayedExportDialogRequest_ = exportDialog.reqOut();
         QTimer::singleShot(0, this, SLOT(startExportDialogMsgBox()));
     }
 }
@@ -618,11 +626,12 @@ void uPlotBase::startExportDialogMsgBox()
     }
 }
 
+// TODO: Is it used at all?
 void uPlotBase::slotLoadEcChartsDialog()
 {
     // Is there anything plotted?
     if (!owner_) {
-        PlotMod::Instance().MetviewError("Display Window empty", "Warning");
+        MvLog().popup().warn() << "Display Window empty";
         return;
     }
 
@@ -632,8 +641,8 @@ void uPlotBase::slotLoadEcChartsDialog()
         return;
 
     // Get information from the dialog window
-    //   string ecCharts_layername = dialog.getLayerName();
-    string outputFileName = dialog.getOutputFileName();
+    //   std::string ecCharts_layername = dialog.getLayerName();
+    std::string outputFileName = dialog.getOutputFileName();
 
     // Build request
     MvRequest plotReq = owner_->ExportToEcCharts();
@@ -644,7 +653,7 @@ void uPlotBase::slotLoadEcChartsDialog()
     /*
    if ( owner_->ExportPlot(req1) == false )
    {
-      COUT << "CREATE A ERROR WINDOW MESSAGE" << endl;
+      COUT << "CREATE A ERROR WINDOW MESSAGE" << std::endl;
    }*/
 }
 
@@ -660,7 +669,7 @@ void uPlotBase::slotLoadWeatherRoomDialog()
 #ifdef METVIEW_WEATHER_ROOM
     // Is there anything plotted?
     if (!owner_) {
-        PlotMod::Instance().MetviewError("Weather Room-> Nothing to be exported", "Warning");
+        MvLog().warn() << "Weather Room-> Nothing to be exported";
         return;
     }
 
@@ -697,12 +706,12 @@ bool uPlotBase::plotWeatherRoom(bool checkSync)
     // Set the syncronous flag, e.g. make sure the file is created
     // before uploading it
     if (owner_->ExportPlot(&devReq, true) == false) {
-        PlotMod::Instance().MetviewError("Weather Room-> Failed to upload plot", "Warning");
+        MvLog().warn() << "Weather Room-> Failed to upload plot";
         return false;
     }
 
     // Upload file to the weather room
-    string fName = (const char*)devReq("OUTPUT_FULLNAME");
+    std::string fName = (const char*)devReq("OUTPUT_FULLNAME");
     this->uploadWeatherRoom(fName);
 
     return true;
@@ -715,13 +724,13 @@ void uPlotBase::outputDeviceWeatherRoom(MvRequest& devReq)
     // Define output device. Create a temporary file.
     wroomFormat_ = "pdf";
     devReq.setVerb("PDFOUTPUT");
-    string fName              = marstmp();
+    std::string fName         = marstmp();
     devReq("OUTPUT_FULLNAME") = fName.c_str();
 }
 #endif
 
 #ifdef METVIEW_WEATHER_ROOM
-void uPlotBase::uploadWeatherRoom(const string& fName)
+void uPlotBase::uploadWeatherRoom(const std::string& fName)
 {
     // Get data unit information used to create the plot
     MvRequest req("DataInfo");
@@ -817,7 +826,7 @@ void uPlotBase::slotLoadPrintDialog()
 {
     // Is there anything plotted?
     if (!owner_) {
-        PlotMod::Instance().MetviewError("uPlot-> Nothing to be printed", "Warning");
+        MvLog().popup().warn() << "uPlot-> Nothing to be printed";
         return;
     }
 
@@ -866,7 +875,7 @@ void uPlotBase::slotLoadPrintDialog()
         return;
 
     // Get printer parameters
-    string name     = pr->printerName().toLocal8Bit().constData();
+    std::string name = pr->printerName().toLocal8Bit().constData();
 
 //TODO: use proper enum instead of int!
 #if QT_VERSION >= QT_VERSION_CHECK(5, 3, 0)
@@ -903,10 +912,9 @@ void uPlotBase::slotLoadPrintDialog()
 void uPlotBase::processExportDialogRequest()
 {
     if (delayedExportDialogRequest_) {
-
         // Is there anything plotted?
         if (!owner_) {
-            PlotMod::Instance().MetviewError("uPlot-> Nothing to be exported", "Warning");
+            MvLog().popup().warn() << "uPlot-> Nothing to be exported";
             return;
         }
 
@@ -919,12 +927,12 @@ void uPlotBase::processExportDialogRequest()
 
         // Process export calling Magics
         // Set the environment to upload the result later
-        MvRequest reqExp = setExportVariables(&delayedExportDialogRequest_);
+        MvRequest reqExp            = setExportVariables(&delayedExportDialogRequest_);
         delayedExportDialogRequest_ = MvRequest();
 
         // Ask my owner to recreate the plot and save it accordingly
         if (!owner_->ExportPlot(&reqExp)) {
-            PlotMod::Instance().MetviewError("uPlot-> Failed to export plot", "Warning");
+            MvLog().popup().warn() << "uPlot-> Failed to export plot";
             return;
         }
 
@@ -936,8 +944,7 @@ void uPlotBase::processExportDialogRequest()
 void uPlotBase::processExportQt()
 {
     if (!plotView_->hasFeatures()) {
-        PlotMod::Instance().UserErrorMessage(
-            "Export: Internal Error: empty Display Window");
+        MvLog().popup().err() << "Export: Internal Error: empty Display Window";
         return;
     }
 
@@ -958,21 +965,21 @@ void uPlotBase::processExportQt()
     fn += "." + format;
 
     QSizeF sourceSize = plotScene_->sceneRect().size();
-    auto sourceRatio = sourceSize.height() / sourceSize.width();
+    auto sourceRatio  = sourceSize.height() / sourceSize.width();
 
     // Initialise output format object
-   if (format == "pdf") {
+    if (format == "pdf") {
         int targetWidth = (int)delayedExportDialogRequest_("OUTPUT_WIDTH");
         QSizeF imageSize(targetWidth, static_cast<int>(
-                                                     targetWidth*sourceRatio));
+                                          targetWidth * sourceRatio));
 
         QPdfWriter pdfWriter(fn.c_str());
-        pdfWriter.setPageSize(QPageSize(imageSize,QPageSize::Point));
+        pdfWriter.setPageSize(QPageSize(imageSize, QPageSize::Point));
 
         QPainter painter(&pdfWriter);
         painter.setRenderHint(QPainter::Antialiasing, true);
-        painter.translate(0,painter.viewport().height());
-        painter.scale(1.,-1.);         //plot directions: W->E and S->N
+        painter.translate(0, painter.viewport().height());
+        painter.scale(1., -1.);  //plot directions: W->E and S->N
 
 #if 0
         plotScene_->render(&painter);
@@ -980,28 +987,28 @@ void uPlotBase::processExportQt()
         QStyleOptionGraphicsItem option;
         imageSize *= 15;
         auto targetRect = QRectF(0, 0, imageSize.width(), imageSize.height());
-        auto sourceRect =  plotScene_->sceneRect();
+        auto sourceRect = plotScene_->sceneRect();
         plotScene_->renderContents(&painter, &option, targetRect, sourceRect,
                                    true);
 #endif
     }
     else if (format == "png") {
         int targetWidth = (int)delayedExportDialogRequest_("OUTPUT_WIDTH");
-        QPixmap pix(targetWidth, static_cast<int>(targetWidth*sourceRatio));
+        QPixmap pix(targetWidth, static_cast<int>(targetWidth * sourceRatio));
 
         // background filling
         const char* colour = (const char*)delayedExportDialogRequest_(
-                                            "OUTPUT_BACKGROUND_COLOUR");
+            "OUTPUT_BACKGROUND_COLOUR");
         pix.fill(MvQPalette::magics(colour));
 
         QPainter painter(&pix);
         painter.setRenderHint(QPainter::Antialiasing, true);
         painter.translate(0, pix.height());
-        painter.scale(1.,-1.);
+        painter.scale(1., -1.);
 
         QStyleOptionGraphicsItem option;
         auto targetRect = QRectF(0, 0, pix.width(), pix.height());
-        auto sourceRect =  plotScene_->sceneRect();
+        auto sourceRect = plotScene_->sceneRect();
         plotScene_->renderContents(&painter, &option, targetRect, sourceRect,
                                    true);
 
@@ -1012,12 +1019,12 @@ void uPlotBase::processExportQt()
 MvRequest uPlotBase::setExportVariables(MvRequest* preq)
 {
     if (!preq) {
-        PlotMod::Instance().UserErrorMessage("Export: Internal Error: empty Display Window");
+        MvLog().popup().err() << "Export: Internal Error: empty Display Window";
         return *preq;
     }
 
     // This version only allows the ANIMATED_GIT_OUTPUT format
-    MvRequest req = *preq;
+    MvRequest req  = *preq;
     export_format_ = (const char*)req.getVerb();
     if (export_format_ != "ANIMATED_GIF_OUTPUT")
         return req;
@@ -1027,10 +1034,10 @@ MvRequest uPlotBase::setExportVariables(MvRequest* preq)
 
     // Create a temporary directory to store the animation files
     // This directory will be deleted at the end
-    string name = mbasename(export_fname_.c_str());
+    std::string name = mbasename(export_fname_.c_str());
     export_tmp_path_ = CreateTmpPath(name.c_str());
 
-#if 0 //FAMI20200319 ProgressManager removed
+#if 0   //FAMI20200319 ProgressManager removed
     // Define directories/files to be watched
     if (pm_) {
         pm_->setVisible(false);
@@ -1040,9 +1047,9 @@ MvRequest uPlotBase::setExportVariables(MvRequest* preq)
 
     // Define output gif full filename
     // To 'watch' this file Qt requires that it already exists
-    string fullname = export_fname_ + ".gif";
+    std::string fullname = export_fname_ + ".gif";
     fstream fs;
-    fs.open(fullname.c_str(), ios::out);
+    fs.open(fullname.c_str(), std::ios::out);
     fs.close();
 
     int ntemp_files = 1;  // only one PS file; otherwise use stepNum()
@@ -1061,18 +1068,18 @@ MvRequest uPlotBase::setExportVariables(MvRequest* preq)
 
     // Show progress bar
     pm_->setVisible(true);
-#endif //FAMI20200319
+#endif  //FAMI20200319
 
     // Define temporary output device
     // A postscript file will be generated first and then converted
     // to the animated gif format
-    string psfullfname = export_tmp_path_ + "/" + name;
+    std::string psfullfname = export_tmp_path_ + "/" + name;
     MvRequest devReq("PSOUTPUT");
     devReq("OUTPUT_NAME") = (const char*)(psfullfname.c_str());
     if ((const char*)req("OUTPUT_FRAME_LIST")) {
-        int cnt = req.iterInit( "OUTPUT_FRAME_LIST" );
+        int cnt = req.iterInit("OUTPUT_FRAME_LIST");
         double val;
-        for( int i = 0; i < cnt; ++i ) {
+        for (int i = 0; i < cnt; ++i) {
             req.iterGetNextValue(val);
             devReq.addValue("OUTPUT_FRAME_LIST", (int)val);
         }
@@ -1094,35 +1101,34 @@ void uPlotBase::processExport()
     // Read the selected output format request from the Metview/Defaults
     // directory. If not found, create a default request
     MvRequest reqOut = ObjectList::UserDefaultRequest(export_format_.c_str());
-    reqOut = ObjectList::ExpandRequest ( reqOut, EXPAND_DEFAULTS );
+    reqOut           = ObjectList::ExpandRequest(reqOut, EXPAND_DEFAULTS);
 
     // Define parameters: output/input filenames, image looping
-    string ofname = export_fname_ + ".gif";
-    string ifname = export_tmp_path_ + "/" + mbasename(export_fname_.c_str())
-                    + ".ps";
-    int nloops=1;
-    if(strcmp((const char*)reqOut("OUTPUT_CONTINUOUS_LOOPING"),"YES") == 0)
+    std::string ofname = export_fname_ + ".gif";
+    std::string ifname = export_tmp_path_ + "/" + mbasename(export_fname_.c_str()) + ".ps";
+    int nloops         = 1;
+    if (strcmp((const char*)reqOut("OUTPUT_CONTINUOUS_LOOPING"), "YES") == 0)
         nloops = 999;
 
     // Check if ps files is completed
-    string data;
-    FILE * stream;
+    std::string data;
+    FILE* stream;
     const int max_buffer = 256;
     char buffer[max_buffer];
-    string ctail("tail -1 ");
+    std::string ctail("tail -1 ");
     ctail += ifname + " 2>&1";
-    while(true) {
+    while (true) {
         // Get result of command tail
         stream = popen(ctail.c_str(), "r");
         if (stream) {
             while (!feof(stream))
-                if (fgets(buffer, max_buffer, stream) != NULL)
+                if (fgets(buffer, max_buffer, stream) != nullptr)
                     data.append(buffer);
             pclose(stream);
         }
 
         // Check if ps file is completed
-        if (data.substr(0,5) == "%%EOF")
+        if (data.substr(0, 5) == "%%EOF")
             break;
         else {
             data.clear();
@@ -1130,33 +1136,32 @@ void uPlotBase::processExport()
         }
     }
 
-     //TODO: move this command into a shell script
+    //TODO: move this command into a shell script
     // Postscript file has been generated
     // Call external function convert to create the animated gif
     std::stringstream out, err;
     std::ostringstream cmd;
-    cmd << "convert -delay " << (const char*)reqOut("OUTPUT_DELAY") <<
-           " -rotate " << (int)reqOut("OUTPUT_ROTATE") <<
-           " -resize " << (int)reqOut("OUTPUT_WIDTH") <<
-           " -loop " << nloops << " " <<
-           "'" << ifname << "'" << "  " << "'" << ofname << "'";
+    cmd << "convert -delay " << (const char*)reqOut("OUTPUT_DELAY") << " -rotate " << (int)reqOut("OUTPUT_ROTATE") << " -resize " << (int)reqOut("OUTPUT_WIDTH") << " -loop " << nloops << " "
+        << "'" << ifname << "'"
+        << "  "
+        << "'" << ofname << "'";
 
-    metview::shellCommand(cmd.str(),out,err);
+    metview::shellCommand(cmd.str(), out, err);
     if (!err.str().empty()) {
         QString message = tr("<b>Export Error: </b>") + tr(err.str().c_str());
         QMessageBox::warning(0, tr("Metview"), message);
-        DeletePath(export_tmp_path_.c_str()); // delete temporary directory
+        DeletePath(export_tmp_path_.c_str());  // delete temporary directory
     }
 
     // Delete temporary directory
     DeletePath(export_tmp_path_.c_str());
 }
 
-#if 0 //FAMII20200319  ProgressBar removed
+#if 0  //FAMII20200319  ProgressBar removed
 void uPlotBase::fileChangedExport(const QString& fname)
 {
     // Send a popup window message
-    string stext = "The Animated GIF file has been created at:\n" + fname.toStdString();
+    std::string stext = "The Animated GIF file has been created at:\n" + fname.toStdString();
 //    PlotMod::Instance().warningMessage(stext, true);
 //    PlotMod::Instance().MetviewError("Display Window empty", "Warning");
 
@@ -1181,7 +1186,7 @@ void uPlotBase::fileChangedExport(const QString& fname)
 void uPlotBase::slotGenerateMacro()
 {
     if (!owner_) {
-        PlotMod::Instance().MetviewError("uPlot-> Display Window empty. Nothing to be generated", "Warning");
+        MvLog().popup().warn() << "uPlot-> Display Window empty. Nothing to be generated";
         return;
     }
 
@@ -1191,7 +1196,7 @@ void uPlotBase::slotGenerateMacro()
 
 void uPlotBase::slotShowAboutBox()
 {
-    string magicsVersionString = getMagicsVersionString();
+    std::string magicsVersionString = getMagicsVersionString();
     QString magicsVersion(QString::fromUtf8(magicsVersionString.c_str()));
 
     QMap<MvQAbout::Version, QString> text;
@@ -1420,15 +1425,17 @@ void uPlotBase::slotBuildContextMenu(const QPoint& globalPos, const QPointF& sce
     //If there is only one scene
     if (plotScene_->sceneItems().count() <= 1) {
         actions << actionZoomUp_ << actionZoomDown_;
-    //More than one scene: check which scene is clicked
-    } else {
+        //More than one scene: check which scene is clicked
+    }
+    else {
         item = plotScene_->findSceneItem(scenePos);
         if (item) {
             //Context menu triggered from the active scene
             if (item == activeScene_) {
                 actions << actionZoomUp_ << actionZoomDown_;
-            //Context menu triggered from a non-active scene
-            } else {
+                //Context menu triggered from a non-active scene
+            }
+            else {
                 actions << actionContextSelectScene_ << actionContextZoomUp_ << actionContextZoomDown_;
 
                 //Set the status of the context zoom actions
@@ -1462,22 +1469,26 @@ void uPlotBase::slotBuildContextMenu(const QPoint& globalPos, const QPointF& sce
         }
     }
 
-    if (QAction* ac = plotView_->handleContextMenu(actions, globalPos, scenePos) ) {
+    if (QAction* ac = plotView_->handleContextMenu(actions, globalPos, scenePos)) {
         if (ac == actionContextSelectScene_) {
             slotSetActiveScene(item);
-        } else if (ac == actionContextZoomUp_) {
+        }
+        else if (ac == actionContextZoomUp_) {
             slotSetActiveScene(item);
             //Now this scene is active. We can use the original zoomUp action!!
             actionZoomUp_->trigger();
-        } else if (ac == actionContextZoomDown_) {
+        }
+        else if (ac == actionContextZoomDown_) {
             slotSetActiveScene(item);
             //Now this scene is active. We can use the original zoomDown action!!
             actionZoomDown_->trigger();
-        } else if (ac == actionRedo_) {
+        }
+        else if (ac == actionRedo_) {
             if (undoStack_) {
                 undoStack_->redo();
             }
-        } else if (ac == actionUndo_) {
+        }
+        else if (ac == actionUndo_) {
             if (undoStack_) {
                 undoStack_->undo();
             }
@@ -1506,7 +1517,7 @@ int uPlotBase::screenResolutionInDpi()
 // sends the given message to the Metview message log window
 // ----------------------------------------------------------------------------
 
-void uPlotBase::messageToLogWindow (const string& msg, int severity)
+void uPlotBase::messageToLogWindow (const std::string& msg, int severity)
 {
 	MvRequest reqst("USER_MESSAGE");
 	reqst("INFO") = msg.c_str(); 
@@ -1524,3 +1535,11 @@ void uPlotBase::setPlotWidgetSize(float hor, float ver)
 {
     setPlot(hor, ver);
 }
+
+std::string uPlotBase::currentWorkDir() const
+{
+    if (owner_) {
+        return ObjectInfo::ObjectFullPath(owner_->Request());
+    }
+    return {};
+}
