@@ -7,8 +7,9 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef uPlotBase_H
-#define uPlotBase_H
+#pragma once
+
+#include <string>
 
 #include <QComboBox>
 #include <QMessageBox>
@@ -43,17 +44,16 @@ class MvQZoomStackWidget;
 class ShareTarget;
 class MvQProgressManager;
 
-using namespace std;
-
 class uPlotBase;
 
-class ExportMessageBox: public QMessageBox
+class ExportMessageBox : public QMessageBox
 {
     Q_OBJECT
 public:
     ExportMessageBox(uPlotBase*);
 protected slots:
     void doDelayedProc();
+
 protected:
     uPlotBase* owner_;
 };
@@ -62,20 +62,21 @@ class uPlotBase : public MvQMainWindow
 {
     Q_OBJECT
     friend class ExportMessageBox;
+
 public:
     uPlotBase(QWidget* parent = 0);
     virtual ~uPlotBase();
 
     void setPlot(float hor, float ver);
     void setPlotWidgetSize(float hor, float ver);
-    // void messageToLogWindow (const string&, int severity);
+    // void messageToLogWindow (const std::string&, int severity);
 
     MvQPlotView* plotView() { return plotView_; }
     MgQPlotScene* plotScene() { return plotScene_; }
 
     virtual void newRequestForDriversBegin() = 0;
     virtual void newRequestForDriversEnd()   = 0;
-    virtual void progressMessage(const string&){}
+    virtual void progressMessage(const std::string&) {}
 
     void processContentsRequest(MvRequest&);
 
@@ -84,13 +85,15 @@ public:
         owner_ = &owner;
     }
 
+    std::string currentWorkDir() const;
+
     virtual MvRequest SuperPageRequest() { return MvRequest(); }
 
-    void tempDir(string& dir)
+    void tempDir(std::string& dir)
     {
         uPlotTempDir_ = dir;
     }
-    static string& tempDir()
+    static std::string& tempDir()
     {
         return uPlotTempDir_;
     }
@@ -108,7 +111,7 @@ signals:
 public slots:
     void slotEnableAntialias(bool);
     void slotZoomStackLevelChanged(QString, int);
-    void slotPerformZoom(const string& sid, const string& def);
+    void slotPerformZoom(const std::string& sid, const std::string& def);
     void slotStepCacheStateChanged();
     void slotLoadExportDialog();
     void slotLoadPrintDialog();
@@ -167,7 +170,7 @@ protected:
 
     // Temporary directory name related to this session.
     // It can be used to store temporary files ,e.g. Layers icon editing.
-    static string uPlotTempDir_;
+    static std::string uPlotTempDir_;
 
     MvQMainWindow::MenuItemMap menuItems_;
 
@@ -194,7 +197,7 @@ protected:
 
     //Active scene
     MgQSceneItem* activeScene_{nullptr};
-    string prevActiveSceneId_;
+    std::string prevActiveSceneId_;
 
     //Size
     enum SizeOptions
@@ -216,14 +219,14 @@ protected:
 
 #ifdef METVIEW_WEATHER_ROOM
     // Weather room
-    void uploadWeatherRoom(const string&);
+    void uploadWeatherRoom(const std::string&);
     void outputDeviceWeatherRoom(MvRequest&);
     bool syncWeatherRoom() { return wroomSync_; }
 
-    bool wroomSync_;      // flag indicating if a plot should be sent to the video wall
-    int wroomCell_;       // cell number
-    string wroomWall_;    // wall id
-    string wroomFormat_;  // wall output graphics format
+    bool wroomSync_;           // flag indicating if a plot should be sent to the video wall
+    int wroomCell_;            // cell number
+    std::string wroomWall_;    // wall id
+    std::string wroomFormat_;  // wall output graphics format
 #endif
 
     MvRequest delayedExportDialogRequest_;
@@ -234,14 +237,12 @@ protected:
     // Export animated gif
     MvRequest setExportVariables(MvRequest*);
     //MvQProgressManager* pm_ {0};  // progress manager
-    string export_format_;        // output format
-    string export_fname_;         // output path+filename
-    string export_tmp_path_;      // temporary path to store temporary files
+    std::string export_format_;    // output format
+    std::string export_fname_;     // output path+filename
+    std::string export_tmp_path_;  // temporary path to store temporary files
 
     // Export the contents of the Display Window
     // false = call Magics to create the output file
     // true  = call Qt (if Display Window contains features/symbols)
     bool export_qt_{false};
 };
-
-#endif
