@@ -13,12 +13,15 @@
 #include "mir/input/GribInput.h"
 
 #include <algorithm>
+#include <cstring>
 #include <functional>
 #include <iterator>
 #include <memory>
 #include <numeric>
 #include <ostream>
 #include <sstream>
+#include <utility>
+#include <vector>
 
 #include "eckit/config/Resource.h"
 #include "eckit/io/Buffer.h"
@@ -52,7 +55,9 @@ public:
     Condition() = default;
 
     Condition(const Condition&) = delete;
+    Condition(Condition&&)      = delete;
     Condition& operator=(const Condition&) = delete;
+    Condition& operator=(Condition&&) = delete;
 
     virtual ~Condition()                  = default;
     virtual bool eval(grib_handle*) const = 0;
@@ -63,7 +68,7 @@ template <class T>
 class ConditionT : public Condition {
     const char* key_;
     T value_;
-    bool eval(grib_handle*) const override;
+    bool eval(grib_handle* /*unused*/) const override;
 
 public:
     ConditionT(const char* key, const T& value) : key_(key), value_(value) {}
@@ -142,6 +147,11 @@ class ConditionOR : public Condition {
 
 public:
     ConditionOR(const Condition* left, const Condition* right) : left_(left), right_(right) {}
+
+    ConditionOR(const ConditionOR&) = delete;
+    ConditionOR(ConditionOR&&)      = delete;
+    ConditionOR& operator=(const ConditionOR&) = delete;
+    ConditionOR& operator=(ConditionOR&&) = delete;
 };
 
 
@@ -149,10 +159,19 @@ public:
 class ConditionAND : public Condition {
     const Condition* left_;
     const Condition* right_;
-     bool eval(grib_handle* h) const override  { return left_->eval(h) && right_->eval(h); }
+    bool eval(grib_handle* h) const override  { return left_->eval(h) && right_->eval(h); }
+    ~ConditionAND() override {
+        delete right_;
+        delete left_;
+    }
 
 public:
     ConditionAND(const Condition* left, const Condition* right) : left_(left), right_(right) {}
+
+    ConditionAND(const ConditionAND&) = delete;
+    ConditionAND( ConditionAND&&) = delete;
+    ConditionAND& operator=(const ConditionAND&) = delete;
+    ConditionAND& operator=( ConditionAND&&) = delete;
 };
 */
 
@@ -160,7 +179,10 @@ public:
 /*
 class ConditionNOT : public Condition {
     const Condition* c_;
-     bool eval(grib_handle* h) const  override { return !c_->eval(h); }
+    bool eval(grib_handle* h) const  override { return !c_->eval(h); }
+    ~ConditionNOT() override {
+        delete c_;
+    }
 
 public:
     ConditionNOT(const Condition* c) : c_(c) {}
@@ -245,38 +267,41 @@ static Condition *_not(const Condition *c) {
 
 
 static const char* get_key(const std::string& name, grib_handle* h) {
-
-    static struct {
-        const char* name;
+    struct P {
+        const std::string name;
         const char* key;
-        const Condition* condition;
-    } mappings[] = {
+        const std::unique_ptr<const Condition> condition;
+        P(const std::string _name, const char* _key, const Condition* _condition = nullptr) :
+            name(_name), key(_key), condition(_condition) {}
+    };
+
+    static const std::initializer_list<P> mappings{
         {"west_east_increment", "iDirectionIncrementInDegrees_fix_for_periodic_regular_grids",
          is("gridType", "regular_ll")},
-        {"west_east_increment", "iDirectionIncrementInDegrees", nullptr},
-        {"south_north_increment", "jDirectionIncrementInDegrees", nullptr},
+        {"west_east_increment", "iDirectionIncrementInDegrees"},
+        {"south_north_increment", "jDirectionIncrementInDegrees"},
 
-        {"west", "longitudeOfFirstGridPointInDegrees", nullptr},
+        {"west", "longitudeOfFirstGridPointInDegrees"},
         {"east", "longitudeOfLastGridPointInDegrees_fix_for_global_reduced_grids", is("gridType", "reduced_gg")},
-        {"east", "longitudeOfLastGridPointInDegrees", nullptr},
+        {"east", "longitudeOfLastGridPointInDegrees"},
 
         {"north", "latitudeOfFirstGridPointInDegrees", is("scanningMode", 0L)},
         {"south", "latitudeOfLastGridPointInDegrees", is("scanningMode", 0L)},
 
         {"north", "latitudeOfLastGridPointInDegrees", is("jScansPositively", 1L)},
         {"south", "latitudeOfFirstGridPointInDegrees", is("jScansPositively", 1L)},
-        {"north", "latitudeOfFirstGridPointInDegrees", nullptr},
-        {"south", "latitudeOfLastGridPointInDegrees", nullptr},
+        {"north", "latitudeOfFirstGridPointInDegrees"},
+        {"south", "latitudeOfLastGridPointInDegrees"},
 
-        {"truncation", "pentagonalResolutionParameterJ", nullptr},  // Assumes triangular truncation
-        {"accuracy", "bitsPerValue", nullptr},
+        {"truncation", "pentagonalResolutionParameterJ"},  // Assumes triangular truncation
+        {"accuracy", "bitsPerValue"},
 
-        {"south_pole_latitude", "latitudeOfSouthernPoleInDegrees", nullptr},
-        {"south_pole_longitude", "longitudeOfSouthernPoleInDegrees", nullptr},
-        {"south_pole_rotation_angle", "angleOfRotationInDegrees", nullptr},
+        {"south_pole_latitude", "latitudeOfSouthernPoleInDegrees"},
+        {"south_pole_longitude", "longitudeOfSouthernPoleInDegrees"},
+        {"south_pole_rotation_angle", "angleOfRotationInDegrees"},
 
-        {"proj", "projTargetString", nullptr},
-        {"projSource", "projSourceString", nullptr},
+        {"proj", "projTargetString"},
+        {"projSource", "projSourceString"},
 
         // This will be just called for has()
         {
@@ -296,16 +321,16 @@ static const char* get_key(const std::string& name, grib_handle* h) {
             "numberOfGridInReference" /*just a dummy*/,
             is("gridType", "unstructured_grid"),
         },
-        {"gridded", "numberOfPointsAlongAMeridian", nullptr},  // Is that always true?
+        {"gridded", "numberOfPointsAlongAMeridian"},  // Is that always true?
         {"gridded_regular_ll", "Ni", _or(is("gridType", "regular_ll"), is("gridType", "rotated_ll"))},
-        {"gridded_named", "gridName", nullptr},
+        {"gridded_named", "gridName"},
 
         {"grid", "gridName",
          _or(_or(_or(_or(is("gridType", "regular_gg"), is("gridType", "reduced_gg")), is("gridType", "rotated_gg")),
                  is("gridType", "reduced_rotated_gg")),
              is("gridType", "unstructured_grid"))},
 
-        {"spectral", "pentagonalResolutionParameterJ", nullptr},
+        {"spectral", "pentagonalResolutionParameterJ"},
 
         {"uid", "uuidOfHGrid", is("gridType", "unstructured_grid")},
 
@@ -315,21 +340,19 @@ static const char* get_key(const std::string& name, grib_handle* h) {
         {"octahedral", "numberOfParallelsBetweenAPoleAndTheEquator", is("isOctahedral", 1L)},
 
         /// TODO: is that a good idea?
-        {"param", "paramId", nullptr},
-        {"statistics", "", nullptr},  // (avoid ecCodes error "statistics: Function not yet implemented")
-
-        {nullptr, nullptr, nullptr},
+        {"param", "paramId"},
+        {"statistics", ""},  // (avoid ecCodes error "statistics: Function not yet implemented")
     };
 
-    for (size_t i = 0; mappings[i].name != nullptr; ++i) {
-        if (name == mappings[i].name) {
-            if (mappings[i].condition == nullptr || mappings[i].condition->eval(h)) {
-                return mappings[i].key;
+    for (const auto& m : mappings) {
+        if (name == m.name) {
+            if (!m.condition || m.condition->eval(h)) {
+                return m.key;
             }
         }
     }
 
-    auto key = name.c_str();
+    const auto* key = name.c_str();
     return key;
 }
 
@@ -339,8 +362,11 @@ struct ProcessingT {
     using fun_t = std::function<bool(grib_handle*, T&)>;
     fun_t fun_;
     ProcessingT(fun_t&& fun) : fun_(fun) {}
+    ~ProcessingT()                  = default;
     ProcessingT(const ProcessingT&) = delete;
+    ProcessingT(ProcessingT&&)      = delete;
     void operator=(const ProcessingT&) = delete;
+    void operator=(ProcessingT&&) = delete;
     bool eval(grib_handle* h, T& v) const { return fun_(h, v); }
 };
 
@@ -526,7 +552,7 @@ static ProcessingT<std::vector<double>>* vector_double(std::initializer_list<std
 
         values.assign(keys_.size(), 0);
         size_t i = 0;
-        for (auto& key : keys_) {
+        for (const auto& key : keys_) {
             if (codes_is_defined(h, key.c_str()) == 0) {
                 return false;
             }
@@ -568,12 +594,25 @@ static ProcessingT<std::string>* packing() {
 }
 
 
-template <typename T, typename P>
-static bool get_value(const std::string& name, grib_handle* h, T& value, const P& process) {
-    for (size_t i = 0; process[i].name != nullptr; ++i) {
-        auto& p = process[i];
+template <class T>
+struct ConditionedProcessingT {
+    const std::string name;
+    const std::unique_ptr<const T> processing;
+    const std::unique_ptr<const Condition> condition;
+    ConditionedProcessingT(const std::string& _name, const T* _processing, const Condition* _condition = nullptr) :
+        name(_name), processing(_processing), condition(_condition) {}
+};
+
+
+template <class T>
+using ProcessingList = std::initializer_list<ConditionedProcessingT<ProcessingT<T>>>;
+
+
+template <typename T>
+static bool get_value(const std::string& name, grib_handle* h, T& value, const ProcessingList<T>& process) {
+    for (auto& p : process) {
         if (name == p.name) {
-            if (p.condition == nullptr || p.condition->eval(h)) {
+            if (!p.condition || p.condition->eval(h)) {
                 ASSERT(p.processing);
                 return p.processing->eval(h, value);
             }
@@ -695,7 +734,7 @@ data::MIRField GribInput::field() const {
             values.swap(values_extended);
 
             ASSERT(get("pl", pl));
-            size_t pl_sum = size_t(std::accumulate(pl.begin(), pl.end(), 0));
+            size_t pl_sum = size_t(std::accumulate(pl.begin(), pl.end(), 0L));
             ASSERT(pl_sum == values.size());
         }
     }
@@ -726,8 +765,10 @@ bool GribInput::has(const std::string& name) const {
     util::lock_guard<util::recursive_mutex> lock(mutex_);
 
     ASSERT(grib_);
-    const char* key = get_key(name, grib_);
-    if (std::string(key).empty()) {
+    const auto* key = get_key(name, grib_);
+
+    ASSERT(key != nullptr);
+    if (std::strlen(key) == 0) {
         return false;
     }
 
@@ -743,8 +784,10 @@ bool GribInput::get(const std::string& name, bool& value) const {
     util::lock_guard<util::recursive_mutex> lock(mutex_);
 
     ASSERT(grib_);
-    const char* key = get_key(name, grib_);
-    if (std::string(key).empty()) {
+    const auto* key = get_key(name, grib_);
+
+    ASSERT(key != nullptr);
+    if (std::strlen(key) == 0) {
         return false;
     }
 
@@ -783,7 +826,7 @@ bool GribInput::get(const std::string& name, long& value) const {
     util::lock_guard<util::recursive_mutex> lock(mutex_);
 
     ASSERT(grib_);
-    std::string key = get_key(name, grib_);
+    const std::string key = get_key(name, grib_);
     if (key.empty()) {
         return false;
     }
@@ -801,14 +844,9 @@ bool GribInput::get(const std::string& name, long& value) const {
     // FIXME: make sure that 'value' is not set if CODES_MISSING_LONG
     int err = codes_get_long(grib_, key.c_str(), &value);
     if (err == CODES_NOT_FOUND || codes_is_missing(grib_, key.c_str(), &err) != 0) {
-        static struct {
-            const char* name;
-            const ProcessingT<long>* processing;
-            const Condition* condition;
-        } process[] = {
-            {"is_wind_component_uv", is_wind_component_uv(), nullptr},
-            {"is_wind_component_vod", is_wind_component_vod(), nullptr},
-            {nullptr, nullptr, nullptr},
+        static const ProcessingList<long> process{
+            {"is_wind_component_uv", is_wind_component_uv()},
+            {"is_wind_component_vod", is_wind_component_vod()},
         };
 
         return get_value(key, grib_, value, process) || FieldParametrisation::get(name, value);
@@ -838,25 +876,22 @@ bool GribInput::get(const std::string& name, double& value) const {
     util::lock_guard<util::recursive_mutex> lock(mutex_);
 
     ASSERT(grib_);
-    const char* key = get_key(name, grib_);
-    if (std::string(key).empty()) {
+    const auto* key = get_key(name, grib_);
+
+    ASSERT(key != nullptr);
+    if (std::strlen(key) == 0) {
         return false;
     }
 
     // FIXME: make sure that 'value' is not set if CODES_MISSING_DOUBLE
     int err = codes_get_double(grib_, key, &value);
     if (err == CODES_NOT_FOUND || codes_is_missing(grib_, key, &err) != 0) {
-        static struct {
-            const char* name;
-            const ProcessingT<double>* processing;
-            const Condition* condition;
-        } process[] = {
-            {"angular_precision", angular_precision(), nullptr},
+        static const ProcessingList<double> process{
+            {"angular_precision", angular_precision()},
             {"longitudeOfLastGridPointInDegrees_fix_for_global_reduced_grids",
-             longitudeOfLastGridPointInDegrees_fix_for_global_reduced_grids(), nullptr},
+             longitudeOfLastGridPointInDegrees_fix_for_global_reduced_grids()},
             {"iDirectionIncrementInDegrees_fix_for_periodic_regular_grids",
-             iDirectionIncrementInDegrees_fix_for_periodic_regular_grids(), nullptr},
-            {nullptr, nullptr, nullptr},
+             iDirectionIncrementInDegrees_fix_for_periodic_regular_grids()},
         };
 
         return get_value(key, grib_, value, process) || FieldParametrisation::get(name, value);
@@ -873,7 +908,7 @@ bool GribInput::get(const std::string& name, double& value) const {
 }
 
 
-bool GribInput::get(const std::string&, std::vector<int>&) const {
+bool GribInput::get(const std::string& /*name*/, std::vector<int>& /*value*/) const {
     NOTIMP;
 }
 
@@ -882,8 +917,10 @@ bool GribInput::get(const std::string& name, std::vector<long>& value) const {
     util::lock_guard<util::recursive_mutex> lock(mutex_);
 
     ASSERT(grib_);
-    const char* key = get_key(name, grib_);
-    if (std::string(key).empty()) {
+    const auto* key = get_key(name, grib_);
+
+    ASSERT(key != nullptr);
+    if (std::strlen(key) == 0) {
         return false;
     }
 
@@ -943,8 +980,10 @@ bool GribInput::get(const std::string& name, std::string& value) const {
     util::lock_guard<util::recursive_mutex> lock(mutex_);
 
     ASSERT(grib_);
-    const char* key = get_key(name, grib_);
-    if (std::string(key).empty()) {
+    const auto* key = get_key(name, grib_);
+
+    ASSERT(key != nullptr);
+    if (std::strlen(key) == 0) {
         return false;
     }
 
@@ -953,13 +992,8 @@ bool GribInput::get(const std::string& name, std::string& value) const {
     int err     = codes_get_string(grib_, key, buffer, &size);
 
     if (err == CODES_NOT_FOUND) {
-        static struct {
-            const char* name;
-            const ProcessingT<std::string>* processing;
-            const Condition* condition;
-        } process[] = {
-            {"packing", packing(), nullptr},
-            {nullptr, nullptr, nullptr},
+        static const ProcessingList<std::string> process{
+            {"packing", packing()},
         };
 
         return get_value(key, grib_, value, process) || FieldParametrisation::get(name, value);
@@ -991,18 +1025,15 @@ bool GribInput::get(const std::string& name, std::vector<double>& value) const {
     util::lock_guard<util::recursive_mutex> lock(mutex_);
 
     ASSERT(grib_);
-    const char* key = get_key(name, grib_);
+    const auto* key = get_key(name, grib_);
 
     // NOTE: MARS client sets 'grid=vector' (deprecated) which needs to be compared against GRIB gridName
-    if (std::string(key).empty() || std::string(key) == "gridName") {
+    ASSERT(key != nullptr);
+    if (std::strlen(key) == 0 || std::strncmp(key, "gridName", 8) == 0) {
         return false;
     }
 
-    static struct {
-        const char* name;
-        const ProcessingT<std::vector<double>>* processing;
-        const Condition* condition;
-    } process[] = {
+    static const ProcessingList<std::vector<double>> process{
         {"grid", vector_double({"iDirectionIncrementInDegrees", "jDirectionIncrementInDegrees"}),
          _or(is("gridType", "regular_ll"), is("gridType", "rotated_ll"))},
         {"grid", vector_double({"xDirectionGridLengthInMetres", "yDirectionGridLengthInMetres"}),
@@ -1014,7 +1045,6 @@ bool GribInput::get(const std::string& name, std::vector<double>& value) const {
         {"rotation", vector_double({"latitudeOfSouthernPoleInDegrees", "longitudeOfSouthernPoleInDegrees"}),
          _or(_or(_or(is("gridType", "rotated_ll"), is("gridType", "rotated_gg")), is("gridType", "rotated_sh")),
              is("gridType", "reduced_rotated_gg"))},
-        {nullptr, nullptr, nullptr},
     };
 
     if (get_value(key, grib_, value, process)) {
@@ -1049,7 +1079,8 @@ bool GribInput::get(const std::string& name, std::vector<double>& value) const {
     return true;
 }
 
-bool GribInput::get(const std::string&, std::vector<std::string>&) const {
+
+bool GribInput::get(const std::string& /*name*/, std::vector<std::string>& /*value*/) const {
     NOTIMP;
 }
 
@@ -1068,8 +1099,8 @@ bool GribInput::handle(grib_handle* h) {
         GRIB_CALL(codes_get_long(h, "7777", &value));
 
         // apply user-defined fixes, if any
-        static GribFixes gribFixes;
-        gribFixes.fix(*this, cache_.cache_);
+        static const GribFixes gribFixes;
+        gribFixes.find(parametrisation(0)).copyValuesTo(cache_.cache_);
 
         return true;
     }
@@ -1181,7 +1212,7 @@ void GribInput::marsRequest(std::ostream& out) const {
 
     static std::string gribToRequestNamespace = eckit::Resource<std::string>("gribToRequestNamespace", "mars");
 
-    auto keys = codes_keys_iterator_new(grib_, CODES_KEYS_ITERATOR_ALL_KEYS, gribToRequestNamespace.c_str());
+    auto* keys = codes_keys_iterator_new(grib_, CODES_KEYS_ITERATOR_ALL_KEYS, gribToRequestNamespace.c_str());
     ASSERT(keys);
 
     try {
