@@ -66,7 +66,7 @@ Gaussian::~Gaussian() = default;
 
 
 bool Gaussian::sameAs(const Representation& other) const {
-    auto o = dynamic_cast<const Gaussian*>(&other);
+    const auto* o = dynamic_cast<const Gaussian*>(&other);
     return (o != nullptr) && (N_ == o->N_) && (domain() == o->domain());
 }
 
@@ -170,7 +170,7 @@ std::vector<double> Gaussian::calculateUnrotatedGridBoxLatitudeEdges() const {
     size_t Nj = N_ * 2;
     ASSERT(Nj > 1);
 
-    auto& w = weights();
+    const auto& w = weights();
     ASSERT(w.size() == Nj);
 
     std::vector<double> edges(Nj + 1);
@@ -226,7 +226,7 @@ const std::vector<double>& Gaussian::latitudes(size_t N) {
     ASSERT(N);
     auto j = ml->find(N);
     if (j == ml->end()) {
-        trace::Timer timer("Gaussian latitudes " + std::to_string(N), Log::debug());
+        trace::Timer timer("Gaussian latitudes " + std::to_string(N));
 
         // calculate latitudes and insert in known-N-latitudes map
         std::vector<double> latitudes(N * 2);
@@ -254,7 +254,7 @@ const std::vector<double>& Gaussian::weights(size_t N) {
     ASSERT(N);
     auto j = mw->find(N);
     if (j == mw->end()) {
-        trace::Timer timer("Gaussian quadrature weights " + std::to_string(N), Log::debug());
+        trace::Timer timer("Gaussian quadrature weights " + std::to_string(N));
 
         // calculate quadrature weights and insert in known-N-weights map
         // FIXME: innefficient interface, latitudes are discarded
